{
  "cells": [
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# Exploratory data analysis with Altair\n",
        "\n",
        "<a href=\"https://www.linkedin.com/in/jacopo-repossi/\">Jacopo\n",
        "Repossi</a>  \n",
        "2023-01-01"
      ],
      "id": "7b1b0577-27a5-414b-88f9-437ea8cf8d8a"
    },
    {
      "cell_type": "code",
      "execution_count": 14,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<p>2930 rows × 82 columns</p>\n",
              "</div>"
            ]
          }
        }
      ],
      "source": [
        "import altair as alt\n",
        "import numpy as np \n",
        "import pandas as pd\n",
        "\n",
        "\n",
        "ames_data = \"https://github.com/eaisi/discover-projects/blob/main/ames-housing/AmesHousing.csv?raw=true\"\n",
        "train = pd.read_csv(ames_data).rename(columns=lambda s: s.replace(\" \",\"\"))\n",
        "\n",
        "train"
      ],
      "id": "cell-1"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Bar Chart with Highlighted Bar\n",
        "\n",
        "Basic bar chart with a **bars highlighted based on the percentage of\n",
        "missing values**."
      ],
      "id": "23cd9914-7952-4660-b2b3-7c758942dcd4"
    },
    {
      "cell_type": "code",
      "execution_count": 15,
      "metadata": {
        "cell_id": "275b96c3d2fa4df0a5eab723dcc0642a",
        "deepnote_cell_type": "code",
        "deepnote_to_be_reexecuted": false,
        "execution_millis": 350,
        "execution_start": 1685107097064,
        "papermill": {
          "duration": 0.051676,
          "end_time": "2023-01-11T23:38:27.350910",
          "exception": false,
          "start_time": "2023-01-11T23:38:27.299234",
          "status": "completed"
        },
        "source_hash": "b1ee4ec8",
        "tags": []
      },
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "</div>"
            ]
          }
        }
      ],
      "source": [
        "missing = train.isnull().sum()*100/train.isnull().sum().sum()\n",
        "missing = missing[missing > 0].reset_index()\n",
        "missing.columns = ['Column', 'Count missing']\n",
        "missing.head()"
      ],
      "id": "cell-4"
    },
    {
      "cell_type": "code",
      "execution_count": 16,
      "metadata": {
        "cell_id": "691f5b8fb74a4ec8ad2384cb0ca1f0b7",
        "deepnote_cell_type": "code",
        "deepnote_to_be_reexecuted": false,
        "execution_millis": 349,
        "execution_start": 1685107097068,
        "papermill": {
          "duration": 0.074134,
          "end_time": "2023-01-11T23:38:27.443770",
          "exception": false,
          "start_time": "2023-01-11T23:38:27.369636",
          "status": "completed"
        },
        "source_hash": "99fb9306",
        "tags": []
      },
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-29817d16d2dd4a8bb9f9b2751ed47f05.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-29817d16d2dd4a8bb9f9b2751ed47f05.vega-embed details,\n",
              "  #altair-viz-29817d16d2dd4a8bb9f9b2751ed47f05.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-29817d16d2dd4a8bb9f9b2751ed47f05\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-29817d16d2dd4a8bb9f9b2751ed47f05\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-29817d16d2dd4a8bb9f9b2751ed47f05\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"axis\": {\"grid\": false}}, \"data\": {\"name\": \"data-136decaa6c251cb55576e8c4d7fe8407\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"test\": \"(datum['Count missing'] > 10)\", \"value\": \"orange\"}, \"value\": \"steelblue\"}, \"tooltip\": [{\"field\": \"Count missing\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"Column\", \"sort\": \"-y\", \"type\": \"nominal\"}, \"y\": {\"field\": \"Count missing\", \"type\": \"quantitative\"}}, \"height\": 300, \"width\": 500, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-136decaa6c251cb55576e8c4d7fe8407\": [{\"Column\": \"LotFrontage\", \"Count missing\": 3.1113086545177473}, {\"Column\": \"Alley\", \"Count missing\": 17.347133151311194}, {\"Column\": \"MasVnrType\", \"Count missing\": 11.270556860753064}, {\"Column\": \"MasVnrArea\", \"Count missing\": 0.14604101847736364}, {\"Column\": \"BsmtQual\", \"Count missing\": 0.5079687599212649}, {\"Column\": \"BsmtCond\", \"Count missing\": 0.5079687599212649}, {\"Column\": \"BsmtExposure\", \"Count missing\": 0.5270175884183123}, {\"Column\": \"BsmtFinType1\", \"Count missing\": 0.5079687599212649}, {\"Column\": \"BsmtFinSF1\", \"Count missing\": 0.00634960949901581}, {\"Column\": \"BsmtFinType2\", \"Count missing\": 0.5143183694202806}, {\"Column\": \"BsmtFinSF2\", \"Count missing\": 0.00634960949901581}, {\"Column\": \"BsmtUnfSF\", \"Count missing\": 0.00634960949901581}, {\"Column\": \"TotalBsmtSF\", \"Count missing\": 0.00634960949901581}, {\"Column\": \"Electrical\", \"Count missing\": 0.00634960949901581}, {\"Column\": \"BsmtFullBath\", \"Count missing\": 0.01269921899803162}, {\"Column\": \"BsmtHalfBath\", \"Count missing\": 0.01269921899803162}, {\"Column\": \"FireplaceQu\", \"Count missing\": 9.029144707600482}, {\"Column\": \"GarageType\", \"Count missing\": 0.9968886913454823}, {\"Column\": \"GarageYrBlt\", \"Count missing\": 1.009587910343514}, {\"Column\": \"GarageFinish\", \"Count missing\": 1.009587910343514}, {\"Column\": \"GarageCars\", \"Count missing\": 0.00634960949901581}, {\"Column\": \"GarageArea\", \"Count missing\": 0.00634960949901581}, {\"Column\": \"GarageQual\", \"Count missing\": 1.009587910343514}, {\"Column\": \"GarageCond\", \"Count missing\": 1.009587910343514}, {\"Column\": \"PoolQC\", \"Count missing\": 18.52181090862912}, {\"Column\": \"Fence\", \"Count missing\": 14.972379198679281}, {\"Column\": \"MiscFeature\", \"Count missing\": 17.93129722522065}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "alt.Chart(missing).mark_bar().encode(\n",
        "    x=alt.X('Column', sort='-y'),\n",
        "    y='Count missing',\n",
        "    color=alt.condition(\n",
        "        alt.datum['Count missing'] >10,  # If count missing is > 10%, returns True,\n",
        "        alt.value('orange'),             # which sets the bar orange.\n",
        "        alt.value('steelblue')           # And if it's not true it sets the bar steelblue.\n",
        "    ),\n",
        "    tooltip=['Count missing']\n",
        ").properties(\n",
        "    width=500,\n",
        "    height=300\n",
        ").configure_axis(\n",
        "    grid=False\n",
        ")"
      ],
      "id": "cell-5"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Boxplot\n",
        "\n",
        "Creation of a basic boxplot using **`.mark_boxplot()` method**"
      ],
      "id": "bfc3d094-14b8-4ebb-b994-f945b993063a"
    },
    {
      "cell_type": "code",
      "execution_count": 17,
      "metadata": {
        "cell_id": "06ad1d8c0126448f838fb6220962f5dc",
        "deepnote_cell_type": "code",
        "deepnote_to_be_reexecuted": false,
        "execution_millis": 1527,
        "execution_start": 1685107097108,
        "papermill": {
          "duration": 0.489146,
          "end_time": "2023-01-11T23:38:28.028312",
          "exception": false,
          "start_time": "2023-01-11T23:38:27.539166",
          "status": "completed"
        },
        "source_hash": "28ad5178",
        "tags": []
      },
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-83f1cbe102574ffbacfa7e0f87290185.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-83f1cbe102574ffbacfa7e0f87290185.vega-embed details,\n",
              "  #altair-viz-83f1cbe102574ffbacfa7e0f87290185.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-83f1cbe102574ffbacfa7e0f87290185\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-83f1cbe102574ffbacfa7e0f87290185\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-83f1cbe102574ffbacfa7e0f87290185\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-bd4440f2bd659840503c9701cdb81363\"}, \"mark\": {\"type\": \"boxplot\"}, \"encoding\": {\"color\": {\"field\": \"OverallQual\", \"type\": \"nominal\"}, \"x\": {\"field\": \"OverallQual\", \"type\": \"ordinal\"}, \"y\": {\"field\": \"SalePrice\", \"type\": \"quantitative\"}}, \"height\": 300, \"width\": 500, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-bd4440f2bd659840503c9701cdb81363\": [{\"Order\": 1, \"PID\": 526301100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 141.0, \"LotArea\": 31770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2, \"PID\": 526350040, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 80.0, \"LotArea\": 11622, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 3, \"PID\": 526351010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 393, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 12500, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 4, \"PID\": 526353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1045.0, \"TotalBsmtSF\": 2110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 5, \"PID\": 527105010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189900}, {\"Order\": 6, \"PID\": 527105030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 7, \"PID\": 527127150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 8, \"PID\": 527145080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 263.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191500}, {\"Order\": 9, \"PID\": 527146030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1180.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 10, \"PID\": 527162130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 776, \"LowQualFinSF\": 0, \"GrLivArea\": 1804, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 11, \"PID\": 527163010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 763, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1655, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 157, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 12, \"PID\": 527165230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1992, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 935.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 233.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 13, \"PID\": 527166040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180400}, {\"Order\": 14, \"PID\": 527180040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 15, \"PID\": 527182190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 1120.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 16, \"PID\": 527216070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 53504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 603.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1690, \"2ndFlrSF\": 1589, \"LowQualFinSF\": 0, \"GrLivArea\": 3279, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 841.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 503, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 538000}, {\"Order\": 17, \"PID\": 527225035, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 152.0, \"LotArea\": 12134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1988, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 427.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 325, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 18, \"PID\": 527258010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 2, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 1856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394432}, {\"Order\": 19, \"PID\": 527276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 19138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 20, \"PID\": 527302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 163.0, \"BsmtUnfSF\": 589.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 21, \"PID\": 527358140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 22, \"PID\": 527358200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 81.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 885.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1173, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 170000}, {\"Order\": 23, \"PID\": 527368020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 814, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 24, \"PID\": 527402200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11241, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 25, \"PID\": 527402250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12537, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 26, \"PID\": 527403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 27, \"PID\": 527404120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 78.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 28, \"PID\": 527425090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 29, \"PID\": 527427230, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 5858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1051.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 30, \"PID\": 527451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 327.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 31, \"PID\": 527451330, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 32, \"PID\": 527451410, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 381.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 88000}, {\"Order\": 33, \"PID\": 527452190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 709.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 34, \"PID\": 527453130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 514.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 35, \"PID\": 527453150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 836.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 36, \"PID\": 527454200, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 37, \"PID\": 528108120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1590.0, \"TotalBsmtSF\": 1590.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1627, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 2334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 376162}, {\"Order\": 38, \"PID\": 528112020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 39, \"PID\": 528120060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1940, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395192}, {\"Order\": 40, \"PID\": 528120090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1544.0, \"TotalBsmtSF\": 1544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290941}, {\"Order\": 41, \"PID\": 528120100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 220000}, {\"Order\": 42, \"PID\": 528120120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 615.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 43, \"PID\": 528138020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1794.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1822, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259000}, {\"Order\": 44, \"PID\": 528138060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1515.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 45, \"PID\": 528150070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12919, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 760.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 2330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 611657}, {\"Order\": 46, \"PID\": 528175010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6371, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224000}, {\"Order\": 47, \"PID\": 528176010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1095.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1473.0, \"TotalBsmtSF\": 2846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 958.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 500000}, {\"Order\": 48, \"PID\": 528176070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 563, \"LowQualFinSF\": 0, \"GrLivArea\": 2250, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 49, \"PID\": 528180070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 412.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1296.0, \"TotalBsmtSF\": 1752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 50, \"PID\": 528181050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 7132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 51, \"PID\": 528188120, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 52, \"PID\": 528218150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 18494, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1324.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 53, \"PID\": 528228285, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 54, \"PID\": 528228440, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 55, \"PID\": 528231020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 58.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 56, \"PID\": 528240070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 1100, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216500}, {\"Order\": 57, \"PID\": 528240130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185088}, {\"Order\": 58, \"PID\": 528250100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 59, \"PID\": 528292020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9505, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 1151, \"LowQualFinSF\": 0, \"GrLivArea\": 2035, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 60, \"PID\": 528328100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 14774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1393.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2599, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 668, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 333168}, {\"Order\": 61, \"PID\": 528344070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 17433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1629.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1645, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 2475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 962.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 23, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 62, \"PID\": 528358010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 919.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 56, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260400}, {\"Order\": 63, \"PID\": 528363130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 1122, \"LowQualFinSF\": 0, \"GrLivArea\": 2622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 64, \"PID\": 528382020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1999, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 348.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1106, \"LowQualFinSF\": 0, \"GrLivArea\": 2270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 671.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 65, \"PID\": 528382030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 66, \"PID\": 528386040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 14720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 579.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1217.0, \"TotalBsmtSF\": 2033.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2053, \"2ndFlrSF\": 1185, \"LowQualFinSF\": 0, \"GrLivArea\": 3238, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 283, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 67, \"PID\": 528445060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8987, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221500}, {\"Order\": 68, \"PID\": 528456160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 92.0, \"LotArea\": 9215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204500}, {\"Order\": 69, \"PID\": 528458070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1547, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215200}, {\"Order\": 70, \"PID\": 528458110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 488.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1566, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 71, \"PID\": 528477080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 12552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 222.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 956, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 72, \"PID\": 528480090, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271500}, {\"Order\": 73, \"PID\": 531367050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 956.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233000}, {\"Order\": 74, \"PID\": 531369060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 75, \"PID\": 531380080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 76, \"PID\": 531451110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 543.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 119.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 77, \"PID\": 531451280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 635, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 78, \"PID\": 531452020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 79, \"PID\": 531452050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 353, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 80, \"PID\": 531452180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1744, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 238, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 81, \"PID\": 531453010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 82, \"PID\": 531453040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 83, \"PID\": 531477050, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67500}, {\"Order\": 84, \"PID\": 532351140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1318, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 85, \"PID\": 532354090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 899.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1155, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1155, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 86, \"PID\": 532376160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 416, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 87, \"PID\": 532377060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 31.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 88, \"PID\": 532377100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 220, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 89, \"PID\": 532378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6897, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 90, \"PID\": 532479070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 15410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 126.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 859.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 169000}, {\"Order\": 91, \"PID\": 533130020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10186, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 92, \"PID\": 533130130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 981.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1231.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2349, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 362500}, {\"Order\": 93, \"PID\": 533130160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1129.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 823, \"LowQualFinSF\": 0, \"GrLivArea\": 2225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 713.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 94, \"PID\": 533205060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 25.0, \"LotArea\": 4835, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 95, \"PID\": 533208090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 39.0, \"LotArea\": 3515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 96, \"PID\": 533210060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3215, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 97, \"PID\": 533212010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 98, \"PID\": 533212020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 99, \"PID\": 533212060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 376.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 100, \"PID\": 533213030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 101, \"PID\": 533221090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 102, \"PID\": 533221110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1159.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 466.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 103, \"PID\": 533223020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 696, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 104, \"PID\": 533223100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 244.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147110}, {\"Order\": 105, \"PID\": 533238045, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 57.0, \"LotArea\": 12853, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 1642.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 224, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267916}, {\"Order\": 106, \"PID\": 533244030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 7379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 107, \"PID\": 533253060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 4420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 108, \"PID\": 533253210, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1052.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 223, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 109, \"PID\": 533352170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13517, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 475.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 110, \"PID\": 534102025, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 659.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 111, \"PID\": 534129040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1323.0, \"TotalBsmtSF\": 1829.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1829, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 535.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218500}, {\"Order\": 112, \"PID\": 534151175, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1137.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243500}, {\"Order\": 113, \"PID\": 534152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 114, \"PID\": 534152070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 687.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 46.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 1891, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 115, \"PID\": 534152100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10421, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 394.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 734, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 66, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 116, \"PID\": 534176060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 982.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 1161.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1381, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1381, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 117, \"PID\": 534176230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 715, \"LowQualFinSF\": 0, \"GrLivArea\": 1645, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 118, \"PID\": 534202160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142250}, {\"Order\": 119, \"PID\": 534251320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 451.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 81.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1328.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 120, \"PID\": 534276360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128950}, {\"Order\": 121, \"PID\": 534401110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1209, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 122, \"PID\": 534401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 9680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1510, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 123, \"PID\": 534403360, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10600, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136300}, {\"Order\": 124, \"PID\": 534403410, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14112, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1014.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 227, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 125, \"PID\": 534425310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 156.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 126, \"PID\": 534427010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 13260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 127, \"PID\": 534430080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 49.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1029.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142125}, {\"Order\": 128, \"PID\": 534431050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 670.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1929, \"2ndFlrSF\": 532, \"LowQualFinSF\": 0, \"GrLivArea\": 2461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197600}, {\"Order\": 129, \"PID\": 534431070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 17360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1019, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 130, \"PID\": 534450180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 131, \"PID\": 534451150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1940, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 263, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76500}, {\"Order\": 132, \"PID\": 534475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 133, \"PID\": 534476260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 132.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 189, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 134, \"PID\": 534479320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 244.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 135, \"PID\": 535101020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 136, \"PID\": 535106190, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 361.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1169, \"LowQualFinSF\": 0, \"GrLivArea\": 2274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154300}, {\"Order\": 137, \"PID\": 535125010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 287.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 912.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1947.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2207, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 301, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 138, \"PID\": 535126040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 137.0, \"LotArea\": 16492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 713.0, \"BsmtUnfSF\": 557.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 139, \"PID\": 535152010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1604.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 140, \"PID\": 535152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 300, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 141, \"PID\": 535152130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 142, \"PID\": 535152150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 143, \"PID\": 535152250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 144, \"PID\": 535153070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1194.0, \"TotalBsmtSF\": 1194.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 145, \"PID\": 535154050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142000}, {\"Order\": 146, \"PID\": 535175070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 324.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 571.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 143, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 147, \"PID\": 535175180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10725, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 91.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1206, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108538}, {\"Order\": 148, \"PID\": 535179020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 149, \"PID\": 535180130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 832, \"2ndFlrSF\": 505, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 263.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 150, \"PID\": 535302080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 339.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 151, \"PID\": 535302200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 119.0, \"LotArea\": 10895, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 152, \"PID\": 535304060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 153, \"PID\": 535304180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 731.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109000}, {\"Order\": 154, \"PID\": 535325400, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 155, \"PID\": 535327140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 156, \"PID\": 535350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 362.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 157, \"PID\": 535350040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 5868, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 158, \"PID\": 535353190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 17503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97500}, {\"Order\": 159, \"PID\": 535377090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 160, \"PID\": 535401080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 72.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 258.0, \"BsmtUnfSF\": 733.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 161, \"PID\": 535425010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 1080, \"LowQualFinSF\": 0, \"GrLivArea\": 2978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 162, \"PID\": 535450210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 481.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 163, \"PID\": 535453070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 906.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 164, \"PID\": 535454070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 475, \"LowQualFinSF\": 0, \"GrLivArea\": 1385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 165, \"PID\": 535456110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 486.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134800}, {\"Order\": 166, \"PID\": 535457010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1116.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 385, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 167, \"PID\": 535457090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 7635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 350.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 168, \"PID\": 535476350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 263.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1395, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 657, \"OpenPorchSF\": 0, \"EnclosedPorch\": 113, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 169, \"PID\": 535477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 170, \"PID\": 902102100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 771.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80400}, {\"Order\": 171, \"PID\": 902104060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 172, \"PID\": 902106130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4485, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 579.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 51, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 173, \"PID\": 902106140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1028, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 130, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 174, \"PID\": 902110090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 5805, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1073.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1347, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 175, \"PID\": 902125080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1605, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107400}, {\"Order\": 176, \"PID\": 902125160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 4608, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 177, \"PID\": 902128170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 294.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 804, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 178, \"PID\": 902206040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 692.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 390, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 179, \"PID\": 902206130, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 827.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 180, \"PID\": 902206220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 606, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 181, \"PID\": 902206240, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 185, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 334, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 182, \"PID\": 902207130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1923, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 780.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 12789}, {\"Order\": 183, \"PID\": 902207140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1928, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105900}, {\"Order\": 184, \"PID\": 902305110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 228, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 185, \"PID\": 902327040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 966, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 186, \"PID\": 902329030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 187, \"PID\": 902401060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 18, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 188, \"PID\": 902402010, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 7407, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 923.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149700}, {\"Order\": 189, \"PID\": 902402130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 622, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 190, \"PID\": 902402250, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1885, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 777.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 191, \"PID\": 902403070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140750}, {\"Order\": 192, \"PID\": 903204040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1030, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 363.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 193, \"PID\": 903206120, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 194, \"PID\": 903225150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 765, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 765, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 195, \"PID\": 903226160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 452.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 12.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 134000}, {\"Order\": 196, \"PID\": 903227020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 197, \"PID\": 903227150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 955, \"2ndFlrSF\": 498, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 148, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 198, \"PID\": 903228150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 221, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 199, \"PID\": 903232190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 548, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 200, \"PID\": 903233120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 928, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138400}, {\"Order\": 201, \"PID\": 903234050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 164.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 202, \"PID\": 903425110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 10300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 11, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 203, \"PID\": 903426180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 888.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 1074, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 364, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 204, \"PID\": 903426200, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 205, \"PID\": 903430080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 3068, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 662, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 206, \"PID\": 903450110, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 110.0, \"LotArea\": 8472, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 207, \"PID\": 903454060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 372, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3500, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 208, \"PID\": 903476030, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 7630, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 209, \"PID\": 904100140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1032.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 1196, \"LowQualFinSF\": 0, \"GrLivArea\": 2403, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 0, \"EnclosedPorch\": 318, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 244400}, {\"Order\": 210, \"PID\": 904101110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 365.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 211, \"PID\": 904300150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 499, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Po\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 212, \"PID\": 904302260, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1026.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 180, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 213, \"PID\": 904350045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 214, \"PID\": 904351040, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 6449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1907, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 73.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93369}, {\"Order\": 215, \"PID\": 904352190, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 6048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114900}, {\"Order\": 216, \"PID\": 905101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 6342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1875, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94000}, {\"Order\": 217, \"PID\": 905101300, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1832, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 218, \"PID\": 905101310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1768.0, \"TotalBsmtSF\": 1768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 219, \"PID\": 905102060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 1039.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 220, \"PID\": 905103060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11341, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1302.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 221, \"PID\": 905104210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8521, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 842.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 222, \"PID\": 905105070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 668.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 223, \"PID\": 905105200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 47.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 474.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 224, \"PID\": 905106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 663, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 379, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 225, \"PID\": 905106170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137250}, {\"Order\": 226, \"PID\": 905107110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7424, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1373, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1373, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160250}, {\"Order\": 227, \"PID\": 905107250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 453.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 228, \"PID\": 905107320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 328.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1386, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 229, \"PID\": 905109130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 954, \"LowQualFinSF\": 0, \"GrLivArea\": 2260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 328000}, {\"Order\": 230, \"PID\": 905109170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1092.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1483, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1483, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 496, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 231, \"PID\": 905201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 756, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 232, \"PID\": 905202090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 233, \"PID\": 905325030, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23595, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 74.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 192, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 234, \"PID\": 905352140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 336, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 235, \"PID\": 905378040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 18600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 684.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 558, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 236, \"PID\": 905426060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 108.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 835, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 237, \"PID\": 905426200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11479, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 387.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 238, \"PID\": 905451320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 44, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 239, \"PID\": 905452110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 362, \"GrLivArea\": 1531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 209.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 240, \"PID\": 905452160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 954.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 1172.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1172, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 241, \"PID\": 905453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1176.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 242, \"PID\": 905453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 17485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1508, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Partial\", \"SalePrice\": 308030}, {\"Order\": 243, \"PID\": 905475510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1250.0, \"TotalBsmtSF\": 1250.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 244, \"PID\": 905478190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 245, \"PID\": 906201030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 977, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1732, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 246, \"PID\": 906201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 11980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 177.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1433.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1433.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 278, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 247, \"PID\": 906204230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 12361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 86.0, \"TotalBsmtSF\": 946.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1017.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 450, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 248, \"PID\": 906223090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 750.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 249, \"PID\": 906225210, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 250, \"PID\": 906378100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245350}, {\"Order\": 251, \"PID\": 906380190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 252, \"PID\": 906385010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 10402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 740.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198900}, {\"Order\": 253, \"PID\": 906385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1222.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1222, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 254, \"PID\": 906402200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12376, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1470.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 1523, \"LowQualFinSF\": 0, \"GrLivArea\": 3222, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 367, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 255, \"PID\": 906425045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 14235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 614, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 256, \"PID\": 906477110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 257, \"PID\": 907125090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 71, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 258, \"PID\": 907180050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 878.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 259, \"PID\": 907185060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 260, \"PID\": 907200280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 15240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 688.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 261, \"PID\": 907200290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161750}, {\"Order\": 262, \"PID\": 907200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 365, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128200}, {\"Order\": 263, \"PID\": 907203070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 264, \"PID\": 907250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 296.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 265, \"PID\": 907252120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 479.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1581.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 266, \"PID\": 907262050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 9548, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 223.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 458.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 613.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 267, \"PID\": 907280040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 331, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 268, \"PID\": 907290040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1649.0, \"TotalBsmtSF\": 1649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 269, \"PID\": 907290170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 270, \"PID\": 907290240, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 271, \"PID\": 907401090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 10635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 972.0, \"BsmtUnfSF\": 315.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 262, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 272, \"PID\": 907410080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 109.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 761.0, \"TotalBsmtSF\": 1473.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 273, \"PID\": 907414030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185500}, {\"Order\": 274, \"PID\": 908102060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 84900}, {\"Order\": 275, \"PID\": 908102110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 155891}, {\"Order\": 276, \"PID\": 908102130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 277, \"PID\": 908102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 278, \"PID\": 908102300, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 792, \"2ndFlrSF\": 328, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 64000}, {\"Order\": 279, \"PID\": 908103350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125200}, {\"Order\": 280, \"PID\": 908152080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 7819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 422.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 281, \"PID\": 908203100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 282, \"PID\": 908208020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 8546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1121.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 283, \"PID\": 908225320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 94.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1487, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 284, \"PID\": 908226130, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 285, \"PID\": 908275300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1526, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 286, \"PID\": 909100080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 4853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 974.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 287, \"PID\": 909100110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 841, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 288, \"PID\": 909101070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 289, \"PID\": 909176140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 242, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 290, \"PID\": 909176150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 166, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 291, \"PID\": 909177100, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 862, \"2ndFlrSF\": 1788, \"LowQualFinSF\": 0, \"GrLivArea\": 2650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 292, \"PID\": 909250030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 293, \"PID\": 909250060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 804.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 2447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 294, \"PID\": 909281080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 371.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 86, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 295, \"PID\": 909426080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 657.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1075, \"LowQualFinSF\": 0, \"GrLivArea\": 2177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 296, \"PID\": 909427230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 877.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 1152, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266500}, {\"Order\": 297, \"PID\": 909428280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 207, \"EnclosedPorch\": 162, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 298, \"PID\": 909452114, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 423.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203135}, {\"Order\": 299, \"PID\": 909455030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 300, \"PID\": 909455040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 76.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1115.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1191, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1191, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 301, \"PID\": 909475140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15602, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1801, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 289000}, {\"Order\": 302, \"PID\": 910202060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 61.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 358, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 303, \"PID\": 910203250, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 540, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 304, \"PID\": 910205120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 727, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 305, \"PID\": 911128180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 68400}, {\"Order\": 306, \"PID\": 911202100, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 859.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 859, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 102776}, {\"Order\": 307, \"PID\": 911204090, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 54, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 55993}, {\"Order\": 308, \"PID\": 911204100, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1896, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1896.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 265, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 50138}, {\"Order\": 309, \"PID\": 911370510, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246000}, {\"Order\": 310, \"PID\": 914467040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 615.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1916, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 741.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 311, \"PID\": 914475090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9620, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1243.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 375, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 80, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 312, \"PID\": 914476520, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 9196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 313, \"PID\": 914478045, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 473.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169900}, {\"Order\": 314, \"PID\": 914478110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1958.0, \"TotalBsmtSF\": 1958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 315, \"PID\": 916125360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 57200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 334.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 50, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 316, \"PID\": 916386010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 78.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1346, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 317, \"PID\": 916386020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1214.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179781}, {\"Order\": 318, \"PID\": 916386060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 319, \"PID\": 916386090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 774.0, \"TotalBsmtSF\": 774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 1194, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 269500}, {\"Order\": 320, \"PID\": 916455170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 1894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214900}, {\"Order\": 321, \"PID\": 916475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202900}, {\"Order\": 322, \"PID\": 921128020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 13214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2002.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2018, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2018, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378500}, {\"Order\": 323, \"PID\": 923201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 42.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 324, \"PID\": 923202105, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10114, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1430.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 325, \"PID\": 923204150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 326, \"PID\": 923205015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1344.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166500}, {\"Order\": 327, \"PID\": 923225300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83500}, {\"Order\": 328, \"PID\": 923225390, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 31.0, \"LotArea\": 2394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 945, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 329, \"PID\": 923225440, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 2592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 129.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 232.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 536, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 330, \"PID\": 923226250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 331, \"PID\": 923226320, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1491, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75500}, {\"Order\": 332, \"PID\": 923228270, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88250}, {\"Order\": 333, \"PID\": 923228370, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 334, \"PID\": 923230190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 469.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 335, \"PID\": 923251080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 26142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 336, \"PID\": 923276030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 207.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 337, \"PID\": 923276250, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1985, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1216.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 338, \"PID\": 923426070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 22, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 339, \"PID\": 924100050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 388.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 615, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 287, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 340, \"PID\": 924151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1341.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 284.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1679.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 64, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 341, \"PID\": 924152030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12961, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 342, \"PID\": 526302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 343, \"PID\": 526351100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 440.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 844.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 344, \"PID\": 526355080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 542.0, \"TotalBsmtSF\": 1952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 2704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 269, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 345, \"PID\": 527105070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 346, \"PID\": 527105130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 1275, \"LowQualFinSF\": 0, \"GrLivArea\": 2283, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 347, \"PID\": 527107130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1628, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 490, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 348, \"PID\": 527108070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 14892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1746, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377500}, {\"Order\": 349, \"PID\": 527110020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 22.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 350, \"PID\": 527127100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 28.0, \"LotArea\": 7296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 243.0, \"TotalBsmtSF\": 2208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2522, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 351, \"PID\": 527131030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 5664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1659, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 352, \"PID\": 527132090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 353, \"PID\": 527146010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 354, \"PID\": 527161040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 355, \"PID\": 527162110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 94, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 291, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 356, \"PID\": 527162120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 357, \"PID\": 527163040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 799.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 799, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 358, \"PID\": 527163070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 359, \"PID\": 527163130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181316}, {\"Order\": 360, \"PID\": 527164020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 7250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 361, \"PID\": 527164060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 362, \"PID\": 527164090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 702, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1481, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 363, \"PID\": 527165130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 364, \"PID\": 527166010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 694.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 1983, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 365, \"PID\": 527180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1424.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 508, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 366, \"PID\": 527182110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 187500}, {\"Order\": 367, \"PID\": 527214050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 17423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 748.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 2216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1166.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 501837}, {\"Order\": 368, \"PID\": 527254020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 464.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2046.0, \"TotalBsmtSF\": 2046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372500}, {\"Order\": 369, \"PID\": 527258020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 16158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 370, \"PID\": 527276160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1934, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 371, \"PID\": 527301320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 692.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 1200, \"LowQualFinSF\": 0, \"GrLivArea\": 2353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 372, \"PID\": 527302175, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 17043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1586, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 373, \"PID\": 527326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 82500}, {\"Order\": 374, \"PID\": 527326150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 375, \"PID\": 527352150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 154000}, {\"Order\": 376, \"PID\": 527353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 363.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 377, \"PID\": 527353060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 229.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1539, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2673, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 378, \"PID\": 527354100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 225.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 379, \"PID\": 527354200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 380, \"PID\": 527355150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1420.0, \"TotalBsmtSF\": 2524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 381, \"PID\": 527356040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157000}, {\"Order\": 382, \"PID\": 527359050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 383, \"PID\": 527359180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 448, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 384, \"PID\": 527364030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1016, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 581.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240900}, {\"Order\": 385, \"PID\": 527365030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 8004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 1103, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 263435}, {\"Order\": 386, \"PID\": 527366030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1058.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 387, \"PID\": 527368010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 225.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 471.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 839, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 388, \"PID\": 527375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1333.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 490, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 389, \"PID\": 527375180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 888.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 390, \"PID\": 527375210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 391, \"PID\": 527376100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 392, \"PID\": 527378140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 333.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 2119, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158000}, {\"Order\": 393, \"PID\": 527401160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 394, \"PID\": 527402220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1002, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 902.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 395, \"PID\": 527403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 439.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 472.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 396, \"PID\": 527404020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1180.0, \"TotalBsmtSF\": 1180.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 397, \"PID\": 527404030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 398, \"PID\": 527405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 726.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 399, \"PID\": 527405160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 239.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 400, \"PID\": 527405180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 401, \"PID\": 527425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97000}, {\"Order\": 402, \"PID\": 527425110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 403, \"PID\": 527450280, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 254.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 404, \"PID\": 527451110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 312.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 405, \"PID\": 527451320, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 406, \"PID\": 527451540, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 79.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 407, \"PID\": 527451640, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 510.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 408, \"PID\": 527451650, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 409, \"PID\": 527452060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 410, \"PID\": 527453050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 411, \"PID\": 527453060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 87, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 412, \"PID\": 527453140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 622.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 413, \"PID\": 527454050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 260, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 414, \"PID\": 527454130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2349, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 389.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 415, \"PID\": 527455050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 416, \"PID\": 527455060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 586, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 417, \"PID\": 527455080, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 279.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 418, \"PID\": 527455090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 345.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 419, \"PID\": 527455240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 420, \"PID\": 527455280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 421, \"PID\": 528102040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1172.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337500}, {\"Order\": 422, \"PID\": 528102140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 726.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1794, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 462000}, {\"Order\": 423, \"PID\": 528104070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 13518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 860.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1926.0, \"TotalBsmtSF\": 1926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 1174, \"LowQualFinSF\": 0, \"GrLivArea\": 3140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 485000}, {\"Order\": 424, \"PID\": 528106020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1767.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 3094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2402, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 555000}, {\"Order\": 425, \"PID\": 528106070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 404, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 426, \"PID\": 528108010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 640.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1566.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 890.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256300}, {\"Order\": 427, \"PID\": 528108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2042.0, \"TotalBsmtSF\": 2042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 253293}, {\"Order\": 428, \"PID\": 528108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1365, \"2ndFlrSF\": 1325, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 197, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 398800}, {\"Order\": 429, \"PID\": 528108070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 154.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 430, \"PID\": 528108130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 2020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 404000}, {\"Order\": 431, \"PID\": 528108140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 2006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 402861}, {\"Order\": 432, \"PID\": 528110010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 13478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1722.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 2296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 842.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 451950}, {\"Order\": 433, \"PID\": 528110020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 2630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2674, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2674, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 610000}, {\"Order\": 434, \"PID\": 528110090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 424.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1734.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 1088, \"LowQualFinSF\": 0, \"GrLivArea\": 2822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1020.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 582933}, {\"Order\": 435, \"PID\": 528112040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1736.0, \"TotalBsmtSF\": 1736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1736, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1736, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 436, \"PID\": 528116010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 99, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 296000}, {\"Order\": 437, \"PID\": 528118060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 23303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 273, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 409900}, {\"Order\": 438, \"PID\": 528120020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1709.0, \"TotalBsmtSF\": 1709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1717, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255500}, {\"Order\": 439, \"PID\": 528120030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1015.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 1739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 927.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 440, \"PID\": 528120160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 262.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274900}, {\"Order\": 441, \"PID\": 528120170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1037.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1531, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 700.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 442, \"PID\": 528138010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 13514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 285.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1142.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 1774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1808, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 443, \"PID\": 528142040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8834, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1170.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1462, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 444, \"PID\": 528142090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 11362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 862.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 185, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 445, \"PID\": 528142130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1124.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 479.0, \"BsmtUnfSF\": 1603.0, \"TotalBsmtSF\": 3206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 446, \"PID\": 528142150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12878, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 418.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 1760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1760, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 190, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 447, \"PID\": 528144020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1502.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233170}, {\"Order\": 448, \"PID\": 528166060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 922.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2336.0, \"TotalBsmtSF\": 2392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 386250}, {\"Order\": 449, \"PID\": 528166090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 724.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1972.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 2452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 886.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 445000}, {\"Order\": 450, \"PID\": 528168030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1295, \"LowQualFinSF\": 0, \"GrLivArea\": 2400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 451, \"PID\": 528172060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1598.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1606, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1606, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 452, \"PID\": 528174050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 6904, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 453, \"PID\": 528174060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 900.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 454, \"PID\": 528174070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 455, \"PID\": 528175050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 456, \"PID\": 528175060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 457, \"PID\": 528176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 730.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2146.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 2492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 949.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 552000}, {\"Order\": 458, \"PID\": 528178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 117.0, \"LotArea\": 15262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 470.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 643.0, \"TotalBsmtSF\": 2200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 685.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 382500}, {\"Order\": 459, \"PID\": 528180120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 308.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1084.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 460, \"PID\": 528180130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 461, \"PID\": 528186010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 1712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 183, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286500}, {\"Order\": 462, \"PID\": 528186180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 863.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 463, \"PID\": 528188020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 464, \"PID\": 528188060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2268, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 465, \"PID\": 528218090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 466, \"PID\": 528220040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 745.0, \"TotalBsmtSF\": 745.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 745, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167800}, {\"Order\": 467, \"PID\": 528221060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 12589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 468, \"PID\": 528221070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 469, \"PID\": 528228290, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1373.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 470, \"PID\": 528228295, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1569, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1569, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 471, \"PID\": 528228435, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1357.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 472, \"PID\": 528228450, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 473, \"PID\": 528228455, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 474, \"PID\": 528228460, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 11.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160200}, {\"Order\": 475, \"PID\": 528235010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 476, \"PID\": 528235090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1010.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1010, \"2ndFlrSF\": 1257, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 477, \"PID\": 528235200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 478, \"PID\": 528240030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 479, \"PID\": 528240060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 779, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184100}, {\"Order\": 480, \"PID\": 528240150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 481, \"PID\": 528250020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 482, \"PID\": 528250040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8174, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 483, \"PID\": 528253010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 484, \"PID\": 528275070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 1276, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 485, \"PID\": 528275160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 1126, \"LowQualFinSF\": 0, \"GrLivArea\": 2004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 486, \"PID\": 528280230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 487, \"PID\": 528290030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9734, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 113.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 488, \"PID\": 528290120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8123, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 489, \"PID\": 528290180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 8433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 683.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1514, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 490, \"PID\": 528290190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 491, \"PID\": 528292030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1177.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2312, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 492, \"PID\": 528292040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 841.0, \"TotalBsmtSF\": 841.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 493, \"PID\": 528292070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 772.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1038, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 494, \"PID\": 528294050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7848, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 495, \"PID\": 528315090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 673.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1163.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337000}, {\"Order\": 496, \"PID\": 528321010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 15138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 689.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 773.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1490, \"2ndFlrSF\": 1304, \"LowQualFinSF\": 0, \"GrLivArea\": 2794, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 403000}, {\"Order\": 497, \"PID\": 528327070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 1455.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1221, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 327000}, {\"Order\": 498, \"PID\": 528344040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 731.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2450, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1069.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 499, \"PID\": 528344100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 975.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 854.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1225.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 1336, \"LowQualFinSF\": 0, \"GrLivArea\": 2612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 336000}, {\"Order\": 500, \"PID\": 528354050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10208, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 921.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1264.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 1067, \"LowQualFinSF\": 0, \"GrLivArea\": 2344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 889.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 501, \"PID\": 528363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 634.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1526.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 2024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 815.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 502, \"PID\": 528365070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 987.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 1274, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 60, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 503, \"PID\": 528385050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 967, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 102, \"EnclosedPorch\": 209, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 504, \"PID\": 528387030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 372.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 623.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263550}, {\"Order\": 505, \"PID\": 528390100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 46589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 528.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 517, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 402000}, {\"Order\": 506, \"PID\": 528390210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 29959, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 507, \"PID\": 528427020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 244600}, {\"Order\": 508, \"PID\": 528431020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1696.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 972.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 509, \"PID\": 528431070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 294.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1614.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1658, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 510, \"PID\": 528435030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1573.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287090}, {\"Order\": 511, \"PID\": 528435050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 512, \"PID\": 528439060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 513, \"PID\": 528441020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 772.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 689.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 514, \"PID\": 528441090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2490, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 226, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 468000}, {\"Order\": 515, \"PID\": 528456180, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 920, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252678}, {\"Order\": 516, \"PID\": 528456220, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 517, \"PID\": 528456240, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7862, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 27.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208300}, {\"Order\": 518, \"PID\": 528458020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 90.0, \"LotArea\": 7993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 519, \"PID\": 528458040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229456}, {\"Order\": 520, \"PID\": 528458060, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1402.0, \"TotalBsmtSF\": 1402.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 205, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229800}, {\"Order\": 521, \"PID\": 528458140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 984.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 522, \"PID\": 528458160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 645.0, \"TotalBsmtSF\": 1766.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 195, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370878}, {\"Order\": 523, \"PID\": 528458180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1348.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1448, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1448, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238500}, {\"Order\": 524, \"PID\": 528477050, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 981, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 310000}, {\"Order\": 525, \"PID\": 528477070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 121.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 526, \"PID\": 528480040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1043.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 527, \"PID\": 528480130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 438, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241000}, {\"Order\": 528, \"PID\": 528480170, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264500}, {\"Order\": 529, \"PID\": 528482040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1662, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1662, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 530, \"PID\": 528482130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 531, \"PID\": 528488100, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1221.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 532, \"PID\": 528490040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 8736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 771.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 360.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1553.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234500}, {\"Order\": 533, \"PID\": 528490070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8127, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 841, \"LowQualFinSF\": 0, \"GrLivArea\": 1653, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 534, \"PID\": 531363010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 178, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 535, \"PID\": 531363030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1087.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 536, \"PID\": 531363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 537, \"PID\": 531369010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 871, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 538, \"PID\": 531369020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 774.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1512.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 845.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 539, \"PID\": 531371050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10083, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 540, \"PID\": 531375040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 541, \"PID\": 531375090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 542, \"PID\": 531375130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 543, \"PID\": 531376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1450, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224243}, {\"Order\": 544, \"PID\": 531379050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 11492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 1209, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 559.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 545, \"PID\": 531382070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10994, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 366.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 257000}, {\"Order\": 546, \"PID\": 531385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1434.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 547, \"PID\": 531450120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 364.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1730, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 548, \"PID\": 531452010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 626, \"2ndFlrSF\": 591, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 549, \"PID\": 531452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1332.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1332, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 550, \"PID\": 531452260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 786, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 551, \"PID\": 531453100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 141.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 465.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 552, \"PID\": 531475220, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 553, \"PID\": 531477020, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 721.0, \"TotalBsmtSF\": 721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 841, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 841, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 554, \"PID\": 531479020, \"MSSubClass\": 45, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 91, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 555, \"PID\": 532353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 884.0, \"BsmtUnfSF\": 28.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 556, \"PID\": 532353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 557, \"PID\": 532354160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 558, \"PID\": 532354230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9079, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 559, \"PID\": 532376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Family\", \"SalePrice\": 124100}, {\"Order\": 560, \"PID\": 532376110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 561, \"PID\": 532377130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131400}, {\"Order\": 562, \"PID\": 532378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 311.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 62383}, {\"Order\": 563, \"PID\": 532378180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 140.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 564, \"PID\": 532478020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15676, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1733.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 92.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 2014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 462, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 255, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 565, \"PID\": 533135020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11949, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1991, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 601.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 216.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 502, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 566, \"PID\": 533206020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 2880, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1376.0, \"TotalBsmtSF\": 1376.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1376, \"2ndFlrSF\": 1629, \"LowQualFinSF\": 0, \"GrLivArea\": 3005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 177, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280750}, {\"Order\": 567, \"PID\": 533210010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164500}, {\"Order\": 568, \"PID\": 533210020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173733}, {\"Order\": 569, \"PID\": 533213010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 3830, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1726.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 254, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 570, \"PID\": 533213020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4217, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 183.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 571, \"PID\": 533213040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 894.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1471, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 572, \"PID\": 533221040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 249.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 573, \"PID\": 533223030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 574, \"PID\": 533236050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1739, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 172500}, {\"Order\": 575, \"PID\": 533252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1252.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 136.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 501, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 225, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318750}, {\"Order\": 576, \"PID\": 533253070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 3782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211500}, {\"Order\": 577, \"PID\": 533254050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15417, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1619.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 20, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241600}, {\"Order\": 578, \"PID\": 533254110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1487, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180500}, {\"Order\": 579, \"PID\": 533352150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1281.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 580, \"PID\": 534125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 727.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 829, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 581, \"PID\": 534127130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 571.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1442.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 371, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 582, \"PID\": 534127170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9156, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185750}, {\"Order\": 583, \"PID\": 534128010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 859.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 32.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 204, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 350, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 584, \"PID\": 534128020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 782, \"LowQualFinSF\": 0, \"GrLivArea\": 2067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 585, \"PID\": 534128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 735, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 586, \"PID\": 534128190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1369, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256900}, {\"Order\": 587, \"PID\": 534129080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1724, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 588, \"PID\": 534129370, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 589, \"PID\": 534129380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 955.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113000}, {\"Order\": 590, \"PID\": 534151120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 283.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 2288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 591, \"PID\": 534152120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 592, \"PID\": 534175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1127.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 78, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213250}, {\"Order\": 593, \"PID\": 534177230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 594, \"PID\": 534200030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 595, \"PID\": 534202170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 596, \"PID\": 534226120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 466.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 597, \"PID\": 534250400, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 168500}, {\"Order\": 598, \"PID\": 534251030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 509.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 599, \"PID\": 534252240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 251.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 630.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 197, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 600, \"PID\": 534275060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 360, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 601, \"PID\": 534275100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 602, \"PID\": 534276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 603, \"PID\": 534277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 604, \"PID\": 534278070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 201.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177625}, {\"Order\": 605, \"PID\": 534278230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 606, \"PID\": 534400050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 345.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 1516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 152, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 607, \"PID\": 534400290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 217.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 512.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1313, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 121, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 608, \"PID\": 534402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1292.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1292, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145100}, {\"Order\": 609, \"PID\": 534402140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 230.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1154.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 610, \"PID\": 534402170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 549.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 611, \"PID\": 534403370, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 563.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 612, \"PID\": 534426110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 991.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 50.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 613, \"PID\": 534429150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 614, \"PID\": 534431130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 100.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 613.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 615, \"PID\": 534450150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 616, \"PID\": 534451110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 185.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 224, \"LowQualFinSF\": 0, \"GrLivArea\": 1203, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 617, \"PID\": 534475185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 1505.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1505, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 162, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 618, \"PID\": 534475250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 260, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 619, \"PID\": 534476150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 1416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 620, \"PID\": 534476320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 621, \"PID\": 534477110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 556, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 622, \"PID\": 534478230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 607.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 623, \"PID\": 535101120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 624, \"PID\": 535104120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10573, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 3.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 625, \"PID\": 535105100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 247.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1394.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1394, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 185, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 626, \"PID\": 535125070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 1562.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 342, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 627, \"PID\": 535125090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 314.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1186, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 628, \"PID\": 535126010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 576.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 2142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 252, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 629, \"PID\": 535126100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1392.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 630, \"PID\": 535150070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1281, \"2ndFlrSF\": 457, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 631, \"PID\": 535151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 313.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 632, \"PID\": 535152230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 661.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 633, \"PID\": 535154060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 203, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 634, \"PID\": 535154130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 635, \"PID\": 535175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 620.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 636, \"PID\": 535175050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1215.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 234, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 637, \"PID\": 535178040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 565.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1202, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1202, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 638, \"PID\": 535178120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 172.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 727.0, \"TotalBsmtSF\": 1382.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 639, \"PID\": 535179160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 155.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 750.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144000}, {\"Order\": 640, \"PID\": 535300120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 19296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 399.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 690.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 641, \"PID\": 535301170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 1297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1297, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1297, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 642, \"PID\": 535302120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 657.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1866.0, \"TotalBsmtSF\": 1866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 643, \"PID\": 535303110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 8128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 644, \"PID\": 535303150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10634, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1319, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1319, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 645, \"PID\": 535304100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 631.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 646, \"PID\": 535325290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1005.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 647, \"PID\": 535351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 178.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 648, \"PID\": 535352090, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 793, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 649, \"PID\": 535353040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1952, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1031.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1031, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 650, \"PID\": 535353060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102900}, {\"Order\": 651, \"PID\": 535353140, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1699, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 95000}, {\"Order\": 652, \"PID\": 535353240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 699.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 801, \"2ndFlrSF\": 726, \"LowQualFinSF\": 0, \"GrLivArea\": 1527, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 653, \"PID\": 535354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 654, \"PID\": 535354100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 655, \"PID\": 535375010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 656, \"PID\": 535375050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 704, \"LowQualFinSF\": 144, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 140, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 657, \"PID\": 535376060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 658, \"PID\": 535377150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 717, \"2ndFlrSF\": 322, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 111, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 659, \"PID\": 535378020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 9022, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1924, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 660, \"PID\": 535378120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10230, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 661, \"PID\": 535381040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 1064, \"GrLivArea\": 2377, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 432, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142900}, {\"Order\": 662, \"PID\": 535382100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 760, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 663, \"PID\": 535383060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 599, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 599, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 59000}, {\"Order\": 664, \"PID\": 535383070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 198, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 665, \"PID\": 535383110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 666, \"PID\": 535383120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 725, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78500}, {\"Order\": 667, \"PID\": 535402010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1248.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 907.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 668, \"PID\": 535402090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 996.0, \"TotalBsmtSF\": 1380.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1380, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 669, \"PID\": 535402270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 670, \"PID\": 535402330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2634, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 671, \"PID\": 535403190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1958, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 672, \"PID\": 535403210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 559.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1105, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 673, \"PID\": 535403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 674, \"PID\": 535425070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1270.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 675, \"PID\": 535426150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 676, \"PID\": 535450070, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 232, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 677, \"PID\": 535450160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 92900}, {\"Order\": 678, \"PID\": 535450200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 231, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 679, \"PID\": 535451170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 680, \"PID\": 535451250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 352.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 681, \"PID\": 535452090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1041.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 682, \"PID\": 535452100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 683, \"PID\": 535452140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 102.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 732, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118900}, {\"Order\": 684, \"PID\": 535453100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 433.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 95.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1183, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 685, \"PID\": 535453200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 686, \"PID\": 535454100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 832, \"2ndFlrSF\": 629, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 687, \"PID\": 535454160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 431, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 688, \"PID\": 535475010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 7570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1806, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144750}, {\"Order\": 689, \"PID\": 535476110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 124.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 690, \"PID\": 535476240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 7936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 826.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 691, \"PID\": 535477150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 692, \"PID\": 902101010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3950, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 693, \"PID\": 902102080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 682, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 694, \"PID\": 902103100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 4080, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 695, \"PID\": 902103120, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 972, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 696, \"PID\": 902103170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 5720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 455, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 66500}, {\"Order\": 697, \"PID\": 902105050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 496, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 698, \"PID\": 902105060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 699, \"PID\": 902106010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6406, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 269.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 868, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 700, \"PID\": 902106060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1892, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 994, \"LowQualFinSF\": 0, \"GrLivArea\": 2372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 287, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 701, \"PID\": 902109130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94550}, {\"Order\": 702, \"PID\": 902109140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7596, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1000, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 703, \"PID\": 902110080, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3378, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1946, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 651.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 682, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 704, \"PID\": 902134120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 801, \"2ndFlrSF\": 646, \"LowQualFinSF\": 0, \"GrLivArea\": 1447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 705, \"PID\": 902135020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 706, \"PID\": 902201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 707, \"PID\": 902202150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 811.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 811, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 708, \"PID\": 902204080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 709, \"PID\": 902205010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 25, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 45000}, {\"Order\": 710, \"PID\": 902205030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 37900}, {\"Order\": 711, \"PID\": 902206260, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1938, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 886, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91300}, {\"Order\": 712, \"PID\": 902207170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 713, \"PID\": 902300090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 4456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 113000}, {\"Order\": 714, \"PID\": 902301060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 677.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 715, \"PID\": 902301080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 716, \"PID\": 902325070, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1898, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 849.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 1063, \"LowQualFinSF\": 0, \"GrLivArea\": 2138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 717, \"PID\": 902326030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 181, \"OpenPorchSF\": 0, \"EnclosedPorch\": 386, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265979}, {\"Order\": 718, \"PID\": 902327070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 917.0, \"TotalBsmtSF\": 917.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 719, \"PID\": 902329080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1917, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 720, \"PID\": 902330040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 121.0, \"LotArea\": 17671, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1882, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 826, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 424.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 721, \"PID\": 902331010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 3300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 722, \"PID\": 902401130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1920, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 26.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 723, \"PID\": 902402150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 226, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 724, \"PID\": 902405100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 98.0, \"LotArea\": 8820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 561, \"LowQualFinSF\": 120, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 725, \"PID\": 902405120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 436, \"GrLivArea\": 1480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 207.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 119000}, {\"Order\": 726, \"PID\": 902406070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 238, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 727, \"PID\": 902477120, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 523, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 34900}, {\"Order\": 728, \"PID\": 902477130, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 72.0, \"LotArea\": 9392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 245.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 44000}, {\"Order\": 729, \"PID\": 903200080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 144.0, \"LotArea\": 21384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 15.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 730, \"PID\": 903201020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1022.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 731, \"PID\": 903201080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 732, \"PID\": 903202170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 244, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 733, \"PID\": 903205040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 192.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 40, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 734, \"PID\": 903226130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 735, \"PID\": 903226170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 390, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 736, \"PID\": 903227070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 737, \"PID\": 903227090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 825, \"2ndFlrSF\": 587, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 45, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 738, \"PID\": 903228070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 444.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 320, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 739, \"PID\": 903228120, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 740, \"PID\": 903230100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 741, \"PID\": 903231010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 927.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 742, \"PID\": 903231030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 989, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 54, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 743, \"PID\": 903231060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 744, \"PID\": 903231130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1931, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 745, \"PID\": 903232060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 995, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 15, \"EnclosedPorch\": 51, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 746, \"PID\": 903234220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 679.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 994, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 189, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 150, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 747, \"PID\": 903236040, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 134.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 1072.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 5.0, \"GarageArea\": 1184.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 748, \"PID\": 903400220, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11888, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 2134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 268, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214500}, {\"Order\": 749, \"PID\": 903425245, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 883, \"LowQualFinSF\": 0, \"GrLivArea\": 2019, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 509, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 750, \"PID\": 903427120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 751, \"PID\": 903429080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 2500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 752, \"PID\": 903429110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 753, \"PID\": 903430060, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 92.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 929, \"LowQualFinSF\": 371, \"GrLivArea\": 2229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 198, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 104000}, {\"Order\": 754, \"PID\": 903430070, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Sev\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 62500}, {\"Order\": 755, \"PID\": 903451090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 316.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 213, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 756, \"PID\": 903458170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 757, \"PID\": 903475100, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 758, \"PID\": 903476090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1902, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 169.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 978, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 759, \"PID\": 903481120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 760, \"PID\": 903481130, \"MSSubClass\": 85, \"MSZoning\": \"RM\", \"LotFrontage\": 86.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 749.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 63.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 70000}, {\"Order\": 761, \"PID\": 903484110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 262.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 754, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 288, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 762, \"PID\": 904100190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1946, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 704, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88750}, {\"Order\": 763, \"PID\": 904301060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 764, \"PID\": 904301070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 765, \"PID\": 904301100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 766, \"PID\": 904301375, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61000}, {\"Order\": 767, \"PID\": 904351200, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 54.0, \"LotArea\": 6629, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 551.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103600}, {\"Order\": 768, \"PID\": 904351240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 687, \"2ndFlrSF\": 425, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 226.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63000}, {\"Order\": 769, \"PID\": 905101260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12886, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 770, \"PID\": 905101490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 771, \"PID\": 905103040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 92.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 500.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1683, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 772, \"PID\": 905103070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 215, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113500}, {\"Order\": 773, \"PID\": 905105190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 774, \"PID\": 905107310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 775, \"PID\": 905108190, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7252, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 776, \"PID\": 905108220, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 860, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 777, \"PID\": 905200220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 170.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 778, \"PID\": 905200260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 611, \"LowQualFinSF\": 259, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 779, \"PID\": 905200350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15312, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 780, \"PID\": 905225090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 366.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2071, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2071, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 781, \"PID\": 905228050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63900}, {\"Order\": 782, \"PID\": 905229040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1104.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 783, \"PID\": 905325020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 25095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1473, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1473, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 60, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 143000}, {\"Order\": 784, \"PID\": 905377010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 284.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 785, \"PID\": 905377130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 786, \"PID\": 905401100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10708, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 768.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1867, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1867, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 476, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 787, \"PID\": 905402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139600}, {\"Order\": 788, \"PID\": 905402070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 789, \"PID\": 905450020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 790, \"PID\": 905451300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 340.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 791, \"PID\": 905451340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1276, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 60000}, {\"Order\": 792, \"PID\": 905452040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 747, \"LowQualFinSF\": 0, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154400}, {\"Order\": 793, \"PID\": 905452050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 344.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 794, \"PID\": 905475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1089.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1089, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 795, \"PID\": 905475500, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 290.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84000}, {\"Order\": 796, \"PID\": 905476230, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 393.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1049, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 266.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 797, \"PID\": 905478030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11409, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 798, \"PID\": 905480030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 799, \"PID\": 905480210, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 800, \"PID\": 906201021, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 286.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 801, \"PID\": 906201050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 19255, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 450.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 802, \"PID\": 906201130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1983, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 2132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316600}, {\"Order\": 803, \"PID\": 906203120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 177.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 2158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271900}, {\"Order\": 804, \"PID\": 906223060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 137.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 227.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 769, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 425.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 234, \"OpenPorchSF\": 72, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 805, \"PID\": 906223080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1879, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 100, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 806, \"PID\": 906223210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 807, \"PID\": 906226060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 26400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 2016, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 808, \"PID\": 906226070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118964}, {\"Order\": 809, \"PID\": 906226080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1086.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 153337}, {\"Order\": 810, \"PID\": 906226090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 1114, \"LowQualFinSF\": 0, \"GrLivArea\": 2228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 73, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 147983}, {\"Order\": 811, \"PID\": 906226100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 812, \"PID\": 906226110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 813, \"PID\": 906226120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 1120, \"LowQualFinSF\": 0, \"GrLivArea\": 2240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 142953}, {\"Order\": 814, \"PID\": 906226130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1094.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 148325}, {\"Order\": 815, \"PID\": 906226140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 113722}, {\"Order\": 816, \"PID\": 906230010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 817, \"PID\": 906230020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7939, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 818, \"PID\": 906230030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 819, \"PID\": 906340100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10933, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1021.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1555.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1138.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 323262}, {\"Order\": 820, \"PID\": 906340110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 417.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 297000}, {\"Order\": 821, \"PID\": 906340120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1622.0, \"TotalBsmtSF\": 1622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 860.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295493}, {\"Order\": 822, \"PID\": 906340130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 364.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 332000}, {\"Order\": 823, \"PID\": 906378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 904.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 824, \"PID\": 906380050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 825, \"PID\": 906380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11422, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1359.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 222, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272500}, {\"Order\": 826, \"PID\": 906380100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 827, \"PID\": 906380130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 828, \"PID\": 906380210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1282.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 829, \"PID\": 906380220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 10324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 382.0, \"TotalBsmtSF\": 1254.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221800}, {\"Order\": 830, \"PID\": 906392070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 82.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 831, \"PID\": 906392110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1474.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 832, \"PID\": 906392130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 704, \"2ndFlrSF\": 718, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 833, \"PID\": 906402060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 396, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 834, \"PID\": 906426210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 1449.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 815, \"LowQualFinSF\": 0, \"GrLivArea\": 1759, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 193, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233500}, {\"Order\": 835, \"PID\": 906475070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 28698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 764.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 966, \"LowQualFinSF\": 0, \"GrLivArea\": 2126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 836, \"PID\": 907126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 837, \"PID\": 907126050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9757, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 838, \"PID\": 907130100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 15426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 836, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 839, \"PID\": 907131090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 834, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 840, \"PID\": 907131190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14753, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 950.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1463, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1463, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 841, \"PID\": 907135040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 10859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1097.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 392, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 842, \"PID\": 907135170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 746.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 843, \"PID\": 907175100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 866.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 913, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 844, \"PID\": 907180130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1490.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 845, \"PID\": 907181100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9017, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 871.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 846, \"PID\": 907185050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 847, \"PID\": 907192030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8935, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 848, \"PID\": 907192090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 9808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1573, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 849, \"PID\": 907194010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1840, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 850, \"PID\": 907194110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 16285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1413.0, \"TotalBsmtSF\": 1413.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187100}, {\"Order\": 851, \"PID\": 907194160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10739, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 852, \"PID\": 907196060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11166, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 201000}, {\"Order\": 853, \"PID\": 907200230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 854, \"PID\": 907201220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16269, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 855, \"PID\": 907201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 6950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 710.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 856, \"PID\": 907202050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150500}, {\"Order\": 857, \"PID\": 907202080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 858, \"PID\": 907202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1072.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 859, \"PID\": 907227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 15523, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 860, \"PID\": 907227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 215, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 861, \"PID\": 907227110, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 862, \"PID\": 907227290, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8445, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 863, \"PID\": 907250070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 335.0, \"TotalBsmtSF\": 1569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 864, \"PID\": 907252060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1068.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254750}, {\"Order\": 865, \"PID\": 907252210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 866, \"PID\": 907252220, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 990.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 309.0, \"TotalBsmtSF\": 1299.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 573, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 261500}, {\"Order\": 867, \"PID\": 907253130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 2153, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 313000}, {\"Order\": 868, \"PID\": 907260030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 869, \"PID\": 907265010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 944.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 926, \"LowQualFinSF\": 0, \"GrLivArea\": 1870, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 870, \"PID\": 907275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 871, \"PID\": 907275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 814.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 872, \"PID\": 907275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 873, \"PID\": 907280170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1111.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1417, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1417, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 117, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 874, \"PID\": 907285020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 573.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 977, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 576, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 875, \"PID\": 907285050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 876, \"PID\": 907290070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1212.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 877, \"PID\": 907290090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1630.0, \"TotalBsmtSF\": 1630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 878, \"PID\": 907290180, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 879, \"PID\": 907290210, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 880, \"PID\": 907410130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1478.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 293200}, {\"Order\": 881, \"PID\": 907412020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 882, \"PID\": 907414020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1480.0, \"TotalBsmtSF\": 1500.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 883, \"PID\": 907414080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 193.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 884, \"PID\": 907420040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 885, \"PID\": 908102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 886, \"PID\": 908102270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1486.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 887, \"PID\": 908102290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 888, \"PID\": 908128060, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 495, \"2ndFlrSF\": 1427, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 177, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 889, \"PID\": 908151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 155.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 890, \"PID\": 908152035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 615.0, \"TotalBsmtSF\": 1014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 891, \"PID\": 908152100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 255.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 631.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 892, \"PID\": 908154040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 13286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 464.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 327, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 893, \"PID\": 908186080, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 894, \"PID\": 908201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1947, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 895, \"PID\": 908203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 332.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 243.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 896, \"PID\": 908225290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 900, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 897, \"PID\": 908225370, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 441, \"LowQualFinSF\": 0, \"GrLivArea\": 1529, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 898, \"PID\": 908229020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 899, \"PID\": 908250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 900, \"PID\": 908275040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1678.0, \"TotalBsmtSF\": 1678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1678, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1678, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 901, \"PID\": 908275110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 902, \"PID\": 908276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 903, \"PID\": 909101010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12354, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 800, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 904, \"PID\": 909101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 444, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 905, \"PID\": 909101140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10998, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 420.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 906, \"PID\": 909129090, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 907, \"PID\": 909129100, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1932, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 159434}, {\"Order\": 908, \"PID\": 909175080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 438, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 438, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 909, \"PID\": 909178160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 545, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 910, \"PID\": 909179020, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 15863, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 3, \"YearBuilt\": 1920, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 998, \"LowQualFinSF\": 397, \"GrLivArea\": 3082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 911, \"PID\": 909250080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 583.0, \"TotalBsmtSF\": 583.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 647, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 329, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 912, \"PID\": 909250220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 913, \"PID\": 909251050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 914, \"PID\": 909251170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137450}, {\"Order\": 915, \"PID\": 909252020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1936, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 575, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1135, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 916, \"PID\": 909253010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7558, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1913, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 917, \"PID\": 909253180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 877, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1477, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 918, \"PID\": 909254010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 919, \"PID\": 909257050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 10918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 920, \"PID\": 909275080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 921, \"PID\": 909276110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 753, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 213.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 922, \"PID\": 909276200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 332, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 923, \"PID\": 909277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1273, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 307.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 924, \"PID\": 909277100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13360, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 713.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 44, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 925, \"PID\": 909278020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7681, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 731.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 523, \"LowQualFinSF\": 0, \"GrLivArea\": 1343, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 186.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154900}, {\"Order\": 926, \"PID\": 909279010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 674.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 13, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 57, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 927, \"PID\": 909282130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 154.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 694.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144800}, {\"Order\": 928, \"PID\": 909425060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 929, \"PID\": 909425130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 65.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 875.0, \"BsmtUnfSF\": 621.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 930, \"PID\": 909426090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 507.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 295.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 931, \"PID\": 909427200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 158500}, {\"Order\": 932, \"PID\": 909428240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 91.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1906, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1906, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 201, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 933, \"PID\": 909451040, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 279, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 934, \"PID\": 909451100, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 935, \"PID\": 909451140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 561.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 936, \"PID\": 909451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 937, \"PID\": 909452050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13607, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 118.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208000}, {\"Order\": 938, \"PID\": 909475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17597, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1971, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 419.0, \"BsmtUnfSF\": 581.0, \"TotalBsmtSF\": 1803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2365, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 939, \"PID\": 909475300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1988, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 808.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 182, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 940, \"PID\": 910202070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 10690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 941, \"PID\": 910204050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 760.0, \"TotalBsmtSF\": 760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 928, \"LowQualFinSF\": 312, \"GrLivArea\": 2168, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 160, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 942, \"PID\": 910205020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 596, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 189.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 943, \"PID\": 911103050, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 105.0, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1915, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1013.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 513, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85000}, {\"Order\": 944, \"PID\": 911104060, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 72, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 945, \"PID\": 911370500, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230000}, {\"Order\": 946, \"PID\": 912251110, \"MSSubClass\": 30, \"MSZoning\": \"I (all)\", \"LotFrontage\": 109.0, \"LotArea\": 21780, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 119, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 57625}, {\"Order\": 947, \"PID\": 914465020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 250.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 948, \"PID\": 914465040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 2149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 239686}, {\"Order\": 949, \"PID\": 914465055, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1710.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 950, \"PID\": 914474070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 12209, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 1157, \"LowQualFinSF\": 0, \"GrLivArea\": 1961, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 951, \"PID\": 914475010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 926, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156450}, {\"Order\": 952, \"PID\": 914475030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 953, \"PID\": 914476020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 954, \"PID\": 914476380, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9947, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 955, \"PID\": 914476430, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 55.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1527.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 152000}, {\"Order\": 956, \"PID\": 916176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSeWa\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 541.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 118, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 233, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 957, \"PID\": 916176125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 215245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 820.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 958, \"PID\": 916380070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1022.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315500}, {\"Order\": 959, \"PID\": 916382010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224500}, {\"Order\": 960, \"PID\": 916382100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 13438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 2190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 780.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 961, \"PID\": 916382110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 406.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1115.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316500}, {\"Order\": 962, \"PID\": 916386140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 963, \"PID\": 916403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 387.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1412, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 964, \"PID\": 916403200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2237, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 965, \"PID\": 916403250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 14419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 624.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 1645.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 966, \"PID\": 916455070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 967, \"PID\": 916460110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 968, \"PID\": 916475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14601, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 584.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 578.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 969, \"PID\": 921128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1640.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 308, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 425000}, {\"Order\": 970, \"PID\": 923201100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 971, \"PID\": 923202060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1771, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 972, \"PID\": 923203110, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 247, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 973, \"PID\": 923203190, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 883.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 974, \"PID\": 923225360, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 975, \"PID\": 923225490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 9858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 33, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 976, \"PID\": 923226270, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 515.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 977, \"PID\": 923227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13383, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1404, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 978, \"PID\": 923228110, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 979, \"PID\": 923228150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 980, \"PID\": 923228230, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 981, \"PID\": 923230200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7689, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 76.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131900}, {\"Order\": 982, \"PID\": 923252075, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7706, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131250}, {\"Order\": 983, \"PID\": 923275040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1097.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 602.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 303, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 984, \"PID\": 923275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 985, \"PID\": 923276260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 718.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 883, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 883, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 698.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 986, \"PID\": 923400025, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 566, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 320, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 987, \"PID\": 923400110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10429, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 988, \"PID\": 924100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1567.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 989, \"PID\": 924100060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 496.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 368, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 990, \"PID\": 526351030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 411.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 601.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 190, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 991, \"PID\": 526353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1205.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237500}, {\"Order\": 992, \"PID\": 526354070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 2112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206900}, {\"Order\": 993, \"PID\": 527105050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 994, \"PID\": 527106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 995, \"PID\": 527106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 996, \"PID\": 527106150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 997, \"PID\": 527107010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 998, \"PID\": 527107090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 898.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177900}, {\"Order\": 999, \"PID\": 527107210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 21872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1446, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 406.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1000, \"PID\": 527127140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1593.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1593, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 1001, \"PID\": 527131110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 6264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247900}, {\"Order\": 1002, \"PID\": 527140090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1003, \"PID\": 527145090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1280.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1004, \"PID\": 527161010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 926.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1005, \"PID\": 527162180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 183000}, {\"Order\": 1006, \"PID\": 527163100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1007, \"PID\": 527164120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1895, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 1008, \"PID\": 527165010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1009, \"PID\": 527183030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1010, \"PID\": 527183060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 5950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1011, \"PID\": 527208010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 13543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 1012, \"PID\": 527212050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1122.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 1370, \"LowQualFinSF\": 0, \"GrLivArea\": 2504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1013, \"PID\": 527214030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 15401, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 547.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 387000}, {\"Order\": 1014, \"PID\": 527226020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 31220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 2, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1474, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 750, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1015, \"PID\": 527252080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1034.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 557.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 1016, \"PID\": 527276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 47280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1488.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 133000}, {\"Order\": 1017, \"PID\": 527301170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 20544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 791.0, \"TotalBsmtSF\": 791.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 2093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1018, \"PID\": 527301245, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 983.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 1675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1688, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 141, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1019, \"PID\": 527302050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 228.0, \"BsmtUnfSF\": 606.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1020, \"PID\": 527302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1021, \"PID\": 527302185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 18559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 186.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 2048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1022, \"PID\": 527302210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 449.0, \"BsmtUnfSF\": 469.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 1023, \"PID\": 527325070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 424.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 896.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 550, \"OpenPorchSF\": 282, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 1024, \"PID\": 527325240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 48.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 1211.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 174, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1025, \"PID\": 527326130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1026, \"PID\": 527354160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 2044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1027, \"PID\": 527357110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9743, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146900}, {\"Order\": 1028, \"PID\": 527357180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12511, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1420, \"2ndFlrSF\": 1420, \"LowQualFinSF\": 0, \"GrLivArea\": 2840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1314.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 208, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 292500}, {\"Order\": 1029, \"PID\": 527358120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 11361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1193.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1523, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1030, \"PID\": 527359030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1444.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1031, \"PID\": 527359070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1032, \"PID\": 527378020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1033, \"PID\": 527380240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1236.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 787.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 180, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 1034, \"PID\": 527401130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1035, \"PID\": 527402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 438.0, \"BsmtUnfSF\": 14.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 80, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1036, \"PID\": 527402130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 16, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111900}, {\"Order\": 1037, \"PID\": 527403360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 613.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1038, \"PID\": 527425035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111250}, {\"Order\": 1039, \"PID\": 527427110, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1040, \"PID\": 527450110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103400}, {\"Order\": 1041, \"PID\": 527450250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1042, \"PID\": 527450520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 411, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100500}, {\"Order\": 1043, \"PID\": 527451060, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 127.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1044, \"PID\": 527451290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85400}, {\"Order\": 1045, \"PID\": 527451400, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 604.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1046, \"PID\": 527451550, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111750}, {\"Order\": 1047, \"PID\": 527452150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 559.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1048, \"PID\": 527453160, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 286.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 275.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1049, \"PID\": 527454120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 1050, \"PID\": 527455270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1051, \"PID\": 528102030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12444, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 426.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 304, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394617}, {\"Order\": 1052, \"PID\": 528102110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 590, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 426000}, {\"Order\": 1053, \"PID\": 528104050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 816.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 442.0, \"TotalBsmtSF\": 2078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2084, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 385000}, {\"Order\": 1054, \"PID\": 528104080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 14948, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 1237, \"LowQualFinSF\": 0, \"GrLivArea\": 2713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 858.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 446261}, {\"Order\": 1055, \"PID\": 528108150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 317500}, {\"Order\": 1056, \"PID\": 528110080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 436.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372402}, {\"Order\": 1057, \"PID\": 528110110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1728.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 2418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 358, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 417500}, {\"Order\": 1058, \"PID\": 528114040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 14418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 1950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 383000}, {\"Order\": 1059, \"PID\": 528118030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 2748, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 390000}, {\"Order\": 1060, \"PID\": 528118090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12539, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 468.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 1158, \"LowQualFinSF\": 0, \"GrLivArea\": 2790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1150.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 460000}, {\"Order\": 1061, \"PID\": 528120130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12151, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2331, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1003.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 379000}, {\"Order\": 1062, \"PID\": 528142020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 908.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1063, \"PID\": 528142140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1162, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316000}, {\"Order\": 1064, \"PID\": 528164060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 680.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 2535.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2470, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2470, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 144, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 615000}, {\"Order\": 1065, \"PID\": 528166120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 664.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 1096, \"LowQualFinSF\": 0, \"GrLivArea\": 2668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 412500}, {\"Order\": 1066, \"PID\": 528170070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1067, \"PID\": 528172080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 454.0, \"TotalBsmtSF\": 1603.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1068, \"PID\": 528178070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 16900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1075.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1515, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2649, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 421250}, {\"Order\": 1069, \"PID\": 528178090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 16451, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 221.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1765.0, \"TotalBsmtSF\": 1765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1804, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1070, \"PID\": 528180110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1486.0, \"TotalBsmtSF\": 1858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336860}, {\"Order\": 1071, \"PID\": 528180140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 766.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 367294}, {\"Order\": 1072, \"PID\": 528181010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 135.0, \"LotArea\": 12304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1347.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1367, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1073, \"PID\": 528186030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 12677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1074, \"PID\": 528186080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 616.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1684, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1684, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 495, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266000}, {\"Order\": 1075, \"PID\": 528186130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 8232, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 714.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370967}, {\"Order\": 1076, \"PID\": 528186160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234250}, {\"Order\": 1077, \"PID\": 528186170, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1318.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1078, \"PID\": 528188090, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1079, \"PID\": 528188150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 1080, \"PID\": 528190010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1081, \"PID\": 528228345, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1073.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 1415.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1455, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1455, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1082, \"PID\": 528228405, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1087.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219990}, {\"Order\": 1083, \"PID\": 528228445, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1084, \"PID\": 528228465, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159895}, {\"Order\": 1085, \"PID\": 528228540, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1146.0, \"TotalBsmtSF\": 1146.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 428.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187687}, {\"Order\": 1086, \"PID\": 528235020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1515, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1087, \"PID\": 528235120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7415, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 759.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 839.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1088, \"PID\": 528235180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1166, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1089, \"PID\": 528240040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 8029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1090, \"PID\": 528240050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1091, \"PID\": 528250030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8396, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1139, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1092, \"PID\": 528253020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 217300}, {\"Order\": 1093, \"PID\": 528280130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1094, \"PID\": 528280180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 647.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226750}, {\"Order\": 1095, \"PID\": 528290010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 15384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1096, \"PID\": 528290090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1097, \"PID\": 528292060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12460, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1098, \"PID\": 528294060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 873, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1099, \"PID\": 528315060, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1173.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284500}, {\"Order\": 1100, \"PID\": 528315110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1470, \"2ndFlrSF\": 1160, \"LowQualFinSF\": 0, \"GrLivArea\": 2630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 696.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 1101, \"PID\": 528326030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 14260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 1053, \"LowQualFinSF\": 0, \"GrLivArea\": 2198, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1102, \"PID\": 528326110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1519.0, \"TotalBsmtSF\": 1519.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 687.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 1103, \"PID\": 528346050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 136.0, \"LotArea\": 11675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 495.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2006, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1104, \"PID\": 528354100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 1061, \"LowQualFinSF\": 0, \"GrLivArea\": 2125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 1105, \"PID\": 528363020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1242.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1250, \"LowQualFinSF\": 0, \"GrLivArea\": 2501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1106, \"PID\": 528363110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10437, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 2109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 236, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1107, \"PID\": 528365060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 651.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1311.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 1093, \"LowQualFinSF\": 0, \"GrLivArea\": 2418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 983.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 154, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 341000}, {\"Order\": 1108, \"PID\": 528365080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 852.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2197, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 783.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 385, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287500}, {\"Order\": 1109, \"PID\": 528387050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 448.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 904, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1110, \"PID\": 528390020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 1986.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1987, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301500}, {\"Order\": 1111, \"PID\": 528427010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11932, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 830.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235128}, {\"Order\": 1112, \"PID\": 528427070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14598, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 74.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 1039, \"LowQualFinSF\": 0, \"GrLivArea\": 1933, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1113, \"PID\": 528429050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1574, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 824.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 1114, \"PID\": 528429070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13253, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1115, \"PID\": 528429080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264132}, {\"Order\": 1116, \"PID\": 528431060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 468.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 33.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1563.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1563, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1563, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1117, \"PID\": 528431080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 12274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1417.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227680}, {\"Order\": 1118, \"PID\": 528431120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1341.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 851.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 1119, \"PID\": 528435020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 919, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 297900}, {\"Order\": 1120, \"PID\": 528439010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1460.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1460, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1460, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247000}, {\"Order\": 1121, \"PID\": 528458030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1363.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212700}, {\"Order\": 1122, \"PID\": 528458050, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1372.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250580}, {\"Order\": 1123, \"PID\": 528462040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 95.0, \"LotArea\": 11639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1428.0, \"TotalBsmtSF\": 1428.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 182000}, {\"Order\": 1124, \"PID\": 528477040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226700}, {\"Order\": 1125, \"PID\": 528478030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 768.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1053.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 939, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1126, \"PID\": 528478040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 932, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1127, \"PID\": 528480060, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1034.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 1028, \"LowQualFinSF\": 0, \"GrLivArea\": 2078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 339750}, {\"Order\": 1128, \"PID\": 528480160, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 843, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 562.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205950}, {\"Order\": 1129, \"PID\": 528482020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1660.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1130, \"PID\": 528488140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230348}, {\"Order\": 1131, \"PID\": 528490080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 64.0, \"LotArea\": 8791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 361.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 673.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1132, \"PID\": 531363060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1133, \"PID\": 531371070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 555.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 861, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1134, \"PID\": 531373060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 1135, \"PID\": 531375050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1136, \"PID\": 531375110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1137, \"PID\": 531375120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1138, \"PID\": 531376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1139, \"PID\": 531376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1162.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1162, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1140, \"PID\": 531382090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 362.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1141, \"PID\": 531382110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 886.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 794, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1142, \"PID\": 531382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 258.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1679, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1679, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 1143, \"PID\": 531384030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 14565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 537.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1144, \"PID\": 531385060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1677, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190500}, {\"Order\": 1145, \"PID\": 531450030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 439.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1146, \"PID\": 531450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1147, \"PID\": 531450170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1148, \"PID\": 531451020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 165.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1617, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1617, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1149, \"PID\": 531452140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 899.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1199, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1150, \"PID\": 532351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 53.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 799.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1151, \"PID\": 532353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12968, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1152, \"PID\": 532354150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 764.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1153, \"PID\": 532376170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 890.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 890, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 890, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1154, \"PID\": 532377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119916}, {\"Order\": 1155, \"PID\": 532378200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1156, \"PID\": 532477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 19508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 108, \"EnclosedPorch\": 165, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1157, \"PID\": 532479020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 811.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 92, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1158, \"PID\": 533125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 1319, \"LowQualFinSF\": 0, \"GrLivArea\": 2683, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 251, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1159, \"PID\": 533125140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1328.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1827, \"2ndFlrSF\": 959, \"LowQualFinSF\": 0, \"GrLivArea\": 2786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372500}, {\"Order\": 1160, \"PID\": 533206050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 59.0, \"LotArea\": 4282, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1391, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 1161, \"PID\": 533208080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4017, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171900}, {\"Order\": 1162, \"PID\": 533208140, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3435, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1211.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 1163, \"PID\": 533212050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1164, \"PID\": 533212140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1165, \"PID\": 533212150, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3604, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1166, \"PID\": 533213070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179400}, {\"Order\": 1167, \"PID\": 533213120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 194.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 792, \"LowQualFinSF\": 0, \"GrLivArea\": 1549, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172900}, {\"Order\": 1168, \"PID\": 533215020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1027.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 587.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1638, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1169, \"PID\": 533215030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4538, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 179.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1170, \"PID\": 533215040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 42.0, \"LotArea\": 4385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1171, \"PID\": 533215070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1557.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1172, \"PID\": 533215080, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 50.0, \"LotArea\": 5119, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1709, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 97, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"CWD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 328900}, {\"Order\": 1173, \"PID\": 533217050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 628, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1174, \"PID\": 533217060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 20, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1175, \"PID\": 533234020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 79.0, \"LotArea\": 10646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 1789, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 1176, \"PID\": 533236060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1177, \"PID\": 533236070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 147.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1607, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1178, \"PID\": 533236090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 36.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 128.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 842.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1469, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2393, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 94, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 1179, \"PID\": 533250050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 14963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245500}, {\"Order\": 1180, \"PID\": 533250110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 22.0, \"LotArea\": 11064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1230.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1239, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1239, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 1181, \"PID\": 533250160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 32.0, \"LotArea\": 10846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1719.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1719, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1719, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 1182, \"PID\": 533251120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1183, \"PID\": 533350090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1050.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 584.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1599, \"2ndFlrSF\": 1345, \"LowQualFinSF\": 0, \"GrLivArea\": 2944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 70, \"EnclosedPorch\": 16, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1184, \"PID\": 533350120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 16280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1044.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 382.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1426.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1185, \"PID\": 534104100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 469.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1186, \"PID\": 534126090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1304.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 98, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1187, \"PID\": 534127210, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1427, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1188, \"PID\": 534127230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1439.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1189, \"PID\": 534128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1190, \"PID\": 534129060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 62, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1191, \"PID\": 534175140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1625.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1192, \"PID\": 534177180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1522.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 1066, \"LowQualFinSF\": 0, \"GrLivArea\": 2614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 243, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1193, \"PID\": 534201240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1194, \"PID\": 534202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1195, \"PID\": 534204030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 456.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1196, \"PID\": 534225110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1728.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1197, \"PID\": 534225120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1497.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142600}, {\"Order\": 1198, \"PID\": 534250010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 9246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 564.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1199, \"PID\": 534250335, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1200, \"PID\": 534250370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 1540, \"LowQualFinSF\": 0, \"GrLivArea\": 2715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 299800}, {\"Order\": 1201, \"PID\": 534250410, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 933, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1202, \"PID\": 534251280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 800, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1203, \"PID\": 534252090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 867.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178400}, {\"Order\": 1204, \"PID\": 534252270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1205, \"PID\": 534276190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7785, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 267.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1206, \"PID\": 534277060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 619.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109008}, {\"Order\": 1207, \"PID\": 534277070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135750}, {\"Order\": 1208, \"PID\": 534400030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 20, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1209, \"PID\": 534400060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 407, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 1210, \"PID\": 534401130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1165, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 129, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174900}, {\"Order\": 1211, \"PID\": 534401190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 892.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 426, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1212, \"PID\": 534403050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 305.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1213, \"PID\": 534403080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 1219.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1265, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 96, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1214, \"PID\": 534403100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 336.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1215, \"PID\": 534403260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 164, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1216, \"PID\": 534426040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 806.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 1217, \"PID\": 534427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10721, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 243.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1252.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1218, \"PID\": 534428020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12493, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 306.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1219, \"PID\": 534428100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1118.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1220, \"PID\": 534451080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Floor\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72500}, {\"Order\": 1221, \"PID\": 534451170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52000}, {\"Order\": 1222, \"PID\": 534452060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 4, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1223, \"PID\": 534453140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 453, \"2ndFlrSF\": 453, \"LowQualFinSF\": 0, \"GrLivArea\": 906, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 1224, \"PID\": 534455030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1225, \"PID\": 534477080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 220, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 1226, \"PID\": 534477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 32.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 308.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1227, \"PID\": 534477270, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 377.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 178, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1228, \"PID\": 534479150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 505.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112900}, {\"Order\": 1229, \"PID\": 535103050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 273, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201800}, {\"Order\": 1230, \"PID\": 535104020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 491.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1231, \"PID\": 535105030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139950}, {\"Order\": 1232, \"PID\": 535105060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1962, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 237.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1319.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1233, \"PID\": 535105090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 9150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1234, \"PID\": 535126140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 529.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 230, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1235, \"PID\": 535150210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 151.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 1098.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1236, \"PID\": 535150280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 25.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 872.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1237, \"PID\": 535151160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1283, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1283, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1238, \"PID\": 535152200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8856, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 52.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1239, \"PID\": 535153140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1240, \"PID\": 535153150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1261.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1261, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1261, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1400, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1241, \"PID\": 535176100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 187.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1570, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1570, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 490, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166800}, {\"Order\": 1242, \"PID\": 535178060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 580.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1243, \"PID\": 535179060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 387.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 458.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 1244, \"PID\": 535180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 135.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 130, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1245, \"PID\": 535180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1104, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1246, \"PID\": 535301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1247, \"PID\": 535302130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 196.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1248, \"PID\": 535302140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1249, \"PID\": 535303030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 14250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 998.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1250, \"PID\": 535305030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 852.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 1251, \"PID\": 535305160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 773, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 1252, \"PID\": 535327230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1253, \"PID\": 535352080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 1254, \"PID\": 535354200, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1255, \"PID\": 535375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 66, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89900}, {\"Order\": 1256, \"PID\": 535375160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 7506, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1257, \"PID\": 535380050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10930, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1258, \"PID\": 535380110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 1259, \"PID\": 535380140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 182, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 1488.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1260, \"PID\": 535383100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 694, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 114, \"EnclosedPorch\": 210, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106250}, {\"Order\": 1261, \"PID\": 535402120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9247, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 539.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1262, \"PID\": 535403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1263, \"PID\": 535425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Othr\", \"MiscVal\": 6500, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 1264, \"PID\": 535426260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1253.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 213, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1265, \"PID\": 535426350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 276.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1081.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1081, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 401.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1266, \"PID\": 535427070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 27650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2069, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 1267, \"PID\": 535451010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 910, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 414.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1268, \"PID\": 535451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 94000}, {\"Order\": 1269, \"PID\": 535451230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98300}, {\"Order\": 1270, \"PID\": 535452120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1507, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1507, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1271, \"PID\": 535453020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 488.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1272, \"PID\": 535453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 319.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125900}, {\"Order\": 1273, \"PID\": 535453210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 532.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1269.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1274, \"PID\": 535454150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 453.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 501, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1275, \"PID\": 535455060, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1276, \"PID\": 535455080, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 1277, \"PID\": 535455090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 181.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1278, \"PID\": 535456050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 8513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1279, \"PID\": 535456070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1280, \"PID\": 535456100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1281, \"PID\": 535475020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 415.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1282, \"PID\": 535476370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 106.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 1283, \"PID\": 535477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136870}, {\"Order\": 1284, \"PID\": 902100020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 96.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143000}, {\"Order\": 1285, \"PID\": 902100030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 30.0, \"LotArea\": 5232, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 1286, \"PID\": 902102060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1904, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 78, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1287, \"PID\": 902103150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9184, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 375, \"LowQualFinSF\": 0, \"GrLivArea\": 1323, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122600}, {\"Order\": 1288, \"PID\": 902105010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 680, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 1289, \"PID\": 902105020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 547, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 480, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1150, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1290, \"PID\": 902105130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1291, \"PID\": 902107030, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1292, \"PID\": 902109080, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 828.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 828, \"2ndFlrSF\": 658, \"LowQualFinSF\": 108, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 109, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1293, \"PID\": 902109110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 2082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1294, \"PID\": 902109120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 561, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119164}, {\"Order\": 1295, \"PID\": 902109160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 7308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122250}, {\"Order\": 1296, \"PID\": 902128075, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 931.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1297, \"PID\": 902128150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 590.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 552, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1298, \"PID\": 902134100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6756, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 481.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 1299, \"PID\": 902136110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 5914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 396, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 165, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1300, \"PID\": 902201120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 169.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 115000}, {\"Order\": 1301, \"PID\": 902201140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 608.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1302, \"PID\": 902202090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 904.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 869.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1303, \"PID\": 902205070, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 407.0, \"TotalBsmtSF\": 407.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 407, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 407, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 46500}, {\"Order\": 1304, \"PID\": 902205090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 620.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1305, \"PID\": 902205140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 901, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107900}, {\"Order\": 1306, \"PID\": 902207120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 103.0, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 1, \"YearBuilt\": 1949, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 65000}, {\"Order\": 1307, \"PID\": 902207220, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 87.0, \"LotArea\": 18386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1880, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1470.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 1818, \"LowQualFinSF\": 0, \"GrLivArea\": 3493, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295000}, {\"Order\": 1308, \"PID\": 902300110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 797.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 830, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1627, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1309, \"PID\": 902300215, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 540, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 418, \"OpenPorchSF\": 0, \"EnclosedPorch\": 194, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1310, \"PID\": 902300260, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 730, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1311, \"PID\": 902301140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 34.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 513.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98000}, {\"Order\": 1312, \"PID\": 902301150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9143, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 709, \"2ndFlrSF\": 308, \"LowQualFinSF\": 0, \"GrLivArea\": 1017, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 139, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1313, \"PID\": 902304060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 973, \"LowQualFinSF\": 0, \"GrLivArea\": 2350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 219, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1314, \"PID\": 902305080, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2058, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 259, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1315, \"PID\": 902306120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1905, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129400}, {\"Order\": 1316, \"PID\": 902306130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1928, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1317, \"PID\": 902326060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1905, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 691, \"LowQualFinSF\": 0, \"GrLivArea\": 1912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1318, \"PID\": 902328040, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 291, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1319, \"PID\": 902330010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5250, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1872, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 205, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 1320, \"PID\": 902401010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 572, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1321, \"PID\": 902401120, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1893, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1521, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 880.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 502, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1322, \"PID\": 902402260, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 2, \"OverallCond\": 1, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 723, \"2ndFlrSF\": 363, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1323, \"PID\": 902405070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 299, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1324, \"PID\": 902406020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1325, \"PID\": 902406090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1050.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 1326, \"PID\": 902427045, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 12702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 1327, \"PID\": 902427150, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8516, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 869.0, \"TotalBsmtSF\": 869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115500}, {\"Order\": 1328, \"PID\": 903201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7111, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1329, \"PID\": 903204010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 1330, \"PID\": 903204095, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 156, \"GrLivArea\": 935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 1331, \"PID\": 903206070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 175.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 594, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1332, \"PID\": 903225050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1333, \"PID\": 903225140, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1334, \"PID\": 903225160, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 554, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106900}, {\"Order\": 1335, \"PID\": 903226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 658, \"LowQualFinSF\": 0, \"GrLivArea\": 1672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 1336, \"PID\": 903226150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 949.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1337, \"PID\": 903227080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 862.0, \"TotalBsmtSF\": 862.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 208.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1338, \"PID\": 903228040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 201.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1497, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1339, \"PID\": 903228060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1340, \"PID\": 903228090, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 992.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1013, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 101, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1341, \"PID\": 903230110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 565, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1342, \"PID\": 903230120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 99.0, \"LotArea\": 5940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": null, \"BsmtFinType2\": null, \"BsmtFinSF2\": null, \"BsmtUnfSF\": null, \"TotalBsmtSF\": null, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79000}, {\"Order\": 1343, \"PID\": 903231080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 365, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1344, \"PID\": 903232030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81300}, {\"Order\": 1345, \"PID\": 903232090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1078.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 1346, \"PID\": 903233080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 989.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1347, \"PID\": 903234090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 897.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 139, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 1348, \"PID\": 903234100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129900}, {\"Order\": 1349, \"PID\": 903235010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 611.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1350, \"PID\": 903235100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 87, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68500}, {\"Order\": 1351, \"PID\": 903236010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 213, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1352, \"PID\": 903400180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 13053, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 220, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1353, \"PID\": 903401020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1354, \"PID\": 903401030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1355, \"PID\": 903401050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 883.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1356, \"PID\": 903425420, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 606.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1357, \"PID\": 903426160, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1000, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1358, \"PID\": 903427090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5100, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1359, \"PID\": 903429010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 4347, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1360, \"PID\": 903452025, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6291, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93850}, {\"Order\": 1361, \"PID\": 903453050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10266, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 216, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 136000}, {\"Order\": 1362, \"PID\": 903454100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1272.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 0, \"LowQualFinSF\": 697, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1363, \"PID\": 903455030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 428, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 117, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1364, \"PID\": 903455140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1365, \"PID\": 903456130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 647.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 127000}, {\"Order\": 1366, \"PID\": 903458110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 371, \"LowQualFinSF\": 0, \"GrLivArea\": 1406, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1367, \"PID\": 903475020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 645.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1368, \"PID\": 903476110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5586, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 110, \"LowQualFinSF\": 0, \"GrLivArea\": 1198, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79900}, {\"Order\": 1369, \"PID\": 903481010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 451.0, \"TotalBsmtSF\": 451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 759, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Family\", \"SalePrice\": 85000}, {\"Order\": 1370, \"PID\": 903481100, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 808, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 204, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82375}, {\"Order\": 1371, \"PID\": 903484020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1906, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 1469, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1906.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 57, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1372, \"PID\": 904100020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 122, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 1373, \"PID\": 904100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 1374, \"PID\": 904100160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 21286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1271, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1375, \"PID\": 904101170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134432}, {\"Order\": 1376, \"PID\": 904351280, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10106, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 181.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 547, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1377, \"PID\": 905100020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 64, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 148000}, {\"Order\": 1378, \"PID\": 905102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 906.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1379, \"PID\": 905103030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 39.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1380, \"PID\": 905104080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109900}, {\"Order\": 1381, \"PID\": 905104110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1382, \"PID\": 905104180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 702.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1383, \"PID\": 905107280, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 311, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1384, \"PID\": 905107380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9981, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 221.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 852.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1385, \"PID\": 905108170, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 956.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1386, \"PID\": 905200090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1198.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 108959}, {\"Order\": 1387, \"PID\": 905200100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 95541}, {\"Order\": 1388, \"PID\": 905200160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 1006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1006, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 1389, \"PID\": 905200510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149350}, {\"Order\": 1390, \"PID\": 905201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 634.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 1391, \"PID\": 905201110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 102, \"OpenPorchSF\": 89, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1392, \"PID\": 905201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1064.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 354.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 511, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1393, \"PID\": 905202230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 429.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1080.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 409, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1394, \"PID\": 905225040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1021, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1395, \"PID\": 905226030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1396, \"PID\": 905226110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1397, \"PID\": 905227050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 486, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152400}, {\"Order\": 1398, \"PID\": 905300020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1399, \"PID\": 905351089, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1003.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1291.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1291, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1400, \"PID\": 905352030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 299.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 2022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 117, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1401, \"PID\": 905352070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 20270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1402, \"PID\": 905401045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 39104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Membran\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1063.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1403, \"PID\": 905401060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1663, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1404, \"PID\": 905402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 11512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1019.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1357, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1357, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 163, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1405, \"PID\": 905403060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 617, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1079, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 249.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125600}, {\"Order\": 1406, \"PID\": 905403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 287, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1407, \"PID\": 905425125, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 45600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 907.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1307, \"2ndFlrSF\": 1051, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1908.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1408, \"PID\": 905426030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"PreCast\", \"Exterior2nd\": \"PreCast\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1035.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1409, \"PID\": 905427050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1163.0, \"TotalBsmtSF\": 1163.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 511, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1410, \"PID\": 905427070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 2108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1411, \"PID\": 905451330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1509.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 576, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1412, \"PID\": 905452070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99600}, {\"Order\": 1413, \"PID\": 905452120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 621, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1414, \"PID\": 905476120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1415, \"PID\": 905477050, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 969.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 527, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 1416, \"PID\": 905479110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1417, \"PID\": 905480150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 572, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 8, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 1418, \"PID\": 905480240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 380.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1419, \"PID\": 906204150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1475.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1532, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2329, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262280}, {\"Order\": 1420, \"PID\": 906204280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9771, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 1721, \"LowQualFinSF\": 0, \"GrLivArea\": 2814, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1421, \"PID\": 906223110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 251.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1626, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1422, \"PID\": 906223140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 355.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 1099, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1423, \"PID\": 906223220, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 735, \"LowQualFinSF\": 0, \"GrLivArea\": 2037, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 1424, \"PID\": 906378190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 628.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177439}, {\"Order\": 1425, \"PID\": 906380030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1615.0, \"TotalBsmtSF\": 1615.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1615, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1615, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 1426, \"PID\": 906412010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 2271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2276, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1348.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 475000}, {\"Order\": 1427, \"PID\": 906412050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1751.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395039}, {\"Order\": 1428, \"PID\": 906420130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 531.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 187, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 1429, \"PID\": 906424010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 631.0, \"TotalBsmtSF\": 1401.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 811.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1430, \"PID\": 906475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1182.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1643, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1643, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 339, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1431, \"PID\": 906476030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12798, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 154.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 1072, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 403, \"OpenPorchSF\": 114, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1432, \"PID\": 907126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 722.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1433, \"PID\": 907135020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1099.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1099, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1099, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1434, \"PID\": 907135260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1435, \"PID\": 907175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226001}, {\"Order\": 1436, \"PID\": 907176010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 688.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 899, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215700}, {\"Order\": 1437, \"PID\": 907181120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 782, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1438, \"PID\": 907181140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 873.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 193000}, {\"Order\": 1439, \"PID\": 907187030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1440, \"PID\": 907187080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 9382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1441, \"PID\": 907192130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 1442, \"PID\": 907194020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 963.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 963, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 245, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 1443, \"PID\": 907196040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1823, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 4500, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1444, \"PID\": 907196050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 1445, \"PID\": 907200110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 491.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 938, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130250}, {\"Order\": 1446, \"PID\": 907201060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 328.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 1447, \"PID\": 907202010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1174, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 211, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1448, \"PID\": 907202160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1449, \"PID\": 907202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1076, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143195}, {\"Order\": 1450, \"PID\": 907202240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 88.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1558, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1451, \"PID\": 907203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 7990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1452, \"PID\": 907227050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1453, \"PID\": 907227300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 780, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 1454, \"PID\": 907250020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1777.0, \"TotalBsmtSF\": 1777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 159, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1455, \"PID\": 907251090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9473, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 903, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 1456, \"PID\": 907253060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 257.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1457, \"PID\": 907253110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 1458, \"PID\": 907254020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9066, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 106, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1459, \"PID\": 907254090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 1460, \"PID\": 907255020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 396.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287000}, {\"Order\": 1461, \"PID\": 907255030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1357.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1366, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1462, \"PID\": 907255060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1786, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 715.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1463, \"PID\": 907260010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 1141, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 1464, \"PID\": 907262030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 334.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 1465, \"PID\": 907262060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 10905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1129.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1129, \"2ndFlrSF\": 1198, \"LowQualFinSF\": 0, \"GrLivArea\": 2327, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1466, \"PID\": 907262070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 595.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1467, \"PID\": 907265100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1468, \"PID\": 907285080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 642.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 933, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1469, \"PID\": 907290150, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1470, \"PID\": 907290250, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1471, \"PID\": 907295020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 215.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1493, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1493, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208900}, {\"Order\": 1472, \"PID\": 907295100, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 83.0, \"LotArea\": 10126, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1593.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 1473, \"PID\": 907405020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 726.0, \"TotalBsmtSF\": 1536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1536, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1474, \"PID\": 907405140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 854, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208500}, {\"Order\": 1475, \"PID\": 907412040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1421.0, \"TotalBsmtSF\": 1445.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1476, \"PID\": 907412070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 946.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 139, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1477, \"PID\": 907412080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 770, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1478, \"PID\": 907412090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1234, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1479, \"PID\": 907418010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1508.0, \"TotalBsmtSF\": 1564.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218836}, {\"Order\": 1480, \"PID\": 907418040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1327.0, \"TotalBsmtSF\": 1351.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1481, \"PID\": 907420080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1482, \"PID\": 907425010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149300}, {\"Order\": 1483, \"PID\": 907425015, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1484, \"PID\": 907425030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1485, \"PID\": 907425035, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 1486, \"PID\": 908102030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1487, \"PID\": 908102040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 928, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145900}, {\"Order\": 1488, \"PID\": 908102140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 259, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 123000}, {\"Order\": 1489, \"PID\": 908102260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 830.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 736, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1490, \"PID\": 908103260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 12102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 222.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1033, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1033, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 165000}, {\"Order\": 1491, \"PID\": 908103280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1033.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1127, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1492, \"PID\": 908127120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1493, \"PID\": 908128050, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 38.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1181, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1181, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1494, \"PID\": 908128110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 92.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165400}, {\"Order\": 1495, \"PID\": 908151040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 120.0, \"BsmtUnfSF\": 541.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1496, \"PID\": 908152110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1497, \"PID\": 908152270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1132.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1498, \"PID\": 908154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 123.0, \"LotArea\": 47007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3820, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3820, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 372, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284700}, {\"Order\": 1499, \"PID\": 908154235, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 63887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"ClyTile\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 796.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 5644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 6110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 4692, \"2ndFlrSF\": 950, \"LowQualFinSF\": 0, \"GrLivArea\": 5642, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 1418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 292, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 480, \"PoolQC\": \"Gd\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 160000}, {\"Order\": 1500, \"PID\": 908186040, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 459.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1501, \"PID\": 908201100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1502, \"PID\": 908201110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1503, \"PID\": 908201120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1307.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1504, \"PID\": 908204160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 1505, \"PID\": 908225170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91900}, {\"Order\": 1506, \"PID\": 908226120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 585, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 120000}, {\"Order\": 1507, \"PID\": 908250040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 1508, \"PID\": 908250090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 134, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Gar2\", \"MiscVal\": 3000, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1509, \"PID\": 908275130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1510, \"PID\": 908275180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1511, \"PID\": 908275280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 521, \"LowQualFinSF\": 0, \"GrLivArea\": 1393, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 265, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 1512, \"PID\": 908276140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1513, \"PID\": 909100150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 343, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1514, \"PID\": 909100170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1515, \"PID\": 909101060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 41.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 823.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67000}, {\"Order\": 1516, \"PID\": 909101180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5687, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135900}, {\"Order\": 1517, \"PID\": 909131170, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 254, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1518, \"PID\": 909175050, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 720, \"LowQualFinSF\": 420, \"GrLivArea\": 2192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179500}, {\"Order\": 1519, \"PID\": 909175100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 423.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 758.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 304, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1520, \"PID\": 909177120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1521, \"PID\": 909201110, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 8525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1911, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 940.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1522, \"PID\": 909250040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 1611, \"LowQualFinSF\": 0, \"GrLivArea\": 2601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 183, \"OpenPorchSF\": 0, \"EnclosedPorch\": 301, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1523, \"PID\": 909250230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 679.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 161900}, {\"Order\": 1524, \"PID\": 909251080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8969, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 369.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1525, \"PID\": 909251090, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1423, \"2ndFlrSF\": 748, \"LowQualFinSF\": 384, \"GrLivArea\": 2555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1526, \"PID\": 909252110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1527, \"PID\": 909252220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15564, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1528, \"PID\": 909253190, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 1529, \"PID\": 909254050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7609, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 16, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 1530, \"PID\": 909256060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 473, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1531, \"PID\": 909275040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 599.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 217, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1532, \"PID\": 909275050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1533, \"PID\": 909276170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1934, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 389.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 849, \"2ndFlrSF\": 811, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188700}, {\"Order\": 1534, \"PID\": 909277040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 673, \"LowQualFinSF\": 0, \"GrLivArea\": 1938, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 1535, \"PID\": 909277070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 932, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1536, \"PID\": 909281030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 7801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 591.0, \"TotalBsmtSF\": 1091.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 344.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 221, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 1537, \"PID\": 909281110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 786.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 207, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 257076}, {\"Order\": 1538, \"PID\": 909282030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1935, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1968, \"2ndFlrSF\": 1479, \"LowQualFinSF\": 0, \"GrLivArea\": 3447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1014.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 381000}, {\"Order\": 1539, \"PID\": 909425010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 817, \"LowQualFinSF\": 0, \"GrLivArea\": 1954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 311500}, {\"Order\": 1540, \"PID\": 909425085, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 943, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263400}, {\"Order\": 1541, \"PID\": 909428170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 26073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1898.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1898, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 1542, \"PID\": 909428190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 568.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 924.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 1543, \"PID\": 909451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 366.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 213, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 1544, \"PID\": 909451150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 612.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1545, \"PID\": 910200080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 555.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 919, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1546, \"PID\": 910201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 330, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1547, \"PID\": 910202050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1548, \"PID\": 910202100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1549, \"PID\": 910203020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 71.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 125.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 778, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 924.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1550, \"PID\": 910203090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 780, \"2ndFlrSF\": 420, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1551, \"PID\": 910205010, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1552, \"PID\": 910206110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 1553, \"PID\": 910226040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1955, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1554, \"PID\": 910251050, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 80.0, \"LotArea\": 14584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Po\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 13100}, {\"Order\": 1555, \"PID\": 911102090, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 5280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1895, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1895.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 185.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 1556, \"PID\": 911102170, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 649, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1317, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 172, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 40000}, {\"Order\": 1557, \"PID\": 911102180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 52.0, \"LotArea\": 5150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 671, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80900}, {\"Order\": 1558, \"PID\": 911226010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 120.0, \"LotArea\": 18000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 560, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1559, \"PID\": 911226030, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 432, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 65000}, {\"Order\": 1560, \"PID\": 911370410, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 5587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392500}, {\"Order\": 1561, \"PID\": 911370490, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294464}, {\"Order\": 1562, \"PID\": 911370520, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1563, \"PID\": 911370540, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 1564, \"PID\": 914453045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 668.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2032, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1565, \"PID\": 914465060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 857.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1566, \"PID\": 914467050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 910.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 318, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1567, \"PID\": 914475020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 574.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 358.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 576, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1568, \"PID\": 914476010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 83, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 1569, \"PID\": 914476080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1570, \"PID\": 914476450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 428, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 1571, \"PID\": 916125425, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 164660, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 1499.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1619, \"2ndFlrSF\": 167, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 670, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228950}, {\"Order\": 1572, \"PID\": 916226030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 893.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1573, \"PID\": 916325080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15498, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1165.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 665.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 174, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 287000}, {\"Order\": 1574, \"PID\": 916380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 258.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1575, \"PID\": 916382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293077}, {\"Order\": 1576, \"PID\": 916384100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264966}, {\"Order\": 1577, \"PID\": 916386040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 712, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 1578, \"PID\": 916386080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": null, \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 1579, \"PID\": 916386180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 12018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 218689}, {\"Order\": 1580, \"PID\": 916402015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1495.0, \"TotalBsmtSF\": 1495.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1495, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1581, \"PID\": 916402115, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 12416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1398.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 208.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1582, \"PID\": 916402215, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 18265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1583, \"PID\": 916403230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 219.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 783.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1584, \"PID\": 916455120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11202, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1029.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 1432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232500}, {\"Order\": 1585, \"PID\": 916460060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7915, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1586, \"PID\": 916477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 2262, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 749.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1587, \"PID\": 921126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1011.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 873.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 276, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 298751}, {\"Order\": 1588, \"PID\": 921201060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1571.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 393.0, \"TotalBsmtSF\": 1964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 892.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1589, \"PID\": 923202005, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 97.0, \"LotArea\": 8940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 209200}, {\"Order\": 1590, \"PID\": 923202015, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 206300}, {\"Order\": 1591, \"PID\": 923202137, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9278, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1592, \"PID\": 923203140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 197.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 1189.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1189, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1189, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1593, \"PID\": 923204040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 171, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1594, \"PID\": 923225080, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 271.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1595, \"PID\": 923225150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1596, \"PID\": 923225200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 318.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1597, \"PID\": 923225310, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 501.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 526.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1598, \"PID\": 923225370, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 120, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94900}, {\"Order\": 1599, \"PID\": 923227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1160, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 257.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 1600, \"PID\": 923228080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1970, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1601, \"PID\": 923228420, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1602, \"PID\": 923250210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 988.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1603, \"PID\": 923252100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 6490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1604, \"PID\": 923275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 6951, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 362, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1605, \"PID\": 923277030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1982, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1606, \"PID\": 923277040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1982, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1607, \"PID\": 923277080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1608, \"PID\": 923400040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 983.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1300, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1609, \"PID\": 923426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 647.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 889, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1610, \"PID\": 924100020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 562.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 193.0, \"BsmtUnfSF\": 29.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1611, \"PID\": 1007100110, \"MSSubClass\": 70, \"MSZoning\": \"I (all)\", \"LotFrontage\": null, \"LotArea\": 56600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1612, \"PID\": 526352080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 838.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 749.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1587, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1587, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167300}, {\"Order\": 1613, \"PID\": 526352090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1277, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 526.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 1614, \"PID\": 526355170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 2223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2223, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2223, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 1615, \"PID\": 526355190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 15865, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 823.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 2217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 1616, \"PID\": 527105140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 225000}, {\"Order\": 1617, \"PID\": 527107040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 373.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1618, \"PID\": 527110080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 794, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1619, \"PID\": 527110120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 1620, \"PID\": 527110130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 1621, \"PID\": 527126030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 1622, \"PID\": 527158090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 770, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1623, \"PID\": 527161090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 947, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1624, \"PID\": 527162080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178750}, {\"Order\": 1625, \"PID\": 527162090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1626, \"PID\": 527162140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 957, \"2ndFlrSF\": 1342, \"LowQualFinSF\": 0, \"GrLivArea\": 2299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1627, \"PID\": 527163080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1168.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1628, \"PID\": 527165020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1629, \"PID\": 527165100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163900}, {\"Order\": 1630, \"PID\": 527165170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 903.0, \"TotalBsmtSF\": 903.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1631, \"PID\": 527175130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 18160, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 154204}, {\"Order\": 1632, \"PID\": 527182040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1633, \"PID\": 527182170, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1634, \"PID\": 527184020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 4740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1166.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 135, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1635, \"PID\": 527184110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 5118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 926.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1321, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1321, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 1636, \"PID\": 527210060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377426}, {\"Order\": 1637, \"PID\": 527212060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1377, \"LowQualFinSF\": 0, \"GrLivArea\": 2541, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 729.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 349265}, {\"Order\": 1638, \"PID\": 527216080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 51974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 710.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1101.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1559.0, \"TotalBsmtSF\": 2660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1110.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 591587}, {\"Order\": 1639, \"PID\": 527226040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 195.0, \"LotArea\": 41600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1047.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 53.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1640, \"PID\": 527252050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8035, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 797.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 164, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 1641, \"PID\": 527252070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8089, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 1642, \"PID\": 527256030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 945.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1558.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 2220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 441929}, {\"Order\": 1643, \"PID\": 527256040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 13870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 174, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 455000}, {\"Order\": 1644, \"PID\": 527301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 99, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182900}, {\"Order\": 1645, \"PID\": 527301280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1028.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1646, \"PID\": 527302020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 178000}, {\"Order\": 1647, \"PID\": 527302060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 167, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1648, \"PID\": 527302090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1328.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 1529.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1649, \"PID\": 527325090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 11339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 549.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 22.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1650, \"PID\": 527325110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11952, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1161, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 276, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1651, \"PID\": 527327050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12046, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 2030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1652, \"PID\": 527328020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 605.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1653, \"PID\": 527328050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1177, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1654, \"PID\": 527353080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 539.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 1655, \"PID\": 527354050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 253.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1259.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1353, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192350}, {\"Order\": 1656, \"PID\": 527356050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 263.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1657, \"PID\": 527357020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 13001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 249, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1658, \"PID\": 527358060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1659, \"PID\": 527359010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 175.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1660, \"PID\": 527359080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 1661, \"PID\": 527359160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 604.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 585.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 407, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1662, \"PID\": 527377110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 153.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1877, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 1663, \"PID\": 527402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 349.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 533, \"LowQualFinSF\": 0, \"GrLivArea\": 1109, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 35, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1664, \"PID\": 527402150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 35.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143250}, {\"Order\": 1665, \"PID\": 527402240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1972, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1666, \"PID\": 527403310, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1667, \"PID\": 527404050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 619.0, \"BsmtUnfSF\": 214.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1668, \"PID\": 527404100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 412.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1669, \"PID\": 527404140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8294, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1670, \"PID\": 527404150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 322.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1671, \"PID\": 527425025, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1672, \"PID\": 527425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1673, \"PID\": 527427090, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 139.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 767, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 367.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1674, \"PID\": 527427160, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 33.0, \"LotArea\": 4113, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1337.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1675, \"PID\": 527427200, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 10943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1676, \"PID\": 527450030, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 1677, \"PID\": 527450150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 356.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1678, \"PID\": 527450220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113700}, {\"Order\": 1679, \"PID\": 527451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2016, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1680, \"PID\": 527451170, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 376.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 1681, \"PID\": 527452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 958.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 205, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1682, \"PID\": 527453010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 556.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1683, \"PID\": 527455030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 6.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 1061.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 1684, \"PID\": 527455250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 725.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129250}, {\"Order\": 1685, \"PID\": 528102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12469, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1151.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1790.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356000}, {\"Order\": 1686, \"PID\": 528102090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 452.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1774.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 260, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 314813}, {\"Order\": 1687, \"PID\": 528102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1688, \"PID\": 528102120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 322400}, {\"Order\": 1689, \"PID\": 528102130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 328.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 730.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1690, \"PID\": 528104010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 2108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345474}, {\"Order\": 1691, \"PID\": 528106040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 315.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2121.0, \"TotalBsmtSF\": 2121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 415298}, {\"Order\": 1692, \"PID\": 528106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13641, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1304.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1934.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1943, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 2656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1040.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 492000}, {\"Order\": 1693, \"PID\": 528106060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1108.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 1402, \"LowQualFinSF\": 0, \"GrLivArea\": 2550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338931}, {\"Order\": 1694, \"PID\": 528106110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 400.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 450000}, {\"Order\": 1695, \"PID\": 528108160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 14154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1063.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1071, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 947.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 280000}, {\"Order\": 1696, \"PID\": 528110040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 2552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 479069}, {\"Order\": 1697, \"PID\": 528110070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 375.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1935.0, \"TotalBsmtSF\": 1935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1973, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1973, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395000}, {\"Order\": 1698, \"PID\": 528110100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 772.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2153.0, \"TotalBsmtSF\": 2153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 2643, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 694.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 380000}, {\"Order\": 1699, \"PID\": 528112150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1626.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1634, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1634, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1700, \"PID\": 528114050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14977, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 1976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 440000}, {\"Order\": 1701, \"PID\": 528118040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13654, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1704.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1722, \"2ndFlrSF\": 1036, \"LowQualFinSF\": 0, \"GrLivArea\": 2758, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 418000}, {\"Order\": 1702, \"PID\": 528118050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 17169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 970.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 2320.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1174.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 500067}, {\"Order\": 1703, \"PID\": 528120010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1582.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 570, \"LowQualFinSF\": 0, \"GrLivArea\": 2152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 368, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260116}, {\"Order\": 1704, \"PID\": 528120150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 317000}, {\"Order\": 1705, \"PID\": 528142050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9709, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319500}, {\"Order\": 1706, \"PID\": 528144050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325624}, {\"Order\": 1707, \"PID\": 528150040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 510.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1802.0, \"TotalBsmtSF\": 1802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1802, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372000}, {\"Order\": 1708, \"PID\": 528150110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 13069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 502.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1706.0, \"TotalBsmtSF\": 1706.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 1238, \"LowQualFinSF\": 0, \"GrLivArea\": 2956, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 916.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 342000}, {\"Order\": 1709, \"PID\": 528150120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 388.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 970.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 872.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 354000}, {\"Order\": 1710, \"PID\": 528166150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14277, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1317.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1711, \"PID\": 528168040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11999, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1712, \"PID\": 528172030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 669.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 895.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 895, \"2ndFlrSF\": 923, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281500}, {\"Order\": 1713, \"PID\": 528172050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1178.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245700}, {\"Order\": 1714, \"PID\": 528172070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9254, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1602.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232698}, {\"Order\": 1715, \"PID\": 528172075, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1298.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 876.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 1716, \"PID\": 528174010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194700}, {\"Order\": 1717, \"PID\": 528174020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3901, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204000}, {\"Order\": 1718, \"PID\": 528174030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 272.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1719, \"PID\": 528174040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 6289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1720, \"PID\": 528181060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1721, \"PID\": 528181070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1722, \"PID\": 528181080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 1723, \"PID\": 528186050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 7841, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 394.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 848.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 729.0, \"TotalBsmtSF\": 1577.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1577, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 1724, \"PID\": 528186090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 1725, \"PID\": 528186120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1869.0, \"TotalBsmtSF\": 1869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318061}, {\"Order\": 1726, \"PID\": 528186190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1300.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221370}, {\"Order\": 1727, \"PID\": 528188160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 235.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1728, \"PID\": 528218010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 15810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181755}, {\"Order\": 1729, \"PID\": 528218020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1730, \"PID\": 528218050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 783, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 178900}, {\"Order\": 1731, \"PID\": 528218100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 13204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 168165}, {\"Order\": 1732, \"PID\": 528221030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8857, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 757, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 171925}, {\"Order\": 1733, \"PID\": 528221040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9729, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 1048, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198444}, {\"Order\": 1734, \"PID\": 528221050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 918.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 1735, \"PID\": 528221090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179540}, {\"Order\": 1736, \"PID\": 528222030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 176485}, {\"Order\": 1737, \"PID\": 528222040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1340.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181134}, {\"Order\": 1738, \"PID\": 528222050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 796, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156932}, {\"Order\": 1739, \"PID\": 528222060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8229, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 22.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1740, \"PID\": 528222080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7713, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177594}, {\"Order\": 1741, \"PID\": 528222090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1246.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173500}, {\"Order\": 1742, \"PID\": 528228270, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172500}, {\"Order\": 1743, \"PID\": 528228275, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194201}, {\"Order\": 1744, \"PID\": 528228375, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3621, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1589, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1745, \"PID\": 528228555, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185485}, {\"Order\": 1746, \"PID\": 528231010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 182.0, \"LotArea\": 14572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 259000}, {\"Order\": 1747, \"PID\": 528231030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 16219, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1119, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1119, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1748, \"PID\": 528235000, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 175000}, {\"Order\": 1749, \"PID\": 528235160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11796, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1112, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1750, \"PID\": 528235170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1510.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 206580}, {\"Order\": 1751, \"PID\": 528240020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 1752, \"PID\": 528250010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1753, \"PID\": 528250070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 1754, \"PID\": 528275035, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1755, \"PID\": 528275110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 1131, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1756, \"PID\": 528280110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 694, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1757, \"PID\": 528280150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1758, \"PID\": 528290060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 1759, \"PID\": 528290170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1760, \"PID\": 528294010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9649, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1761, \"PID\": 528320050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 15623, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2411, \"2ndFlrSF\": 2065, \"LowQualFinSF\": 0, \"GrLivArea\": 4476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 813.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 555, \"PoolQC\": \"Ex\", \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 745000}, {\"Order\": 1762, \"PID\": 528322020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 515.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 2551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 384500}, {\"Order\": 1763, \"PID\": 528326060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 1288, \"LowQualFinSF\": 0, \"GrLivArea\": 2285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 1764, \"PID\": 528327060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 705.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1351.0, \"TotalBsmtSF\": 2633.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2633, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2633, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 804.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 466500}, {\"Order\": 1765, \"PID\": 528340030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10557, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 1407, \"LowQualFinSF\": 0, \"GrLivArea\": 3078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 806.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 1766, \"PID\": 528344020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1048.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 1171, \"LowQualFinSF\": 0, \"GrLivArea\": 2582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 322500}, {\"Order\": 1767, \"PID\": 528348030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 275.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1066.0, \"TotalBsmtSF\": 1066.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1277, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 1768, \"PID\": 528351010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 21535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1170.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 989.0, \"TotalBsmtSF\": 2444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2444, \"2ndFlrSF\": 1872, \"LowQualFinSF\": 0, \"GrLivArea\": 4316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 832.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 755000}, {\"Order\": 1769, \"PID\": 528354060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 862.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2013, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 455.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269790}, {\"Order\": 1770, \"PID\": 528354110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11787, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 594.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 1379.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 1015, \"LowQualFinSF\": 0, \"GrLivArea\": 2398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315750}, {\"Order\": 1771, \"PID\": 528358040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1203.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 290000}, {\"Order\": 1772, \"PID\": 528364110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1318.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 752.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1773, \"PID\": 528366050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1969.0, \"TotalBsmtSF\": 3200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 75, \"EnclosedPorch\": 291, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 430000}, {\"Order\": 1774, \"PID\": 528366070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 335.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2202, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 1775, \"PID\": 528376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 526.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1225.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1325.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2538, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 933.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 1776, \"PID\": 528427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1369.0, \"TotalBsmtSF\": 1369.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1369, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 203, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 213133}, {\"Order\": 1777, \"PID\": 528427100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1542, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260261}, {\"Order\": 1778, \"PID\": 528429090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 11670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1905.0, \"TotalBsmtSF\": 1905.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1905, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1905, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 1779, \"PID\": 528429110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282922}, {\"Order\": 1780, \"PID\": 528431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1534, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 215000}, {\"Order\": 1781, \"PID\": 528431040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 754.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 394.0, \"TotalBsmtSF\": 1966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1966, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1092.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 419005}, {\"Order\": 1782, \"PID\": 528431050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13501, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 63.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1623.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1783, \"PID\": 528431110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9986, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 428.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1795.0, \"TotalBsmtSF\": 1795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 1784, \"PID\": 528435010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1528, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235876}, {\"Order\": 1785, \"PID\": 528435040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1126.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 311872}, {\"Order\": 1786, \"PID\": 528435060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 954.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248328}, {\"Order\": 1787, \"PID\": 528435070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 825.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1788, \"PID\": 528439040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8847, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 1538.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1538, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1538, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1789, \"PID\": 528439050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 1790, \"PID\": 528439080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8251, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 1791, \"PID\": 528441080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 255, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 307000}, {\"Order\": 1792, \"PID\": 528445020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 982, \"2ndFlrSF\": 995, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 250000}, {\"Order\": 1793, \"PID\": 528445070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 528, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 859.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221300}, {\"Order\": 1794, \"PID\": 528456190, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1314.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1795, \"PID\": 528456230, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1335.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1335, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210400}, {\"Order\": 1796, \"PID\": 528458080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 255000}, {\"Order\": 1797, \"PID\": 528458090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 10411, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212109}, {\"Order\": 1798, \"PID\": 528458120, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1025.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 1799, \"PID\": 528458130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 64.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1120.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1184, \"2ndFlrSF\": 1426, \"LowQualFinSF\": 0, \"GrLivArea\": 2610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 364, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 303477}, {\"Order\": 1800, \"PID\": 528458150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1880, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310013}, {\"Order\": 1801, \"PID\": 528477020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 11096, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249700}, {\"Order\": 1802, \"PID\": 528480020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 874.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1761, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227875}, {\"Order\": 1803, \"PID\": 528480180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1574.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 256, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 261329}, {\"Order\": 1804, \"PID\": 528482010, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 11824, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1685.0, \"TotalBsmtSF\": 1685.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1685, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1685, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 1805, \"PID\": 528482030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 353.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2443, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 744.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 1806, \"PID\": 528482090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 102.0, \"LotArea\": 11143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 159, \"OpenPorchSF\": 214, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 1807, \"PID\": 531363020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 146000}, {\"Order\": 1808, \"PID\": 531363040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1809, \"PID\": 531375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1810, \"PID\": 531376060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1461.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1811, \"PID\": 531380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 1812, \"PID\": 531384070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11613, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191750}, {\"Order\": 1813, \"PID\": 531385070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1349.0, \"TotalBsmtSF\": 1349.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1349, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1349, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1814, \"PID\": 531385130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 39.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 402, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1815, \"PID\": 531451030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1145.0, \"TotalBsmtSF\": 1575.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1816, \"PID\": 531451150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1817, \"PID\": 531453140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1818, \"PID\": 531477040, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1819, \"PID\": 532353120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 351.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120750}, {\"Order\": 1820, \"PID\": 532354010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1821, \"PID\": 532354060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1822, \"PID\": 532354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 999.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1823, \"PID\": 532376040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 6970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1824, \"PID\": 532376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 13673, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143900}, {\"Order\": 1825, \"PID\": 532377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 7476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1826, \"PID\": 532377140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 57.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 827.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1827, \"PID\": 532378240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1828, \"PID\": 532476080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1232, \"LowQualFinSF\": 0, \"GrLivArea\": 2503, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1829, \"PID\": 532477040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 125.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1031.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 2167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1830, \"PID\": 532479050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 10751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1037, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1831, \"PID\": 532479120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16647, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1701, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 611.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1832, \"PID\": 532479140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 968.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 455, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 147000}, {\"Order\": 1833, \"PID\": 533120030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 482.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 1357, \"LowQualFinSF\": 0, \"GrLivArea\": 2810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 500, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 1834, \"PID\": 533130170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10678, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 337.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 983.0, \"TotalBsmtSF\": 1683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2129, \"2ndFlrSF\": 743, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1835, \"PID\": 533205110, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 45.0, \"LotArea\": 4379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 527.0, \"TotalBsmtSF\": 1378.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1836, \"PID\": 533206060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 3523, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1081.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1151, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1837, \"PID\": 533206070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 3784, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1511.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193800}, {\"Order\": 1838, \"PID\": 533208010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 47.0, \"LotArea\": 4230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1352.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1839, \"PID\": 533208020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3606, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 937.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 1840, \"PID\": 533208030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1550, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 207500}, {\"Order\": 1841, \"PID\": 533208040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4274, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1106.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1241.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1241, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1241, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199900}, {\"Order\": 1842, \"PID\": 533208070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4251, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164700}, {\"Order\": 1843, \"PID\": 533213130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 1844, \"PID\": 533213140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1129.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1845, \"PID\": 533221030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1846, \"PID\": 533221060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1847, \"PID\": 533221100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1848, \"PID\": 533223050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 5105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 551.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 551, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 1849, \"PID\": 533236040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1850, \"PID\": 533241030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 66.0, \"LotArea\": 7399, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 1851, \"PID\": 533242080, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 73.0, \"LotArea\": 7321, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1339.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1852, \"PID\": 533242090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 1853, \"PID\": 533244040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 106.0, \"LotArea\": 8413, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 1105.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 1854, \"PID\": 533250190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1037.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 217, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279700}, {\"Order\": 1855, \"PID\": 533251110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1856, \"PID\": 533251130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 1857, \"PID\": 533252130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1157.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 1858, \"PID\": 533253180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 176.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 89, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213750}, {\"Order\": 1859, \"PID\": 533254100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 761, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1860, \"PID\": 533254130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 978.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181500}, {\"Order\": 1861, \"PID\": 533350020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 17778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1632.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 829.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 2461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2497, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2497, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 373000}, {\"Order\": 1862, \"PID\": 533352075, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAe\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 211.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 1361.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 1259, \"LowQualFinSF\": 0, \"GrLivArea\": 2620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 24, \"EnclosedPorch\": 145, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 8300, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1863, \"PID\": 534104090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 1929, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 1864, \"PID\": 534125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143450}, {\"Order\": 1865, \"PID\": 534127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 1008, \"LowQualFinSF\": 0, \"GrLivArea\": 2411, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240050}, {\"Order\": 1866, \"PID\": 534127140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 973.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1867, \"PID\": 534127260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 385.0, \"TotalBsmtSF\": 1295.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 194, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 1868, \"PID\": 534128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 11358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1869, \"PID\": 534151090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1594, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1870, \"PID\": 534151180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1871, \"PID\": 534175010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAn\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136905}, {\"Order\": 1872, \"PID\": 534176140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 792.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1873, \"PID\": 534177210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 916.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1874, \"PID\": 534178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1875, \"PID\": 534201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 38.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1876, \"PID\": 534202030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 519.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1877, \"PID\": 534204120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1878, \"PID\": 534252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1879, \"PID\": 534252060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10624, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1880, \"PID\": 534252070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1881, \"PID\": 534252110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 978.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 1882, \"PID\": 534275170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1960, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 15500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1883, \"PID\": 534275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 66.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1065, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 1884, \"PID\": 534276070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 63.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 81.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1885, \"PID\": 534276160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 285, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1886, \"PID\": 534276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 206.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1887, \"PID\": 534276290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 1888, \"PID\": 534278150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 167.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1889, \"PID\": 534278170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1890, \"PID\": 534278190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117600}, {\"Order\": 1891, \"PID\": 534401120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1174.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1892, \"PID\": 534401200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1893, \"PID\": 534403040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 270.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 580.0, \"BsmtUnfSF\": 452.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 309.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 333, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1894, \"PID\": 534403290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 1309, \"LowQualFinSF\": 0, \"GrLivArea\": 2154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 1895, \"PID\": 534403420, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 543.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1130.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1374, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1896, \"PID\": 534425015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 1592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 201, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1897, \"PID\": 534425080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 219.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1429, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1429, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1898, \"PID\": 534427140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1327, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1327, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150750}, {\"Order\": 1899, \"PID\": 534429030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101800}, {\"Order\": 1900, \"PID\": 534430090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 932, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 306.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 214, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1901, \"PID\": 534431020, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 259.0, \"BsmtUnfSF\": 433.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 908, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 1902, \"PID\": 534450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 2, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 39300}, {\"Order\": 1903, \"PID\": 534450110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1904, \"PID\": 534451020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 442, \"2ndFlrSF\": 228, \"LowQualFinSF\": 0, \"GrLivArea\": 670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1905, \"PID\": 534453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 404.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 1906, \"PID\": 534475170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1907, \"PID\": 534476080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1908, \"PID\": 534478140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Roll\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 708.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 992, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1909, \"PID\": 534479120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1910, \"PID\": 534479140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 1911, \"PID\": 535101150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1912, \"PID\": 535102010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 87.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1913, \"PID\": 535105110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 291.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1914, \"PID\": 535106140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 1915, \"PID\": 535106180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11344, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 874, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1916, \"PID\": 535126180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 1021.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1465, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Sev\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129000}, {\"Order\": 1917, \"PID\": 535151020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 873.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 63.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 219, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1918, \"PID\": 535151100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 908.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 1919, \"PID\": 535151110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 109, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142100}, {\"Order\": 1920, \"PID\": 535152060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1921, \"PID\": 535154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 243.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 834.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 275, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 1922, \"PID\": 535155110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 1923, \"PID\": 535176070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1244, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1244, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1924, \"PID\": 535177020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 69.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1144.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1925, \"PID\": 535177110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 138.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1331.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174850}, {\"Order\": 1926, \"PID\": 535179120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1927, \"PID\": 535180030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 586.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1928, \"PID\": 535181030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1237.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1657, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1929, \"PID\": 535181140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1930, \"PID\": 535300040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 928.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1931, \"PID\": 535301060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1932, \"PID\": 535301160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8078, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128600}, {\"Order\": 1933, \"PID\": 535302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1934, \"PID\": 535304170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 85.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 955.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 293.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1935, \"PID\": 535305180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1936, \"PID\": 535325090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 691.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1937, \"PID\": 535325280, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1938, \"PID\": 535325320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 500, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1939, \"PID\": 535327160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1940, \"PID\": 535327200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 377.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 551.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1941, \"PID\": 535353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 368, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1942, \"PID\": 535353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 324, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1943, \"PID\": 535353160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 14190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 544, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1944, \"PID\": 535354050, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 893, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 893, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1945, \"PID\": 535354260, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 512, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1946, \"PID\": 535355020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 21281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 1778, \"LowQualFinSF\": 0, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 208, \"EnclosedPorch\": 290, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 301600}, {\"Order\": 1947, \"PID\": 535375130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 735.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 735, \"2ndFlrSF\": 299, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 1948, \"PID\": 535376010, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 882.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103200}, {\"Order\": 1949, \"PID\": 535378080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 66.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 1950, \"PID\": 535379060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1951, \"PID\": 535379110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1895, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1952, \"PID\": 535382150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 691.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 86000}, {\"Order\": 1953, \"PID\": 535402140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 364.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 242.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1954, \"PID\": 535402180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 1955, \"PID\": 535403030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 952.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1956, \"PID\": 535426130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1957, \"PID\": 535450190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122900}, {\"Order\": 1958, \"PID\": 535450220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119200}, {\"Order\": 1959, \"PID\": 535450310, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10496, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1960, \"PID\": 535451040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 246.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1961, \"PID\": 535451100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1238, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 171, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 1962, \"PID\": 535451110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 398.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 149.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1963, \"PID\": 535452060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 254.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1964, \"PID\": 535453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1965, \"PID\": 535453150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7315, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1170.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1170, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1966, \"PID\": 535453180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 1967, \"PID\": 535457020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1098.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 154.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1377.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1377, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 1968, \"PID\": 535457040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1969, \"PID\": 535457050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1970, \"PID\": 535476360, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 831, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1971, \"PID\": 535477130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 1972, \"PID\": 535477180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 442.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1973, \"PID\": 535478040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 90, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1974, \"PID\": 902100010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1975, \"PID\": 902105110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 664, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 132000}, {\"Order\": 1976, \"PID\": 902106070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 175, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1977, \"PID\": 902106120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 782.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 184.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1978, \"PID\": 902107050, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1979, \"PID\": 902110010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 3153, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 26, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 1980, \"PID\": 902125120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1885, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1047, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1047, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1981, \"PID\": 902128160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 279.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1982, \"PID\": 902201090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 494, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 26, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1983, \"PID\": 902201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 679, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1984, \"PID\": 902202070, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 435.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 89471}, {\"Order\": 1985, \"PID\": 902205020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 122.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 448.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 761, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1986, \"PID\": 902205130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 1987, \"PID\": 902206270, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1075.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 642, \"LowQualFinSF\": 0, \"GrLivArea\": 1798, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1988, \"PID\": 902207010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1945, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 1989, \"PID\": 902207150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 968.0, \"TotalBsmtSF\": 968.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1990, \"PID\": 902300020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10337, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 1991, \"PID\": 902300040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 9863, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 374.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1992, \"PID\": 902301030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 842, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1993, \"PID\": 902301130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1994, \"PID\": 902302150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 1995, \"PID\": 902303100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 667.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 659, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144100}, {\"Order\": 1996, \"PID\": 902304040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1880, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 1997, \"PID\": 902305010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 316.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 687.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 687, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 124500}, {\"Order\": 1998, \"PID\": 902330090, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1879, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 819.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2454, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1999, \"PID\": 902332030, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1046.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 1031, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 99, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 2000, \"PID\": 902401030, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 779.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2001, \"PID\": 902404010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1221.0, \"TotalBsmtSF\": 1559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1559, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1559, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 230, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2002, \"PID\": 902408080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 718.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2003, \"PID\": 902427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 9439, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2004, \"PID\": 902427140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2005, \"PID\": 902427180, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2006, \"PID\": 903201090, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 6854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 227.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 916, \"2ndFlrSF\": 144, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 150, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2007, \"PID\": 903204030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8674, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1435, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128250}, {\"Order\": 2008, \"PID\": 903205085, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 8731, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 645.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2009, \"PID\": 903206170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 915, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2010, \"PID\": 903225040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2011, \"PID\": 903227140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 217.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 2012, \"PID\": 903228080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 349, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2013, \"PID\": 903231050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2014, \"PID\": 903231090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 809.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2015, \"PID\": 903231180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 423, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2016, \"PID\": 903232100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 966.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2017, \"PID\": 903233030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 903, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2018, \"PID\": 903233050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1933.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2019, \"PID\": 903233140, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 854, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2020, \"PID\": 903233180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 959, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 2021, \"PID\": 903234160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2022, \"PID\": 903236130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 7755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1164, \"LowQualFinSF\": 0, \"GrLivArea\": 2264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2023, \"PID\": 903400040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2024, \"PID\": 903401070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2025, \"PID\": 903425270, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 356, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2026, \"PID\": 903425280, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153575}, {\"Order\": 2027, \"PID\": 903426010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1929, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2028, \"PID\": 903427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 546.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 714.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 15, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136000}, {\"Order\": 2029, \"PID\": 903430040, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 933, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 113000}, {\"Order\": 2030, \"PID\": 903430050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 969, \"2ndFlrSF\": 245, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 117000}, {\"Order\": 2031, \"PID\": 903450060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 2032, \"PID\": 903451110, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 7449, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 2033, \"PID\": 903453080, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1497, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2034, \"PID\": 903454010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 0, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2035, \"PID\": 903454090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2036, \"PID\": 903456110, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 398.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 1952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 285, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212300}, {\"Order\": 2037, \"PID\": 903457040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 1042, \"LowQualFinSF\": 0, \"GrLivArea\": 2180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2038, \"PID\": 903457130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 4330, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 477, \"LowQualFinSF\": 0, \"GrLivArea\": 1315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 99500}, {\"Order\": 2039, \"PID\": 903458020, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 581, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101000}, {\"Order\": 2040, \"PID\": 903458060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 197.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 999.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2041, \"PID\": 903475040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 12358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 528, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2042, \"PID\": 903475060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 964, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2043, \"PID\": 903476100, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 4388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2044, \"PID\": 903484080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 771.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 504, \"LowQualFinSF\": 114, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 14, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 84, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 50000}, {\"Order\": 2045, \"PID\": 904100100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1937, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 1005, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 521, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219000}, {\"Order\": 2046, \"PID\": 904101070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 138.0, \"LotArea\": 18030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 977.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 971, \"LowQualFinSF\": 479, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 2047, \"PID\": 904301110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 756, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 126000}, {\"Order\": 2048, \"PID\": 904302010, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 4484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2049, \"PID\": 905100060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2050, \"PID\": 905100080, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158450}, {\"Order\": 2051, \"PID\": 905101070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 14299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115400}, {\"Order\": 2052, \"PID\": 905101200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1029, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 261.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2053, \"PID\": 905102010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 722.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2054, \"PID\": 905103110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 761.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2055, \"PID\": 905104030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 627.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 913, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2056, \"PID\": 905104090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 7094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2057, \"PID\": 905104170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 948.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 108000}, {\"Order\": 2058, \"PID\": 905104240, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 20.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2059, \"PID\": 905105040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 8665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 897, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2060, \"PID\": 905105170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 323.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 529.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2061, \"PID\": 905105260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 955, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2062, \"PID\": 905106150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 8724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2063, \"PID\": 905107140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 2064, \"PID\": 905200010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2065, \"PID\": 905201080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 522.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 323.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2066, \"PID\": 905225020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 16779, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 1087, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 570, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2067, \"PID\": 905226050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1416, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2068, \"PID\": 905226080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165250}, {\"Order\": 2069, \"PID\": 905226130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 231.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2070, \"PID\": 905226170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 873.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"VWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2071, \"PID\": 905228020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 998, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 998, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 2072, \"PID\": 905301050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 115149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 739.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 380, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 2073, \"PID\": 905352010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 891.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2074, \"PID\": 905352180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2075, \"PID\": 905376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 109.0, \"TotalBsmtSF\": 409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1325, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 2076, \"PID\": 905377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 587.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2077, \"PID\": 905377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 17808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2078, \"PID\": 905401020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2079, \"PID\": 905426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 12615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 477.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243000}, {\"Order\": 2080, \"PID\": 905451390, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 491.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 638, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 332.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 2081, \"PID\": 905475270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2082, \"PID\": 905475520, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11515, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2083, \"PID\": 905476160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 7711, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2084, \"PID\": 905476170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 605, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 605, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 2085, \"PID\": 905476225, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 3869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 755.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1038.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1038, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2086, \"PID\": 905478140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2087, \"PID\": 905478220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1080.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 400, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2088, \"PID\": 905480090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 951.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 376, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 2089, \"PID\": 905480180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2090, \"PID\": 906200230, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 23920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1105.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 1012, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 444, \"PoolQC\": \"TA\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2091, \"PID\": 906201022, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 10357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 719.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 244, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2092, \"PID\": 906201023, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 1121, \"LowQualFinSF\": 0, \"GrLivArea\": 2243, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 44, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2093, \"PID\": 906201200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1474.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2730, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 2094, \"PID\": 906203140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 634.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 833.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 192, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2095, \"PID\": 906204140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 807.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 196, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2096, \"PID\": 906223040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 497.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 929, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2097, \"PID\": 906340080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 984.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 1414, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 383970}, {\"Order\": 2098, \"PID\": 906340090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1362, \"LowQualFinSF\": 0, \"GrLivArea\": 2828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 424870}, {\"Order\": 2099, \"PID\": 906378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 2100, \"PID\": 906378150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10481, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2140.0, \"TotalBsmtSF\": 2140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 360000}, {\"Order\": 2101, \"PID\": 906378170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10652, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1494.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 279500}, {\"Order\": 2102, \"PID\": 906380010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 11175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 200141}, {\"Order\": 2103, \"PID\": 906380040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 10235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246500}, {\"Order\": 2104, \"PID\": 906380070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1482.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 1092, \"LowQualFinSF\": 0, \"GrLivArea\": 2574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 276000}, {\"Order\": 2105, \"PID\": 906380120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 349.0, \"TotalBsmtSF\": 1274.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1274, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203000}, {\"Order\": 2106, \"PID\": 906380140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11103, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155835}, {\"Order\": 2107, \"PID\": 906380160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2108, \"PID\": 906380200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 195400}, {\"Order\": 2109, \"PID\": 906382020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1526.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1546, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1546, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2110, \"PID\": 906382060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1453.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 674.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212999}, {\"Order\": 2111, \"PID\": 906392080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1270.0, \"TotalBsmtSF\": 1270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1270, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2112, \"PID\": 906394020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 916, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 2113, \"PID\": 906394050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176432}, {\"Order\": 2114, \"PID\": 906402070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1157.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 882, \"LowQualFinSF\": 0, \"GrLivArea\": 2062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 154, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2115, \"PID\": 906403060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 321.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 927, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2116, \"PID\": 906426060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 159000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 2144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2117, \"PID\": 906426195, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53107, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 985.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 874, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 231, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2118, \"PID\": 906475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2087, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2119, \"PID\": 906475170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 155.0, \"LotArea\": 20064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 51.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 915.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 646, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2120, \"PID\": 907125040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 472.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 747.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2121, \"PID\": 907125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2122, \"PID\": 907130060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11249, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 544.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 2123, \"PID\": 907131060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 10021, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 635.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 646, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2124, \"PID\": 907131120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9531, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 914, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2125, \"PID\": 907135050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2126, \"PID\": 907135080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 16561, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 242.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147900}, {\"Order\": 2127, \"PID\": 907135180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123600}, {\"Order\": 2128, \"PID\": 907180040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 905, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204750}, {\"Order\": 2129, \"PID\": 907187040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 646.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 597.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235500}, {\"Order\": 2130, \"PID\": 907187060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12352, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 853, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1753, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2131, \"PID\": 907192020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 845.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190550}, {\"Order\": 2132, \"PID\": 907192040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8826, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2133, \"PID\": 907192120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 167.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1013.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2134, \"PID\": 907192150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2135, \"PID\": 907200130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 131000}, {\"Order\": 2136, \"PID\": 907200190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 502.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2137, \"PID\": 907200250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1009, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2138, \"PID\": 907200270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 2139, \"PID\": 907202100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 16300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 417.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2140, \"PID\": 907202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 432.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2141, \"PID\": 907203060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 2142, \"PID\": 907203110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 10356, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 969, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2143, \"PID\": 907227060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 671.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2144, \"PID\": 907227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2145, \"PID\": 907250050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 2000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305900}, {\"Order\": 2146, \"PID\": 907252020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1284.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 2169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2147, \"PID\": 907252190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11354, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1412.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1673, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1673, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2148, \"PID\": 907260040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1459.0, \"TotalBsmtSF\": 1459.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1459, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1459, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 2149, \"PID\": 907260050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 2150, \"PID\": 907262020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 214.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2151, \"PID\": 907270040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 16226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 1242, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 267000}, {\"Order\": 2152, \"PID\": 907275080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 519.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 683.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1592, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1592, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2153, \"PID\": 907275150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 1531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2439, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2154, \"PID\": 907280090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2155, \"PID\": 907280100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 2156, \"PID\": 907285040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 438.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1079.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2157, \"PID\": 907290140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 2158, \"PID\": 907295040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 17227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246900}, {\"Order\": 2159, \"PID\": 907401060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1081, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2160, \"PID\": 907405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2161, \"PID\": 907410020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179400}, {\"Order\": 2162, \"PID\": 907410050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 639.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 2163, \"PID\": 907414060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1422.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179600}, {\"Order\": 2164, \"PID\": 907414070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 709.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 2165, \"PID\": 907420050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1330, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167840}, {\"Order\": 2166, \"PID\": 907420060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 753, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168675}, {\"Order\": 2167, \"PID\": 907420110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2168, \"PID\": 908102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2169, \"PID\": 908102160, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 405, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 2170, \"PID\": 908103090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 132.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2171, \"PID\": 908127040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 10921, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 48.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94750}, {\"Order\": 2172, \"PID\": 908127060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 16287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 450, \"LowQualFinSF\": 0, \"GrLivArea\": 1351, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 43, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2173, \"PID\": 908127070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1179.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2174, \"PID\": 908127100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 11841, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2175, \"PID\": 908152060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2176, \"PID\": 908152070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 751.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2177, \"PID\": 908152180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9555, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1133, \"LowQualFinSF\": 0, \"GrLivArea\": 2233, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2178, \"PID\": 908152260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1125.0, \"TotalBsmtSF\": 1125.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155000}, {\"Order\": 2179, \"PID\": 908152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2180, \"PID\": 908152290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 123.0, \"TotalBsmtSF\": 734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 674, \"LowQualFinSF\": 0, \"GrLivArea\": 1408, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 2181, \"PID\": 908154195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 39290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 4010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 5095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 5095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 5095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 15, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1154.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 546, \"OpenPorchSF\": 484, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Elev\", \"MiscVal\": 17000, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 183850}, {\"Order\": 2182, \"PID\": 908154205, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 40094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 762.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 3138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3138, \"2ndFlrSF\": 1538, \"LowQualFinSF\": 0, \"GrLivArea\": 4676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 406, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 184750}, {\"Order\": 2183, \"PID\": 908186050, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 467.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2184, \"PID\": 908204090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 77.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 831.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2185, \"PID\": 908204180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2186, \"PID\": 908225240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 2187, \"PID\": 908225310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1195, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 118, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98500}, {\"Order\": 2188, \"PID\": 908226180, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 4270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 286, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2189, \"PID\": 908228010, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 278.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 740, \"2ndFlrSF\": 125, \"LowQualFinSF\": 0, \"GrLivArea\": 865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2190, \"PID\": 908250100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 2191, \"PID\": 908275090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2192, \"PID\": 908275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2193, \"PID\": 908275240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 79275}, {\"Order\": 2194, \"PID\": 908276230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2195, \"PID\": 909176080, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 10896, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1184.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 1440, \"LowQualFinSF\": 515, \"GrLivArea\": 3395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 8, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 14, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 200000}, {\"Order\": 2196, \"PID\": 909176170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2592, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 742, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1512, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 150000}, {\"Order\": 2197, \"PID\": 909250150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 53, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2198, \"PID\": 909250160, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10594, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 2199, \"PID\": 909251030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7223, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2200, \"PID\": 909251040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6821, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 113.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2201, \"PID\": 909252010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 787, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2202, \"PID\": 909252150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 4000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 567, \"2ndFlrSF\": 531, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 2203, \"PID\": 909252170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 6720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 585, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 2204, \"PID\": 909254090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7642, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 514, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189950}, {\"Order\": 2205, \"PID\": 909254100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 775, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2206, \"PID\": 909254130, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 364.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2207, \"PID\": 909254140, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1913, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 365.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90350}, {\"Order\": 2208, \"PID\": 909254150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 661.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 661, \"2ndFlrSF\": 589, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 242, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2209, \"PID\": 909256120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 920.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119750}, {\"Order\": 2210, \"PID\": 909275020, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 7136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 979, \"2ndFlrSF\": 979, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2211, \"PID\": 909275030, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 6270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 1001, \"LowQualFinSF\": 0, \"GrLivArea\": 2002, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2212, \"PID\": 909275110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1927, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 867, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 291, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2213, \"PID\": 909275160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 126.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 24, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 228, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2214, \"PID\": 909275310, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 22420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1128.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2215, \"PID\": 909276160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12168, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 537.0, \"TotalBsmtSF\": 965.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 3194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 359100}, {\"Order\": 2216, \"PID\": 909276210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 7810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1230, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2217, \"PID\": 909279080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 557.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 19, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2218, \"PID\": 909281020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 6221, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2219, \"PID\": 909281130, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1549, \"2ndFlrSF\": 1178, \"LowQualFinSF\": 0, \"GrLivArea\": 2727, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2220, \"PID\": 909282020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1945, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 150.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 2320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259500}, {\"Order\": 2221, \"PID\": 909425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 1477.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1839, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 2222, \"PID\": 909425270, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2223, \"PID\": 909428120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 35.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 869.0, \"BsmtUnfSF\": 905.0, \"TotalBsmtSF\": 1809.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2259, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2259, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 217000}, {\"Order\": 2224, \"PID\": 909428180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1020.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 584, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 2225, \"PID\": 909428340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21579, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2226, \"PID\": 909451130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 529, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 2227, \"PID\": 909452102, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2228, \"PID\": 909455060, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 577.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2229, \"PID\": 909475050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 652.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 434.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1262.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 2230, \"PID\": 909475070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 2035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2515, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2515, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 200624}, {\"Order\": 2231, \"PID\": 909475230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 18044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 279.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 64, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 228, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2232, \"PID\": 910200040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 997, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2233, \"PID\": 910200110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2234, \"PID\": 910201020, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 803, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2235, \"PID\": 910201050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 176, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129850}, {\"Order\": 2236, \"PID\": 910201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 772, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1123, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 2237, \"PID\": 910201180, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": null, \"GarageArea\": null, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 150909}, {\"Order\": 2238, \"PID\": 910202030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 46.0, \"LotArea\": 3672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 100.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75200}, {\"Order\": 2239, \"PID\": 910203290, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118400}, {\"Order\": 2240, \"PID\": 910204090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 961.0, \"TotalBsmtSF\": 961.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"Mix\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 67000}, {\"Order\": 2241, \"PID\": 910205130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 910, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2242, \"PID\": 910206010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 11067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 205, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68104}, {\"Order\": 2243, \"PID\": 911103060, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1895, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 957.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 957, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 133, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119600}, {\"Order\": 2244, \"PID\": 911128010, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 65.0, \"LotArea\": 6565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 106.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 444, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2245, \"PID\": 911128020, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 837.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1001, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 86, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 2246, \"PID\": 911370450, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2247, \"PID\": 911370460, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 481.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 235000}, {\"Order\": 2248, \"PID\": 914452090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1001.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2249, \"PID\": 914452120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2250, \"PID\": 914452190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2251, \"PID\": 914460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 856.0, \"TotalBsmtSF\": 1441.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2252, \"PID\": 914460110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 12864, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 17.0, \"TotalBsmtSF\": 1409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1409, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 2253, \"PID\": 914476330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2254, \"PID\": 914478020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 530.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 852.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2255, \"PID\": 914478100, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 924.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2256, \"PID\": 916226090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 4054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 949.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 2257, \"PID\": 916253320, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 9763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 239.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1102.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 2258, \"PID\": 916326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 16905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2259, \"PID\": 916326090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 19958, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 274, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2260, \"PID\": 916384050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 231713}, {\"Order\": 2261, \"PID\": 916384070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8298, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 963.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2207.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267300}, {\"Order\": 2262, \"PID\": 916384080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1476.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265900}, {\"Order\": 2263, \"PID\": 916384150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1571.0, \"TotalBsmtSF\": 1571.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1571, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239000}, {\"Order\": 2264, \"PID\": 916386170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 274.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1638.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248900}, {\"Order\": 2265, \"PID\": 916403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 215.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 1265.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2266, \"PID\": 916403290, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2267, \"PID\": 916455010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 742.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1756, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 2268, \"PID\": 916455050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6718, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2269, \"PID\": 916455110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 82.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2270, \"PID\": 916455150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 886.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 593.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282000}, {\"Order\": 2271, \"PID\": 916460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2272, \"PID\": 916475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 808.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 252, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2273, \"PID\": 916477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 1340, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279900}, {\"Order\": 2274, \"PID\": 917425190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 35133, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 995.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 263, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 263, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186700}, {\"Order\": 2275, \"PID\": 921126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 15306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1652.0, \"TotalBsmtSF\": 1732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 283463}, {\"Order\": 2276, \"PID\": 921128030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 2277, \"PID\": 921205070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1094.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 1349, \"LowQualFinSF\": 0, \"GrLivArea\": 2482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 281213}, {\"Order\": 2278, \"PID\": 923202134, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 914.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 2279, \"PID\": 923202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 200.0, \"LotArea\": 43500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1041.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 561, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2280, \"PID\": 923203010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 6710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 904.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2281, \"PID\": 923204050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 25286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132250}, {\"Order\": 2282, \"PID\": 923204140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 25000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2283, \"PID\": 923205025, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 149.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1622, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 439, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2284, \"PID\": 923225040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 840.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2285, \"PID\": 923225050, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 874.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 536, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2286, \"PID\": 923226300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2287, \"PID\": 923228200, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 27.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 97, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 2288, \"PID\": 923228220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93900}, {\"Order\": 2289, \"PID\": 923228250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 2290, \"PID\": 923228290, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 131.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 499.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2291, \"PID\": 923228390, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 75190}, {\"Order\": 2292, \"PID\": 923229010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146800}, {\"Order\": 2293, \"PID\": 923229040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9129, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2294, \"PID\": 923229100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1356, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 1424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2295, \"PID\": 923229140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 33983, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1112.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1676, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 690, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2296, \"PID\": 923230010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 185.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2297, \"PID\": 923230120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 2298, \"PID\": 923230180, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 149.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2299, \"PID\": 923251160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 27697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"CBlock\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 811.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1608, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2300, \"PID\": 923252080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7599, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2301, \"PID\": 923275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1090.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 88, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2302, \"PID\": 923275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2303, \"PID\": 923276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 596.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 330, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2304, \"PID\": 923400150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 212.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 974.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 974, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 974, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93500}, {\"Order\": 2305, \"PID\": 923425030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 887, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2306, \"PID\": 526302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11027, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1178.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1293, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1293, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2307, \"PID\": 526302040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 280, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2308, \"PID\": 526302120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1127.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 963.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2309, \"PID\": 526303060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 39384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 902.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 252000}, {\"Order\": 2310, \"PID\": 526354020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11727, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 434.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1851.0, \"TotalBsmtSF\": 1851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1851, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192100}, {\"Order\": 2311, \"PID\": 527105060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8238, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2312, \"PID\": 527106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 964.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 1243, \"LowQualFinSF\": 0, \"GrLivArea\": 2236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2313, \"PID\": 527107020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 781, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2314, \"PID\": 527107030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13031, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 592.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2315, \"PID\": 527107120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 821.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 821, \"2ndFlrSF\": 955, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 443.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2316, \"PID\": 527107240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 714.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 413.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 95, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2317, \"PID\": 527108010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 19378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 2462, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2318, \"PID\": 527108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 14859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 27.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1670.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 240000}, {\"Order\": 2319, \"PID\": 527108030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 13128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 990, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2320, \"PID\": 527108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 893.0, \"TotalBsmtSF\": 893.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 2321, \"PID\": 527108060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 13751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1640.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 2212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 773.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 309000}, {\"Order\": 2322, \"PID\": 527108090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 168.0, \"LotArea\": 23257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2021, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 274725}, {\"Order\": 2323, \"PID\": 527146135, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2062.0, \"TotalBsmtSF\": 2062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2079, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2324, \"PID\": 527158020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8076, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2325, \"PID\": 527163020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165600}, {\"Order\": 2326, \"PID\": 527166030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 2327, \"PID\": 527182020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 3701, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2328, \"PID\": 527190050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 5306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 215.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 441, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2329, \"PID\": 527190220, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 28, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2330, \"PID\": 527210030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 1384, \"LowQualFinSF\": 0, \"GrLivArea\": 2798, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 37, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 457347}, {\"Order\": 2331, \"PID\": 527210040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 18062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 662.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 1862, \"LowQualFinSF\": 0, \"GrLivArea\": 3390, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 545224}, {\"Order\": 2332, \"PID\": 527210050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 205.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 889.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1371, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 246, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356383}, {\"Order\": 2333, \"PID\": 527212030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 16056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1752.0, \"TotalBsmtSF\": 1992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1992, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 2868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 716.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 556581}, {\"Order\": 2334, \"PID\": 527212040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 1312, \"LowQualFinSF\": 0, \"GrLivArea\": 2576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 361919}, {\"Order\": 2335, \"PID\": 527214060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 16052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 734.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 2698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 535000}, {\"Order\": 2336, \"PID\": 527216010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 15922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 550.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 1405, \"LowQualFinSF\": 0, \"GrLivArea\": 2795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 401179}, {\"Order\": 2337, \"PID\": 527216050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1031.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1410.0, \"TotalBsmtSF\": 1410.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 1519, \"LowQualFinSF\": 0, \"GrLivArea\": 2945, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 37, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 438780}, {\"Order\": 2338, \"PID\": 527226010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1547, \"2ndFlrSF\": 720, \"LowQualFinSF\": 53, \"GrLivArea\": 2320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2339, \"PID\": 527250040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 34650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2340, \"PID\": 527252090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 523.0, \"TotalBsmtSF\": 1714.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1714, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 2341, \"PID\": 527254070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11302, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Other\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1422.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1826, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319000}, {\"Order\": 2342, \"PID\": 527256120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 18261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 123, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 470000}, {\"Order\": 2343, \"PID\": 527301010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 995.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2344, \"PID\": 527302080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1002.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 2183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2345, \"PID\": 527325160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 34.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 795.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 250, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2346, \"PID\": 527327080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2347, \"PID\": 527328010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2348, \"PID\": 527354040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 604.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 2349, \"PID\": 527355060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1857, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188900}, {\"Order\": 2350, \"PID\": 527355280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 1061.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 384, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2351, \"PID\": 527356020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1392, \"LowQualFinSF\": 0, \"GrLivArea\": 2784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 440, \"PoolArea\": 519, \"PoolQC\": \"Fa\", \"Fence\": \"MnPrv\", \"MiscFeature\": \"TenC\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2352, \"PID\": 527356060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 811, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 208, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2353, \"PID\": 527358090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 42.0, \"TotalBsmtSF\": 1047.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1083, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1083, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 444, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2354, \"PID\": 527365010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1358, \"LowQualFinSF\": 0, \"GrLivArea\": 2318, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 246, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294323}, {\"Order\": 2355, \"PID\": 527375160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 127.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1109, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 485.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 2356, \"PID\": 527376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2357, \"PID\": 527376110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 2358, \"PID\": 527377030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 377.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1309, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1309, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 648, \"PoolQC\": \"Fa\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2359, \"PID\": 527378010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2360, \"PID\": 527402210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 75.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 791.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 138800}, {\"Order\": 2361, \"PID\": 527402380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9353, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 116050}, {\"Order\": 2362, \"PID\": 527403120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 614.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 2363, \"PID\": 527404180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 2364, \"PID\": 527427210, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 951.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1487.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2365, \"PID\": 527450010, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 514.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 2366, \"PID\": 527450080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2367, \"PID\": 527450210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 408.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83000}, {\"Order\": 2368, \"PID\": 527450460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 494, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2369, \"PID\": 527451200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 91500}, {\"Order\": 2370, \"PID\": 527451380, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2371, \"PID\": 527451450, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 465, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2372, \"PID\": 527451460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 382.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2373, \"PID\": 527451520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 297.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94500}, {\"Order\": 2374, \"PID\": 527452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 156.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146300}, {\"Order\": 2375, \"PID\": 527452290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 373.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1387, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2376, \"PID\": 527452310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 175, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2377, \"PID\": 527453070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2378, \"PID\": 527455100, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2379, \"PID\": 528102010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 66.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1447.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 770.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2380, \"PID\": 528102080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 16387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1738, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 2589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 412083}, {\"Order\": 2381, \"PID\": 528106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 111.0, \"LotArea\": 16259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 370.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1249.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1249, \"2ndFlrSF\": 1347, \"LowQualFinSF\": 0, \"GrLivArea\": 2596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 342643}, {\"Order\": 2382, \"PID\": 528106120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 16163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1618.0, \"TotalBsmtSF\": 1618.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1618, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1618, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 2383, \"PID\": 528110050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 690.0, \"TotalBsmtSF\": 2076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2076, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 229, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 465000}, {\"Order\": 2384, \"PID\": 528112010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 12228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1721.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293000}, {\"Order\": 2385, \"PID\": 528114010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 14780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1085.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 354, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2386, \"PID\": 528116030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 16033, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1261.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 519, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 326000}, {\"Order\": 2387, \"PID\": 528118010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 14215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1218, \"LowQualFinSF\": 0, \"GrLivArea\": 2376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 853.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325300}, {\"Order\": 2388, \"PID\": 528118020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 309000}, {\"Order\": 2389, \"PID\": 528118110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13975, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 300000}, {\"Order\": 2390, \"PID\": 528120110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1030.0, \"TotalBsmtSF\": 1030.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 1060, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 2391, \"PID\": 528120140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 385.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 466, \"LowQualFinSF\": 0, \"GrLivArea\": 2091, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338500}, {\"Order\": 2392, \"PID\": 528138030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345000}, {\"Order\": 2393, \"PID\": 528142010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 12867, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1209.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 344133}, {\"Order\": 2394, \"PID\": 528142060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 10672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 1335, \"LowQualFinSF\": 0, \"GrLivArea\": 2389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 298236}, {\"Order\": 2395, \"PID\": 528142070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 814, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 329900}, {\"Order\": 2396, \"PID\": 528142110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 1896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 708.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 2397, \"PID\": 528144030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11065, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 788.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 1085.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 753.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281000}, {\"Order\": 2398, \"PID\": 528150080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372397}, {\"Order\": 2399, \"PID\": 528150090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 131.0, \"LotArea\": 14828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 1780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378000}, {\"Order\": 2400, \"PID\": 528164040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 562.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 374000}, {\"Order\": 2401, \"PID\": 528170040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 20431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 870.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1848, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 2728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 437154}, {\"Order\": 2402, \"PID\": 528172020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 512.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 179, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2403, \"PID\": 528172150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 488, \"LowQualFinSF\": 0, \"GrLivArea\": 1914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2404, \"PID\": 528174080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 705.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185850}, {\"Order\": 2405, \"PID\": 528180080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 5911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282500}, {\"Order\": 2406, \"PID\": 528181030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6955, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202500}, {\"Order\": 2407, \"PID\": 528181040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 6792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202665}, {\"Order\": 2408, \"PID\": 528186100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 518.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 899.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 332200}, {\"Order\": 2409, \"PID\": 528186110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 572.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1251.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310090}, {\"Order\": 2410, \"PID\": 528188040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171750}, {\"Order\": 2411, \"PID\": 528218030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 23, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169990}, {\"Order\": 2412, \"PID\": 528218060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 170440}, {\"Order\": 2413, \"PID\": 528218080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169985}, {\"Order\": 2414, \"PID\": 528218130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 17104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 426.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179665}, {\"Order\": 2415, \"PID\": 528218140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 14054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 1863, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 219210}, {\"Order\": 2416, \"PID\": 528221010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 11660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1326.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 174190}, {\"Order\": 2417, \"PID\": 528221100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172785}, {\"Order\": 2418, \"PID\": 528222010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11631, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1052.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 1321, \"LowQualFinSF\": 0, \"GrLivArea\": 2373, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 258000}, {\"Order\": 2419, \"PID\": 528222020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185101}, {\"Order\": 2420, \"PID\": 528228280, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3087, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 767.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210250}, {\"Order\": 2421, \"PID\": 528228325, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1374.0, \"TotalBsmtSF\": 1374.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 2422, \"PID\": 528228340, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1273.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2423, \"PID\": 528228360, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1038.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246990}, {\"Order\": 2424, \"PID\": 528228415, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1375.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178740}, {\"Order\": 2425, \"PID\": 528228430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2426, \"PID\": 528228545, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167240}, {\"Order\": 2427, \"PID\": 528228550, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1126.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156820}, {\"Order\": 2428, \"PID\": 528228565, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213490}, {\"Order\": 2429, \"PID\": 528228575, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1154.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 1520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264561}, {\"Order\": 2430, \"PID\": 528228580, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246578}, {\"Order\": 2431, \"PID\": 528231050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 21930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192140}, {\"Order\": 2432, \"PID\": 528235050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7861, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183200}, {\"Order\": 2433, \"PID\": 528235130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2434, \"PID\": 528235190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1598, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201490}, {\"Order\": 2435, \"PID\": 528240080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1406.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1454, \"2ndFlrSF\": 482, \"LowQualFinSF\": 0, \"GrLivArea\": 1936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 2436, \"PID\": 528250060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2437, \"PID\": 528275060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8121, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 711, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172400}, {\"Order\": 2438, \"PID\": 528275080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2439, \"PID\": 528280100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 930, \"LowQualFinSF\": 0, \"GrLivArea\": 1886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 89, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199900}, {\"Order\": 2440, \"PID\": 528290140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 959.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 2441, \"PID\": 528292080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287602}, {\"Order\": 2442, \"PID\": 528294070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 1286, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2443, \"PID\": 528315030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1074.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1407, \"2ndFlrSF\": 985, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 348000}, {\"Order\": 2444, \"PID\": 528315070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 31, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 2445, \"PID\": 528315080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 322.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 655.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1205, \"2ndFlrSF\": 1029, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2446, \"PID\": 528320060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 35760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1831, \"2ndFlrSF\": 1796, \"LowQualFinSF\": 0, \"GrLivArea\": 3627, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 807.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 361, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 625000}, {\"Order\": 2447, \"PID\": 528327010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9233, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 877.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 358.0, \"TotalBsmtSF\": 1540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1540, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2855, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 247, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 405000}, {\"Order\": 2448, \"PID\": 528344060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 530.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 374, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2449, \"PID\": 528348010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 258000}, {\"Order\": 2450, \"PID\": 528358030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 397.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 1368, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 169, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 2451, \"PID\": 528360050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 17242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 738.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1393.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1733.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1933, \"2ndFlrSF\": 1567, \"LowQualFinSF\": 0, \"GrLivArea\": 3500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 959.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 870, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 584500}, {\"Order\": 2452, \"PID\": 528363070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 501.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1305, \"2ndFlrSF\": 1189, \"LowQualFinSF\": 0, \"GrLivArea\": 2494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 803.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 321000}, {\"Order\": 2453, \"PID\": 528365090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 391.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1203, \"2ndFlrSF\": 1323, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 309, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 2454, \"PID\": 528366040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1039.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 1234, \"LowQualFinSF\": 0, \"GrLivArea\": 2799, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 432, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2455, \"PID\": 528429060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 760.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252000}, {\"Order\": 2456, \"PID\": 528429100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1562.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336820}, {\"Order\": 2457, \"PID\": 528429120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 20896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1721.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 2077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1134.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 267, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 423000}, {\"Order\": 2458, \"PID\": 528429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290000}, {\"Order\": 2459, \"PID\": 528439030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1616.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 2460, \"PID\": 528445010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1504.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199000}, {\"Order\": 2461, \"PID\": 528456200, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1254.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 584.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198600}, {\"Order\": 2462, \"PID\": 528477010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 13162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 2036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 405749}, {\"Order\": 2463, \"PID\": 528477030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 11216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 232600}, {\"Order\": 2464, \"PID\": 528480070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1053.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 266000}, {\"Order\": 2465, \"PID\": 528480100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186500}, {\"Order\": 2466, \"PID\": 528480110, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200825}, {\"Order\": 2467, \"PID\": 528480150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 798, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 197000}, {\"Order\": 2468, \"PID\": 528488110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 905.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185000}, {\"Order\": 2469, \"PID\": 528488120, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2470, \"PID\": 528488130, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1293.0, \"TotalBsmtSF\": 1293.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187750}, {\"Order\": 2471, \"PID\": 531363080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1118.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 4, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2472, \"PID\": 531367010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 118.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1400.0, \"TotalBsmtSF\": 1400.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1400, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186800}, {\"Order\": 2473, \"PID\": 531375060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1131.0, \"TotalBsmtSF\": 1131.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 132000}, {\"Order\": 2474, \"PID\": 531375070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2475, \"PID\": 531375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 158000}, {\"Order\": 2476, \"PID\": 531376030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 891.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 891, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 2477, \"PID\": 531376050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1585, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 449.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 2478, \"PID\": 531379030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1837, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 688.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2479, \"PID\": 531450040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 761.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2480, \"PID\": 531451290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1731, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3000, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 248500}, {\"Order\": 2481, \"PID\": 531452080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1398, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2482, \"PID\": 531452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 278.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 1217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2483, \"PID\": 531452210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 362.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 636, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2484, \"PID\": 531478010, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 8900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107000}, {\"Order\": 2485, \"PID\": 531479030, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2486, \"PID\": 532351060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2487, \"PID\": 532351090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1332.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2488, \"PID\": 532351150, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1286, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2489, \"PID\": 532353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2490, \"PID\": 532353180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 8471, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 46.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 506.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2491, \"PID\": 532376080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2492, \"PID\": 532376180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2493, \"PID\": 532376250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2494, \"PID\": 532378050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120875}, {\"Order\": 2495, \"PID\": 532378070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 375.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 935, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2496, \"PID\": 532378130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2497, \"PID\": 532378160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 465.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 447.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2498, \"PID\": 532378220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8789, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129200}, {\"Order\": 2499, \"PID\": 532476050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 497.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1748.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2151, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 4, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 641, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 800, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2500, \"PID\": 533110130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 16059, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2417, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2501, \"PID\": 533125120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 692.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1118.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 208, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 2502, \"PID\": 533127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 310000}, {\"Order\": 2503, \"PID\": 533128030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13346, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 1129, \"LowQualFinSF\": 0, \"GrLivArea\": 2295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 2504, \"PID\": 533128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"ImStucc\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 757.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262000}, {\"Order\": 2505, \"PID\": 533206040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3628, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176400}, {\"Order\": 2506, \"PID\": 533208050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3316, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1247.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1247, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1247, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2507, \"PID\": 533212100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2508, \"PID\": 533212110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147400}, {\"Order\": 2509, \"PID\": 533212120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2510, \"PID\": 533212130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 144152}, {\"Order\": 2511, \"PID\": 533221080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 2512, \"PID\": 533223010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 241.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183900}, {\"Order\": 2513, \"PID\": 533223080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 673, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 153, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2514, \"PID\": 533223110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2515, \"PID\": 533241010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 114.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 382, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2516, \"PID\": 533242030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 2517, \"PID\": 533250130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 9549, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1057.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2518, \"PID\": 533252020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2519, \"PID\": 533253030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1009.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 44.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2520, \"PID\": 533253050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 3640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2521, \"PID\": 533253090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3874, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 807.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 419.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2522, \"PID\": 533253160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 526.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2523, \"PID\": 533350050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 50271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 1842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1842, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 857, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 385000}, {\"Order\": 2524, \"PID\": 534125210, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 13110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2525, \"PID\": 534126060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 10192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2526, \"PID\": 534127190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 1203.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2156, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2156, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 290, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 2527, \"PID\": 534127270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 404.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 708.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 708, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 119, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2528, \"PID\": 534128210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 435.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 222, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2529, \"PID\": 534129230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165150}, {\"Order\": 2530, \"PID\": 534175100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 264, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164500}, {\"Order\": 2531, \"PID\": 534176250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1164.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2532, \"PID\": 534201130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2533, \"PID\": 534201230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2534, \"PID\": 534201250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1770, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 270, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 455, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2535, \"PID\": 534201260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 94, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157500}, {\"Order\": 2536, \"PID\": 534201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 2537, \"PID\": 534201300, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2538, \"PID\": 534202020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124400}, {\"Order\": 2539, \"PID\": 534202180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 402.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 568.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2540, \"PID\": 534226060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 661.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2541, \"PID\": 534250300, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1993, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2542, \"PID\": 534275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 319, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2543, \"PID\": 534276010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2544, \"PID\": 534276230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1098.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 145000}, {\"Order\": 2545, \"PID\": 534400120, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 34.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 25, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 460, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185900}, {\"Order\": 2546, \"PID\": 534403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2547, \"PID\": 534403400, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 748.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2548, \"PID\": 534403440, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2549, \"PID\": 534427090, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2550, \"PID\": 534428060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 8973, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 28.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2551, \"PID\": 534429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 2552, \"PID\": 534430050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129800}, {\"Order\": 2553, \"PID\": 534430110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2554, \"PID\": 534431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1043, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1043, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2555, \"PID\": 534451050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 4712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 456, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 63, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 121600}, {\"Order\": 2556, \"PID\": 534451120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 5900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2557, \"PID\": 534451130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 5825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79900}, {\"Order\": 2558, \"PID\": 534453150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 7438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 316, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2559, \"PID\": 534455080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2560, \"PID\": 534475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1404.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 324, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 146500}, {\"Order\": 2561, \"PID\": 534476100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2562, \"PID\": 534477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 756.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1380.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 2136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 2563, \"PID\": 534479130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 165.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 958, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2564, \"PID\": 534479240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2565, \"PID\": 534479300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2566, \"PID\": 535101110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2567, \"PID\": 535103070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 939.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 307.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2568, \"PID\": 535105160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98600}, {\"Order\": 2569, \"PID\": 535125060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 2157, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2570, \"PID\": 535150240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 118000}, {\"Order\": 2571, \"PID\": 535150300, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 25419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 4, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 184.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 1360, \"LowQualFinSF\": 392, \"GrLivArea\": 3112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 552, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 512, \"PoolQC\": \"Ex\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 235000}, {\"Order\": 2572, \"PID\": 535151080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 9723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 332.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2573, \"PID\": 535151130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 303.0, \"TotalBsmtSF\": 1106.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2574, \"PID\": 535152070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 86, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2575, \"PID\": 535152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2576, \"PID\": 535176050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 175.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145250}, {\"Order\": 2577, \"PID\": 535177100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9610, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 2578, \"PID\": 535178100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 281.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 191, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2579, \"PID\": 535179050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 14850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 895.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 122, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2580, \"PID\": 535180020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 914.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 353.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 2581, \"PID\": 535180070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 64.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134450}, {\"Order\": 2582, \"PID\": 535301010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 943.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135960}, {\"Order\": 2583, \"PID\": 535301150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8092, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 156000}, {\"Order\": 2584, \"PID\": 535303050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1367.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2585, \"PID\": 535304020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2586, \"PID\": 535305120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 522.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2587, \"PID\": 535325130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 301.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2588, \"PID\": 535325340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 488.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 517.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2589, \"PID\": 535325350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 912.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2590, \"PID\": 535325450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2591, \"PID\": 535325460, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 21299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 929.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 791.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2592, \"PID\": 535327210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 521.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 75, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 323, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2593, \"PID\": 535353180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 22136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1153.0, \"TotalBsmtSF\": 2171.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1248, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1008.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 631, \"OpenPorchSF\": 48, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2594, \"PID\": 535354130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 900, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2595, \"PID\": 535355100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 865, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2596, \"PID\": 535375040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 713, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 161, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99800}, {\"Order\": 2597, \"PID\": 535376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 418.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2598, \"PID\": 535376100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1073.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108480}, {\"Order\": 2599, \"PID\": 535377070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 715, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 75, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68000}, {\"Order\": 2600, \"PID\": 535377100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 448, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 2601, \"PID\": 535379100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1130, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 229, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2602, \"PID\": 535380010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 821, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155500}, {\"Order\": 2603, \"PID\": 535380130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10818, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 981, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2604, \"PID\": 535381060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 105000}, {\"Order\": 2605, \"PID\": 535382020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 2414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2606, \"PID\": 535382130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1936, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 370, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 436, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2607, \"PID\": 535401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 445.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 2608, \"PID\": 535402070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1047.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159950}, {\"Order\": 2609, \"PID\": 535402100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 379.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1083.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 345, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2610, \"PID\": 535402220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 128, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2611, \"PID\": 535402230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 701.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1135.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1207, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 2612, \"PID\": 535403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 600.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2613, \"PID\": 535403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 8910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 655.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2614, \"PID\": 535403200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 207.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 2615, \"PID\": 535404080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 7100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2616, \"PID\": 535425040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1773, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 2617, \"PID\": 535425050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2618, \"PID\": 535425080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 802.0, \"TotalBsmtSF\": 1438.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1900, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 520, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 2619, \"PID\": 535426195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 16321, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1277.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 258, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2620, \"PID\": 535450100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 597.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 2621, \"PID\": 535450180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 2622, \"PID\": 535451190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 2623, \"PID\": 535451210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2624, \"PID\": 535453160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133700}, {\"Order\": 2625, \"PID\": 535454030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81400}, {\"Order\": 2626, \"PID\": 535454050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 2627, \"PID\": 535454060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2628, \"PID\": 535456010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1556.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1556, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2629, \"PID\": 535456020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 179.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 506.0, \"BsmtUnfSF\": 465.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2630, \"PID\": 535457070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 162, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2631, \"PID\": 535477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2632, \"PID\": 535478010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 10205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2633, \"PID\": 535478070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 809.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 236.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2634, \"PID\": 535478090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2635, \"PID\": 535478110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 953.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 1025.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2636, \"PID\": 902100110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 9856, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 1007, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 167, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2637, \"PID\": 902100130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9906, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 518, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 107000}, {\"Order\": 2638, \"PID\": 902101050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2639, \"PID\": 902103090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 863.0, \"TotalBsmtSF\": 1147.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1147, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2640, \"PID\": 902104020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 476, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2641, \"PID\": 902106040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2642, \"PID\": 902106090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6451, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 208.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 2643, \"PID\": 902108060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 66.0, \"LotArea\": 3960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 502.0, \"TotalBsmtSF\": 502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 502, \"2ndFlrSF\": 502, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2644, \"PID\": 902109010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 813, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 813, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2645, \"PID\": 902110120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7745, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 867, \"LowQualFinSF\": 0, \"GrLivArea\": 1951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 6, \"EnclosedPorch\": 28, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2646, \"PID\": 902110130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7741, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 143.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 2647, \"PID\": 902111010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5633, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 81, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2648, \"PID\": 902125020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1880, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 661, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 293, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 2649, \"PID\": 902128020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2650, \"PID\": 902128100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 648.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 734, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2651, \"PID\": 902134060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 7614, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1905, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 714, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 104, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96900}, {\"Order\": 2652, \"PID\": 902204060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2653, \"PID\": 902204120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 296, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2654, \"PID\": 902206020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2655, \"PID\": 902206090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 297, \"LowQualFinSF\": 0, \"GrLivArea\": 1182, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 378.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2656, \"PID\": 902207080, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 5820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 906.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1163, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126175}, {\"Order\": 2657, \"PID\": 902207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 48.0, \"LotArea\": 5747, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 2658, \"PID\": 902301120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 908, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2659, \"PID\": 902305090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 2, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 679, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2660, \"PID\": 902325050, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 2661, \"PID\": 902325100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2104, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2662, \"PID\": 902325160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 889, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2663, \"PID\": 902328100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 815.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 815, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 330, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2664, \"PID\": 902329070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 684, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114504}, {\"Order\": 2665, \"PID\": 902329090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 998, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 0, \"EnclosedPorch\": 221, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2666, \"PID\": 902400090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 84.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1200.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 125000}, {\"Order\": 2667, \"PID\": 902400110, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 22950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1892, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1107.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 1518, \"LowQualFinSF\": 572, \"GrLivArea\": 3608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 260, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 410, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 475000}, {\"Order\": 2668, \"PID\": 902401090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 5976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 624, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 256, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2669, \"PID\": 902406030, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 4500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2670, \"PID\": 902456015, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 63.0, \"LotArea\": 4761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 2671, \"PID\": 903200050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7446, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 2672, \"PID\": 903202120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 605, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140200}, {\"Order\": 2673, \"PID\": 903206160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1017, \"2ndFlrSF\": 810, \"LowQualFinSF\": 0, \"GrLivArea\": 1827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1943.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 27, \"OpenPorchSF\": 36, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2674, \"PID\": 903225090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2675, \"PID\": 903229040, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 325, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 271, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2676, \"PID\": 903231070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 2677, \"PID\": 903231190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2678, \"PID\": 903231220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 347.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 434, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 258.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 75000}, {\"Order\": 2679, \"PID\": 903231240, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1015, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1015, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 620, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 88000}, {\"Order\": 2680, \"PID\": 903232170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80500}, {\"Order\": 2681, \"PID\": 903233100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1042.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 149000}, {\"Order\": 2682, \"PID\": 903233220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 583, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2683, \"PID\": 903234030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 2684, \"PID\": 903235020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 129, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2685, \"PID\": 903236200, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 993.0, \"TotalBsmtSF\": 993.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2686, \"PID\": 903400030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 11672, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 2687, \"PID\": 903425190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 33120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2688, \"PID\": 903425340, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9873, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 288, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2689, \"PID\": 903430090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 634, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 255.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 394, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2690, \"PID\": 903430130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 153.0, \"LotArea\": 4118, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 693.0, \"TotalBsmtSF\": 693.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 693, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 693, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52500}, {\"Order\": 2691, \"PID\": 903451050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 834, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 2692, \"PID\": 903452090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 665, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 2693, \"PID\": 903454020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 819, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 819, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 72000}, {\"Order\": 2694, \"PID\": 903454080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 198.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2695, \"PID\": 903455090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 803.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 803, \"2ndFlrSF\": 557, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2696, \"PID\": 903456060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1007.0, \"TotalBsmtSF\": 1007.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 2697, \"PID\": 903456090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 234, \"GrLivArea\": 754, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 53, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2698, \"PID\": 903458010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2699, \"PID\": 904100030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 477.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 341, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2700, \"PID\": 904100090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 11136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1921.0, \"TotalBsmtSF\": 1921.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1921, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1921, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2701, \"PID\": 904100170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 225, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2702, \"PID\": 904101040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 6930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 294, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 2703, \"PID\": 904301410, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2704, \"PID\": 904302020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 830.0, \"TotalBsmtSF\": 830.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2705, \"PID\": 904302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 373.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2706, \"PID\": 905100030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 459.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2707, \"PID\": 905101330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 2708, \"PID\": 905101450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154500}, {\"Order\": 2709, \"PID\": 905103130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153600}, {\"Order\": 2710, \"PID\": 905103140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 97.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 328.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 68, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 164500}, {\"Order\": 2711, \"PID\": 905103180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 934, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 934, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 77, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2712, \"PID\": 905105010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1059, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1059, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2713, \"PID\": 905106210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11553, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1159, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 466, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2714, \"PID\": 905107070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 463.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 2715, \"PID\": 905107220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 982.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1458, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2716, \"PID\": 905107240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2717, \"PID\": 905107300, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 794.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 2718, \"PID\": 905108090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9662, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1967.0, \"TotalBsmtSF\": 1967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2719, \"PID\": 905108120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1466.0, \"TotalBsmtSF\": 1949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2720, \"PID\": 905200280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 441.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 2721, \"PID\": 905200290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 682.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2722, \"PID\": 905200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 17920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1085.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 418, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 312, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 2723, \"PID\": 905200380, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2724, \"PID\": 905200490, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1965, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2725, \"PID\": 905201090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 304, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2726, \"PID\": 905202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 826.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 1865.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1830, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 115, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 2727, \"PID\": 905202210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 13050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 850.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2728, \"PID\": 905225080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 15593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 701.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1304, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 667.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2729, \"PID\": 905300010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2730, \"PID\": 905300080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 241, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2731, \"PID\": 905351045, \"MSSubClass\": 150, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 1700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 33.0, \"TotalBsmtSF\": 430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 680, \"LowQualFinSF\": 140, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148400}, {\"Order\": 2732, \"PID\": 905351150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 445.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 190000}, {\"Order\": 2733, \"PID\": 905402110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2734, \"PID\": 905403050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 6488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 799, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 128000}, {\"Order\": 2735, \"PID\": 905426100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 103, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2736, \"PID\": 905426150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 626, \"LowQualFinSF\": 0, \"GrLivArea\": 2201, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 586, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 738, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 274970}, {\"Order\": 2737, \"PID\": 905427010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 19950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2738, \"PID\": 905427030, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 19800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1411.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 1836, \"LowQualFinSF\": 0, \"GrLivArea\": 3672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 684, \"OpenPorchSF\": 80, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2739, \"PID\": 905427140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11679, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1164.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 453, \"OpenPorchSF\": 253, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2740, \"PID\": 905451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 348, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2741, \"PID\": 905451410, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10519, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1057.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2742, \"PID\": 905452140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 325.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136900}, {\"Order\": 2743, \"PID\": 905452150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 532.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 541, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2744, \"PID\": 905475150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 6420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 2745, \"PID\": 905477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 2746, \"PID\": 905480160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 454, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91500}, {\"Order\": 2747, \"PID\": 906202040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 40.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2748, \"PID\": 906204180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1246, \"LowQualFinSF\": 0, \"GrLivArea\": 2559, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 245, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 209000}, {\"Order\": 2749, \"PID\": 906223180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9554, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1911, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2750, \"PID\": 906225180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 261.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1083.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 2751, \"PID\": 906380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 133.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1308.0, \"TotalBsmtSF\": 1308.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 848.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229800}, {\"Order\": 2752, \"PID\": 906380150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 393.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 183600}, {\"Order\": 2753, \"PID\": 906380170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7406, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 515.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 2754, \"PID\": 906380180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193879}, {\"Order\": 2755, \"PID\": 906382030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221500}, {\"Order\": 2756, \"PID\": 906382040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204900}, {\"Order\": 2757, \"PID\": 906382050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 571, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239799}, {\"Order\": 2758, \"PID\": 906392090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13377, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 260.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233555}, {\"Order\": 2759, \"PID\": 906392100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2760, \"PID\": 906392120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1122.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 1570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1590, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294900}, {\"Order\": 2761, \"PID\": 906394010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1809, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 209700}, {\"Order\": 2762, \"PID\": 906394040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1558.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2763, \"PID\": 906394060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 532.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2764, \"PID\": 906420020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 119.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 927, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1915, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 2765, \"PID\": 906426090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 36500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 812.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 198, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2766, \"PID\": 906475050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Metal\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 130, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2767, \"PID\": 906475200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 70761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 1533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1533, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2768, \"PID\": 906476140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 853.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 535.0, \"TotalBsmtSF\": 1388.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1388, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 2769, \"PID\": 907125020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2770, \"PID\": 907125080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2771, \"PID\": 907130110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 795, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 413, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2772, \"PID\": 907131070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 579.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 2773, \"PID\": 907135230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 13568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 274.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2774, \"PID\": 907175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2775, \"PID\": 907175060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2776, \"PID\": 907180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2777, \"PID\": 907181090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9272, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1749, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2778, \"PID\": 907187010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 13426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 57.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 107, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2779, \"PID\": 907192010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2780, \"PID\": 907194130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 2781, \"PID\": 907196020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1541.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 468, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 2782, \"PID\": 907200170, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 428.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2783, \"PID\": 907201160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 62.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 317.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2784, \"PID\": 907201230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2785, \"PID\": 907202140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 971.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 971, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2786, \"PID\": 907203010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 9560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2787, \"PID\": 907203040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 149900}, {\"Order\": 2788, \"PID\": 907227090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2789, \"PID\": 907230240, \"MSSubClass\": 160, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 3612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Landmrk\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2790, \"PID\": 907251100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 1989, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2791, \"PID\": 907252050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 199.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 826.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2792, \"PID\": 907254050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 9468, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2793, \"PID\": 907255010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2794, \"PID\": 907255050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1787, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1787, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2795, \"PID\": 907262080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8726, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 1909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2796, \"PID\": 907265030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 668.0, \"TotalBsmtSF\": 1654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1654, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2797, \"PID\": 907270050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10566, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 1124, \"LowQualFinSF\": 0, \"GrLivArea\": 2214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 646.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268500}, {\"Order\": 2798, \"PID\": 907275030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210900}, {\"Order\": 2799, \"PID\": 907285010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 258.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1070, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 2800, \"PID\": 907285100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 1045, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 2801, \"PID\": 907290020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 989, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274300}, {\"Order\": 2802, \"PID\": 907290080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216837}, {\"Order\": 2803, \"PID\": 907290160, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2804, \"PID\": 907290230, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155900}, {\"Order\": 2805, \"PID\": 907290260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1079.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 685.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233230}, {\"Order\": 2806, \"PID\": 907401050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2807, \"PID\": 907401080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2808, \"PID\": 907405030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2809, \"PID\": 907410040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8581, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203160}, {\"Order\": 2810, \"PID\": 907410100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 827, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195800}, {\"Order\": 2811, \"PID\": 907410110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212900}, {\"Order\": 2812, \"PID\": 907412010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2813, \"PID\": 907414040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198000}, {\"Order\": 2814, \"PID\": 907418020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 750, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173900}, {\"Order\": 2815, \"PID\": 907420070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 163990}, {\"Order\": 2816, \"PID\": 907420090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164990}, {\"Order\": 2817, \"PID\": 908102020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 337.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 420, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 2818, \"PID\": 908102320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 17755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2819, \"PID\": 908102330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2820, \"PID\": 908103310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 7840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 355.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2821, \"PID\": 908103320, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2822, \"PID\": 908127050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 16133, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2823, \"PID\": 908128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2824, \"PID\": 908130020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 475.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 297.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117250}, {\"Order\": 2825, \"PID\": 908178050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1150.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1150, \"LowQualFinSF\": 0, \"GrLivArea\": 2314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2826, \"PID\": 908186060, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2827, \"PID\": 908186070, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 140000}, {\"Order\": 2828, \"PID\": 908186090, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 142500}, {\"Order\": 2829, \"PID\": 908188110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2830, \"PID\": 908188120, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2831, \"PID\": 908188130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2832, \"PID\": 908188140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2833, \"PID\": 908188150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 3363, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 976.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2834, \"PID\": 908225180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6956, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 312, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 265.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97900}, {\"Order\": 2835, \"PID\": 908227010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 846, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 92000}, {\"Order\": 2836, \"PID\": 908227030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1669, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 107000}, {\"Order\": 2837, \"PID\": 908227040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 658.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 658, \"2ndFlrSF\": 526, \"LowQualFinSF\": 0, \"GrLivArea\": 1184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 81000}, {\"Order\": 2838, \"PID\": 908228040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 2839, \"PID\": 908275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 167.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2840, \"PID\": 908275290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 16012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 691.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 609.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2841, \"PID\": 909101050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 207, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2842, \"PID\": 909101080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 450, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 2843, \"PID\": 909101190, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 795.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 795, \"LowQualFinSF\": 481, \"GrLivArea\": 2230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2844, \"PID\": 909101330, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8088, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1922, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 35000}, {\"Order\": 2845, \"PID\": 909103020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 218, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2846, \"PID\": 909131125, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 7082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 980, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2847, \"PID\": 909175030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1192, \"2ndFlrSF\": 403, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2848, \"PID\": 909176180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 128.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 493, \"LowQualFinSF\": 0, \"GrLivArea\": 1551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2849, \"PID\": 909201180, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 58.0, \"LotArea\": 6430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 816, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128000}, {\"Order\": 2850, \"PID\": 909250070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 424.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 743, \"2ndFlrSF\": 736, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 530, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2851, \"PID\": 909250120, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 892, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138887}, {\"Order\": 2852, \"PID\": 909250200, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 4899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 2853, \"PID\": 909250210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 514, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2854, \"PID\": 909253080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9399, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 818, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1919.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2855, \"PID\": 909254070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 901, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200100}, {\"Order\": 2856, \"PID\": 909256010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10164, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2857, \"PID\": 909256020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2858, \"PID\": 909275230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 272, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2859, \"PID\": 909275250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 940, \"2ndFlrSF\": 610, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 429, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2860, \"PID\": 909276010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 725, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2861, \"PID\": 909276070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 113, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2862, \"PID\": 909279040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 67, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2863, \"PID\": 909280030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2864, \"PID\": 909280070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 8170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 526.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 549, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 2865, \"PID\": 909281010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1175, \"LowQualFinSF\": 0, \"GrLivArea\": 2345, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2866, \"PID\": 909282060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 104, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 2867, \"PID\": 909282110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 14210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 697, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 365.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2868, \"PID\": 909425120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 296.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 547.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1811, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 230000}, {\"Order\": 2869, \"PID\": 909425180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 459.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1283.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2870, \"PID\": 909426060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 405.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2871, \"PID\": 909428110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 375.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2872, \"PID\": 909475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 734.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 2873, \"PID\": 910200020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 102000}, {\"Order\": 2874, \"PID\": 910200060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 132, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145400}, {\"Order\": 2875, \"PID\": 910203100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 61.0, \"LotArea\": 8534, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72000}, {\"Order\": 2876, \"PID\": 910203230, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 272.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 2877, \"PID\": 910207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8765, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 327.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 106500}, {\"Order\": 2878, \"PID\": 910226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 327.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2879, \"PID\": 911175360, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 439, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 47, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2880, \"PID\": 911175410, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 69.0, \"LotArea\": 12366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 23, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 51689}, {\"Order\": 2881, \"PID\": 911175430, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 35311}, {\"Order\": 2882, \"PID\": 911175440, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2883, \"PID\": 911225110, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 360, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 2884, \"PID\": 911370430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5748, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1778, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2885, \"PID\": 911370530, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2886, \"PID\": 913350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 23580, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242500}, {\"Order\": 2887, \"PID\": 914452060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1664.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2888, \"PID\": 914474020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9116, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 2889, \"PID\": 914476050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2890, \"PID\": 914476130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 11080, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 257.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2891, \"PID\": 914476500, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1907.0, \"TotalBsmtSF\": 1907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1959, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 766.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 171000}, {\"Order\": 2892, \"PID\": 916225130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 26178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 293.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1210.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 1281, \"LowQualFinSF\": 0, \"GrLivArea\": 2519, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 2893, \"PID\": 916252170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2894, \"PID\": 916325040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 50102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 909.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1650, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 250764}, {\"Order\": 2895, \"PID\": 916326010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 653.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1686.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 574, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2896, \"PID\": 916402125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 13811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2897, \"PID\": 916403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1309.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2898, \"PID\": 916403130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2514, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 693.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2899, \"PID\": 916460070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1136.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 129.0, \"TotalBsmtSF\": 1381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2900, \"PID\": 916475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 630.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 2901, \"PID\": 916477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13618, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2902, \"PID\": 921205030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11443, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2028, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 326, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 369900}, {\"Order\": 2903, \"PID\": 921205050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 382.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 225, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 359900}, {\"Order\": 2904, \"PID\": 923125030, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 125.0, \"LotArea\": 31250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81500}, {\"Order\": 2905, \"PID\": 923202025, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1243.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 45.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2906, \"PID\": 923203090, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 897.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 125, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2907, \"PID\": 923203100, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 443.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 405.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 199, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2908, \"PID\": 923205120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 17217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84500}, {\"Order\": 2909, \"PID\": 923225190, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2910, \"PID\": 923225240, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 173.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 757.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2911, \"PID\": 923225260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 3964, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 837.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 1230, \"LowQualFinSF\": 0, \"GrLivArea\": 2521, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 728, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151400}, {\"Order\": 2912, \"PID\": 923225510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 2913, \"PID\": 923226150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1503.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2914, \"PID\": 923226180, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 2915, \"PID\": 923226290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79400}, {\"Order\": 2916, \"PID\": 923227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2917, \"PID\": 923228130, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 92000}, {\"Order\": 2918, \"PID\": 923228180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 87550}, {\"Order\": 2919, \"PID\": 923228210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 2920, \"PID\": 923228260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90500}, {\"Order\": 2921, \"PID\": 923228310, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1894, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 71000}, {\"Order\": 2922, \"PID\": 923229110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 12640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 396.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150900}, {\"Order\": 2923, \"PID\": 923230040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9297, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 188000}, {\"Order\": 2924, \"PID\": 923250060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2925, \"PID\": 923251180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 20000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 131000}, {\"Order\": 2926, \"PID\": 923275080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 7937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1003.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1003, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1003, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2927, \"PID\": 923276100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 324.0, \"BsmtUnfSF\": 239.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2928, \"PID\": 923400125, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2929, \"PID\": 924100070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1071.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 123.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1389, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2930, \"PID\": 924151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 1004, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "alt.Chart(train).mark_boxplot().encode(\n",
        "    x='OverallQual:O',\n",
        "    y='SalePrice:Q',\n",
        "    color='OverallQual:N'\n",
        ").properties(\n",
        "    width=500,\n",
        "    height=300\n",
        ")"
      ],
      "id": "cell-8"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Heatmaps\n",
        "\n",
        "Creation of a basic heatmap using **`.mark_rect()` method**."
      ],
      "id": "e8638ca1-c715-4da4-b5c8-a20e72ac4ed1"
    },
    {
      "cell_type": "code",
      "execution_count": 18,
      "metadata": {
        "cell_id": "0ec460a726ea46218dd8d2edab18e762",
        "deepnote_cell_type": "code",
        "deepnote_to_be_reexecuted": false,
        "execution_millis": 1017,
        "execution_start": 1685107097954,
        "papermill": {
          "duration": 0.541094,
          "end_time": "2023-01-11T23:38:28.878735",
          "exception": false,
          "start_time": "2023-01-11T23:38:28.337641",
          "status": "completed"
        },
        "source_hash": "e8b2e0cd",
        "tags": []
      },
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-c51cefbf805e4ad6be7329c216bdaf41.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-c51cefbf805e4ad6be7329c216bdaf41.vega-embed details,\n",
              "  #altair-viz-c51cefbf805e4ad6be7329c216bdaf41.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-c51cefbf805e4ad6be7329c216bdaf41\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-c51cefbf805e4ad6be7329c216bdaf41\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-c51cefbf805e4ad6be7329c216bdaf41\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-bd4440f2bd659840503c9701cdb81363\"}, \"mark\": {\"type\": \"rect\"}, \"encoding\": {\"color\": {\"aggregate\": \"average\", \"field\": \"SalePrice\", \"type\": \"quantitative\"}, \"tooltip\": [{\"field\": \"MSZoning\", \"type\": \"nominal\"}, {\"field\": \"ExterQual\", \"type\": \"nominal\"}, {\"aggregate\": \"average\", \"field\": \"SalePrice\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"MSZoning\", \"type\": \"nominal\"}, \"y\": {\"field\": \"ExterQual\", \"type\": \"nominal\"}}, \"height\": 300, \"width\": 500, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-bd4440f2bd659840503c9701cdb81363\": [{\"Order\": 1, \"PID\": 526301100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 141.0, \"LotArea\": 31770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2, \"PID\": 526350040, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 80.0, \"LotArea\": 11622, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 3, \"PID\": 526351010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 393, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 12500, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 4, \"PID\": 526353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1045.0, \"TotalBsmtSF\": 2110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 5, \"PID\": 527105010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189900}, {\"Order\": 6, \"PID\": 527105030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 7, \"PID\": 527127150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 8, \"PID\": 527145080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 263.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191500}, {\"Order\": 9, \"PID\": 527146030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1180.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 10, \"PID\": 527162130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 776, \"LowQualFinSF\": 0, \"GrLivArea\": 1804, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 11, \"PID\": 527163010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 763, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1655, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 157, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 12, \"PID\": 527165230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1992, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 935.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 233.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 13, \"PID\": 527166040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180400}, {\"Order\": 14, \"PID\": 527180040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 15, \"PID\": 527182190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 1120.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 16, \"PID\": 527216070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 53504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 603.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1690, \"2ndFlrSF\": 1589, \"LowQualFinSF\": 0, \"GrLivArea\": 3279, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 841.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 503, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 538000}, {\"Order\": 17, \"PID\": 527225035, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 152.0, \"LotArea\": 12134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1988, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 427.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 325, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 18, \"PID\": 527258010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 2, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 1856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394432}, {\"Order\": 19, \"PID\": 527276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 19138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 20, \"PID\": 527302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 163.0, \"BsmtUnfSF\": 589.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 21, \"PID\": 527358140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 22, \"PID\": 527358200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 81.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 885.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1173, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 170000}, {\"Order\": 23, \"PID\": 527368020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 814, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 24, \"PID\": 527402200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11241, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 25, \"PID\": 527402250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12537, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 26, \"PID\": 527403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 27, \"PID\": 527404120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 78.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 28, \"PID\": 527425090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 29, \"PID\": 527427230, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 5858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1051.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 30, \"PID\": 527451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 327.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 31, \"PID\": 527451330, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 32, \"PID\": 527451410, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 381.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 88000}, {\"Order\": 33, \"PID\": 527452190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 709.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 34, \"PID\": 527453130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 514.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 35, \"PID\": 527453150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 836.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 36, \"PID\": 527454200, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 37, \"PID\": 528108120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1590.0, \"TotalBsmtSF\": 1590.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1627, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 2334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 376162}, {\"Order\": 38, \"PID\": 528112020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 39, \"PID\": 528120060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1940, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395192}, {\"Order\": 40, \"PID\": 528120090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1544.0, \"TotalBsmtSF\": 1544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290941}, {\"Order\": 41, \"PID\": 528120100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 220000}, {\"Order\": 42, \"PID\": 528120120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 615.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 43, \"PID\": 528138020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1794.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1822, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259000}, {\"Order\": 44, \"PID\": 528138060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1515.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 45, \"PID\": 528150070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12919, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 760.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 2330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 611657}, {\"Order\": 46, \"PID\": 528175010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6371, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224000}, {\"Order\": 47, \"PID\": 528176010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1095.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1473.0, \"TotalBsmtSF\": 2846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 958.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 500000}, {\"Order\": 48, \"PID\": 528176070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 563, \"LowQualFinSF\": 0, \"GrLivArea\": 2250, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 49, \"PID\": 528180070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 412.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1296.0, \"TotalBsmtSF\": 1752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 50, \"PID\": 528181050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 7132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 51, \"PID\": 528188120, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 52, \"PID\": 528218150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 18494, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1324.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 53, \"PID\": 528228285, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 54, \"PID\": 528228440, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 55, \"PID\": 528231020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 58.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 56, \"PID\": 528240070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 1100, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216500}, {\"Order\": 57, \"PID\": 528240130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185088}, {\"Order\": 58, \"PID\": 528250100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 59, \"PID\": 528292020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9505, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 1151, \"LowQualFinSF\": 0, \"GrLivArea\": 2035, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 60, \"PID\": 528328100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 14774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1393.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2599, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 668, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 333168}, {\"Order\": 61, \"PID\": 528344070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 17433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1629.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1645, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 2475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 962.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 23, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 62, \"PID\": 528358010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 919.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 56, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260400}, {\"Order\": 63, \"PID\": 528363130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 1122, \"LowQualFinSF\": 0, \"GrLivArea\": 2622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 64, \"PID\": 528382020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1999, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 348.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1106, \"LowQualFinSF\": 0, \"GrLivArea\": 2270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 671.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 65, \"PID\": 528382030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 66, \"PID\": 528386040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 14720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 579.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1217.0, \"TotalBsmtSF\": 2033.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2053, \"2ndFlrSF\": 1185, \"LowQualFinSF\": 0, \"GrLivArea\": 3238, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 283, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 67, \"PID\": 528445060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8987, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221500}, {\"Order\": 68, \"PID\": 528456160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 92.0, \"LotArea\": 9215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204500}, {\"Order\": 69, \"PID\": 528458070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1547, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215200}, {\"Order\": 70, \"PID\": 528458110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 488.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1566, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 71, \"PID\": 528477080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 12552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 222.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 956, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 72, \"PID\": 528480090, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271500}, {\"Order\": 73, \"PID\": 531367050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 956.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233000}, {\"Order\": 74, \"PID\": 531369060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 75, \"PID\": 531380080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 76, \"PID\": 531451110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 543.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 119.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 77, \"PID\": 531451280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 635, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 78, \"PID\": 531452020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 79, \"PID\": 531452050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 353, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 80, \"PID\": 531452180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1744, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 238, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 81, \"PID\": 531453010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 82, \"PID\": 531453040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 83, \"PID\": 531477050, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67500}, {\"Order\": 84, \"PID\": 532351140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1318, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 85, \"PID\": 532354090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 899.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1155, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1155, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 86, \"PID\": 532376160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 416, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 87, \"PID\": 532377060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 31.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 88, \"PID\": 532377100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 220, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 89, \"PID\": 532378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6897, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 90, \"PID\": 532479070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 15410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 126.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 859.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 169000}, {\"Order\": 91, \"PID\": 533130020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10186, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 92, \"PID\": 533130130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 981.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1231.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2349, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 362500}, {\"Order\": 93, \"PID\": 533130160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1129.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 823, \"LowQualFinSF\": 0, \"GrLivArea\": 2225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 713.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 94, \"PID\": 533205060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 25.0, \"LotArea\": 4835, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 95, \"PID\": 533208090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 39.0, \"LotArea\": 3515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 96, \"PID\": 533210060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3215, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 97, \"PID\": 533212010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 98, \"PID\": 533212020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 99, \"PID\": 533212060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 376.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 100, \"PID\": 533213030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 101, \"PID\": 533221090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 102, \"PID\": 533221110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1159.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 466.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 103, \"PID\": 533223020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 696, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 104, \"PID\": 533223100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 244.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147110}, {\"Order\": 105, \"PID\": 533238045, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 57.0, \"LotArea\": 12853, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 1642.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 224, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267916}, {\"Order\": 106, \"PID\": 533244030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 7379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 107, \"PID\": 533253060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 4420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 108, \"PID\": 533253210, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1052.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 223, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 109, \"PID\": 533352170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13517, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 475.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 110, \"PID\": 534102025, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 659.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 111, \"PID\": 534129040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1323.0, \"TotalBsmtSF\": 1829.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1829, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 535.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218500}, {\"Order\": 112, \"PID\": 534151175, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1137.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243500}, {\"Order\": 113, \"PID\": 534152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 114, \"PID\": 534152070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 687.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 46.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 1891, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 115, \"PID\": 534152100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10421, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 394.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 734, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 66, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 116, \"PID\": 534176060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 982.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 1161.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1381, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1381, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 117, \"PID\": 534176230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 715, \"LowQualFinSF\": 0, \"GrLivArea\": 1645, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 118, \"PID\": 534202160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142250}, {\"Order\": 119, \"PID\": 534251320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 451.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 81.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1328.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 120, \"PID\": 534276360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128950}, {\"Order\": 121, \"PID\": 534401110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1209, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 122, \"PID\": 534401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 9680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1510, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 123, \"PID\": 534403360, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10600, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136300}, {\"Order\": 124, \"PID\": 534403410, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14112, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1014.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 227, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 125, \"PID\": 534425310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 156.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 126, \"PID\": 534427010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 13260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 127, \"PID\": 534430080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 49.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1029.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142125}, {\"Order\": 128, \"PID\": 534431050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 670.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1929, \"2ndFlrSF\": 532, \"LowQualFinSF\": 0, \"GrLivArea\": 2461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197600}, {\"Order\": 129, \"PID\": 534431070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 17360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1019, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 130, \"PID\": 534450180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 131, \"PID\": 534451150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1940, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 263, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76500}, {\"Order\": 132, \"PID\": 534475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 133, \"PID\": 534476260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 132.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 189, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 134, \"PID\": 534479320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 244.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 135, \"PID\": 535101020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 136, \"PID\": 535106190, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 361.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1169, \"LowQualFinSF\": 0, \"GrLivArea\": 2274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154300}, {\"Order\": 137, \"PID\": 535125010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 287.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 912.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1947.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2207, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 301, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 138, \"PID\": 535126040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 137.0, \"LotArea\": 16492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 713.0, \"BsmtUnfSF\": 557.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 139, \"PID\": 535152010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1604.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 140, \"PID\": 535152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 300, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 141, \"PID\": 535152130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 142, \"PID\": 535152150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 143, \"PID\": 535152250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 144, \"PID\": 535153070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1194.0, \"TotalBsmtSF\": 1194.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 145, \"PID\": 535154050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142000}, {\"Order\": 146, \"PID\": 535175070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 324.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 571.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 143, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 147, \"PID\": 535175180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10725, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 91.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1206, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108538}, {\"Order\": 148, \"PID\": 535179020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 149, \"PID\": 535180130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 832, \"2ndFlrSF\": 505, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 263.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 150, \"PID\": 535302080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 339.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 151, \"PID\": 535302200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 119.0, \"LotArea\": 10895, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 152, \"PID\": 535304060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 153, \"PID\": 535304180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 731.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109000}, {\"Order\": 154, \"PID\": 535325400, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 155, \"PID\": 535327140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 156, \"PID\": 535350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 362.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 157, \"PID\": 535350040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 5868, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 158, \"PID\": 535353190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 17503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97500}, {\"Order\": 159, \"PID\": 535377090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 160, \"PID\": 535401080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 72.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 258.0, \"BsmtUnfSF\": 733.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 161, \"PID\": 535425010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 1080, \"LowQualFinSF\": 0, \"GrLivArea\": 2978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 162, \"PID\": 535450210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 481.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 163, \"PID\": 535453070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 906.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 164, \"PID\": 535454070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 475, \"LowQualFinSF\": 0, \"GrLivArea\": 1385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 165, \"PID\": 535456110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 486.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134800}, {\"Order\": 166, \"PID\": 535457010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1116.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 385, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 167, \"PID\": 535457090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 7635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 350.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 168, \"PID\": 535476350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 263.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1395, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 657, \"OpenPorchSF\": 0, \"EnclosedPorch\": 113, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 169, \"PID\": 535477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 170, \"PID\": 902102100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 771.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80400}, {\"Order\": 171, \"PID\": 902104060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 172, \"PID\": 902106130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4485, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 579.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 51, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 173, \"PID\": 902106140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1028, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 130, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 174, \"PID\": 902110090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 5805, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1073.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1347, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 175, \"PID\": 902125080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1605, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107400}, {\"Order\": 176, \"PID\": 902125160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 4608, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 177, \"PID\": 902128170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 294.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 804, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 178, \"PID\": 902206040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 692.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 390, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 179, \"PID\": 902206130, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 827.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 180, \"PID\": 902206220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 606, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 181, \"PID\": 902206240, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 185, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 334, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 182, \"PID\": 902207130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1923, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 780.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 12789}, {\"Order\": 183, \"PID\": 902207140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1928, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105900}, {\"Order\": 184, \"PID\": 902305110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 228, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 185, \"PID\": 902327040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 966, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 186, \"PID\": 902329030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 187, \"PID\": 902401060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 18, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 188, \"PID\": 902402010, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 7407, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 923.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149700}, {\"Order\": 189, \"PID\": 902402130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 622, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 190, \"PID\": 902402250, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1885, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 777.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 191, \"PID\": 902403070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140750}, {\"Order\": 192, \"PID\": 903204040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1030, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 363.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 193, \"PID\": 903206120, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 194, \"PID\": 903225150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 765, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 765, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 195, \"PID\": 903226160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 452.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 12.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 134000}, {\"Order\": 196, \"PID\": 903227020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 197, \"PID\": 903227150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 955, \"2ndFlrSF\": 498, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 148, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 198, \"PID\": 903228150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 221, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 199, \"PID\": 903232190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 548, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 200, \"PID\": 903233120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 928, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138400}, {\"Order\": 201, \"PID\": 903234050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 164.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 202, \"PID\": 903425110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 10300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 11, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 203, \"PID\": 903426180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 888.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 1074, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 364, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 204, \"PID\": 903426200, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 205, \"PID\": 903430080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 3068, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 662, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 206, \"PID\": 903450110, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 110.0, \"LotArea\": 8472, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 207, \"PID\": 903454060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 372, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3500, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 208, \"PID\": 903476030, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 7630, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 209, \"PID\": 904100140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1032.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 1196, \"LowQualFinSF\": 0, \"GrLivArea\": 2403, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 0, \"EnclosedPorch\": 318, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 244400}, {\"Order\": 210, \"PID\": 904101110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 365.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 211, \"PID\": 904300150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 499, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Po\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 212, \"PID\": 904302260, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1026.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 180, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 213, \"PID\": 904350045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 214, \"PID\": 904351040, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 6449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1907, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 73.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93369}, {\"Order\": 215, \"PID\": 904352190, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 6048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114900}, {\"Order\": 216, \"PID\": 905101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 6342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1875, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94000}, {\"Order\": 217, \"PID\": 905101300, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1832, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 218, \"PID\": 905101310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1768.0, \"TotalBsmtSF\": 1768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 219, \"PID\": 905102060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 1039.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 220, \"PID\": 905103060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11341, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1302.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 221, \"PID\": 905104210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8521, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 842.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 222, \"PID\": 905105070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 668.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 223, \"PID\": 905105200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 47.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 474.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 224, \"PID\": 905106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 663, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 379, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 225, \"PID\": 905106170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137250}, {\"Order\": 226, \"PID\": 905107110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7424, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1373, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1373, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160250}, {\"Order\": 227, \"PID\": 905107250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 453.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 228, \"PID\": 905107320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 328.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1386, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 229, \"PID\": 905109130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 954, \"LowQualFinSF\": 0, \"GrLivArea\": 2260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 328000}, {\"Order\": 230, \"PID\": 905109170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1092.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1483, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1483, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 496, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 231, \"PID\": 905201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 756, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 232, \"PID\": 905202090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 233, \"PID\": 905325030, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23595, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 74.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 192, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 234, \"PID\": 905352140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 336, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 235, \"PID\": 905378040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 18600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 684.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 558, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 236, \"PID\": 905426060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 108.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 835, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 237, \"PID\": 905426200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11479, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 387.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 238, \"PID\": 905451320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 44, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 239, \"PID\": 905452110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 362, \"GrLivArea\": 1531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 209.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 240, \"PID\": 905452160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 954.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 1172.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1172, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 241, \"PID\": 905453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1176.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 242, \"PID\": 905453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 17485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1508, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Partial\", \"SalePrice\": 308030}, {\"Order\": 243, \"PID\": 905475510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1250.0, \"TotalBsmtSF\": 1250.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 244, \"PID\": 905478190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 245, \"PID\": 906201030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 977, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1732, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 246, \"PID\": 906201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 11980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 177.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1433.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1433.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 278, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 247, \"PID\": 906204230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 12361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 86.0, \"TotalBsmtSF\": 946.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1017.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 450, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 248, \"PID\": 906223090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 750.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 249, \"PID\": 906225210, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 250, \"PID\": 906378100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245350}, {\"Order\": 251, \"PID\": 906380190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 252, \"PID\": 906385010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 10402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 740.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198900}, {\"Order\": 253, \"PID\": 906385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1222.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1222, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 254, \"PID\": 906402200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12376, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1470.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 1523, \"LowQualFinSF\": 0, \"GrLivArea\": 3222, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 367, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 255, \"PID\": 906425045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 14235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 614, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 256, \"PID\": 906477110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 257, \"PID\": 907125090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 71, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 258, \"PID\": 907180050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 878.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 259, \"PID\": 907185060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 260, \"PID\": 907200280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 15240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 688.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 261, \"PID\": 907200290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161750}, {\"Order\": 262, \"PID\": 907200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 365, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128200}, {\"Order\": 263, \"PID\": 907203070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 264, \"PID\": 907250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 296.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 265, \"PID\": 907252120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 479.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1581.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 266, \"PID\": 907262050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 9548, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 223.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 458.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 613.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 267, \"PID\": 907280040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 331, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 268, \"PID\": 907290040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1649.0, \"TotalBsmtSF\": 1649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 269, \"PID\": 907290170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 270, \"PID\": 907290240, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 271, \"PID\": 907401090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 10635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 972.0, \"BsmtUnfSF\": 315.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 262, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 272, \"PID\": 907410080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 109.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 761.0, \"TotalBsmtSF\": 1473.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 273, \"PID\": 907414030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185500}, {\"Order\": 274, \"PID\": 908102060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 84900}, {\"Order\": 275, \"PID\": 908102110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 155891}, {\"Order\": 276, \"PID\": 908102130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 277, \"PID\": 908102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 278, \"PID\": 908102300, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 792, \"2ndFlrSF\": 328, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 64000}, {\"Order\": 279, \"PID\": 908103350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125200}, {\"Order\": 280, \"PID\": 908152080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 7819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 422.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 281, \"PID\": 908203100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 282, \"PID\": 908208020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 8546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1121.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 283, \"PID\": 908225320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 94.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1487, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 284, \"PID\": 908226130, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 285, \"PID\": 908275300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1526, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 286, \"PID\": 909100080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 4853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 974.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 287, \"PID\": 909100110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 841, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 288, \"PID\": 909101070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 289, \"PID\": 909176140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 242, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 290, \"PID\": 909176150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 166, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 291, \"PID\": 909177100, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 862, \"2ndFlrSF\": 1788, \"LowQualFinSF\": 0, \"GrLivArea\": 2650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 292, \"PID\": 909250030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 293, \"PID\": 909250060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 804.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 2447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 294, \"PID\": 909281080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 371.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 86, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 295, \"PID\": 909426080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 657.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1075, \"LowQualFinSF\": 0, \"GrLivArea\": 2177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 296, \"PID\": 909427230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 877.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 1152, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266500}, {\"Order\": 297, \"PID\": 909428280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 207, \"EnclosedPorch\": 162, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 298, \"PID\": 909452114, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 423.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203135}, {\"Order\": 299, \"PID\": 909455030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 300, \"PID\": 909455040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 76.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1115.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1191, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1191, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 301, \"PID\": 909475140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15602, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1801, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 289000}, {\"Order\": 302, \"PID\": 910202060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 61.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 358, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 303, \"PID\": 910203250, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 540, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 304, \"PID\": 910205120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 727, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 305, \"PID\": 911128180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 68400}, {\"Order\": 306, \"PID\": 911202100, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 859.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 859, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 102776}, {\"Order\": 307, \"PID\": 911204090, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 54, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 55993}, {\"Order\": 308, \"PID\": 911204100, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1896, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1896.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 265, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 50138}, {\"Order\": 309, \"PID\": 911370510, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246000}, {\"Order\": 310, \"PID\": 914467040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 615.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1916, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 741.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 311, \"PID\": 914475090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9620, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1243.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 375, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 80, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 312, \"PID\": 914476520, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 9196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 313, \"PID\": 914478045, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 473.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169900}, {\"Order\": 314, \"PID\": 914478110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1958.0, \"TotalBsmtSF\": 1958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 315, \"PID\": 916125360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 57200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 334.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 50, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 316, \"PID\": 916386010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 78.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1346, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 317, \"PID\": 916386020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1214.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179781}, {\"Order\": 318, \"PID\": 916386060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 319, \"PID\": 916386090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 774.0, \"TotalBsmtSF\": 774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 1194, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 269500}, {\"Order\": 320, \"PID\": 916455170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 1894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214900}, {\"Order\": 321, \"PID\": 916475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202900}, {\"Order\": 322, \"PID\": 921128020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 13214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2002.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2018, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2018, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378500}, {\"Order\": 323, \"PID\": 923201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 42.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 324, \"PID\": 923202105, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10114, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1430.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 325, \"PID\": 923204150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 326, \"PID\": 923205015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1344.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166500}, {\"Order\": 327, \"PID\": 923225300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83500}, {\"Order\": 328, \"PID\": 923225390, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 31.0, \"LotArea\": 2394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 945, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 329, \"PID\": 923225440, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 2592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 129.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 232.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 536, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 330, \"PID\": 923226250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 331, \"PID\": 923226320, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1491, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75500}, {\"Order\": 332, \"PID\": 923228270, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88250}, {\"Order\": 333, \"PID\": 923228370, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 334, \"PID\": 923230190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 469.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 335, \"PID\": 923251080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 26142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 336, \"PID\": 923276030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 207.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 337, \"PID\": 923276250, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1985, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1216.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 338, \"PID\": 923426070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 22, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 339, \"PID\": 924100050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 388.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 615, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 287, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 340, \"PID\": 924151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1341.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 284.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1679.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 64, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 341, \"PID\": 924152030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12961, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 342, \"PID\": 526302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 343, \"PID\": 526351100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 440.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 844.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 344, \"PID\": 526355080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 542.0, \"TotalBsmtSF\": 1952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 2704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 269, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 345, \"PID\": 527105070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 346, \"PID\": 527105130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 1275, \"LowQualFinSF\": 0, \"GrLivArea\": 2283, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 347, \"PID\": 527107130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1628, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 490, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 348, \"PID\": 527108070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 14892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1746, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377500}, {\"Order\": 349, \"PID\": 527110020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 22.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 350, \"PID\": 527127100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 28.0, \"LotArea\": 7296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 243.0, \"TotalBsmtSF\": 2208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2522, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 351, \"PID\": 527131030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 5664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1659, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 352, \"PID\": 527132090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 353, \"PID\": 527146010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 354, \"PID\": 527161040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 355, \"PID\": 527162110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 94, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 291, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 356, \"PID\": 527162120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 357, \"PID\": 527163040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 799.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 799, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 358, \"PID\": 527163070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 359, \"PID\": 527163130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181316}, {\"Order\": 360, \"PID\": 527164020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 7250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 361, \"PID\": 527164060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 362, \"PID\": 527164090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 702, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1481, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 363, \"PID\": 527165130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 364, \"PID\": 527166010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 694.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 1983, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 365, \"PID\": 527180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1424.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 508, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 366, \"PID\": 527182110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 187500}, {\"Order\": 367, \"PID\": 527214050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 17423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 748.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 2216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1166.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 501837}, {\"Order\": 368, \"PID\": 527254020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 464.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2046.0, \"TotalBsmtSF\": 2046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372500}, {\"Order\": 369, \"PID\": 527258020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 16158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 370, \"PID\": 527276160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1934, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 371, \"PID\": 527301320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 692.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 1200, \"LowQualFinSF\": 0, \"GrLivArea\": 2353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 372, \"PID\": 527302175, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 17043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1586, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 373, \"PID\": 527326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 82500}, {\"Order\": 374, \"PID\": 527326150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 375, \"PID\": 527352150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 154000}, {\"Order\": 376, \"PID\": 527353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 363.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 377, \"PID\": 527353060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 229.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1539, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2673, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 378, \"PID\": 527354100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 225.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 379, \"PID\": 527354200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 380, \"PID\": 527355150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1420.0, \"TotalBsmtSF\": 2524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 381, \"PID\": 527356040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157000}, {\"Order\": 382, \"PID\": 527359050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 383, \"PID\": 527359180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 448, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 384, \"PID\": 527364030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1016, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 581.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240900}, {\"Order\": 385, \"PID\": 527365030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 8004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 1103, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 263435}, {\"Order\": 386, \"PID\": 527366030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1058.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 387, \"PID\": 527368010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 225.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 471.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 839, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 388, \"PID\": 527375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1333.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 490, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 389, \"PID\": 527375180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 888.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 390, \"PID\": 527375210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 391, \"PID\": 527376100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 392, \"PID\": 527378140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 333.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 2119, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158000}, {\"Order\": 393, \"PID\": 527401160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 394, \"PID\": 527402220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1002, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 902.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 395, \"PID\": 527403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 439.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 472.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 396, \"PID\": 527404020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1180.0, \"TotalBsmtSF\": 1180.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 397, \"PID\": 527404030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 398, \"PID\": 527405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 726.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 399, \"PID\": 527405160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 239.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 400, \"PID\": 527405180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 401, \"PID\": 527425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97000}, {\"Order\": 402, \"PID\": 527425110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 403, \"PID\": 527450280, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 254.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 404, \"PID\": 527451110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 312.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 405, \"PID\": 527451320, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 406, \"PID\": 527451540, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 79.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 407, \"PID\": 527451640, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 510.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 408, \"PID\": 527451650, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 409, \"PID\": 527452060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 410, \"PID\": 527453050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 411, \"PID\": 527453060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 87, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 412, \"PID\": 527453140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 622.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 413, \"PID\": 527454050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 260, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 414, \"PID\": 527454130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2349, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 389.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 415, \"PID\": 527455050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 416, \"PID\": 527455060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 586, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 417, \"PID\": 527455080, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 279.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 418, \"PID\": 527455090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 345.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 419, \"PID\": 527455240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 420, \"PID\": 527455280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 421, \"PID\": 528102040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1172.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337500}, {\"Order\": 422, \"PID\": 528102140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 726.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1794, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 462000}, {\"Order\": 423, \"PID\": 528104070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 13518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 860.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1926.0, \"TotalBsmtSF\": 1926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 1174, \"LowQualFinSF\": 0, \"GrLivArea\": 3140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 485000}, {\"Order\": 424, \"PID\": 528106020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1767.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 3094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2402, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 555000}, {\"Order\": 425, \"PID\": 528106070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 404, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 426, \"PID\": 528108010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 640.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1566.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 890.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256300}, {\"Order\": 427, \"PID\": 528108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2042.0, \"TotalBsmtSF\": 2042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 253293}, {\"Order\": 428, \"PID\": 528108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1365, \"2ndFlrSF\": 1325, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 197, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 398800}, {\"Order\": 429, \"PID\": 528108070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 154.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 430, \"PID\": 528108130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 2020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 404000}, {\"Order\": 431, \"PID\": 528108140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 2006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 402861}, {\"Order\": 432, \"PID\": 528110010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 13478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1722.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 2296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 842.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 451950}, {\"Order\": 433, \"PID\": 528110020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 2630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2674, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2674, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 610000}, {\"Order\": 434, \"PID\": 528110090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 424.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1734.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 1088, \"LowQualFinSF\": 0, \"GrLivArea\": 2822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1020.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 582933}, {\"Order\": 435, \"PID\": 528112040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1736.0, \"TotalBsmtSF\": 1736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1736, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1736, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 436, \"PID\": 528116010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 99, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 296000}, {\"Order\": 437, \"PID\": 528118060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 23303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 273, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 409900}, {\"Order\": 438, \"PID\": 528120020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1709.0, \"TotalBsmtSF\": 1709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1717, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255500}, {\"Order\": 439, \"PID\": 528120030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1015.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 1739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 927.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 440, \"PID\": 528120160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 262.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274900}, {\"Order\": 441, \"PID\": 528120170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1037.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1531, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 700.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 442, \"PID\": 528138010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 13514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 285.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1142.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 1774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1808, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 443, \"PID\": 528142040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8834, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1170.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1462, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 444, \"PID\": 528142090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 11362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 862.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 185, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 445, \"PID\": 528142130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1124.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 479.0, \"BsmtUnfSF\": 1603.0, \"TotalBsmtSF\": 3206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 446, \"PID\": 528142150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12878, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 418.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 1760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1760, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 190, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 447, \"PID\": 528144020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1502.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233170}, {\"Order\": 448, \"PID\": 528166060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 922.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2336.0, \"TotalBsmtSF\": 2392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 386250}, {\"Order\": 449, \"PID\": 528166090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 724.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1972.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 2452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 886.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 445000}, {\"Order\": 450, \"PID\": 528168030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1295, \"LowQualFinSF\": 0, \"GrLivArea\": 2400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 451, \"PID\": 528172060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1598.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1606, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1606, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 452, \"PID\": 528174050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 6904, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 453, \"PID\": 528174060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 900.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 454, \"PID\": 528174070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 455, \"PID\": 528175050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 456, \"PID\": 528175060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 457, \"PID\": 528176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 730.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2146.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 2492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 949.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 552000}, {\"Order\": 458, \"PID\": 528178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 117.0, \"LotArea\": 15262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 470.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 643.0, \"TotalBsmtSF\": 2200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 685.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 382500}, {\"Order\": 459, \"PID\": 528180120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 308.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1084.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 460, \"PID\": 528180130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 461, \"PID\": 528186010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 1712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 183, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286500}, {\"Order\": 462, \"PID\": 528186180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 863.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 463, \"PID\": 528188020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 464, \"PID\": 528188060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2268, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 465, \"PID\": 528218090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 466, \"PID\": 528220040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 745.0, \"TotalBsmtSF\": 745.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 745, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167800}, {\"Order\": 467, \"PID\": 528221060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 12589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 468, \"PID\": 528221070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 469, \"PID\": 528228290, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1373.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 470, \"PID\": 528228295, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1569, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1569, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 471, \"PID\": 528228435, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1357.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 472, \"PID\": 528228450, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 473, \"PID\": 528228455, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 474, \"PID\": 528228460, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 11.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160200}, {\"Order\": 475, \"PID\": 528235010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 476, \"PID\": 528235090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1010.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1010, \"2ndFlrSF\": 1257, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 477, \"PID\": 528235200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 478, \"PID\": 528240030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 479, \"PID\": 528240060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 779, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184100}, {\"Order\": 480, \"PID\": 528240150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 481, \"PID\": 528250020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 482, \"PID\": 528250040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8174, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 483, \"PID\": 528253010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 484, \"PID\": 528275070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 1276, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 485, \"PID\": 528275160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 1126, \"LowQualFinSF\": 0, \"GrLivArea\": 2004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 486, \"PID\": 528280230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 487, \"PID\": 528290030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9734, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 113.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 488, \"PID\": 528290120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8123, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 489, \"PID\": 528290180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 8433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 683.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1514, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 490, \"PID\": 528290190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 491, \"PID\": 528292030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1177.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2312, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 492, \"PID\": 528292040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 841.0, \"TotalBsmtSF\": 841.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 493, \"PID\": 528292070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 772.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1038, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 494, \"PID\": 528294050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7848, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 495, \"PID\": 528315090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 673.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1163.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337000}, {\"Order\": 496, \"PID\": 528321010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 15138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 689.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 773.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1490, \"2ndFlrSF\": 1304, \"LowQualFinSF\": 0, \"GrLivArea\": 2794, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 403000}, {\"Order\": 497, \"PID\": 528327070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 1455.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1221, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 327000}, {\"Order\": 498, \"PID\": 528344040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 731.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2450, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1069.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 499, \"PID\": 528344100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 975.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 854.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1225.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 1336, \"LowQualFinSF\": 0, \"GrLivArea\": 2612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 336000}, {\"Order\": 500, \"PID\": 528354050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10208, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 921.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1264.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 1067, \"LowQualFinSF\": 0, \"GrLivArea\": 2344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 889.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 501, \"PID\": 528363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 634.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1526.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 2024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 815.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 502, \"PID\": 528365070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 987.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 1274, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 60, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 503, \"PID\": 528385050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 967, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 102, \"EnclosedPorch\": 209, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 504, \"PID\": 528387030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 372.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 623.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263550}, {\"Order\": 505, \"PID\": 528390100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 46589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 528.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 517, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 402000}, {\"Order\": 506, \"PID\": 528390210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 29959, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 507, \"PID\": 528427020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 244600}, {\"Order\": 508, \"PID\": 528431020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1696.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 972.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 509, \"PID\": 528431070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 294.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1614.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1658, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 510, \"PID\": 528435030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1573.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287090}, {\"Order\": 511, \"PID\": 528435050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 512, \"PID\": 528439060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 513, \"PID\": 528441020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 772.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 689.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 514, \"PID\": 528441090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2490, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 226, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 468000}, {\"Order\": 515, \"PID\": 528456180, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 920, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252678}, {\"Order\": 516, \"PID\": 528456220, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 517, \"PID\": 528456240, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7862, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 27.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208300}, {\"Order\": 518, \"PID\": 528458020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 90.0, \"LotArea\": 7993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 519, \"PID\": 528458040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229456}, {\"Order\": 520, \"PID\": 528458060, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1402.0, \"TotalBsmtSF\": 1402.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 205, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229800}, {\"Order\": 521, \"PID\": 528458140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 984.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 522, \"PID\": 528458160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 645.0, \"TotalBsmtSF\": 1766.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 195, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370878}, {\"Order\": 523, \"PID\": 528458180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1348.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1448, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1448, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238500}, {\"Order\": 524, \"PID\": 528477050, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 981, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 310000}, {\"Order\": 525, \"PID\": 528477070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 121.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 526, \"PID\": 528480040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1043.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 527, \"PID\": 528480130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 438, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241000}, {\"Order\": 528, \"PID\": 528480170, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264500}, {\"Order\": 529, \"PID\": 528482040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1662, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1662, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 530, \"PID\": 528482130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 531, \"PID\": 528488100, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1221.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 532, \"PID\": 528490040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 8736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 771.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 360.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1553.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234500}, {\"Order\": 533, \"PID\": 528490070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8127, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 841, \"LowQualFinSF\": 0, \"GrLivArea\": 1653, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 534, \"PID\": 531363010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 178, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 535, \"PID\": 531363030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1087.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 536, \"PID\": 531363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 537, \"PID\": 531369010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 871, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 538, \"PID\": 531369020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 774.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1512.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 845.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 539, \"PID\": 531371050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10083, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 540, \"PID\": 531375040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 541, \"PID\": 531375090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 542, \"PID\": 531375130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 543, \"PID\": 531376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1450, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224243}, {\"Order\": 544, \"PID\": 531379050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 11492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 1209, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 559.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 545, \"PID\": 531382070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10994, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 366.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 257000}, {\"Order\": 546, \"PID\": 531385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1434.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 547, \"PID\": 531450120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 364.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1730, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 548, \"PID\": 531452010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 626, \"2ndFlrSF\": 591, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 549, \"PID\": 531452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1332.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1332, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 550, \"PID\": 531452260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 786, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 551, \"PID\": 531453100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 141.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 465.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 552, \"PID\": 531475220, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 553, \"PID\": 531477020, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 721.0, \"TotalBsmtSF\": 721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 841, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 841, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 554, \"PID\": 531479020, \"MSSubClass\": 45, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 91, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 555, \"PID\": 532353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 884.0, \"BsmtUnfSF\": 28.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 556, \"PID\": 532353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 557, \"PID\": 532354160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 558, \"PID\": 532354230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9079, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 559, \"PID\": 532376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Family\", \"SalePrice\": 124100}, {\"Order\": 560, \"PID\": 532376110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 561, \"PID\": 532377130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131400}, {\"Order\": 562, \"PID\": 532378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 311.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 62383}, {\"Order\": 563, \"PID\": 532378180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 140.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 564, \"PID\": 532478020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15676, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1733.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 92.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 2014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 462, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 255, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 565, \"PID\": 533135020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11949, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1991, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 601.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 216.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 502, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 566, \"PID\": 533206020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 2880, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1376.0, \"TotalBsmtSF\": 1376.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1376, \"2ndFlrSF\": 1629, \"LowQualFinSF\": 0, \"GrLivArea\": 3005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 177, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280750}, {\"Order\": 567, \"PID\": 533210010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164500}, {\"Order\": 568, \"PID\": 533210020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173733}, {\"Order\": 569, \"PID\": 533213010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 3830, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1726.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 254, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 570, \"PID\": 533213020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4217, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 183.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 571, \"PID\": 533213040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 894.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1471, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 572, \"PID\": 533221040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 249.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 573, \"PID\": 533223030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 574, \"PID\": 533236050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1739, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 172500}, {\"Order\": 575, \"PID\": 533252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1252.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 136.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 501, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 225, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318750}, {\"Order\": 576, \"PID\": 533253070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 3782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211500}, {\"Order\": 577, \"PID\": 533254050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15417, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1619.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 20, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241600}, {\"Order\": 578, \"PID\": 533254110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1487, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180500}, {\"Order\": 579, \"PID\": 533352150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1281.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 580, \"PID\": 534125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 727.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 829, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 581, \"PID\": 534127130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 571.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1442.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 371, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 582, \"PID\": 534127170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9156, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185750}, {\"Order\": 583, \"PID\": 534128010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 859.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 32.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 204, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 350, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 584, \"PID\": 534128020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 782, \"LowQualFinSF\": 0, \"GrLivArea\": 2067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 585, \"PID\": 534128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 735, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 586, \"PID\": 534128190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1369, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256900}, {\"Order\": 587, \"PID\": 534129080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1724, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 588, \"PID\": 534129370, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 589, \"PID\": 534129380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 955.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113000}, {\"Order\": 590, \"PID\": 534151120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 283.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 2288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 591, \"PID\": 534152120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 592, \"PID\": 534175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1127.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 78, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213250}, {\"Order\": 593, \"PID\": 534177230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 594, \"PID\": 534200030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 595, \"PID\": 534202170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 596, \"PID\": 534226120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 466.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 597, \"PID\": 534250400, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 168500}, {\"Order\": 598, \"PID\": 534251030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 509.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 599, \"PID\": 534252240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 251.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 630.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 197, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 600, \"PID\": 534275060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 360, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 601, \"PID\": 534275100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 602, \"PID\": 534276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 603, \"PID\": 534277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 604, \"PID\": 534278070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 201.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177625}, {\"Order\": 605, \"PID\": 534278230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 606, \"PID\": 534400050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 345.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 1516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 152, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 607, \"PID\": 534400290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 217.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 512.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1313, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 121, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 608, \"PID\": 534402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1292.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1292, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145100}, {\"Order\": 609, \"PID\": 534402140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 230.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1154.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 610, \"PID\": 534402170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 549.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 611, \"PID\": 534403370, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 563.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 612, \"PID\": 534426110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 991.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 50.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 613, \"PID\": 534429150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 614, \"PID\": 534431130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 100.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 613.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 615, \"PID\": 534450150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 616, \"PID\": 534451110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 185.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 224, \"LowQualFinSF\": 0, \"GrLivArea\": 1203, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 617, \"PID\": 534475185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 1505.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1505, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 162, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 618, \"PID\": 534475250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 260, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 619, \"PID\": 534476150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 1416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 620, \"PID\": 534476320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 621, \"PID\": 534477110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 556, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 622, \"PID\": 534478230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 607.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 623, \"PID\": 535101120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 624, \"PID\": 535104120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10573, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 3.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 625, \"PID\": 535105100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 247.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1394.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1394, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 185, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 626, \"PID\": 535125070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 1562.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 342, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 627, \"PID\": 535125090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 314.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1186, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 628, \"PID\": 535126010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 576.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 2142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 252, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 629, \"PID\": 535126100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1392.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 630, \"PID\": 535150070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1281, \"2ndFlrSF\": 457, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 631, \"PID\": 535151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 313.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 632, \"PID\": 535152230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 661.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 633, \"PID\": 535154060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 203, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 634, \"PID\": 535154130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 635, \"PID\": 535175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 620.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 636, \"PID\": 535175050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1215.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 234, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 637, \"PID\": 535178040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 565.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1202, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1202, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 638, \"PID\": 535178120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 172.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 727.0, \"TotalBsmtSF\": 1382.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 639, \"PID\": 535179160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 155.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 750.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144000}, {\"Order\": 640, \"PID\": 535300120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 19296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 399.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 690.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 641, \"PID\": 535301170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 1297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1297, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1297, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 642, \"PID\": 535302120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 657.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1866.0, \"TotalBsmtSF\": 1866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 643, \"PID\": 535303110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 8128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 644, \"PID\": 535303150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10634, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1319, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1319, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 645, \"PID\": 535304100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 631.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 646, \"PID\": 535325290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1005.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 647, \"PID\": 535351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 178.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 648, \"PID\": 535352090, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 793, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 649, \"PID\": 535353040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1952, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1031.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1031, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 650, \"PID\": 535353060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102900}, {\"Order\": 651, \"PID\": 535353140, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1699, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 95000}, {\"Order\": 652, \"PID\": 535353240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 699.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 801, \"2ndFlrSF\": 726, \"LowQualFinSF\": 0, \"GrLivArea\": 1527, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 653, \"PID\": 535354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 654, \"PID\": 535354100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 655, \"PID\": 535375010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 656, \"PID\": 535375050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 704, \"LowQualFinSF\": 144, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 140, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 657, \"PID\": 535376060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 658, \"PID\": 535377150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 717, \"2ndFlrSF\": 322, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 111, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 659, \"PID\": 535378020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 9022, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1924, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 660, \"PID\": 535378120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10230, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 661, \"PID\": 535381040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 1064, \"GrLivArea\": 2377, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 432, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142900}, {\"Order\": 662, \"PID\": 535382100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 760, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 663, \"PID\": 535383060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 599, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 599, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 59000}, {\"Order\": 664, \"PID\": 535383070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 198, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 665, \"PID\": 535383110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 666, \"PID\": 535383120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 725, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78500}, {\"Order\": 667, \"PID\": 535402010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1248.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 907.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 668, \"PID\": 535402090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 996.0, \"TotalBsmtSF\": 1380.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1380, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 669, \"PID\": 535402270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 670, \"PID\": 535402330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2634, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 671, \"PID\": 535403190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1958, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 672, \"PID\": 535403210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 559.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1105, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 673, \"PID\": 535403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 674, \"PID\": 535425070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1270.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 675, \"PID\": 535426150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 676, \"PID\": 535450070, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 232, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 677, \"PID\": 535450160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 92900}, {\"Order\": 678, \"PID\": 535450200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 231, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 679, \"PID\": 535451170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 680, \"PID\": 535451250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 352.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 681, \"PID\": 535452090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1041.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 682, \"PID\": 535452100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 683, \"PID\": 535452140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 102.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 732, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118900}, {\"Order\": 684, \"PID\": 535453100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 433.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 95.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1183, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 685, \"PID\": 535453200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 686, \"PID\": 535454100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 832, \"2ndFlrSF\": 629, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 687, \"PID\": 535454160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 431, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 688, \"PID\": 535475010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 7570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1806, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144750}, {\"Order\": 689, \"PID\": 535476110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 124.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 690, \"PID\": 535476240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 7936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 826.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 691, \"PID\": 535477150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 692, \"PID\": 902101010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3950, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 693, \"PID\": 902102080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 682, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 694, \"PID\": 902103100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 4080, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 695, \"PID\": 902103120, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 972, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 696, \"PID\": 902103170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 5720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 455, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 66500}, {\"Order\": 697, \"PID\": 902105050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 496, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 698, \"PID\": 902105060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 699, \"PID\": 902106010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6406, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 269.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 868, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 700, \"PID\": 902106060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1892, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 994, \"LowQualFinSF\": 0, \"GrLivArea\": 2372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 287, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 701, \"PID\": 902109130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94550}, {\"Order\": 702, \"PID\": 902109140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7596, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1000, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 703, \"PID\": 902110080, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3378, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1946, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 651.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 682, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 704, \"PID\": 902134120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 801, \"2ndFlrSF\": 646, \"LowQualFinSF\": 0, \"GrLivArea\": 1447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 705, \"PID\": 902135020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 706, \"PID\": 902201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 707, \"PID\": 902202150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 811.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 811, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 708, \"PID\": 902204080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 709, \"PID\": 902205010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 25, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 45000}, {\"Order\": 710, \"PID\": 902205030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 37900}, {\"Order\": 711, \"PID\": 902206260, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1938, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 886, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91300}, {\"Order\": 712, \"PID\": 902207170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 713, \"PID\": 902300090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 4456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 113000}, {\"Order\": 714, \"PID\": 902301060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 677.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 715, \"PID\": 902301080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 716, \"PID\": 902325070, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1898, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 849.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 1063, \"LowQualFinSF\": 0, \"GrLivArea\": 2138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 717, \"PID\": 902326030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 181, \"OpenPorchSF\": 0, \"EnclosedPorch\": 386, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265979}, {\"Order\": 718, \"PID\": 902327070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 917.0, \"TotalBsmtSF\": 917.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 719, \"PID\": 902329080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1917, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 720, \"PID\": 902330040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 121.0, \"LotArea\": 17671, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1882, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 826, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 424.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 721, \"PID\": 902331010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 3300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 722, \"PID\": 902401130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1920, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 26.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 723, \"PID\": 902402150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 226, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 724, \"PID\": 902405100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 98.0, \"LotArea\": 8820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 561, \"LowQualFinSF\": 120, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 725, \"PID\": 902405120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 436, \"GrLivArea\": 1480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 207.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 119000}, {\"Order\": 726, \"PID\": 902406070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 238, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 727, \"PID\": 902477120, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 523, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 34900}, {\"Order\": 728, \"PID\": 902477130, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 72.0, \"LotArea\": 9392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 245.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 44000}, {\"Order\": 729, \"PID\": 903200080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 144.0, \"LotArea\": 21384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 15.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 730, \"PID\": 903201020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1022.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 731, \"PID\": 903201080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 732, \"PID\": 903202170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 244, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 733, \"PID\": 903205040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 192.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 40, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 734, \"PID\": 903226130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 735, \"PID\": 903226170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 390, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 736, \"PID\": 903227070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 737, \"PID\": 903227090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 825, \"2ndFlrSF\": 587, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 45, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 738, \"PID\": 903228070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 444.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 320, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 739, \"PID\": 903228120, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 740, \"PID\": 903230100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 741, \"PID\": 903231010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 927.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 742, \"PID\": 903231030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 989, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 54, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 743, \"PID\": 903231060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 744, \"PID\": 903231130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1931, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 745, \"PID\": 903232060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 995, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 15, \"EnclosedPorch\": 51, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 746, \"PID\": 903234220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 679.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 994, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 189, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 150, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 747, \"PID\": 903236040, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 134.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 1072.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 5.0, \"GarageArea\": 1184.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 748, \"PID\": 903400220, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11888, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 2134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 268, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214500}, {\"Order\": 749, \"PID\": 903425245, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 883, \"LowQualFinSF\": 0, \"GrLivArea\": 2019, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 509, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 750, \"PID\": 903427120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 751, \"PID\": 903429080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 2500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 752, \"PID\": 903429110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 753, \"PID\": 903430060, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 92.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 929, \"LowQualFinSF\": 371, \"GrLivArea\": 2229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 198, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 104000}, {\"Order\": 754, \"PID\": 903430070, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Sev\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 62500}, {\"Order\": 755, \"PID\": 903451090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 316.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 213, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 756, \"PID\": 903458170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 757, \"PID\": 903475100, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 758, \"PID\": 903476090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1902, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 169.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 978, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 759, \"PID\": 903481120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 760, \"PID\": 903481130, \"MSSubClass\": 85, \"MSZoning\": \"RM\", \"LotFrontage\": 86.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 749.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 63.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 70000}, {\"Order\": 761, \"PID\": 903484110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 262.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 754, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 288, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 762, \"PID\": 904100190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1946, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 704, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88750}, {\"Order\": 763, \"PID\": 904301060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 764, \"PID\": 904301070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 765, \"PID\": 904301100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 766, \"PID\": 904301375, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61000}, {\"Order\": 767, \"PID\": 904351200, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 54.0, \"LotArea\": 6629, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 551.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103600}, {\"Order\": 768, \"PID\": 904351240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 687, \"2ndFlrSF\": 425, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 226.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63000}, {\"Order\": 769, \"PID\": 905101260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12886, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 770, \"PID\": 905101490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 771, \"PID\": 905103040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 92.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 500.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1683, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 772, \"PID\": 905103070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 215, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113500}, {\"Order\": 773, \"PID\": 905105190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 774, \"PID\": 905107310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 775, \"PID\": 905108190, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7252, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 776, \"PID\": 905108220, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 860, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 777, \"PID\": 905200220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 170.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 778, \"PID\": 905200260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 611, \"LowQualFinSF\": 259, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 779, \"PID\": 905200350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15312, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 780, \"PID\": 905225090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 366.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2071, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2071, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 781, \"PID\": 905228050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63900}, {\"Order\": 782, \"PID\": 905229040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1104.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 783, \"PID\": 905325020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 25095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1473, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1473, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 60, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 143000}, {\"Order\": 784, \"PID\": 905377010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 284.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 785, \"PID\": 905377130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 786, \"PID\": 905401100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10708, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 768.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1867, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1867, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 476, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 787, \"PID\": 905402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139600}, {\"Order\": 788, \"PID\": 905402070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 789, \"PID\": 905450020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 790, \"PID\": 905451300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 340.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 791, \"PID\": 905451340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1276, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 60000}, {\"Order\": 792, \"PID\": 905452040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 747, \"LowQualFinSF\": 0, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154400}, {\"Order\": 793, \"PID\": 905452050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 344.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 794, \"PID\": 905475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1089.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1089, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 795, \"PID\": 905475500, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 290.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84000}, {\"Order\": 796, \"PID\": 905476230, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 393.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1049, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 266.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 797, \"PID\": 905478030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11409, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 798, \"PID\": 905480030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 799, \"PID\": 905480210, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 800, \"PID\": 906201021, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 286.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 801, \"PID\": 906201050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 19255, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 450.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 802, \"PID\": 906201130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1983, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 2132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316600}, {\"Order\": 803, \"PID\": 906203120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 177.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 2158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271900}, {\"Order\": 804, \"PID\": 906223060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 137.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 227.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 769, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 425.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 234, \"OpenPorchSF\": 72, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 805, \"PID\": 906223080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1879, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 100, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 806, \"PID\": 906223210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 807, \"PID\": 906226060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 26400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 2016, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 808, \"PID\": 906226070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118964}, {\"Order\": 809, \"PID\": 906226080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1086.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 153337}, {\"Order\": 810, \"PID\": 906226090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 1114, \"LowQualFinSF\": 0, \"GrLivArea\": 2228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 73, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 147983}, {\"Order\": 811, \"PID\": 906226100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 812, \"PID\": 906226110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 813, \"PID\": 906226120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 1120, \"LowQualFinSF\": 0, \"GrLivArea\": 2240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 142953}, {\"Order\": 814, \"PID\": 906226130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1094.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 148325}, {\"Order\": 815, \"PID\": 906226140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 113722}, {\"Order\": 816, \"PID\": 906230010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 817, \"PID\": 906230020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7939, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 818, \"PID\": 906230030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 819, \"PID\": 906340100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10933, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1021.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1555.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1138.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 323262}, {\"Order\": 820, \"PID\": 906340110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 417.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 297000}, {\"Order\": 821, \"PID\": 906340120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1622.0, \"TotalBsmtSF\": 1622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 860.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295493}, {\"Order\": 822, \"PID\": 906340130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 364.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 332000}, {\"Order\": 823, \"PID\": 906378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 904.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 824, \"PID\": 906380050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 825, \"PID\": 906380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11422, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1359.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 222, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272500}, {\"Order\": 826, \"PID\": 906380100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 827, \"PID\": 906380130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 828, \"PID\": 906380210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1282.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 829, \"PID\": 906380220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 10324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 382.0, \"TotalBsmtSF\": 1254.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221800}, {\"Order\": 830, \"PID\": 906392070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 82.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 831, \"PID\": 906392110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1474.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 832, \"PID\": 906392130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 704, \"2ndFlrSF\": 718, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 833, \"PID\": 906402060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 396, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 834, \"PID\": 906426210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 1449.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 815, \"LowQualFinSF\": 0, \"GrLivArea\": 1759, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 193, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233500}, {\"Order\": 835, \"PID\": 906475070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 28698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 764.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 966, \"LowQualFinSF\": 0, \"GrLivArea\": 2126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 836, \"PID\": 907126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 837, \"PID\": 907126050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9757, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 838, \"PID\": 907130100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 15426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 836, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 839, \"PID\": 907131090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 834, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 840, \"PID\": 907131190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14753, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 950.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1463, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1463, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 841, \"PID\": 907135040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 10859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1097.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 392, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 842, \"PID\": 907135170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 746.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 843, \"PID\": 907175100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 866.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 913, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 844, \"PID\": 907180130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1490.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 845, \"PID\": 907181100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9017, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 871.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 846, \"PID\": 907185050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 847, \"PID\": 907192030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8935, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 848, \"PID\": 907192090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 9808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1573, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 849, \"PID\": 907194010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1840, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 850, \"PID\": 907194110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 16285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1413.0, \"TotalBsmtSF\": 1413.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187100}, {\"Order\": 851, \"PID\": 907194160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10739, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 852, \"PID\": 907196060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11166, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 201000}, {\"Order\": 853, \"PID\": 907200230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 854, \"PID\": 907201220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16269, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 855, \"PID\": 907201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 6950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 710.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 856, \"PID\": 907202050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150500}, {\"Order\": 857, \"PID\": 907202080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 858, \"PID\": 907202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1072.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 859, \"PID\": 907227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 15523, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 860, \"PID\": 907227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 215, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 861, \"PID\": 907227110, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 862, \"PID\": 907227290, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8445, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 863, \"PID\": 907250070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 335.0, \"TotalBsmtSF\": 1569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 864, \"PID\": 907252060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1068.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254750}, {\"Order\": 865, \"PID\": 907252210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 866, \"PID\": 907252220, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 990.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 309.0, \"TotalBsmtSF\": 1299.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 573, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 261500}, {\"Order\": 867, \"PID\": 907253130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 2153, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 313000}, {\"Order\": 868, \"PID\": 907260030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 869, \"PID\": 907265010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 944.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 926, \"LowQualFinSF\": 0, \"GrLivArea\": 1870, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 870, \"PID\": 907275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 871, \"PID\": 907275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 814.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 872, \"PID\": 907275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 873, \"PID\": 907280170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1111.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1417, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1417, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 117, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 874, \"PID\": 907285020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 573.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 977, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 576, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 875, \"PID\": 907285050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 876, \"PID\": 907290070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1212.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 877, \"PID\": 907290090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1630.0, \"TotalBsmtSF\": 1630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 878, \"PID\": 907290180, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 879, \"PID\": 907290210, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 880, \"PID\": 907410130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1478.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 293200}, {\"Order\": 881, \"PID\": 907412020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 882, \"PID\": 907414020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1480.0, \"TotalBsmtSF\": 1500.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 883, \"PID\": 907414080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 193.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 884, \"PID\": 907420040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 885, \"PID\": 908102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 886, \"PID\": 908102270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1486.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 887, \"PID\": 908102290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 888, \"PID\": 908128060, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 495, \"2ndFlrSF\": 1427, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 177, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 889, \"PID\": 908151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 155.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 890, \"PID\": 908152035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 615.0, \"TotalBsmtSF\": 1014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 891, \"PID\": 908152100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 255.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 631.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 892, \"PID\": 908154040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 13286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 464.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 327, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 893, \"PID\": 908186080, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 894, \"PID\": 908201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1947, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 895, \"PID\": 908203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 332.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 243.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 896, \"PID\": 908225290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 900, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 897, \"PID\": 908225370, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 441, \"LowQualFinSF\": 0, \"GrLivArea\": 1529, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 898, \"PID\": 908229020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 899, \"PID\": 908250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 900, \"PID\": 908275040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1678.0, \"TotalBsmtSF\": 1678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1678, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1678, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 901, \"PID\": 908275110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 902, \"PID\": 908276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 903, \"PID\": 909101010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12354, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 800, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 904, \"PID\": 909101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 444, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 905, \"PID\": 909101140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10998, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 420.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 906, \"PID\": 909129090, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 907, \"PID\": 909129100, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1932, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 159434}, {\"Order\": 908, \"PID\": 909175080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 438, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 438, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 909, \"PID\": 909178160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 545, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 910, \"PID\": 909179020, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 15863, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 3, \"YearBuilt\": 1920, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 998, \"LowQualFinSF\": 397, \"GrLivArea\": 3082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 911, \"PID\": 909250080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 583.0, \"TotalBsmtSF\": 583.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 647, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 329, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 912, \"PID\": 909250220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 913, \"PID\": 909251050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 914, \"PID\": 909251170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137450}, {\"Order\": 915, \"PID\": 909252020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1936, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 575, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1135, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 916, \"PID\": 909253010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7558, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1913, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 917, \"PID\": 909253180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 877, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1477, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 918, \"PID\": 909254010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 919, \"PID\": 909257050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 10918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 920, \"PID\": 909275080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 921, \"PID\": 909276110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 753, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 213.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 922, \"PID\": 909276200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 332, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 923, \"PID\": 909277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1273, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 307.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 924, \"PID\": 909277100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13360, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 713.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 44, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 925, \"PID\": 909278020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7681, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 731.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 523, \"LowQualFinSF\": 0, \"GrLivArea\": 1343, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 186.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154900}, {\"Order\": 926, \"PID\": 909279010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 674.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 13, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 57, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 927, \"PID\": 909282130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 154.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 694.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144800}, {\"Order\": 928, \"PID\": 909425060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 929, \"PID\": 909425130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 65.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 875.0, \"BsmtUnfSF\": 621.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 930, \"PID\": 909426090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 507.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 295.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 931, \"PID\": 909427200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 158500}, {\"Order\": 932, \"PID\": 909428240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 91.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1906, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1906, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 201, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 933, \"PID\": 909451040, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 279, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 934, \"PID\": 909451100, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 935, \"PID\": 909451140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 561.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 936, \"PID\": 909451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 937, \"PID\": 909452050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13607, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 118.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208000}, {\"Order\": 938, \"PID\": 909475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17597, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1971, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 419.0, \"BsmtUnfSF\": 581.0, \"TotalBsmtSF\": 1803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2365, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 939, \"PID\": 909475300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1988, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 808.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 182, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 940, \"PID\": 910202070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 10690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 941, \"PID\": 910204050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 760.0, \"TotalBsmtSF\": 760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 928, \"LowQualFinSF\": 312, \"GrLivArea\": 2168, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 160, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 942, \"PID\": 910205020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 596, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 189.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 943, \"PID\": 911103050, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 105.0, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1915, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1013.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 513, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85000}, {\"Order\": 944, \"PID\": 911104060, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 72, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 945, \"PID\": 911370500, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230000}, {\"Order\": 946, \"PID\": 912251110, \"MSSubClass\": 30, \"MSZoning\": \"I (all)\", \"LotFrontage\": 109.0, \"LotArea\": 21780, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 119, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 57625}, {\"Order\": 947, \"PID\": 914465020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 250.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 948, \"PID\": 914465040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 2149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 239686}, {\"Order\": 949, \"PID\": 914465055, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1710.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 950, \"PID\": 914474070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 12209, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 1157, \"LowQualFinSF\": 0, \"GrLivArea\": 1961, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 951, \"PID\": 914475010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 926, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156450}, {\"Order\": 952, \"PID\": 914475030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 953, \"PID\": 914476020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 954, \"PID\": 914476380, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9947, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 955, \"PID\": 914476430, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 55.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1527.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 152000}, {\"Order\": 956, \"PID\": 916176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSeWa\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 541.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 118, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 233, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 957, \"PID\": 916176125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 215245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 820.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 958, \"PID\": 916380070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1022.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315500}, {\"Order\": 959, \"PID\": 916382010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224500}, {\"Order\": 960, \"PID\": 916382100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 13438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 2190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 780.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 961, \"PID\": 916382110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 406.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1115.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316500}, {\"Order\": 962, \"PID\": 916386140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 963, \"PID\": 916403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 387.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1412, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 964, \"PID\": 916403200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2237, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 965, \"PID\": 916403250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 14419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 624.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 1645.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 966, \"PID\": 916455070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 967, \"PID\": 916460110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 968, \"PID\": 916475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14601, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 584.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 578.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 969, \"PID\": 921128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1640.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 308, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 425000}, {\"Order\": 970, \"PID\": 923201100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 971, \"PID\": 923202060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1771, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 972, \"PID\": 923203110, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 247, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 973, \"PID\": 923203190, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 883.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 974, \"PID\": 923225360, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 975, \"PID\": 923225490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 9858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 33, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 976, \"PID\": 923226270, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 515.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 977, \"PID\": 923227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13383, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1404, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 978, \"PID\": 923228110, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 979, \"PID\": 923228150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 980, \"PID\": 923228230, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 981, \"PID\": 923230200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7689, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 76.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131900}, {\"Order\": 982, \"PID\": 923252075, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7706, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131250}, {\"Order\": 983, \"PID\": 923275040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1097.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 602.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 303, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 984, \"PID\": 923275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 985, \"PID\": 923276260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 718.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 883, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 883, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 698.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 986, \"PID\": 923400025, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 566, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 320, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 987, \"PID\": 923400110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10429, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 988, \"PID\": 924100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1567.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 989, \"PID\": 924100060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 496.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 368, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 990, \"PID\": 526351030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 411.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 601.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 190, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 991, \"PID\": 526353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1205.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237500}, {\"Order\": 992, \"PID\": 526354070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 2112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206900}, {\"Order\": 993, \"PID\": 527105050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 994, \"PID\": 527106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 995, \"PID\": 527106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 996, \"PID\": 527106150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 997, \"PID\": 527107010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 998, \"PID\": 527107090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 898.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177900}, {\"Order\": 999, \"PID\": 527107210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 21872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1446, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 406.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1000, \"PID\": 527127140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1593.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1593, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 1001, \"PID\": 527131110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 6264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247900}, {\"Order\": 1002, \"PID\": 527140090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1003, \"PID\": 527145090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1280.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1004, \"PID\": 527161010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 926.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1005, \"PID\": 527162180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 183000}, {\"Order\": 1006, \"PID\": 527163100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1007, \"PID\": 527164120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1895, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 1008, \"PID\": 527165010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1009, \"PID\": 527183030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1010, \"PID\": 527183060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 5950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1011, \"PID\": 527208010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 13543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 1012, \"PID\": 527212050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1122.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 1370, \"LowQualFinSF\": 0, \"GrLivArea\": 2504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1013, \"PID\": 527214030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 15401, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 547.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 387000}, {\"Order\": 1014, \"PID\": 527226020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 31220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 2, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1474, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 750, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1015, \"PID\": 527252080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1034.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 557.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 1016, \"PID\": 527276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 47280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1488.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 133000}, {\"Order\": 1017, \"PID\": 527301170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 20544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 791.0, \"TotalBsmtSF\": 791.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 2093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1018, \"PID\": 527301245, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 983.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 1675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1688, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 141, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1019, \"PID\": 527302050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 228.0, \"BsmtUnfSF\": 606.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1020, \"PID\": 527302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1021, \"PID\": 527302185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 18559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 186.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 2048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1022, \"PID\": 527302210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 449.0, \"BsmtUnfSF\": 469.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 1023, \"PID\": 527325070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 424.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 896.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 550, \"OpenPorchSF\": 282, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 1024, \"PID\": 527325240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 48.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 1211.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 174, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1025, \"PID\": 527326130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1026, \"PID\": 527354160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 2044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1027, \"PID\": 527357110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9743, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146900}, {\"Order\": 1028, \"PID\": 527357180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12511, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1420, \"2ndFlrSF\": 1420, \"LowQualFinSF\": 0, \"GrLivArea\": 2840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1314.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 208, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 292500}, {\"Order\": 1029, \"PID\": 527358120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 11361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1193.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1523, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1030, \"PID\": 527359030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1444.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1031, \"PID\": 527359070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1032, \"PID\": 527378020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1033, \"PID\": 527380240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1236.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 787.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 180, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 1034, \"PID\": 527401130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1035, \"PID\": 527402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 438.0, \"BsmtUnfSF\": 14.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 80, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1036, \"PID\": 527402130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 16, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111900}, {\"Order\": 1037, \"PID\": 527403360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 613.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1038, \"PID\": 527425035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111250}, {\"Order\": 1039, \"PID\": 527427110, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1040, \"PID\": 527450110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103400}, {\"Order\": 1041, \"PID\": 527450250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1042, \"PID\": 527450520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 411, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100500}, {\"Order\": 1043, \"PID\": 527451060, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 127.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1044, \"PID\": 527451290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85400}, {\"Order\": 1045, \"PID\": 527451400, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 604.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1046, \"PID\": 527451550, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111750}, {\"Order\": 1047, \"PID\": 527452150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 559.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1048, \"PID\": 527453160, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 286.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 275.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1049, \"PID\": 527454120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 1050, \"PID\": 527455270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1051, \"PID\": 528102030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12444, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 426.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 304, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394617}, {\"Order\": 1052, \"PID\": 528102110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 590, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 426000}, {\"Order\": 1053, \"PID\": 528104050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 816.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 442.0, \"TotalBsmtSF\": 2078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2084, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 385000}, {\"Order\": 1054, \"PID\": 528104080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 14948, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 1237, \"LowQualFinSF\": 0, \"GrLivArea\": 2713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 858.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 446261}, {\"Order\": 1055, \"PID\": 528108150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 317500}, {\"Order\": 1056, \"PID\": 528110080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 436.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372402}, {\"Order\": 1057, \"PID\": 528110110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1728.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 2418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 358, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 417500}, {\"Order\": 1058, \"PID\": 528114040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 14418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 1950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 383000}, {\"Order\": 1059, \"PID\": 528118030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 2748, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 390000}, {\"Order\": 1060, \"PID\": 528118090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12539, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 468.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 1158, \"LowQualFinSF\": 0, \"GrLivArea\": 2790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1150.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 460000}, {\"Order\": 1061, \"PID\": 528120130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12151, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2331, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1003.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 379000}, {\"Order\": 1062, \"PID\": 528142020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 908.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1063, \"PID\": 528142140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1162, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316000}, {\"Order\": 1064, \"PID\": 528164060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 680.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 2535.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2470, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2470, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 144, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 615000}, {\"Order\": 1065, \"PID\": 528166120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 664.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 1096, \"LowQualFinSF\": 0, \"GrLivArea\": 2668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 412500}, {\"Order\": 1066, \"PID\": 528170070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1067, \"PID\": 528172080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 454.0, \"TotalBsmtSF\": 1603.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1068, \"PID\": 528178070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 16900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1075.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1515, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2649, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 421250}, {\"Order\": 1069, \"PID\": 528178090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 16451, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 221.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1765.0, \"TotalBsmtSF\": 1765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1804, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1070, \"PID\": 528180110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1486.0, \"TotalBsmtSF\": 1858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336860}, {\"Order\": 1071, \"PID\": 528180140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 766.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 367294}, {\"Order\": 1072, \"PID\": 528181010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 135.0, \"LotArea\": 12304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1347.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1367, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1073, \"PID\": 528186030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 12677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1074, \"PID\": 528186080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 616.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1684, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1684, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 495, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266000}, {\"Order\": 1075, \"PID\": 528186130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 8232, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 714.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370967}, {\"Order\": 1076, \"PID\": 528186160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234250}, {\"Order\": 1077, \"PID\": 528186170, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1318.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1078, \"PID\": 528188090, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1079, \"PID\": 528188150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 1080, \"PID\": 528190010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1081, \"PID\": 528228345, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1073.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 1415.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1455, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1455, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1082, \"PID\": 528228405, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1087.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219990}, {\"Order\": 1083, \"PID\": 528228445, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1084, \"PID\": 528228465, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159895}, {\"Order\": 1085, \"PID\": 528228540, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1146.0, \"TotalBsmtSF\": 1146.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 428.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187687}, {\"Order\": 1086, \"PID\": 528235020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1515, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1087, \"PID\": 528235120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7415, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 759.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 839.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1088, \"PID\": 528235180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1166, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1089, \"PID\": 528240040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 8029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1090, \"PID\": 528240050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1091, \"PID\": 528250030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8396, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1139, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1092, \"PID\": 528253020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 217300}, {\"Order\": 1093, \"PID\": 528280130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1094, \"PID\": 528280180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 647.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226750}, {\"Order\": 1095, \"PID\": 528290010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 15384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1096, \"PID\": 528290090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1097, \"PID\": 528292060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12460, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1098, \"PID\": 528294060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 873, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1099, \"PID\": 528315060, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1173.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284500}, {\"Order\": 1100, \"PID\": 528315110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1470, \"2ndFlrSF\": 1160, \"LowQualFinSF\": 0, \"GrLivArea\": 2630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 696.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 1101, \"PID\": 528326030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 14260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 1053, \"LowQualFinSF\": 0, \"GrLivArea\": 2198, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1102, \"PID\": 528326110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1519.0, \"TotalBsmtSF\": 1519.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 687.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 1103, \"PID\": 528346050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 136.0, \"LotArea\": 11675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 495.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2006, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1104, \"PID\": 528354100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 1061, \"LowQualFinSF\": 0, \"GrLivArea\": 2125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 1105, \"PID\": 528363020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1242.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1250, \"LowQualFinSF\": 0, \"GrLivArea\": 2501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1106, \"PID\": 528363110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10437, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 2109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 236, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1107, \"PID\": 528365060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 651.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1311.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 1093, \"LowQualFinSF\": 0, \"GrLivArea\": 2418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 983.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 154, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 341000}, {\"Order\": 1108, \"PID\": 528365080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 852.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2197, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 783.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 385, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287500}, {\"Order\": 1109, \"PID\": 528387050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 448.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 904, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1110, \"PID\": 528390020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 1986.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1987, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301500}, {\"Order\": 1111, \"PID\": 528427010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11932, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 830.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235128}, {\"Order\": 1112, \"PID\": 528427070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14598, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 74.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 1039, \"LowQualFinSF\": 0, \"GrLivArea\": 1933, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1113, \"PID\": 528429050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1574, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 824.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 1114, \"PID\": 528429070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13253, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1115, \"PID\": 528429080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264132}, {\"Order\": 1116, \"PID\": 528431060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 468.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 33.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1563.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1563, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1563, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1117, \"PID\": 528431080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 12274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1417.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227680}, {\"Order\": 1118, \"PID\": 528431120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1341.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 851.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 1119, \"PID\": 528435020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 919, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 297900}, {\"Order\": 1120, \"PID\": 528439010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1460.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1460, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1460, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247000}, {\"Order\": 1121, \"PID\": 528458030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1363.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212700}, {\"Order\": 1122, \"PID\": 528458050, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1372.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250580}, {\"Order\": 1123, \"PID\": 528462040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 95.0, \"LotArea\": 11639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1428.0, \"TotalBsmtSF\": 1428.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 182000}, {\"Order\": 1124, \"PID\": 528477040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226700}, {\"Order\": 1125, \"PID\": 528478030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 768.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1053.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 939, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1126, \"PID\": 528478040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 932, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1127, \"PID\": 528480060, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1034.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 1028, \"LowQualFinSF\": 0, \"GrLivArea\": 2078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 339750}, {\"Order\": 1128, \"PID\": 528480160, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 843, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 562.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205950}, {\"Order\": 1129, \"PID\": 528482020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1660.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1130, \"PID\": 528488140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230348}, {\"Order\": 1131, \"PID\": 528490080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 64.0, \"LotArea\": 8791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 361.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 673.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1132, \"PID\": 531363060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1133, \"PID\": 531371070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 555.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 861, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1134, \"PID\": 531373060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 1135, \"PID\": 531375050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1136, \"PID\": 531375110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1137, \"PID\": 531375120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1138, \"PID\": 531376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1139, \"PID\": 531376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1162.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1162, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1140, \"PID\": 531382090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 362.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1141, \"PID\": 531382110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 886.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 794, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1142, \"PID\": 531382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 258.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1679, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1679, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 1143, \"PID\": 531384030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 14565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 537.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1144, \"PID\": 531385060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1677, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190500}, {\"Order\": 1145, \"PID\": 531450030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 439.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1146, \"PID\": 531450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1147, \"PID\": 531450170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1148, \"PID\": 531451020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 165.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1617, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1617, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1149, \"PID\": 531452140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 899.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1199, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1150, \"PID\": 532351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 53.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 799.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1151, \"PID\": 532353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12968, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1152, \"PID\": 532354150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 764.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1153, \"PID\": 532376170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 890.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 890, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 890, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1154, \"PID\": 532377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119916}, {\"Order\": 1155, \"PID\": 532378200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1156, \"PID\": 532477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 19508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 108, \"EnclosedPorch\": 165, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1157, \"PID\": 532479020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 811.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 92, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1158, \"PID\": 533125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 1319, \"LowQualFinSF\": 0, \"GrLivArea\": 2683, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 251, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1159, \"PID\": 533125140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1328.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1827, \"2ndFlrSF\": 959, \"LowQualFinSF\": 0, \"GrLivArea\": 2786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372500}, {\"Order\": 1160, \"PID\": 533206050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 59.0, \"LotArea\": 4282, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1391, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 1161, \"PID\": 533208080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4017, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171900}, {\"Order\": 1162, \"PID\": 533208140, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3435, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1211.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 1163, \"PID\": 533212050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1164, \"PID\": 533212140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1165, \"PID\": 533212150, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3604, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1166, \"PID\": 533213070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179400}, {\"Order\": 1167, \"PID\": 533213120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 194.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 792, \"LowQualFinSF\": 0, \"GrLivArea\": 1549, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172900}, {\"Order\": 1168, \"PID\": 533215020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1027.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 587.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1638, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1169, \"PID\": 533215030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4538, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 179.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1170, \"PID\": 533215040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 42.0, \"LotArea\": 4385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1171, \"PID\": 533215070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1557.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1172, \"PID\": 533215080, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 50.0, \"LotArea\": 5119, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1709, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 97, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"CWD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 328900}, {\"Order\": 1173, \"PID\": 533217050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 628, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1174, \"PID\": 533217060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 20, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1175, \"PID\": 533234020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 79.0, \"LotArea\": 10646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 1789, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 1176, \"PID\": 533236060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1177, \"PID\": 533236070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 147.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1607, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1178, \"PID\": 533236090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 36.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 128.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 842.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1469, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2393, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 94, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 1179, \"PID\": 533250050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 14963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245500}, {\"Order\": 1180, \"PID\": 533250110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 22.0, \"LotArea\": 11064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1230.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1239, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1239, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 1181, \"PID\": 533250160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 32.0, \"LotArea\": 10846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1719.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1719, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1719, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 1182, \"PID\": 533251120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1183, \"PID\": 533350090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1050.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 584.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1599, \"2ndFlrSF\": 1345, \"LowQualFinSF\": 0, \"GrLivArea\": 2944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 70, \"EnclosedPorch\": 16, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1184, \"PID\": 533350120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 16280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1044.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 382.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1426.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1185, \"PID\": 534104100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 469.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1186, \"PID\": 534126090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1304.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 98, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1187, \"PID\": 534127210, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1427, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1188, \"PID\": 534127230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1439.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1189, \"PID\": 534128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1190, \"PID\": 534129060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 62, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1191, \"PID\": 534175140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1625.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1192, \"PID\": 534177180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1522.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 1066, \"LowQualFinSF\": 0, \"GrLivArea\": 2614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 243, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1193, \"PID\": 534201240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1194, \"PID\": 534202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1195, \"PID\": 534204030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 456.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1196, \"PID\": 534225110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1728.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1197, \"PID\": 534225120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1497.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142600}, {\"Order\": 1198, \"PID\": 534250010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 9246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 564.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1199, \"PID\": 534250335, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1200, \"PID\": 534250370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 1540, \"LowQualFinSF\": 0, \"GrLivArea\": 2715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 299800}, {\"Order\": 1201, \"PID\": 534250410, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 933, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1202, \"PID\": 534251280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 800, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1203, \"PID\": 534252090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 867.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178400}, {\"Order\": 1204, \"PID\": 534252270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1205, \"PID\": 534276190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7785, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 267.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1206, \"PID\": 534277060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 619.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109008}, {\"Order\": 1207, \"PID\": 534277070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135750}, {\"Order\": 1208, \"PID\": 534400030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 20, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1209, \"PID\": 534400060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 407, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 1210, \"PID\": 534401130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1165, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 129, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174900}, {\"Order\": 1211, \"PID\": 534401190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 892.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 426, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1212, \"PID\": 534403050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 305.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1213, \"PID\": 534403080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 1219.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1265, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 96, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1214, \"PID\": 534403100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 336.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1215, \"PID\": 534403260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 164, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1216, \"PID\": 534426040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 806.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 1217, \"PID\": 534427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10721, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 243.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1252.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1218, \"PID\": 534428020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12493, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 306.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1219, \"PID\": 534428100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1118.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1220, \"PID\": 534451080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Floor\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72500}, {\"Order\": 1221, \"PID\": 534451170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52000}, {\"Order\": 1222, \"PID\": 534452060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 4, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1223, \"PID\": 534453140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 453, \"2ndFlrSF\": 453, \"LowQualFinSF\": 0, \"GrLivArea\": 906, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 1224, \"PID\": 534455030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1225, \"PID\": 534477080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 220, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 1226, \"PID\": 534477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 32.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 308.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1227, \"PID\": 534477270, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 377.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 178, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1228, \"PID\": 534479150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 505.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112900}, {\"Order\": 1229, \"PID\": 535103050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 273, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201800}, {\"Order\": 1230, \"PID\": 535104020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 491.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1231, \"PID\": 535105030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139950}, {\"Order\": 1232, \"PID\": 535105060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1962, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 237.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1319.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1233, \"PID\": 535105090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 9150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1234, \"PID\": 535126140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 529.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 230, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1235, \"PID\": 535150210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 151.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 1098.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1236, \"PID\": 535150280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 25.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 872.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1237, \"PID\": 535151160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1283, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1283, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1238, \"PID\": 535152200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8856, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 52.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1239, \"PID\": 535153140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1240, \"PID\": 535153150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1261.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1261, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1261, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1400, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1241, \"PID\": 535176100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 187.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1570, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1570, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 490, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166800}, {\"Order\": 1242, \"PID\": 535178060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 580.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1243, \"PID\": 535179060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 387.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 458.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 1244, \"PID\": 535180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 135.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 130, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1245, \"PID\": 535180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1104, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1246, \"PID\": 535301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1247, \"PID\": 535302130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 196.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1248, \"PID\": 535302140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1249, \"PID\": 535303030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 14250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 998.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1250, \"PID\": 535305030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 852.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 1251, \"PID\": 535305160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 773, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 1252, \"PID\": 535327230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1253, \"PID\": 535352080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 1254, \"PID\": 535354200, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1255, \"PID\": 535375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 66, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89900}, {\"Order\": 1256, \"PID\": 535375160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 7506, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1257, \"PID\": 535380050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10930, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1258, \"PID\": 535380110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 1259, \"PID\": 535380140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 182, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 1488.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1260, \"PID\": 535383100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 694, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 114, \"EnclosedPorch\": 210, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106250}, {\"Order\": 1261, \"PID\": 535402120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9247, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 539.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1262, \"PID\": 535403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1263, \"PID\": 535425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Othr\", \"MiscVal\": 6500, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 1264, \"PID\": 535426260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1253.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 213, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1265, \"PID\": 535426350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 276.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1081.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1081, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 401.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1266, \"PID\": 535427070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 27650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2069, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 1267, \"PID\": 535451010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 910, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 414.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1268, \"PID\": 535451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 94000}, {\"Order\": 1269, \"PID\": 535451230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98300}, {\"Order\": 1270, \"PID\": 535452120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1507, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1507, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1271, \"PID\": 535453020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 488.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1272, \"PID\": 535453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 319.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125900}, {\"Order\": 1273, \"PID\": 535453210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 532.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1269.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1274, \"PID\": 535454150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 453.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 501, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1275, \"PID\": 535455060, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1276, \"PID\": 535455080, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 1277, \"PID\": 535455090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 181.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1278, \"PID\": 535456050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 8513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1279, \"PID\": 535456070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1280, \"PID\": 535456100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1281, \"PID\": 535475020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 415.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1282, \"PID\": 535476370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 106.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 1283, \"PID\": 535477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136870}, {\"Order\": 1284, \"PID\": 902100020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 96.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143000}, {\"Order\": 1285, \"PID\": 902100030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 30.0, \"LotArea\": 5232, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 1286, \"PID\": 902102060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1904, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 78, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1287, \"PID\": 902103150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9184, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 375, \"LowQualFinSF\": 0, \"GrLivArea\": 1323, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122600}, {\"Order\": 1288, \"PID\": 902105010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 680, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 1289, \"PID\": 902105020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 547, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 480, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1150, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1290, \"PID\": 902105130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1291, \"PID\": 902107030, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1292, \"PID\": 902109080, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 828.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 828, \"2ndFlrSF\": 658, \"LowQualFinSF\": 108, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 109, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1293, \"PID\": 902109110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 2082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1294, \"PID\": 902109120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 561, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119164}, {\"Order\": 1295, \"PID\": 902109160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 7308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122250}, {\"Order\": 1296, \"PID\": 902128075, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 931.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1297, \"PID\": 902128150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 590.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 552, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1298, \"PID\": 902134100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6756, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 481.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 1299, \"PID\": 902136110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 5914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 396, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 165, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1300, \"PID\": 902201120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 169.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 115000}, {\"Order\": 1301, \"PID\": 902201140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 608.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1302, \"PID\": 902202090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 904.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 869.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1303, \"PID\": 902205070, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 407.0, \"TotalBsmtSF\": 407.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 407, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 407, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 46500}, {\"Order\": 1304, \"PID\": 902205090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 620.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1305, \"PID\": 902205140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 901, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107900}, {\"Order\": 1306, \"PID\": 902207120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 103.0, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 1, \"YearBuilt\": 1949, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 65000}, {\"Order\": 1307, \"PID\": 902207220, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 87.0, \"LotArea\": 18386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1880, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1470.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 1818, \"LowQualFinSF\": 0, \"GrLivArea\": 3493, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295000}, {\"Order\": 1308, \"PID\": 902300110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 797.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 830, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1627, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1309, \"PID\": 902300215, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 540, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 418, \"OpenPorchSF\": 0, \"EnclosedPorch\": 194, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1310, \"PID\": 902300260, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 730, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1311, \"PID\": 902301140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 34.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 513.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98000}, {\"Order\": 1312, \"PID\": 902301150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9143, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 709, \"2ndFlrSF\": 308, \"LowQualFinSF\": 0, \"GrLivArea\": 1017, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 139, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1313, \"PID\": 902304060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 973, \"LowQualFinSF\": 0, \"GrLivArea\": 2350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 219, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1314, \"PID\": 902305080, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2058, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 259, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1315, \"PID\": 902306120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1905, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129400}, {\"Order\": 1316, \"PID\": 902306130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1928, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1317, \"PID\": 902326060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1905, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 691, \"LowQualFinSF\": 0, \"GrLivArea\": 1912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1318, \"PID\": 902328040, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 291, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1319, \"PID\": 902330010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5250, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1872, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 205, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 1320, \"PID\": 902401010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 572, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1321, \"PID\": 902401120, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1893, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1521, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 880.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 502, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1322, \"PID\": 902402260, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 2, \"OverallCond\": 1, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 723, \"2ndFlrSF\": 363, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1323, \"PID\": 902405070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 299, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1324, \"PID\": 902406020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1325, \"PID\": 902406090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1050.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 1326, \"PID\": 902427045, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 12702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 1327, \"PID\": 902427150, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8516, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 869.0, \"TotalBsmtSF\": 869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115500}, {\"Order\": 1328, \"PID\": 903201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7111, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1329, \"PID\": 903204010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 1330, \"PID\": 903204095, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 156, \"GrLivArea\": 935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 1331, \"PID\": 903206070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 175.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 594, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1332, \"PID\": 903225050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1333, \"PID\": 903225140, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1334, \"PID\": 903225160, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 554, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106900}, {\"Order\": 1335, \"PID\": 903226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 658, \"LowQualFinSF\": 0, \"GrLivArea\": 1672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 1336, \"PID\": 903226150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 949.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1337, \"PID\": 903227080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 862.0, \"TotalBsmtSF\": 862.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 208.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1338, \"PID\": 903228040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 201.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1497, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1339, \"PID\": 903228060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1340, \"PID\": 903228090, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 992.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1013, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 101, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1341, \"PID\": 903230110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 565, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1342, \"PID\": 903230120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 99.0, \"LotArea\": 5940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": null, \"BsmtFinType2\": null, \"BsmtFinSF2\": null, \"BsmtUnfSF\": null, \"TotalBsmtSF\": null, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79000}, {\"Order\": 1343, \"PID\": 903231080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 365, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1344, \"PID\": 903232030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81300}, {\"Order\": 1345, \"PID\": 903232090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1078.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 1346, \"PID\": 903233080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 989.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1347, \"PID\": 903234090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 897.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 139, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 1348, \"PID\": 903234100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129900}, {\"Order\": 1349, \"PID\": 903235010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 611.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1350, \"PID\": 903235100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 87, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68500}, {\"Order\": 1351, \"PID\": 903236010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 213, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1352, \"PID\": 903400180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 13053, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 220, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1353, \"PID\": 903401020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1354, \"PID\": 903401030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1355, \"PID\": 903401050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 883.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1356, \"PID\": 903425420, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 606.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1357, \"PID\": 903426160, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1000, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1358, \"PID\": 903427090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5100, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1359, \"PID\": 903429010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 4347, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1360, \"PID\": 903452025, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6291, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93850}, {\"Order\": 1361, \"PID\": 903453050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10266, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 216, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 136000}, {\"Order\": 1362, \"PID\": 903454100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1272.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 0, \"LowQualFinSF\": 697, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1363, \"PID\": 903455030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 428, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 117, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1364, \"PID\": 903455140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1365, \"PID\": 903456130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 647.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 127000}, {\"Order\": 1366, \"PID\": 903458110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 371, \"LowQualFinSF\": 0, \"GrLivArea\": 1406, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1367, \"PID\": 903475020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 645.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1368, \"PID\": 903476110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5586, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 110, \"LowQualFinSF\": 0, \"GrLivArea\": 1198, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79900}, {\"Order\": 1369, \"PID\": 903481010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 451.0, \"TotalBsmtSF\": 451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 759, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Family\", \"SalePrice\": 85000}, {\"Order\": 1370, \"PID\": 903481100, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 808, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 204, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82375}, {\"Order\": 1371, \"PID\": 903484020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1906, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 1469, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1906.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 57, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1372, \"PID\": 904100020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 122, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 1373, \"PID\": 904100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 1374, \"PID\": 904100160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 21286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1271, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1375, \"PID\": 904101170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134432}, {\"Order\": 1376, \"PID\": 904351280, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10106, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 181.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 547, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1377, \"PID\": 905100020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 64, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 148000}, {\"Order\": 1378, \"PID\": 905102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 906.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1379, \"PID\": 905103030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 39.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1380, \"PID\": 905104080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109900}, {\"Order\": 1381, \"PID\": 905104110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1382, \"PID\": 905104180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 702.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1383, \"PID\": 905107280, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 311, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1384, \"PID\": 905107380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9981, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 221.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 852.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1385, \"PID\": 905108170, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 956.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1386, \"PID\": 905200090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1198.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 108959}, {\"Order\": 1387, \"PID\": 905200100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 95541}, {\"Order\": 1388, \"PID\": 905200160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 1006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1006, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 1389, \"PID\": 905200510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149350}, {\"Order\": 1390, \"PID\": 905201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 634.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 1391, \"PID\": 905201110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 102, \"OpenPorchSF\": 89, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1392, \"PID\": 905201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1064.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 354.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 511, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1393, \"PID\": 905202230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 429.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1080.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 409, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1394, \"PID\": 905225040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1021, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1395, \"PID\": 905226030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1396, \"PID\": 905226110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1397, \"PID\": 905227050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 486, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152400}, {\"Order\": 1398, \"PID\": 905300020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1399, \"PID\": 905351089, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1003.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1291.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1291, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1400, \"PID\": 905352030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 299.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 2022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 117, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1401, \"PID\": 905352070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 20270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1402, \"PID\": 905401045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 39104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Membran\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1063.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1403, \"PID\": 905401060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1663, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1404, \"PID\": 905402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 11512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1019.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1357, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1357, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 163, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1405, \"PID\": 905403060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 617, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1079, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 249.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125600}, {\"Order\": 1406, \"PID\": 905403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 287, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1407, \"PID\": 905425125, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 45600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 907.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1307, \"2ndFlrSF\": 1051, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1908.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1408, \"PID\": 905426030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"PreCast\", \"Exterior2nd\": \"PreCast\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1035.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1409, \"PID\": 905427050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1163.0, \"TotalBsmtSF\": 1163.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 511, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1410, \"PID\": 905427070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 2108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1411, \"PID\": 905451330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1509.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 576, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1412, \"PID\": 905452070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99600}, {\"Order\": 1413, \"PID\": 905452120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 621, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1414, \"PID\": 905476120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1415, \"PID\": 905477050, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 969.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 527, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 1416, \"PID\": 905479110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1417, \"PID\": 905480150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 572, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 8, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 1418, \"PID\": 905480240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 380.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1419, \"PID\": 906204150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1475.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1532, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2329, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262280}, {\"Order\": 1420, \"PID\": 906204280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9771, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 1721, \"LowQualFinSF\": 0, \"GrLivArea\": 2814, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1421, \"PID\": 906223110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 251.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1626, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1422, \"PID\": 906223140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 355.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 1099, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1423, \"PID\": 906223220, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 735, \"LowQualFinSF\": 0, \"GrLivArea\": 2037, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 1424, \"PID\": 906378190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 628.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177439}, {\"Order\": 1425, \"PID\": 906380030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1615.0, \"TotalBsmtSF\": 1615.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1615, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1615, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 1426, \"PID\": 906412010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 2271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2276, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1348.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 475000}, {\"Order\": 1427, \"PID\": 906412050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1751.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395039}, {\"Order\": 1428, \"PID\": 906420130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 531.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 187, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 1429, \"PID\": 906424010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 631.0, \"TotalBsmtSF\": 1401.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 811.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1430, \"PID\": 906475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1182.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1643, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1643, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 339, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1431, \"PID\": 906476030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12798, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 154.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 1072, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 403, \"OpenPorchSF\": 114, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1432, \"PID\": 907126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 722.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1433, \"PID\": 907135020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1099.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1099, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1099, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1434, \"PID\": 907135260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1435, \"PID\": 907175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226001}, {\"Order\": 1436, \"PID\": 907176010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 688.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 899, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215700}, {\"Order\": 1437, \"PID\": 907181120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 782, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1438, \"PID\": 907181140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 873.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 193000}, {\"Order\": 1439, \"PID\": 907187030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1440, \"PID\": 907187080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 9382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1441, \"PID\": 907192130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 1442, \"PID\": 907194020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 963.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 963, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 245, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 1443, \"PID\": 907196040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1823, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 4500, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1444, \"PID\": 907196050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 1445, \"PID\": 907200110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 491.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 938, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130250}, {\"Order\": 1446, \"PID\": 907201060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 328.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 1447, \"PID\": 907202010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1174, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 211, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1448, \"PID\": 907202160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1449, \"PID\": 907202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1076, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143195}, {\"Order\": 1450, \"PID\": 907202240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 88.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1558, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1451, \"PID\": 907203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 7990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1452, \"PID\": 907227050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1453, \"PID\": 907227300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 780, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 1454, \"PID\": 907250020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1777.0, \"TotalBsmtSF\": 1777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 159, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1455, \"PID\": 907251090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9473, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 903, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 1456, \"PID\": 907253060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 257.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1457, \"PID\": 907253110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 1458, \"PID\": 907254020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9066, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 106, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1459, \"PID\": 907254090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 1460, \"PID\": 907255020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 396.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287000}, {\"Order\": 1461, \"PID\": 907255030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1357.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1366, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1462, \"PID\": 907255060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1786, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 715.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1463, \"PID\": 907260010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 1141, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 1464, \"PID\": 907262030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 334.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 1465, \"PID\": 907262060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 10905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1129.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1129, \"2ndFlrSF\": 1198, \"LowQualFinSF\": 0, \"GrLivArea\": 2327, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1466, \"PID\": 907262070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 595.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1467, \"PID\": 907265100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1468, \"PID\": 907285080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 642.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 933, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1469, \"PID\": 907290150, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1470, \"PID\": 907290250, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1471, \"PID\": 907295020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 215.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1493, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1493, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208900}, {\"Order\": 1472, \"PID\": 907295100, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 83.0, \"LotArea\": 10126, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1593.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 1473, \"PID\": 907405020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 726.0, \"TotalBsmtSF\": 1536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1536, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1474, \"PID\": 907405140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 854, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208500}, {\"Order\": 1475, \"PID\": 907412040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1421.0, \"TotalBsmtSF\": 1445.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1476, \"PID\": 907412070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 946.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 139, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1477, \"PID\": 907412080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 770, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1478, \"PID\": 907412090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1234, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1479, \"PID\": 907418010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1508.0, \"TotalBsmtSF\": 1564.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218836}, {\"Order\": 1480, \"PID\": 907418040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1327.0, \"TotalBsmtSF\": 1351.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1481, \"PID\": 907420080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1482, \"PID\": 907425010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149300}, {\"Order\": 1483, \"PID\": 907425015, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1484, \"PID\": 907425030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1485, \"PID\": 907425035, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 1486, \"PID\": 908102030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1487, \"PID\": 908102040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 928, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145900}, {\"Order\": 1488, \"PID\": 908102140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 259, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 123000}, {\"Order\": 1489, \"PID\": 908102260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 830.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 736, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1490, \"PID\": 908103260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 12102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 222.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1033, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1033, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 165000}, {\"Order\": 1491, \"PID\": 908103280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1033.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1127, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1492, \"PID\": 908127120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1493, \"PID\": 908128050, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 38.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1181, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1181, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1494, \"PID\": 908128110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 92.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165400}, {\"Order\": 1495, \"PID\": 908151040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 120.0, \"BsmtUnfSF\": 541.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1496, \"PID\": 908152110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1497, \"PID\": 908152270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1132.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1498, \"PID\": 908154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 123.0, \"LotArea\": 47007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3820, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3820, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 372, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284700}, {\"Order\": 1499, \"PID\": 908154235, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 63887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"ClyTile\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 796.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 5644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 6110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 4692, \"2ndFlrSF\": 950, \"LowQualFinSF\": 0, \"GrLivArea\": 5642, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 1418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 292, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 480, \"PoolQC\": \"Gd\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 160000}, {\"Order\": 1500, \"PID\": 908186040, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 459.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1501, \"PID\": 908201100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1502, \"PID\": 908201110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1503, \"PID\": 908201120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1307.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1504, \"PID\": 908204160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 1505, \"PID\": 908225170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91900}, {\"Order\": 1506, \"PID\": 908226120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 585, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 120000}, {\"Order\": 1507, \"PID\": 908250040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 1508, \"PID\": 908250090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 134, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Gar2\", \"MiscVal\": 3000, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1509, \"PID\": 908275130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1510, \"PID\": 908275180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1511, \"PID\": 908275280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 521, \"LowQualFinSF\": 0, \"GrLivArea\": 1393, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 265, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 1512, \"PID\": 908276140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1513, \"PID\": 909100150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 343, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1514, \"PID\": 909100170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1515, \"PID\": 909101060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 41.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 823.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67000}, {\"Order\": 1516, \"PID\": 909101180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5687, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135900}, {\"Order\": 1517, \"PID\": 909131170, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 254, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1518, \"PID\": 909175050, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 720, \"LowQualFinSF\": 420, \"GrLivArea\": 2192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179500}, {\"Order\": 1519, \"PID\": 909175100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 423.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 758.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 304, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1520, \"PID\": 909177120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1521, \"PID\": 909201110, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 8525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1911, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 940.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1522, \"PID\": 909250040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 1611, \"LowQualFinSF\": 0, \"GrLivArea\": 2601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 183, \"OpenPorchSF\": 0, \"EnclosedPorch\": 301, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1523, \"PID\": 909250230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 679.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 161900}, {\"Order\": 1524, \"PID\": 909251080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8969, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 369.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1525, \"PID\": 909251090, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1423, \"2ndFlrSF\": 748, \"LowQualFinSF\": 384, \"GrLivArea\": 2555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1526, \"PID\": 909252110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1527, \"PID\": 909252220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15564, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1528, \"PID\": 909253190, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 1529, \"PID\": 909254050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7609, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 16, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 1530, \"PID\": 909256060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 473, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1531, \"PID\": 909275040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 599.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 217, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1532, \"PID\": 909275050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1533, \"PID\": 909276170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1934, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 389.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 849, \"2ndFlrSF\": 811, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188700}, {\"Order\": 1534, \"PID\": 909277040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 673, \"LowQualFinSF\": 0, \"GrLivArea\": 1938, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 1535, \"PID\": 909277070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 932, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1536, \"PID\": 909281030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 7801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 591.0, \"TotalBsmtSF\": 1091.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 344.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 221, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 1537, \"PID\": 909281110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 786.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 207, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 257076}, {\"Order\": 1538, \"PID\": 909282030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1935, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1968, \"2ndFlrSF\": 1479, \"LowQualFinSF\": 0, \"GrLivArea\": 3447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1014.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 381000}, {\"Order\": 1539, \"PID\": 909425010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 817, \"LowQualFinSF\": 0, \"GrLivArea\": 1954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 311500}, {\"Order\": 1540, \"PID\": 909425085, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 943, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263400}, {\"Order\": 1541, \"PID\": 909428170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 26073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1898.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1898, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 1542, \"PID\": 909428190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 568.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 924.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 1543, \"PID\": 909451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 366.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 213, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 1544, \"PID\": 909451150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 612.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1545, \"PID\": 910200080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 555.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 919, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1546, \"PID\": 910201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 330, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1547, \"PID\": 910202050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1548, \"PID\": 910202100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1549, \"PID\": 910203020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 71.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 125.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 778, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 924.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1550, \"PID\": 910203090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 780, \"2ndFlrSF\": 420, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1551, \"PID\": 910205010, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1552, \"PID\": 910206110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 1553, \"PID\": 910226040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1955, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1554, \"PID\": 910251050, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 80.0, \"LotArea\": 14584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Po\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 13100}, {\"Order\": 1555, \"PID\": 911102090, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 5280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1895, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1895.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 185.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 1556, \"PID\": 911102170, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 649, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1317, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 172, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 40000}, {\"Order\": 1557, \"PID\": 911102180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 52.0, \"LotArea\": 5150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 671, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80900}, {\"Order\": 1558, \"PID\": 911226010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 120.0, \"LotArea\": 18000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 560, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1559, \"PID\": 911226030, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 432, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 65000}, {\"Order\": 1560, \"PID\": 911370410, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 5587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392500}, {\"Order\": 1561, \"PID\": 911370490, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294464}, {\"Order\": 1562, \"PID\": 911370520, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1563, \"PID\": 911370540, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 1564, \"PID\": 914453045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 668.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2032, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1565, \"PID\": 914465060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 857.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1566, \"PID\": 914467050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 910.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 318, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1567, \"PID\": 914475020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 574.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 358.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 576, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1568, \"PID\": 914476010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 83, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 1569, \"PID\": 914476080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1570, \"PID\": 914476450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 428, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 1571, \"PID\": 916125425, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 164660, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 1499.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1619, \"2ndFlrSF\": 167, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 670, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228950}, {\"Order\": 1572, \"PID\": 916226030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 893.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1573, \"PID\": 916325080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15498, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1165.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 665.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 174, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 287000}, {\"Order\": 1574, \"PID\": 916380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 258.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1575, \"PID\": 916382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293077}, {\"Order\": 1576, \"PID\": 916384100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264966}, {\"Order\": 1577, \"PID\": 916386040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 712, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 1578, \"PID\": 916386080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": null, \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 1579, \"PID\": 916386180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 12018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 218689}, {\"Order\": 1580, \"PID\": 916402015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1495.0, \"TotalBsmtSF\": 1495.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1495, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1581, \"PID\": 916402115, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 12416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1398.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 208.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1582, \"PID\": 916402215, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 18265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1583, \"PID\": 916403230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 219.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 783.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1584, \"PID\": 916455120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11202, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1029.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 1432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232500}, {\"Order\": 1585, \"PID\": 916460060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7915, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1586, \"PID\": 916477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 2262, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 749.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1587, \"PID\": 921126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1011.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 873.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 276, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 298751}, {\"Order\": 1588, \"PID\": 921201060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1571.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 393.0, \"TotalBsmtSF\": 1964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 892.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1589, \"PID\": 923202005, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 97.0, \"LotArea\": 8940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 209200}, {\"Order\": 1590, \"PID\": 923202015, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 206300}, {\"Order\": 1591, \"PID\": 923202137, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9278, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1592, \"PID\": 923203140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 197.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 1189.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1189, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1189, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1593, \"PID\": 923204040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 171, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1594, \"PID\": 923225080, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 271.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1595, \"PID\": 923225150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1596, \"PID\": 923225200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 318.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1597, \"PID\": 923225310, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 501.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 526.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1598, \"PID\": 923225370, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 120, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94900}, {\"Order\": 1599, \"PID\": 923227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1160, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 257.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 1600, \"PID\": 923228080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1970, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1601, \"PID\": 923228420, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1602, \"PID\": 923250210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 988.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1603, \"PID\": 923252100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 6490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1604, \"PID\": 923275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 6951, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 362, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1605, \"PID\": 923277030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1982, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1606, \"PID\": 923277040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1982, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1607, \"PID\": 923277080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1608, \"PID\": 923400040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 983.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1300, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1609, \"PID\": 923426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 647.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 889, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1610, \"PID\": 924100020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 562.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 193.0, \"BsmtUnfSF\": 29.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1611, \"PID\": 1007100110, \"MSSubClass\": 70, \"MSZoning\": \"I (all)\", \"LotFrontage\": null, \"LotArea\": 56600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1612, \"PID\": 526352080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 838.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 749.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1587, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1587, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167300}, {\"Order\": 1613, \"PID\": 526352090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1277, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 526.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 1614, \"PID\": 526355170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 2223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2223, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2223, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 1615, \"PID\": 526355190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 15865, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 823.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 2217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 1616, \"PID\": 527105140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 225000}, {\"Order\": 1617, \"PID\": 527107040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 373.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1618, \"PID\": 527110080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 794, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1619, \"PID\": 527110120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 1620, \"PID\": 527110130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 1621, \"PID\": 527126030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 1622, \"PID\": 527158090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 770, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1623, \"PID\": 527161090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 947, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1624, \"PID\": 527162080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178750}, {\"Order\": 1625, \"PID\": 527162090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1626, \"PID\": 527162140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 957, \"2ndFlrSF\": 1342, \"LowQualFinSF\": 0, \"GrLivArea\": 2299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1627, \"PID\": 527163080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1168.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1628, \"PID\": 527165020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1629, \"PID\": 527165100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163900}, {\"Order\": 1630, \"PID\": 527165170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 903.0, \"TotalBsmtSF\": 903.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1631, \"PID\": 527175130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 18160, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 154204}, {\"Order\": 1632, \"PID\": 527182040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1633, \"PID\": 527182170, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1634, \"PID\": 527184020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 4740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1166.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 135, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1635, \"PID\": 527184110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 5118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 926.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1321, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1321, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 1636, \"PID\": 527210060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377426}, {\"Order\": 1637, \"PID\": 527212060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1377, \"LowQualFinSF\": 0, \"GrLivArea\": 2541, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 729.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 349265}, {\"Order\": 1638, \"PID\": 527216080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 51974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 710.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1101.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1559.0, \"TotalBsmtSF\": 2660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1110.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 591587}, {\"Order\": 1639, \"PID\": 527226040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 195.0, \"LotArea\": 41600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1047.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 53.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1640, \"PID\": 527252050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8035, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 797.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 164, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 1641, \"PID\": 527252070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8089, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 1642, \"PID\": 527256030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 945.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1558.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 2220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 441929}, {\"Order\": 1643, \"PID\": 527256040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 13870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 174, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 455000}, {\"Order\": 1644, \"PID\": 527301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 99, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182900}, {\"Order\": 1645, \"PID\": 527301280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1028.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1646, \"PID\": 527302020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 178000}, {\"Order\": 1647, \"PID\": 527302060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 167, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1648, \"PID\": 527302090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1328.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 1529.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1649, \"PID\": 527325090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 11339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 549.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 22.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1650, \"PID\": 527325110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11952, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1161, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 276, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1651, \"PID\": 527327050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12046, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 2030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1652, \"PID\": 527328020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 605.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1653, \"PID\": 527328050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1177, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1654, \"PID\": 527353080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 539.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 1655, \"PID\": 527354050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 253.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1259.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1353, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192350}, {\"Order\": 1656, \"PID\": 527356050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 263.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1657, \"PID\": 527357020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 13001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 249, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1658, \"PID\": 527358060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1659, \"PID\": 527359010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 175.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1660, \"PID\": 527359080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 1661, \"PID\": 527359160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 604.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 585.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 407, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1662, \"PID\": 527377110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 153.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1877, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 1663, \"PID\": 527402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 349.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 533, \"LowQualFinSF\": 0, \"GrLivArea\": 1109, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 35, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1664, \"PID\": 527402150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 35.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143250}, {\"Order\": 1665, \"PID\": 527402240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1972, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1666, \"PID\": 527403310, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1667, \"PID\": 527404050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 619.0, \"BsmtUnfSF\": 214.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1668, \"PID\": 527404100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 412.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1669, \"PID\": 527404140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8294, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1670, \"PID\": 527404150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 322.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1671, \"PID\": 527425025, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1672, \"PID\": 527425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1673, \"PID\": 527427090, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 139.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 767, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 367.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1674, \"PID\": 527427160, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 33.0, \"LotArea\": 4113, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1337.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1675, \"PID\": 527427200, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 10943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1676, \"PID\": 527450030, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 1677, \"PID\": 527450150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 356.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1678, \"PID\": 527450220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113700}, {\"Order\": 1679, \"PID\": 527451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2016, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1680, \"PID\": 527451170, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 376.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 1681, \"PID\": 527452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 958.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 205, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1682, \"PID\": 527453010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 556.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1683, \"PID\": 527455030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 6.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 1061.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 1684, \"PID\": 527455250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 725.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129250}, {\"Order\": 1685, \"PID\": 528102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12469, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1151.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1790.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356000}, {\"Order\": 1686, \"PID\": 528102090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 452.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1774.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 260, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 314813}, {\"Order\": 1687, \"PID\": 528102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1688, \"PID\": 528102120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 322400}, {\"Order\": 1689, \"PID\": 528102130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 328.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 730.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1690, \"PID\": 528104010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 2108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345474}, {\"Order\": 1691, \"PID\": 528106040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 315.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2121.0, \"TotalBsmtSF\": 2121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 415298}, {\"Order\": 1692, \"PID\": 528106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13641, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1304.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1934.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1943, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 2656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1040.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 492000}, {\"Order\": 1693, \"PID\": 528106060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1108.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 1402, \"LowQualFinSF\": 0, \"GrLivArea\": 2550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338931}, {\"Order\": 1694, \"PID\": 528106110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 400.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 450000}, {\"Order\": 1695, \"PID\": 528108160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 14154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1063.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1071, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 947.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 280000}, {\"Order\": 1696, \"PID\": 528110040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 2552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 479069}, {\"Order\": 1697, \"PID\": 528110070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 375.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1935.0, \"TotalBsmtSF\": 1935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1973, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1973, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395000}, {\"Order\": 1698, \"PID\": 528110100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 772.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2153.0, \"TotalBsmtSF\": 2153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 2643, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 694.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 380000}, {\"Order\": 1699, \"PID\": 528112150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1626.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1634, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1634, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1700, \"PID\": 528114050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14977, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 1976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 440000}, {\"Order\": 1701, \"PID\": 528118040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13654, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1704.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1722, \"2ndFlrSF\": 1036, \"LowQualFinSF\": 0, \"GrLivArea\": 2758, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 418000}, {\"Order\": 1702, \"PID\": 528118050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 17169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 970.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 2320.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1174.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 500067}, {\"Order\": 1703, \"PID\": 528120010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1582.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 570, \"LowQualFinSF\": 0, \"GrLivArea\": 2152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 368, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260116}, {\"Order\": 1704, \"PID\": 528120150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 317000}, {\"Order\": 1705, \"PID\": 528142050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9709, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319500}, {\"Order\": 1706, \"PID\": 528144050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325624}, {\"Order\": 1707, \"PID\": 528150040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 510.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1802.0, \"TotalBsmtSF\": 1802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1802, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372000}, {\"Order\": 1708, \"PID\": 528150110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 13069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 502.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1706.0, \"TotalBsmtSF\": 1706.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 1238, \"LowQualFinSF\": 0, \"GrLivArea\": 2956, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 916.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 342000}, {\"Order\": 1709, \"PID\": 528150120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 388.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 970.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 872.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 354000}, {\"Order\": 1710, \"PID\": 528166150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14277, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1317.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1711, \"PID\": 528168040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11999, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1712, \"PID\": 528172030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 669.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 895.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 895, \"2ndFlrSF\": 923, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281500}, {\"Order\": 1713, \"PID\": 528172050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1178.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245700}, {\"Order\": 1714, \"PID\": 528172070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9254, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1602.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232698}, {\"Order\": 1715, \"PID\": 528172075, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1298.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 876.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 1716, \"PID\": 528174010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194700}, {\"Order\": 1717, \"PID\": 528174020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3901, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204000}, {\"Order\": 1718, \"PID\": 528174030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 272.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1719, \"PID\": 528174040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 6289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1720, \"PID\": 528181060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1721, \"PID\": 528181070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1722, \"PID\": 528181080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 1723, \"PID\": 528186050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 7841, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 394.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 848.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 729.0, \"TotalBsmtSF\": 1577.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1577, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 1724, \"PID\": 528186090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 1725, \"PID\": 528186120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1869.0, \"TotalBsmtSF\": 1869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318061}, {\"Order\": 1726, \"PID\": 528186190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1300.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221370}, {\"Order\": 1727, \"PID\": 528188160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 235.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1728, \"PID\": 528218010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 15810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181755}, {\"Order\": 1729, \"PID\": 528218020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1730, \"PID\": 528218050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 783, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 178900}, {\"Order\": 1731, \"PID\": 528218100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 13204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 168165}, {\"Order\": 1732, \"PID\": 528221030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8857, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 757, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 171925}, {\"Order\": 1733, \"PID\": 528221040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9729, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 1048, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198444}, {\"Order\": 1734, \"PID\": 528221050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 918.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 1735, \"PID\": 528221090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179540}, {\"Order\": 1736, \"PID\": 528222030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 176485}, {\"Order\": 1737, \"PID\": 528222040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1340.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181134}, {\"Order\": 1738, \"PID\": 528222050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 796, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156932}, {\"Order\": 1739, \"PID\": 528222060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8229, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 22.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1740, \"PID\": 528222080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7713, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177594}, {\"Order\": 1741, \"PID\": 528222090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1246.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173500}, {\"Order\": 1742, \"PID\": 528228270, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172500}, {\"Order\": 1743, \"PID\": 528228275, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194201}, {\"Order\": 1744, \"PID\": 528228375, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3621, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1589, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1745, \"PID\": 528228555, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185485}, {\"Order\": 1746, \"PID\": 528231010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 182.0, \"LotArea\": 14572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 259000}, {\"Order\": 1747, \"PID\": 528231030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 16219, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1119, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1119, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1748, \"PID\": 528235000, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 175000}, {\"Order\": 1749, \"PID\": 528235160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11796, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1112, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1750, \"PID\": 528235170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1510.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 206580}, {\"Order\": 1751, \"PID\": 528240020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 1752, \"PID\": 528250010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1753, \"PID\": 528250070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 1754, \"PID\": 528275035, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1755, \"PID\": 528275110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 1131, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1756, \"PID\": 528280110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 694, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1757, \"PID\": 528280150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1758, \"PID\": 528290060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 1759, \"PID\": 528290170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1760, \"PID\": 528294010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9649, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1761, \"PID\": 528320050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 15623, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2411, \"2ndFlrSF\": 2065, \"LowQualFinSF\": 0, \"GrLivArea\": 4476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 813.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 555, \"PoolQC\": \"Ex\", \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 745000}, {\"Order\": 1762, \"PID\": 528322020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 515.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 2551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 384500}, {\"Order\": 1763, \"PID\": 528326060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 1288, \"LowQualFinSF\": 0, \"GrLivArea\": 2285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 1764, \"PID\": 528327060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 705.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1351.0, \"TotalBsmtSF\": 2633.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2633, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2633, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 804.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 466500}, {\"Order\": 1765, \"PID\": 528340030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10557, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 1407, \"LowQualFinSF\": 0, \"GrLivArea\": 3078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 806.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 1766, \"PID\": 528344020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1048.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 1171, \"LowQualFinSF\": 0, \"GrLivArea\": 2582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 322500}, {\"Order\": 1767, \"PID\": 528348030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 275.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1066.0, \"TotalBsmtSF\": 1066.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1277, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 1768, \"PID\": 528351010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 21535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1170.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 989.0, \"TotalBsmtSF\": 2444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2444, \"2ndFlrSF\": 1872, \"LowQualFinSF\": 0, \"GrLivArea\": 4316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 832.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 755000}, {\"Order\": 1769, \"PID\": 528354060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 862.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2013, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 455.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269790}, {\"Order\": 1770, \"PID\": 528354110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11787, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 594.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 1379.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 1015, \"LowQualFinSF\": 0, \"GrLivArea\": 2398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315750}, {\"Order\": 1771, \"PID\": 528358040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1203.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 290000}, {\"Order\": 1772, \"PID\": 528364110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1318.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 752.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1773, \"PID\": 528366050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1969.0, \"TotalBsmtSF\": 3200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 75, \"EnclosedPorch\": 291, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 430000}, {\"Order\": 1774, \"PID\": 528366070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 335.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2202, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 1775, \"PID\": 528376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 526.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1225.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1325.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2538, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 933.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 1776, \"PID\": 528427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1369.0, \"TotalBsmtSF\": 1369.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1369, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 203, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 213133}, {\"Order\": 1777, \"PID\": 528427100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1542, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260261}, {\"Order\": 1778, \"PID\": 528429090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 11670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1905.0, \"TotalBsmtSF\": 1905.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1905, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1905, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 1779, \"PID\": 528429110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282922}, {\"Order\": 1780, \"PID\": 528431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1534, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 215000}, {\"Order\": 1781, \"PID\": 528431040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 754.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 394.0, \"TotalBsmtSF\": 1966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1966, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1092.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 419005}, {\"Order\": 1782, \"PID\": 528431050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13501, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 63.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1623.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1783, \"PID\": 528431110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9986, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 428.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1795.0, \"TotalBsmtSF\": 1795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 1784, \"PID\": 528435010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1528, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235876}, {\"Order\": 1785, \"PID\": 528435040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1126.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 311872}, {\"Order\": 1786, \"PID\": 528435060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 954.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248328}, {\"Order\": 1787, \"PID\": 528435070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 825.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1788, \"PID\": 528439040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8847, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 1538.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1538, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1538, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1789, \"PID\": 528439050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 1790, \"PID\": 528439080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8251, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 1791, \"PID\": 528441080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 255, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 307000}, {\"Order\": 1792, \"PID\": 528445020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 982, \"2ndFlrSF\": 995, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 250000}, {\"Order\": 1793, \"PID\": 528445070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 528, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 859.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221300}, {\"Order\": 1794, \"PID\": 528456190, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1314.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1795, \"PID\": 528456230, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1335.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1335, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210400}, {\"Order\": 1796, \"PID\": 528458080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 255000}, {\"Order\": 1797, \"PID\": 528458090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 10411, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212109}, {\"Order\": 1798, \"PID\": 528458120, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1025.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 1799, \"PID\": 528458130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 64.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1120.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1184, \"2ndFlrSF\": 1426, \"LowQualFinSF\": 0, \"GrLivArea\": 2610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 364, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 303477}, {\"Order\": 1800, \"PID\": 528458150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1880, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310013}, {\"Order\": 1801, \"PID\": 528477020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 11096, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249700}, {\"Order\": 1802, \"PID\": 528480020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 874.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1761, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227875}, {\"Order\": 1803, \"PID\": 528480180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1574.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 256, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 261329}, {\"Order\": 1804, \"PID\": 528482010, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 11824, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1685.0, \"TotalBsmtSF\": 1685.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1685, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1685, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 1805, \"PID\": 528482030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 353.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2443, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 744.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 1806, \"PID\": 528482090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 102.0, \"LotArea\": 11143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 159, \"OpenPorchSF\": 214, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 1807, \"PID\": 531363020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 146000}, {\"Order\": 1808, \"PID\": 531363040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1809, \"PID\": 531375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1810, \"PID\": 531376060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1461.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1811, \"PID\": 531380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 1812, \"PID\": 531384070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11613, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191750}, {\"Order\": 1813, \"PID\": 531385070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1349.0, \"TotalBsmtSF\": 1349.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1349, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1349, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1814, \"PID\": 531385130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 39.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 402, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1815, \"PID\": 531451030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1145.0, \"TotalBsmtSF\": 1575.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1816, \"PID\": 531451150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1817, \"PID\": 531453140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1818, \"PID\": 531477040, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1819, \"PID\": 532353120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 351.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120750}, {\"Order\": 1820, \"PID\": 532354010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1821, \"PID\": 532354060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1822, \"PID\": 532354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 999.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1823, \"PID\": 532376040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 6970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1824, \"PID\": 532376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 13673, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143900}, {\"Order\": 1825, \"PID\": 532377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 7476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1826, \"PID\": 532377140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 57.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 827.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1827, \"PID\": 532378240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1828, \"PID\": 532476080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1232, \"LowQualFinSF\": 0, \"GrLivArea\": 2503, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1829, \"PID\": 532477040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 125.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1031.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 2167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1830, \"PID\": 532479050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 10751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1037, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1831, \"PID\": 532479120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16647, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1701, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 611.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1832, \"PID\": 532479140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 968.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 455, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 147000}, {\"Order\": 1833, \"PID\": 533120030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 482.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 1357, \"LowQualFinSF\": 0, \"GrLivArea\": 2810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 500, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 1834, \"PID\": 533130170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10678, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 337.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 983.0, \"TotalBsmtSF\": 1683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2129, \"2ndFlrSF\": 743, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1835, \"PID\": 533205110, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 45.0, \"LotArea\": 4379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 527.0, \"TotalBsmtSF\": 1378.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1836, \"PID\": 533206060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 3523, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1081.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1151, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1837, \"PID\": 533206070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 3784, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1511.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193800}, {\"Order\": 1838, \"PID\": 533208010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 47.0, \"LotArea\": 4230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1352.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1839, \"PID\": 533208020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3606, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 937.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 1840, \"PID\": 533208030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1550, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 207500}, {\"Order\": 1841, \"PID\": 533208040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4274, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1106.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1241.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1241, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1241, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199900}, {\"Order\": 1842, \"PID\": 533208070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4251, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164700}, {\"Order\": 1843, \"PID\": 533213130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 1844, \"PID\": 533213140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1129.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1845, \"PID\": 533221030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1846, \"PID\": 533221060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1847, \"PID\": 533221100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1848, \"PID\": 533223050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 5105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 551.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 551, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 1849, \"PID\": 533236040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1850, \"PID\": 533241030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 66.0, \"LotArea\": 7399, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 1851, \"PID\": 533242080, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 73.0, \"LotArea\": 7321, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1339.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1852, \"PID\": 533242090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 1853, \"PID\": 533244040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 106.0, \"LotArea\": 8413, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 1105.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 1854, \"PID\": 533250190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1037.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 217, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279700}, {\"Order\": 1855, \"PID\": 533251110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1856, \"PID\": 533251130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 1857, \"PID\": 533252130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1157.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 1858, \"PID\": 533253180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 176.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 89, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213750}, {\"Order\": 1859, \"PID\": 533254100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 761, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1860, \"PID\": 533254130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 978.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181500}, {\"Order\": 1861, \"PID\": 533350020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 17778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1632.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 829.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 2461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2497, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2497, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 373000}, {\"Order\": 1862, \"PID\": 533352075, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAe\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 211.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 1361.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 1259, \"LowQualFinSF\": 0, \"GrLivArea\": 2620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 24, \"EnclosedPorch\": 145, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 8300, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1863, \"PID\": 534104090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 1929, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 1864, \"PID\": 534125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143450}, {\"Order\": 1865, \"PID\": 534127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 1008, \"LowQualFinSF\": 0, \"GrLivArea\": 2411, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240050}, {\"Order\": 1866, \"PID\": 534127140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 973.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1867, \"PID\": 534127260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 385.0, \"TotalBsmtSF\": 1295.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 194, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 1868, \"PID\": 534128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 11358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1869, \"PID\": 534151090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1594, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1870, \"PID\": 534151180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1871, \"PID\": 534175010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAn\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136905}, {\"Order\": 1872, \"PID\": 534176140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 792.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1873, \"PID\": 534177210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 916.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1874, \"PID\": 534178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1875, \"PID\": 534201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 38.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1876, \"PID\": 534202030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 519.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1877, \"PID\": 534204120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1878, \"PID\": 534252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1879, \"PID\": 534252060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10624, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1880, \"PID\": 534252070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1881, \"PID\": 534252110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 978.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 1882, \"PID\": 534275170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1960, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 15500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1883, \"PID\": 534275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 66.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1065, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 1884, \"PID\": 534276070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 63.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 81.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1885, \"PID\": 534276160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 285, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1886, \"PID\": 534276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 206.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1887, \"PID\": 534276290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 1888, \"PID\": 534278150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 167.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1889, \"PID\": 534278170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1890, \"PID\": 534278190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117600}, {\"Order\": 1891, \"PID\": 534401120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1174.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1892, \"PID\": 534401200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1893, \"PID\": 534403040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 270.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 580.0, \"BsmtUnfSF\": 452.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 309.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 333, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1894, \"PID\": 534403290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 1309, \"LowQualFinSF\": 0, \"GrLivArea\": 2154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 1895, \"PID\": 534403420, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 543.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1130.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1374, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1896, \"PID\": 534425015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 1592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 201, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1897, \"PID\": 534425080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 219.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1429, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1429, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1898, \"PID\": 534427140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1327, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1327, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150750}, {\"Order\": 1899, \"PID\": 534429030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101800}, {\"Order\": 1900, \"PID\": 534430090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 932, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 306.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 214, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1901, \"PID\": 534431020, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 259.0, \"BsmtUnfSF\": 433.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 908, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 1902, \"PID\": 534450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 2, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 39300}, {\"Order\": 1903, \"PID\": 534450110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1904, \"PID\": 534451020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 442, \"2ndFlrSF\": 228, \"LowQualFinSF\": 0, \"GrLivArea\": 670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1905, \"PID\": 534453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 404.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 1906, \"PID\": 534475170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1907, \"PID\": 534476080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1908, \"PID\": 534478140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Roll\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 708.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 992, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1909, \"PID\": 534479120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1910, \"PID\": 534479140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 1911, \"PID\": 535101150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1912, \"PID\": 535102010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 87.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1913, \"PID\": 535105110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 291.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1914, \"PID\": 535106140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 1915, \"PID\": 535106180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11344, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 874, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1916, \"PID\": 535126180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 1021.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1465, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Sev\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129000}, {\"Order\": 1917, \"PID\": 535151020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 873.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 63.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 219, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1918, \"PID\": 535151100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 908.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 1919, \"PID\": 535151110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 109, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142100}, {\"Order\": 1920, \"PID\": 535152060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1921, \"PID\": 535154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 243.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 834.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 275, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 1922, \"PID\": 535155110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 1923, \"PID\": 535176070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1244, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1244, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1924, \"PID\": 535177020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 69.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1144.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1925, \"PID\": 535177110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 138.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1331.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174850}, {\"Order\": 1926, \"PID\": 535179120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1927, \"PID\": 535180030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 586.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1928, \"PID\": 535181030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1237.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1657, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1929, \"PID\": 535181140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1930, \"PID\": 535300040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 928.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1931, \"PID\": 535301060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1932, \"PID\": 535301160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8078, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128600}, {\"Order\": 1933, \"PID\": 535302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1934, \"PID\": 535304170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 85.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 955.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 293.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1935, \"PID\": 535305180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1936, \"PID\": 535325090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 691.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1937, \"PID\": 535325280, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1938, \"PID\": 535325320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 500, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1939, \"PID\": 535327160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1940, \"PID\": 535327200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 377.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 551.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1941, \"PID\": 535353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 368, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1942, \"PID\": 535353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 324, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1943, \"PID\": 535353160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 14190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 544, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1944, \"PID\": 535354050, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 893, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 893, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1945, \"PID\": 535354260, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 512, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1946, \"PID\": 535355020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 21281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 1778, \"LowQualFinSF\": 0, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 208, \"EnclosedPorch\": 290, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 301600}, {\"Order\": 1947, \"PID\": 535375130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 735.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 735, \"2ndFlrSF\": 299, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 1948, \"PID\": 535376010, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 882.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103200}, {\"Order\": 1949, \"PID\": 535378080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 66.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 1950, \"PID\": 535379060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1951, \"PID\": 535379110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1895, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1952, \"PID\": 535382150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 691.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 86000}, {\"Order\": 1953, \"PID\": 535402140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 364.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 242.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1954, \"PID\": 535402180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 1955, \"PID\": 535403030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 952.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1956, \"PID\": 535426130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1957, \"PID\": 535450190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122900}, {\"Order\": 1958, \"PID\": 535450220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119200}, {\"Order\": 1959, \"PID\": 535450310, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10496, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1960, \"PID\": 535451040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 246.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1961, \"PID\": 535451100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1238, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 171, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 1962, \"PID\": 535451110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 398.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 149.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1963, \"PID\": 535452060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 254.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1964, \"PID\": 535453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1965, \"PID\": 535453150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7315, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1170.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1170, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1966, \"PID\": 535453180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 1967, \"PID\": 535457020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1098.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 154.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1377.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1377, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 1968, \"PID\": 535457040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1969, \"PID\": 535457050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1970, \"PID\": 535476360, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 831, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1971, \"PID\": 535477130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 1972, \"PID\": 535477180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 442.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1973, \"PID\": 535478040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 90, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1974, \"PID\": 902100010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1975, \"PID\": 902105110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 664, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 132000}, {\"Order\": 1976, \"PID\": 902106070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 175, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1977, \"PID\": 902106120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 782.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 184.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1978, \"PID\": 902107050, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1979, \"PID\": 902110010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 3153, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 26, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 1980, \"PID\": 902125120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1885, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1047, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1047, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1981, \"PID\": 902128160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 279.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1982, \"PID\": 902201090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 494, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 26, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1983, \"PID\": 902201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 679, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1984, \"PID\": 902202070, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 435.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 89471}, {\"Order\": 1985, \"PID\": 902205020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 122.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 448.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 761, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1986, \"PID\": 902205130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 1987, \"PID\": 902206270, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1075.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 642, \"LowQualFinSF\": 0, \"GrLivArea\": 1798, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1988, \"PID\": 902207010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1945, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 1989, \"PID\": 902207150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 968.0, \"TotalBsmtSF\": 968.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1990, \"PID\": 902300020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10337, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 1991, \"PID\": 902300040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 9863, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 374.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1992, \"PID\": 902301030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 842, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1993, \"PID\": 902301130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1994, \"PID\": 902302150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 1995, \"PID\": 902303100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 667.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 659, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144100}, {\"Order\": 1996, \"PID\": 902304040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1880, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 1997, \"PID\": 902305010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 316.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 687.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 687, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 124500}, {\"Order\": 1998, \"PID\": 902330090, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1879, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 819.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2454, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1999, \"PID\": 902332030, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1046.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 1031, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 99, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 2000, \"PID\": 902401030, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 779.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2001, \"PID\": 902404010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1221.0, \"TotalBsmtSF\": 1559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1559, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1559, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 230, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2002, \"PID\": 902408080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 718.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2003, \"PID\": 902427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 9439, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2004, \"PID\": 902427140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2005, \"PID\": 902427180, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2006, \"PID\": 903201090, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 6854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 227.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 916, \"2ndFlrSF\": 144, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 150, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2007, \"PID\": 903204030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8674, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1435, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128250}, {\"Order\": 2008, \"PID\": 903205085, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 8731, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 645.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2009, \"PID\": 903206170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 915, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2010, \"PID\": 903225040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2011, \"PID\": 903227140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 217.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 2012, \"PID\": 903228080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 349, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2013, \"PID\": 903231050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2014, \"PID\": 903231090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 809.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2015, \"PID\": 903231180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 423, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2016, \"PID\": 903232100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 966.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2017, \"PID\": 903233030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 903, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2018, \"PID\": 903233050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1933.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2019, \"PID\": 903233140, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 854, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2020, \"PID\": 903233180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 959, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 2021, \"PID\": 903234160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2022, \"PID\": 903236130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 7755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1164, \"LowQualFinSF\": 0, \"GrLivArea\": 2264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2023, \"PID\": 903400040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2024, \"PID\": 903401070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2025, \"PID\": 903425270, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 356, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2026, \"PID\": 903425280, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153575}, {\"Order\": 2027, \"PID\": 903426010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1929, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2028, \"PID\": 903427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 546.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 714.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 15, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136000}, {\"Order\": 2029, \"PID\": 903430040, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 933, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 113000}, {\"Order\": 2030, \"PID\": 903430050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 969, \"2ndFlrSF\": 245, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 117000}, {\"Order\": 2031, \"PID\": 903450060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 2032, \"PID\": 903451110, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 7449, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 2033, \"PID\": 903453080, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1497, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2034, \"PID\": 903454010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 0, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2035, \"PID\": 903454090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2036, \"PID\": 903456110, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 398.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 1952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 285, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212300}, {\"Order\": 2037, \"PID\": 903457040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 1042, \"LowQualFinSF\": 0, \"GrLivArea\": 2180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2038, \"PID\": 903457130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 4330, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 477, \"LowQualFinSF\": 0, \"GrLivArea\": 1315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 99500}, {\"Order\": 2039, \"PID\": 903458020, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 581, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101000}, {\"Order\": 2040, \"PID\": 903458060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 197.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 999.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2041, \"PID\": 903475040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 12358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 528, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2042, \"PID\": 903475060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 964, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2043, \"PID\": 903476100, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 4388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2044, \"PID\": 903484080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 771.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 504, \"LowQualFinSF\": 114, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 14, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 84, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 50000}, {\"Order\": 2045, \"PID\": 904100100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1937, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 1005, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 521, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219000}, {\"Order\": 2046, \"PID\": 904101070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 138.0, \"LotArea\": 18030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 977.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 971, \"LowQualFinSF\": 479, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 2047, \"PID\": 904301110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 756, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 126000}, {\"Order\": 2048, \"PID\": 904302010, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 4484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2049, \"PID\": 905100060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2050, \"PID\": 905100080, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158450}, {\"Order\": 2051, \"PID\": 905101070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 14299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115400}, {\"Order\": 2052, \"PID\": 905101200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1029, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 261.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2053, \"PID\": 905102010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 722.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2054, \"PID\": 905103110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 761.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2055, \"PID\": 905104030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 627.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 913, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2056, \"PID\": 905104090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 7094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2057, \"PID\": 905104170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 948.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 108000}, {\"Order\": 2058, \"PID\": 905104240, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 20.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2059, \"PID\": 905105040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 8665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 897, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2060, \"PID\": 905105170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 323.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 529.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2061, \"PID\": 905105260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 955, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2062, \"PID\": 905106150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 8724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2063, \"PID\": 905107140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 2064, \"PID\": 905200010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2065, \"PID\": 905201080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 522.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 323.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2066, \"PID\": 905225020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 16779, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 1087, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 570, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2067, \"PID\": 905226050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1416, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2068, \"PID\": 905226080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165250}, {\"Order\": 2069, \"PID\": 905226130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 231.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2070, \"PID\": 905226170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 873.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"VWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2071, \"PID\": 905228020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 998, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 998, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 2072, \"PID\": 905301050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 115149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 739.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 380, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 2073, \"PID\": 905352010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 891.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2074, \"PID\": 905352180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2075, \"PID\": 905376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 109.0, \"TotalBsmtSF\": 409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1325, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 2076, \"PID\": 905377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 587.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2077, \"PID\": 905377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 17808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2078, \"PID\": 905401020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2079, \"PID\": 905426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 12615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 477.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243000}, {\"Order\": 2080, \"PID\": 905451390, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 491.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 638, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 332.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 2081, \"PID\": 905475270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2082, \"PID\": 905475520, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11515, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2083, \"PID\": 905476160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 7711, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2084, \"PID\": 905476170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 605, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 605, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 2085, \"PID\": 905476225, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 3869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 755.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1038.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1038, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2086, \"PID\": 905478140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2087, \"PID\": 905478220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1080.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 400, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2088, \"PID\": 905480090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 951.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 376, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 2089, \"PID\": 905480180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2090, \"PID\": 906200230, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 23920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1105.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 1012, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 444, \"PoolQC\": \"TA\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2091, \"PID\": 906201022, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 10357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 719.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 244, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2092, \"PID\": 906201023, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 1121, \"LowQualFinSF\": 0, \"GrLivArea\": 2243, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 44, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2093, \"PID\": 906201200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1474.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2730, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 2094, \"PID\": 906203140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 634.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 833.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 192, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2095, \"PID\": 906204140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 807.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 196, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2096, \"PID\": 906223040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 497.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 929, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2097, \"PID\": 906340080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 984.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 1414, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 383970}, {\"Order\": 2098, \"PID\": 906340090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1362, \"LowQualFinSF\": 0, \"GrLivArea\": 2828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 424870}, {\"Order\": 2099, \"PID\": 906378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 2100, \"PID\": 906378150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10481, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2140.0, \"TotalBsmtSF\": 2140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 360000}, {\"Order\": 2101, \"PID\": 906378170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10652, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1494.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 279500}, {\"Order\": 2102, \"PID\": 906380010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 11175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 200141}, {\"Order\": 2103, \"PID\": 906380040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 10235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246500}, {\"Order\": 2104, \"PID\": 906380070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1482.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 1092, \"LowQualFinSF\": 0, \"GrLivArea\": 2574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 276000}, {\"Order\": 2105, \"PID\": 906380120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 349.0, \"TotalBsmtSF\": 1274.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1274, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203000}, {\"Order\": 2106, \"PID\": 906380140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11103, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155835}, {\"Order\": 2107, \"PID\": 906380160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2108, \"PID\": 906380200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 195400}, {\"Order\": 2109, \"PID\": 906382020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1526.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1546, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1546, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2110, \"PID\": 906382060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1453.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 674.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212999}, {\"Order\": 2111, \"PID\": 906392080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1270.0, \"TotalBsmtSF\": 1270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1270, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2112, \"PID\": 906394020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 916, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 2113, \"PID\": 906394050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176432}, {\"Order\": 2114, \"PID\": 906402070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1157.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 882, \"LowQualFinSF\": 0, \"GrLivArea\": 2062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 154, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2115, \"PID\": 906403060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 321.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 927, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2116, \"PID\": 906426060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 159000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 2144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2117, \"PID\": 906426195, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53107, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 985.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 874, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 231, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2118, \"PID\": 906475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2087, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2119, \"PID\": 906475170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 155.0, \"LotArea\": 20064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 51.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 915.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 646, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2120, \"PID\": 907125040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 472.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 747.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2121, \"PID\": 907125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2122, \"PID\": 907130060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11249, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 544.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 2123, \"PID\": 907131060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 10021, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 635.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 646, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2124, \"PID\": 907131120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9531, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 914, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2125, \"PID\": 907135050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2126, \"PID\": 907135080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 16561, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 242.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147900}, {\"Order\": 2127, \"PID\": 907135180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123600}, {\"Order\": 2128, \"PID\": 907180040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 905, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204750}, {\"Order\": 2129, \"PID\": 907187040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 646.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 597.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235500}, {\"Order\": 2130, \"PID\": 907187060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12352, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 853, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1753, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2131, \"PID\": 907192020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 845.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190550}, {\"Order\": 2132, \"PID\": 907192040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8826, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2133, \"PID\": 907192120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 167.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1013.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2134, \"PID\": 907192150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2135, \"PID\": 907200130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 131000}, {\"Order\": 2136, \"PID\": 907200190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 502.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2137, \"PID\": 907200250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1009, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2138, \"PID\": 907200270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 2139, \"PID\": 907202100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 16300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 417.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2140, \"PID\": 907202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 432.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2141, \"PID\": 907203060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 2142, \"PID\": 907203110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 10356, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 969, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2143, \"PID\": 907227060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 671.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2144, \"PID\": 907227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2145, \"PID\": 907250050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 2000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305900}, {\"Order\": 2146, \"PID\": 907252020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1284.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 2169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2147, \"PID\": 907252190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11354, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1412.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1673, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1673, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2148, \"PID\": 907260040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1459.0, \"TotalBsmtSF\": 1459.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1459, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1459, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 2149, \"PID\": 907260050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 2150, \"PID\": 907262020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 214.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2151, \"PID\": 907270040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 16226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 1242, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 267000}, {\"Order\": 2152, \"PID\": 907275080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 519.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 683.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1592, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1592, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2153, \"PID\": 907275150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 1531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2439, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2154, \"PID\": 907280090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2155, \"PID\": 907280100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 2156, \"PID\": 907285040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 438.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1079.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2157, \"PID\": 907290140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 2158, \"PID\": 907295040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 17227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246900}, {\"Order\": 2159, \"PID\": 907401060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1081, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2160, \"PID\": 907405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2161, \"PID\": 907410020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179400}, {\"Order\": 2162, \"PID\": 907410050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 639.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 2163, \"PID\": 907414060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1422.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179600}, {\"Order\": 2164, \"PID\": 907414070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 709.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 2165, \"PID\": 907420050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1330, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167840}, {\"Order\": 2166, \"PID\": 907420060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 753, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168675}, {\"Order\": 2167, \"PID\": 907420110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2168, \"PID\": 908102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2169, \"PID\": 908102160, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 405, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 2170, \"PID\": 908103090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 132.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2171, \"PID\": 908127040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 10921, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 48.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94750}, {\"Order\": 2172, \"PID\": 908127060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 16287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 450, \"LowQualFinSF\": 0, \"GrLivArea\": 1351, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 43, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2173, \"PID\": 908127070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1179.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2174, \"PID\": 908127100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 11841, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2175, \"PID\": 908152060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2176, \"PID\": 908152070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 751.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2177, \"PID\": 908152180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9555, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1133, \"LowQualFinSF\": 0, \"GrLivArea\": 2233, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2178, \"PID\": 908152260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1125.0, \"TotalBsmtSF\": 1125.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155000}, {\"Order\": 2179, \"PID\": 908152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2180, \"PID\": 908152290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 123.0, \"TotalBsmtSF\": 734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 674, \"LowQualFinSF\": 0, \"GrLivArea\": 1408, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 2181, \"PID\": 908154195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 39290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 4010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 5095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 5095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 5095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 15, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1154.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 546, \"OpenPorchSF\": 484, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Elev\", \"MiscVal\": 17000, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 183850}, {\"Order\": 2182, \"PID\": 908154205, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 40094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 762.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 3138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3138, \"2ndFlrSF\": 1538, \"LowQualFinSF\": 0, \"GrLivArea\": 4676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 406, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 184750}, {\"Order\": 2183, \"PID\": 908186050, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 467.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2184, \"PID\": 908204090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 77.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 831.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2185, \"PID\": 908204180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2186, \"PID\": 908225240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 2187, \"PID\": 908225310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1195, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 118, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98500}, {\"Order\": 2188, \"PID\": 908226180, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 4270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 286, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2189, \"PID\": 908228010, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 278.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 740, \"2ndFlrSF\": 125, \"LowQualFinSF\": 0, \"GrLivArea\": 865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2190, \"PID\": 908250100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 2191, \"PID\": 908275090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2192, \"PID\": 908275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2193, \"PID\": 908275240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 79275}, {\"Order\": 2194, \"PID\": 908276230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2195, \"PID\": 909176080, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 10896, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1184.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 1440, \"LowQualFinSF\": 515, \"GrLivArea\": 3395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 8, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 14, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 200000}, {\"Order\": 2196, \"PID\": 909176170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2592, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 742, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1512, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 150000}, {\"Order\": 2197, \"PID\": 909250150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 53, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2198, \"PID\": 909250160, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10594, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 2199, \"PID\": 909251030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7223, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2200, \"PID\": 909251040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6821, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 113.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2201, \"PID\": 909252010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 787, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2202, \"PID\": 909252150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 4000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 567, \"2ndFlrSF\": 531, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 2203, \"PID\": 909252170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 6720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 585, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 2204, \"PID\": 909254090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7642, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 514, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189950}, {\"Order\": 2205, \"PID\": 909254100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 775, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2206, \"PID\": 909254130, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 364.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2207, \"PID\": 909254140, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1913, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 365.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90350}, {\"Order\": 2208, \"PID\": 909254150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 661.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 661, \"2ndFlrSF\": 589, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 242, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2209, \"PID\": 909256120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 920.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119750}, {\"Order\": 2210, \"PID\": 909275020, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 7136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 979, \"2ndFlrSF\": 979, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2211, \"PID\": 909275030, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 6270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 1001, \"LowQualFinSF\": 0, \"GrLivArea\": 2002, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2212, \"PID\": 909275110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1927, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 867, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 291, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2213, \"PID\": 909275160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 126.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 24, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 228, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2214, \"PID\": 909275310, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 22420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1128.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2215, \"PID\": 909276160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12168, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 537.0, \"TotalBsmtSF\": 965.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 3194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 359100}, {\"Order\": 2216, \"PID\": 909276210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 7810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1230, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2217, \"PID\": 909279080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 557.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 19, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2218, \"PID\": 909281020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 6221, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2219, \"PID\": 909281130, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1549, \"2ndFlrSF\": 1178, \"LowQualFinSF\": 0, \"GrLivArea\": 2727, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2220, \"PID\": 909282020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1945, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 150.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 2320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259500}, {\"Order\": 2221, \"PID\": 909425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 1477.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1839, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 2222, \"PID\": 909425270, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2223, \"PID\": 909428120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 35.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 869.0, \"BsmtUnfSF\": 905.0, \"TotalBsmtSF\": 1809.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2259, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2259, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 217000}, {\"Order\": 2224, \"PID\": 909428180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1020.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 584, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 2225, \"PID\": 909428340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21579, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2226, \"PID\": 909451130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 529, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 2227, \"PID\": 909452102, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2228, \"PID\": 909455060, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 577.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2229, \"PID\": 909475050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 652.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 434.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1262.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 2230, \"PID\": 909475070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 2035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2515, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2515, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 200624}, {\"Order\": 2231, \"PID\": 909475230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 18044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 279.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 64, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 228, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2232, \"PID\": 910200040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 997, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2233, \"PID\": 910200110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2234, \"PID\": 910201020, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 803, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2235, \"PID\": 910201050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 176, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129850}, {\"Order\": 2236, \"PID\": 910201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 772, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1123, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 2237, \"PID\": 910201180, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": null, \"GarageArea\": null, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 150909}, {\"Order\": 2238, \"PID\": 910202030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 46.0, \"LotArea\": 3672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 100.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75200}, {\"Order\": 2239, \"PID\": 910203290, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118400}, {\"Order\": 2240, \"PID\": 910204090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 961.0, \"TotalBsmtSF\": 961.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"Mix\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 67000}, {\"Order\": 2241, \"PID\": 910205130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 910, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2242, \"PID\": 910206010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 11067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 205, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68104}, {\"Order\": 2243, \"PID\": 911103060, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1895, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 957.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 957, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 133, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119600}, {\"Order\": 2244, \"PID\": 911128010, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 65.0, \"LotArea\": 6565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 106.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 444, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2245, \"PID\": 911128020, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 837.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1001, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 86, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 2246, \"PID\": 911370450, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2247, \"PID\": 911370460, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 481.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 235000}, {\"Order\": 2248, \"PID\": 914452090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1001.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2249, \"PID\": 914452120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2250, \"PID\": 914452190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2251, \"PID\": 914460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 856.0, \"TotalBsmtSF\": 1441.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2252, \"PID\": 914460110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 12864, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 17.0, \"TotalBsmtSF\": 1409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1409, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 2253, \"PID\": 914476330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2254, \"PID\": 914478020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 530.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 852.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2255, \"PID\": 914478100, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 924.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2256, \"PID\": 916226090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 4054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 949.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 2257, \"PID\": 916253320, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 9763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 239.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1102.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 2258, \"PID\": 916326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 16905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2259, \"PID\": 916326090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 19958, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 274, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2260, \"PID\": 916384050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 231713}, {\"Order\": 2261, \"PID\": 916384070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8298, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 963.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2207.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267300}, {\"Order\": 2262, \"PID\": 916384080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1476.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265900}, {\"Order\": 2263, \"PID\": 916384150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1571.0, \"TotalBsmtSF\": 1571.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1571, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239000}, {\"Order\": 2264, \"PID\": 916386170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 274.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1638.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248900}, {\"Order\": 2265, \"PID\": 916403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 215.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 1265.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2266, \"PID\": 916403290, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2267, \"PID\": 916455010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 742.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1756, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 2268, \"PID\": 916455050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6718, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2269, \"PID\": 916455110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 82.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2270, \"PID\": 916455150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 886.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 593.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282000}, {\"Order\": 2271, \"PID\": 916460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2272, \"PID\": 916475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 808.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 252, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2273, \"PID\": 916477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 1340, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279900}, {\"Order\": 2274, \"PID\": 917425190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 35133, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 995.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 263, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 263, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186700}, {\"Order\": 2275, \"PID\": 921126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 15306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1652.0, \"TotalBsmtSF\": 1732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 283463}, {\"Order\": 2276, \"PID\": 921128030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 2277, \"PID\": 921205070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1094.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 1349, \"LowQualFinSF\": 0, \"GrLivArea\": 2482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 281213}, {\"Order\": 2278, \"PID\": 923202134, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 914.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 2279, \"PID\": 923202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 200.0, \"LotArea\": 43500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1041.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 561, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2280, \"PID\": 923203010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 6710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 904.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2281, \"PID\": 923204050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 25286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132250}, {\"Order\": 2282, \"PID\": 923204140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 25000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2283, \"PID\": 923205025, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 149.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1622, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 439, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2284, \"PID\": 923225040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 840.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2285, \"PID\": 923225050, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 874.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 536, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2286, \"PID\": 923226300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2287, \"PID\": 923228200, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 27.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 97, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 2288, \"PID\": 923228220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93900}, {\"Order\": 2289, \"PID\": 923228250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 2290, \"PID\": 923228290, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 131.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 499.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2291, \"PID\": 923228390, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 75190}, {\"Order\": 2292, \"PID\": 923229010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146800}, {\"Order\": 2293, \"PID\": 923229040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9129, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2294, \"PID\": 923229100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1356, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 1424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2295, \"PID\": 923229140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 33983, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1112.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1676, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 690, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2296, \"PID\": 923230010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 185.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2297, \"PID\": 923230120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 2298, \"PID\": 923230180, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 149.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2299, \"PID\": 923251160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 27697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"CBlock\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 811.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1608, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2300, \"PID\": 923252080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7599, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2301, \"PID\": 923275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1090.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 88, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2302, \"PID\": 923275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2303, \"PID\": 923276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 596.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 330, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2304, \"PID\": 923400150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 212.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 974.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 974, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 974, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93500}, {\"Order\": 2305, \"PID\": 923425030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 887, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2306, \"PID\": 526302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11027, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1178.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1293, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1293, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2307, \"PID\": 526302040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 280, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2308, \"PID\": 526302120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1127.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 963.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2309, \"PID\": 526303060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 39384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 902.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 252000}, {\"Order\": 2310, \"PID\": 526354020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11727, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 434.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1851.0, \"TotalBsmtSF\": 1851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1851, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192100}, {\"Order\": 2311, \"PID\": 527105060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8238, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2312, \"PID\": 527106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 964.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 1243, \"LowQualFinSF\": 0, \"GrLivArea\": 2236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2313, \"PID\": 527107020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 781, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2314, \"PID\": 527107030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13031, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 592.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2315, \"PID\": 527107120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 821.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 821, \"2ndFlrSF\": 955, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 443.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2316, \"PID\": 527107240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 714.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 413.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 95, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2317, \"PID\": 527108010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 19378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 2462, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2318, \"PID\": 527108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 14859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 27.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1670.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 240000}, {\"Order\": 2319, \"PID\": 527108030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 13128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 990, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2320, \"PID\": 527108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 893.0, \"TotalBsmtSF\": 893.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 2321, \"PID\": 527108060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 13751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1640.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 2212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 773.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 309000}, {\"Order\": 2322, \"PID\": 527108090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 168.0, \"LotArea\": 23257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2021, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 274725}, {\"Order\": 2323, \"PID\": 527146135, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2062.0, \"TotalBsmtSF\": 2062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2079, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2324, \"PID\": 527158020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8076, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2325, \"PID\": 527163020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165600}, {\"Order\": 2326, \"PID\": 527166030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 2327, \"PID\": 527182020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 3701, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2328, \"PID\": 527190050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 5306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 215.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 441, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2329, \"PID\": 527190220, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 28, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2330, \"PID\": 527210030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 1384, \"LowQualFinSF\": 0, \"GrLivArea\": 2798, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 37, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 457347}, {\"Order\": 2331, \"PID\": 527210040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 18062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 662.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 1862, \"LowQualFinSF\": 0, \"GrLivArea\": 3390, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 545224}, {\"Order\": 2332, \"PID\": 527210050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 205.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 889.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1371, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 246, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356383}, {\"Order\": 2333, \"PID\": 527212030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 16056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1752.0, \"TotalBsmtSF\": 1992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1992, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 2868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 716.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 556581}, {\"Order\": 2334, \"PID\": 527212040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 1312, \"LowQualFinSF\": 0, \"GrLivArea\": 2576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 361919}, {\"Order\": 2335, \"PID\": 527214060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 16052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 734.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 2698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 535000}, {\"Order\": 2336, \"PID\": 527216010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 15922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 550.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 1405, \"LowQualFinSF\": 0, \"GrLivArea\": 2795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 401179}, {\"Order\": 2337, \"PID\": 527216050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1031.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1410.0, \"TotalBsmtSF\": 1410.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 1519, \"LowQualFinSF\": 0, \"GrLivArea\": 2945, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 37, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 438780}, {\"Order\": 2338, \"PID\": 527226010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1547, \"2ndFlrSF\": 720, \"LowQualFinSF\": 53, \"GrLivArea\": 2320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2339, \"PID\": 527250040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 34650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2340, \"PID\": 527252090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 523.0, \"TotalBsmtSF\": 1714.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1714, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 2341, \"PID\": 527254070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11302, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Other\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1422.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1826, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319000}, {\"Order\": 2342, \"PID\": 527256120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 18261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 123, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 470000}, {\"Order\": 2343, \"PID\": 527301010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 995.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2344, \"PID\": 527302080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1002.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 2183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2345, \"PID\": 527325160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 34.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 795.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 250, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2346, \"PID\": 527327080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2347, \"PID\": 527328010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2348, \"PID\": 527354040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 604.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 2349, \"PID\": 527355060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1857, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188900}, {\"Order\": 2350, \"PID\": 527355280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 1061.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 384, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2351, \"PID\": 527356020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1392, \"LowQualFinSF\": 0, \"GrLivArea\": 2784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 440, \"PoolArea\": 519, \"PoolQC\": \"Fa\", \"Fence\": \"MnPrv\", \"MiscFeature\": \"TenC\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2352, \"PID\": 527356060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 811, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 208, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2353, \"PID\": 527358090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 42.0, \"TotalBsmtSF\": 1047.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1083, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1083, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 444, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2354, \"PID\": 527365010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1358, \"LowQualFinSF\": 0, \"GrLivArea\": 2318, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 246, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294323}, {\"Order\": 2355, \"PID\": 527375160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 127.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1109, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 485.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 2356, \"PID\": 527376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2357, \"PID\": 527376110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 2358, \"PID\": 527377030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 377.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1309, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1309, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 648, \"PoolQC\": \"Fa\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2359, \"PID\": 527378010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2360, \"PID\": 527402210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 75.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 791.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 138800}, {\"Order\": 2361, \"PID\": 527402380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9353, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 116050}, {\"Order\": 2362, \"PID\": 527403120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 614.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 2363, \"PID\": 527404180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 2364, \"PID\": 527427210, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 951.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1487.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2365, \"PID\": 527450010, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 514.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 2366, \"PID\": 527450080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2367, \"PID\": 527450210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 408.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83000}, {\"Order\": 2368, \"PID\": 527450460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 494, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2369, \"PID\": 527451200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 91500}, {\"Order\": 2370, \"PID\": 527451380, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2371, \"PID\": 527451450, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 465, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2372, \"PID\": 527451460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 382.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2373, \"PID\": 527451520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 297.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94500}, {\"Order\": 2374, \"PID\": 527452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 156.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146300}, {\"Order\": 2375, \"PID\": 527452290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 373.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1387, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2376, \"PID\": 527452310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 175, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2377, \"PID\": 527453070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2378, \"PID\": 527455100, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2379, \"PID\": 528102010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 66.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1447.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 770.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2380, \"PID\": 528102080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 16387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1738, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 2589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 412083}, {\"Order\": 2381, \"PID\": 528106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 111.0, \"LotArea\": 16259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 370.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1249.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1249, \"2ndFlrSF\": 1347, \"LowQualFinSF\": 0, \"GrLivArea\": 2596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 342643}, {\"Order\": 2382, \"PID\": 528106120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 16163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1618.0, \"TotalBsmtSF\": 1618.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1618, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1618, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 2383, \"PID\": 528110050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 690.0, \"TotalBsmtSF\": 2076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2076, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 229, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 465000}, {\"Order\": 2384, \"PID\": 528112010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 12228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1721.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293000}, {\"Order\": 2385, \"PID\": 528114010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 14780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1085.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 354, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2386, \"PID\": 528116030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 16033, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1261.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 519, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 326000}, {\"Order\": 2387, \"PID\": 528118010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 14215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1218, \"LowQualFinSF\": 0, \"GrLivArea\": 2376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 853.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325300}, {\"Order\": 2388, \"PID\": 528118020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 309000}, {\"Order\": 2389, \"PID\": 528118110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13975, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 300000}, {\"Order\": 2390, \"PID\": 528120110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1030.0, \"TotalBsmtSF\": 1030.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 1060, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 2391, \"PID\": 528120140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 385.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 466, \"LowQualFinSF\": 0, \"GrLivArea\": 2091, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338500}, {\"Order\": 2392, \"PID\": 528138030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345000}, {\"Order\": 2393, \"PID\": 528142010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 12867, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1209.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 344133}, {\"Order\": 2394, \"PID\": 528142060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 10672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 1335, \"LowQualFinSF\": 0, \"GrLivArea\": 2389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 298236}, {\"Order\": 2395, \"PID\": 528142070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 814, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 329900}, {\"Order\": 2396, \"PID\": 528142110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 1896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 708.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 2397, \"PID\": 528144030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11065, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 788.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 1085.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 753.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281000}, {\"Order\": 2398, \"PID\": 528150080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372397}, {\"Order\": 2399, \"PID\": 528150090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 131.0, \"LotArea\": 14828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 1780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378000}, {\"Order\": 2400, \"PID\": 528164040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 562.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 374000}, {\"Order\": 2401, \"PID\": 528170040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 20431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 870.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1848, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 2728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 437154}, {\"Order\": 2402, \"PID\": 528172020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 512.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 179, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2403, \"PID\": 528172150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 488, \"LowQualFinSF\": 0, \"GrLivArea\": 1914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2404, \"PID\": 528174080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 705.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185850}, {\"Order\": 2405, \"PID\": 528180080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 5911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282500}, {\"Order\": 2406, \"PID\": 528181030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6955, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202500}, {\"Order\": 2407, \"PID\": 528181040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 6792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202665}, {\"Order\": 2408, \"PID\": 528186100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 518.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 899.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 332200}, {\"Order\": 2409, \"PID\": 528186110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 572.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1251.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310090}, {\"Order\": 2410, \"PID\": 528188040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171750}, {\"Order\": 2411, \"PID\": 528218030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 23, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169990}, {\"Order\": 2412, \"PID\": 528218060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 170440}, {\"Order\": 2413, \"PID\": 528218080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169985}, {\"Order\": 2414, \"PID\": 528218130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 17104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 426.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179665}, {\"Order\": 2415, \"PID\": 528218140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 14054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 1863, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 219210}, {\"Order\": 2416, \"PID\": 528221010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 11660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1326.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 174190}, {\"Order\": 2417, \"PID\": 528221100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172785}, {\"Order\": 2418, \"PID\": 528222010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11631, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1052.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 1321, \"LowQualFinSF\": 0, \"GrLivArea\": 2373, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 258000}, {\"Order\": 2419, \"PID\": 528222020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185101}, {\"Order\": 2420, \"PID\": 528228280, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3087, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 767.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210250}, {\"Order\": 2421, \"PID\": 528228325, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1374.0, \"TotalBsmtSF\": 1374.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 2422, \"PID\": 528228340, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1273.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2423, \"PID\": 528228360, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1038.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246990}, {\"Order\": 2424, \"PID\": 528228415, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1375.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178740}, {\"Order\": 2425, \"PID\": 528228430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2426, \"PID\": 528228545, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167240}, {\"Order\": 2427, \"PID\": 528228550, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1126.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156820}, {\"Order\": 2428, \"PID\": 528228565, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213490}, {\"Order\": 2429, \"PID\": 528228575, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1154.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 1520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264561}, {\"Order\": 2430, \"PID\": 528228580, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246578}, {\"Order\": 2431, \"PID\": 528231050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 21930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192140}, {\"Order\": 2432, \"PID\": 528235050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7861, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183200}, {\"Order\": 2433, \"PID\": 528235130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2434, \"PID\": 528235190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1598, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201490}, {\"Order\": 2435, \"PID\": 528240080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1406.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1454, \"2ndFlrSF\": 482, \"LowQualFinSF\": 0, \"GrLivArea\": 1936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 2436, \"PID\": 528250060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2437, \"PID\": 528275060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8121, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 711, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172400}, {\"Order\": 2438, \"PID\": 528275080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2439, \"PID\": 528280100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 930, \"LowQualFinSF\": 0, \"GrLivArea\": 1886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 89, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199900}, {\"Order\": 2440, \"PID\": 528290140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 959.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 2441, \"PID\": 528292080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287602}, {\"Order\": 2442, \"PID\": 528294070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 1286, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2443, \"PID\": 528315030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1074.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1407, \"2ndFlrSF\": 985, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 348000}, {\"Order\": 2444, \"PID\": 528315070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 31, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 2445, \"PID\": 528315080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 322.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 655.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1205, \"2ndFlrSF\": 1029, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2446, \"PID\": 528320060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 35760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1831, \"2ndFlrSF\": 1796, \"LowQualFinSF\": 0, \"GrLivArea\": 3627, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 807.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 361, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 625000}, {\"Order\": 2447, \"PID\": 528327010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9233, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 877.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 358.0, \"TotalBsmtSF\": 1540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1540, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2855, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 247, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 405000}, {\"Order\": 2448, \"PID\": 528344060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 530.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 374, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2449, \"PID\": 528348010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 258000}, {\"Order\": 2450, \"PID\": 528358030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 397.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 1368, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 169, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 2451, \"PID\": 528360050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 17242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 738.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1393.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1733.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1933, \"2ndFlrSF\": 1567, \"LowQualFinSF\": 0, \"GrLivArea\": 3500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 959.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 870, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 584500}, {\"Order\": 2452, \"PID\": 528363070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 501.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1305, \"2ndFlrSF\": 1189, \"LowQualFinSF\": 0, \"GrLivArea\": 2494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 803.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 321000}, {\"Order\": 2453, \"PID\": 528365090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 391.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1203, \"2ndFlrSF\": 1323, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 309, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 2454, \"PID\": 528366040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1039.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 1234, \"LowQualFinSF\": 0, \"GrLivArea\": 2799, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 432, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2455, \"PID\": 528429060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 760.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252000}, {\"Order\": 2456, \"PID\": 528429100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1562.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336820}, {\"Order\": 2457, \"PID\": 528429120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 20896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1721.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 2077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1134.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 267, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 423000}, {\"Order\": 2458, \"PID\": 528429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290000}, {\"Order\": 2459, \"PID\": 528439030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1616.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 2460, \"PID\": 528445010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1504.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199000}, {\"Order\": 2461, \"PID\": 528456200, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1254.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 584.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198600}, {\"Order\": 2462, \"PID\": 528477010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 13162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 2036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 405749}, {\"Order\": 2463, \"PID\": 528477030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 11216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 232600}, {\"Order\": 2464, \"PID\": 528480070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1053.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 266000}, {\"Order\": 2465, \"PID\": 528480100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186500}, {\"Order\": 2466, \"PID\": 528480110, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200825}, {\"Order\": 2467, \"PID\": 528480150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 798, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 197000}, {\"Order\": 2468, \"PID\": 528488110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 905.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185000}, {\"Order\": 2469, \"PID\": 528488120, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2470, \"PID\": 528488130, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1293.0, \"TotalBsmtSF\": 1293.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187750}, {\"Order\": 2471, \"PID\": 531363080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1118.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 4, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2472, \"PID\": 531367010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 118.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1400.0, \"TotalBsmtSF\": 1400.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1400, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186800}, {\"Order\": 2473, \"PID\": 531375060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1131.0, \"TotalBsmtSF\": 1131.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 132000}, {\"Order\": 2474, \"PID\": 531375070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2475, \"PID\": 531375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 158000}, {\"Order\": 2476, \"PID\": 531376030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 891.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 891, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 2477, \"PID\": 531376050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1585, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 449.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 2478, \"PID\": 531379030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1837, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 688.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2479, \"PID\": 531450040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 761.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2480, \"PID\": 531451290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1731, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3000, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 248500}, {\"Order\": 2481, \"PID\": 531452080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1398, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2482, \"PID\": 531452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 278.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 1217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2483, \"PID\": 531452210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 362.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 636, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2484, \"PID\": 531478010, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 8900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107000}, {\"Order\": 2485, \"PID\": 531479030, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2486, \"PID\": 532351060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2487, \"PID\": 532351090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1332.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2488, \"PID\": 532351150, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1286, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2489, \"PID\": 532353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2490, \"PID\": 532353180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 8471, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 46.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 506.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2491, \"PID\": 532376080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2492, \"PID\": 532376180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2493, \"PID\": 532376250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2494, \"PID\": 532378050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120875}, {\"Order\": 2495, \"PID\": 532378070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 375.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 935, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2496, \"PID\": 532378130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2497, \"PID\": 532378160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 465.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 447.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2498, \"PID\": 532378220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8789, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129200}, {\"Order\": 2499, \"PID\": 532476050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 497.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1748.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2151, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 4, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 641, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 800, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2500, \"PID\": 533110130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 16059, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2417, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2501, \"PID\": 533125120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 692.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1118.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 208, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 2502, \"PID\": 533127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 310000}, {\"Order\": 2503, \"PID\": 533128030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13346, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 1129, \"LowQualFinSF\": 0, \"GrLivArea\": 2295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 2504, \"PID\": 533128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"ImStucc\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 757.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262000}, {\"Order\": 2505, \"PID\": 533206040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3628, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176400}, {\"Order\": 2506, \"PID\": 533208050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3316, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1247.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1247, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1247, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2507, \"PID\": 533212100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2508, \"PID\": 533212110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147400}, {\"Order\": 2509, \"PID\": 533212120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2510, \"PID\": 533212130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 144152}, {\"Order\": 2511, \"PID\": 533221080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 2512, \"PID\": 533223010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 241.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183900}, {\"Order\": 2513, \"PID\": 533223080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 673, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 153, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2514, \"PID\": 533223110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2515, \"PID\": 533241010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 114.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 382, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2516, \"PID\": 533242030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 2517, \"PID\": 533250130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 9549, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1057.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2518, \"PID\": 533252020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2519, \"PID\": 533253030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1009.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 44.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2520, \"PID\": 533253050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 3640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2521, \"PID\": 533253090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3874, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 807.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 419.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2522, \"PID\": 533253160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 526.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2523, \"PID\": 533350050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 50271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 1842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1842, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 857, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 385000}, {\"Order\": 2524, \"PID\": 534125210, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 13110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2525, \"PID\": 534126060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 10192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2526, \"PID\": 534127190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 1203.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2156, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2156, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 290, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 2527, \"PID\": 534127270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 404.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 708.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 708, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 119, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2528, \"PID\": 534128210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 435.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 222, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2529, \"PID\": 534129230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165150}, {\"Order\": 2530, \"PID\": 534175100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 264, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164500}, {\"Order\": 2531, \"PID\": 534176250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1164.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2532, \"PID\": 534201130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2533, \"PID\": 534201230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2534, \"PID\": 534201250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1770, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 270, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 455, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2535, \"PID\": 534201260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 94, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157500}, {\"Order\": 2536, \"PID\": 534201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 2537, \"PID\": 534201300, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2538, \"PID\": 534202020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124400}, {\"Order\": 2539, \"PID\": 534202180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 402.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 568.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2540, \"PID\": 534226060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 661.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2541, \"PID\": 534250300, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1993, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2542, \"PID\": 534275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 319, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2543, \"PID\": 534276010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2544, \"PID\": 534276230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1098.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 145000}, {\"Order\": 2545, \"PID\": 534400120, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 34.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 25, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 460, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185900}, {\"Order\": 2546, \"PID\": 534403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2547, \"PID\": 534403400, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 748.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2548, \"PID\": 534403440, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2549, \"PID\": 534427090, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2550, \"PID\": 534428060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 8973, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 28.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2551, \"PID\": 534429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 2552, \"PID\": 534430050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129800}, {\"Order\": 2553, \"PID\": 534430110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2554, \"PID\": 534431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1043, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1043, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2555, \"PID\": 534451050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 4712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 456, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 63, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 121600}, {\"Order\": 2556, \"PID\": 534451120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 5900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2557, \"PID\": 534451130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 5825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79900}, {\"Order\": 2558, \"PID\": 534453150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 7438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 316, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2559, \"PID\": 534455080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2560, \"PID\": 534475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1404.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 324, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 146500}, {\"Order\": 2561, \"PID\": 534476100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2562, \"PID\": 534477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 756.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1380.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 2136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 2563, \"PID\": 534479130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 165.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 958, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2564, \"PID\": 534479240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2565, \"PID\": 534479300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2566, \"PID\": 535101110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2567, \"PID\": 535103070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 939.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 307.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2568, \"PID\": 535105160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98600}, {\"Order\": 2569, \"PID\": 535125060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 2157, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2570, \"PID\": 535150240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 118000}, {\"Order\": 2571, \"PID\": 535150300, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 25419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 4, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 184.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 1360, \"LowQualFinSF\": 392, \"GrLivArea\": 3112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 552, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 512, \"PoolQC\": \"Ex\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 235000}, {\"Order\": 2572, \"PID\": 535151080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 9723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 332.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2573, \"PID\": 535151130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 303.0, \"TotalBsmtSF\": 1106.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2574, \"PID\": 535152070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 86, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2575, \"PID\": 535152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2576, \"PID\": 535176050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 175.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145250}, {\"Order\": 2577, \"PID\": 535177100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9610, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 2578, \"PID\": 535178100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 281.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 191, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2579, \"PID\": 535179050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 14850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 895.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 122, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2580, \"PID\": 535180020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 914.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 353.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 2581, \"PID\": 535180070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 64.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134450}, {\"Order\": 2582, \"PID\": 535301010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 943.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135960}, {\"Order\": 2583, \"PID\": 535301150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8092, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 156000}, {\"Order\": 2584, \"PID\": 535303050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1367.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2585, \"PID\": 535304020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2586, \"PID\": 535305120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 522.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2587, \"PID\": 535325130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 301.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2588, \"PID\": 535325340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 488.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 517.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2589, \"PID\": 535325350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 912.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2590, \"PID\": 535325450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2591, \"PID\": 535325460, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 21299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 929.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 791.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2592, \"PID\": 535327210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 521.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 75, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 323, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2593, \"PID\": 535353180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 22136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1153.0, \"TotalBsmtSF\": 2171.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1248, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1008.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 631, \"OpenPorchSF\": 48, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2594, \"PID\": 535354130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 900, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2595, \"PID\": 535355100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 865, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2596, \"PID\": 535375040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 713, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 161, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99800}, {\"Order\": 2597, \"PID\": 535376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 418.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2598, \"PID\": 535376100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1073.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108480}, {\"Order\": 2599, \"PID\": 535377070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 715, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 75, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68000}, {\"Order\": 2600, \"PID\": 535377100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 448, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 2601, \"PID\": 535379100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1130, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 229, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2602, \"PID\": 535380010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 821, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155500}, {\"Order\": 2603, \"PID\": 535380130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10818, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 981, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2604, \"PID\": 535381060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 105000}, {\"Order\": 2605, \"PID\": 535382020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 2414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2606, \"PID\": 535382130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1936, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 370, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 436, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2607, \"PID\": 535401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 445.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 2608, \"PID\": 535402070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1047.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159950}, {\"Order\": 2609, \"PID\": 535402100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 379.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1083.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 345, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2610, \"PID\": 535402220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 128, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2611, \"PID\": 535402230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 701.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1135.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1207, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 2612, \"PID\": 535403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 600.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2613, \"PID\": 535403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 8910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 655.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2614, \"PID\": 535403200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 207.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 2615, \"PID\": 535404080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 7100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2616, \"PID\": 535425040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1773, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 2617, \"PID\": 535425050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2618, \"PID\": 535425080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 802.0, \"TotalBsmtSF\": 1438.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1900, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 520, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 2619, \"PID\": 535426195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 16321, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1277.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 258, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2620, \"PID\": 535450100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 597.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 2621, \"PID\": 535450180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 2622, \"PID\": 535451190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 2623, \"PID\": 535451210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2624, \"PID\": 535453160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133700}, {\"Order\": 2625, \"PID\": 535454030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81400}, {\"Order\": 2626, \"PID\": 535454050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 2627, \"PID\": 535454060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2628, \"PID\": 535456010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1556.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1556, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2629, \"PID\": 535456020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 179.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 506.0, \"BsmtUnfSF\": 465.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2630, \"PID\": 535457070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 162, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2631, \"PID\": 535477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2632, \"PID\": 535478010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 10205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2633, \"PID\": 535478070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 809.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 236.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2634, \"PID\": 535478090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2635, \"PID\": 535478110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 953.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 1025.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2636, \"PID\": 902100110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 9856, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 1007, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 167, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2637, \"PID\": 902100130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9906, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 518, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 107000}, {\"Order\": 2638, \"PID\": 902101050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2639, \"PID\": 902103090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 863.0, \"TotalBsmtSF\": 1147.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1147, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2640, \"PID\": 902104020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 476, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2641, \"PID\": 902106040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2642, \"PID\": 902106090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6451, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 208.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 2643, \"PID\": 902108060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 66.0, \"LotArea\": 3960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 502.0, \"TotalBsmtSF\": 502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 502, \"2ndFlrSF\": 502, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2644, \"PID\": 902109010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 813, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 813, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2645, \"PID\": 902110120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7745, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 867, \"LowQualFinSF\": 0, \"GrLivArea\": 1951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 6, \"EnclosedPorch\": 28, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2646, \"PID\": 902110130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7741, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 143.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 2647, \"PID\": 902111010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5633, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 81, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2648, \"PID\": 902125020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1880, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 661, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 293, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 2649, \"PID\": 902128020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2650, \"PID\": 902128100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 648.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 734, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2651, \"PID\": 902134060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 7614, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1905, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 714, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 104, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96900}, {\"Order\": 2652, \"PID\": 902204060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2653, \"PID\": 902204120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 296, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2654, \"PID\": 902206020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2655, \"PID\": 902206090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 297, \"LowQualFinSF\": 0, \"GrLivArea\": 1182, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 378.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2656, \"PID\": 902207080, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 5820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 906.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1163, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126175}, {\"Order\": 2657, \"PID\": 902207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 48.0, \"LotArea\": 5747, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 2658, \"PID\": 902301120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 908, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2659, \"PID\": 902305090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 2, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 679, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2660, \"PID\": 902325050, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 2661, \"PID\": 902325100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2104, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2662, \"PID\": 902325160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 889, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2663, \"PID\": 902328100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 815.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 815, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 330, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2664, \"PID\": 902329070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 684, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114504}, {\"Order\": 2665, \"PID\": 902329090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 998, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 0, \"EnclosedPorch\": 221, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2666, \"PID\": 902400090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 84.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1200.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 125000}, {\"Order\": 2667, \"PID\": 902400110, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 22950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1892, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1107.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 1518, \"LowQualFinSF\": 572, \"GrLivArea\": 3608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 260, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 410, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 475000}, {\"Order\": 2668, \"PID\": 902401090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 5976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 624, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 256, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2669, \"PID\": 902406030, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 4500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2670, \"PID\": 902456015, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 63.0, \"LotArea\": 4761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 2671, \"PID\": 903200050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7446, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 2672, \"PID\": 903202120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 605, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140200}, {\"Order\": 2673, \"PID\": 903206160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1017, \"2ndFlrSF\": 810, \"LowQualFinSF\": 0, \"GrLivArea\": 1827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1943.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 27, \"OpenPorchSF\": 36, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2674, \"PID\": 903225090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2675, \"PID\": 903229040, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 325, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 271, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2676, \"PID\": 903231070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 2677, \"PID\": 903231190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2678, \"PID\": 903231220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 347.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 434, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 258.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 75000}, {\"Order\": 2679, \"PID\": 903231240, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1015, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1015, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 620, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 88000}, {\"Order\": 2680, \"PID\": 903232170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80500}, {\"Order\": 2681, \"PID\": 903233100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1042.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 149000}, {\"Order\": 2682, \"PID\": 903233220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 583, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2683, \"PID\": 903234030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 2684, \"PID\": 903235020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 129, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2685, \"PID\": 903236200, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 993.0, \"TotalBsmtSF\": 993.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2686, \"PID\": 903400030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 11672, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 2687, \"PID\": 903425190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 33120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2688, \"PID\": 903425340, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9873, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 288, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2689, \"PID\": 903430090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 634, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 255.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 394, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2690, \"PID\": 903430130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 153.0, \"LotArea\": 4118, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 693.0, \"TotalBsmtSF\": 693.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 693, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 693, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52500}, {\"Order\": 2691, \"PID\": 903451050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 834, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 2692, \"PID\": 903452090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 665, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 2693, \"PID\": 903454020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 819, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 819, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 72000}, {\"Order\": 2694, \"PID\": 903454080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 198.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2695, \"PID\": 903455090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 803.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 803, \"2ndFlrSF\": 557, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2696, \"PID\": 903456060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1007.0, \"TotalBsmtSF\": 1007.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 2697, \"PID\": 903456090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 234, \"GrLivArea\": 754, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 53, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2698, \"PID\": 903458010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2699, \"PID\": 904100030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 477.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 341, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2700, \"PID\": 904100090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 11136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1921.0, \"TotalBsmtSF\": 1921.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1921, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1921, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2701, \"PID\": 904100170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 225, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2702, \"PID\": 904101040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 6930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 294, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 2703, \"PID\": 904301410, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2704, \"PID\": 904302020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 830.0, \"TotalBsmtSF\": 830.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2705, \"PID\": 904302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 373.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2706, \"PID\": 905100030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 459.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2707, \"PID\": 905101330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 2708, \"PID\": 905101450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154500}, {\"Order\": 2709, \"PID\": 905103130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153600}, {\"Order\": 2710, \"PID\": 905103140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 97.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 328.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 68, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 164500}, {\"Order\": 2711, \"PID\": 905103180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 934, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 934, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 77, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2712, \"PID\": 905105010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1059, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1059, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2713, \"PID\": 905106210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11553, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1159, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 466, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2714, \"PID\": 905107070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 463.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 2715, \"PID\": 905107220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 982.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1458, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2716, \"PID\": 905107240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2717, \"PID\": 905107300, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 794.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 2718, \"PID\": 905108090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9662, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1967.0, \"TotalBsmtSF\": 1967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2719, \"PID\": 905108120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1466.0, \"TotalBsmtSF\": 1949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2720, \"PID\": 905200280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 441.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 2721, \"PID\": 905200290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 682.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2722, \"PID\": 905200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 17920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1085.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 418, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 312, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 2723, \"PID\": 905200380, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2724, \"PID\": 905200490, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1965, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2725, \"PID\": 905201090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 304, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2726, \"PID\": 905202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 826.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 1865.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1830, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 115, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 2727, \"PID\": 905202210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 13050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 850.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2728, \"PID\": 905225080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 15593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 701.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1304, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 667.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2729, \"PID\": 905300010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2730, \"PID\": 905300080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 241, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2731, \"PID\": 905351045, \"MSSubClass\": 150, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 1700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 33.0, \"TotalBsmtSF\": 430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 680, \"LowQualFinSF\": 140, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148400}, {\"Order\": 2732, \"PID\": 905351150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 445.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 190000}, {\"Order\": 2733, \"PID\": 905402110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2734, \"PID\": 905403050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 6488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 799, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 128000}, {\"Order\": 2735, \"PID\": 905426100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 103, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2736, \"PID\": 905426150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 626, \"LowQualFinSF\": 0, \"GrLivArea\": 2201, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 586, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 738, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 274970}, {\"Order\": 2737, \"PID\": 905427010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 19950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2738, \"PID\": 905427030, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 19800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1411.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 1836, \"LowQualFinSF\": 0, \"GrLivArea\": 3672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 684, \"OpenPorchSF\": 80, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2739, \"PID\": 905427140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11679, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1164.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 453, \"OpenPorchSF\": 253, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2740, \"PID\": 905451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 348, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2741, \"PID\": 905451410, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10519, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1057.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2742, \"PID\": 905452140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 325.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136900}, {\"Order\": 2743, \"PID\": 905452150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 532.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 541, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2744, \"PID\": 905475150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 6420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 2745, \"PID\": 905477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 2746, \"PID\": 905480160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 454, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91500}, {\"Order\": 2747, \"PID\": 906202040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 40.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2748, \"PID\": 906204180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1246, \"LowQualFinSF\": 0, \"GrLivArea\": 2559, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 245, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 209000}, {\"Order\": 2749, \"PID\": 906223180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9554, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1911, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2750, \"PID\": 906225180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 261.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1083.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 2751, \"PID\": 906380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 133.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1308.0, \"TotalBsmtSF\": 1308.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 848.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229800}, {\"Order\": 2752, \"PID\": 906380150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 393.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 183600}, {\"Order\": 2753, \"PID\": 906380170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7406, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 515.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 2754, \"PID\": 906380180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193879}, {\"Order\": 2755, \"PID\": 906382030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221500}, {\"Order\": 2756, \"PID\": 906382040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204900}, {\"Order\": 2757, \"PID\": 906382050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 571, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239799}, {\"Order\": 2758, \"PID\": 906392090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13377, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 260.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233555}, {\"Order\": 2759, \"PID\": 906392100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2760, \"PID\": 906392120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1122.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 1570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1590, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294900}, {\"Order\": 2761, \"PID\": 906394010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1809, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 209700}, {\"Order\": 2762, \"PID\": 906394040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1558.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2763, \"PID\": 906394060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 532.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2764, \"PID\": 906420020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 119.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 927, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1915, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 2765, \"PID\": 906426090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 36500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 812.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 198, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2766, \"PID\": 906475050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Metal\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 130, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2767, \"PID\": 906475200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 70761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 1533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1533, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2768, \"PID\": 906476140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 853.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 535.0, \"TotalBsmtSF\": 1388.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1388, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 2769, \"PID\": 907125020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2770, \"PID\": 907125080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2771, \"PID\": 907130110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 795, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 413, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2772, \"PID\": 907131070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 579.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 2773, \"PID\": 907135230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 13568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 274.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2774, \"PID\": 907175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2775, \"PID\": 907175060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2776, \"PID\": 907180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2777, \"PID\": 907181090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9272, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1749, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2778, \"PID\": 907187010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 13426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 57.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 107, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2779, \"PID\": 907192010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2780, \"PID\": 907194130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 2781, \"PID\": 907196020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1541.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 468, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 2782, \"PID\": 907200170, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 428.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2783, \"PID\": 907201160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 62.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 317.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2784, \"PID\": 907201230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2785, \"PID\": 907202140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 971.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 971, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2786, \"PID\": 907203010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 9560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2787, \"PID\": 907203040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 149900}, {\"Order\": 2788, \"PID\": 907227090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2789, \"PID\": 907230240, \"MSSubClass\": 160, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 3612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Landmrk\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2790, \"PID\": 907251100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 1989, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2791, \"PID\": 907252050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 199.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 826.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2792, \"PID\": 907254050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 9468, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2793, \"PID\": 907255010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2794, \"PID\": 907255050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1787, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1787, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2795, \"PID\": 907262080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8726, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 1909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2796, \"PID\": 907265030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 668.0, \"TotalBsmtSF\": 1654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1654, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2797, \"PID\": 907270050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10566, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 1124, \"LowQualFinSF\": 0, \"GrLivArea\": 2214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 646.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268500}, {\"Order\": 2798, \"PID\": 907275030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210900}, {\"Order\": 2799, \"PID\": 907285010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 258.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1070, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 2800, \"PID\": 907285100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 1045, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 2801, \"PID\": 907290020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 989, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274300}, {\"Order\": 2802, \"PID\": 907290080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216837}, {\"Order\": 2803, \"PID\": 907290160, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2804, \"PID\": 907290230, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155900}, {\"Order\": 2805, \"PID\": 907290260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1079.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 685.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233230}, {\"Order\": 2806, \"PID\": 907401050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2807, \"PID\": 907401080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2808, \"PID\": 907405030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2809, \"PID\": 907410040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8581, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203160}, {\"Order\": 2810, \"PID\": 907410100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 827, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195800}, {\"Order\": 2811, \"PID\": 907410110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212900}, {\"Order\": 2812, \"PID\": 907412010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2813, \"PID\": 907414040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198000}, {\"Order\": 2814, \"PID\": 907418020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 750, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173900}, {\"Order\": 2815, \"PID\": 907420070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 163990}, {\"Order\": 2816, \"PID\": 907420090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164990}, {\"Order\": 2817, \"PID\": 908102020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 337.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 420, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 2818, \"PID\": 908102320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 17755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2819, \"PID\": 908102330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2820, \"PID\": 908103310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 7840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 355.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2821, \"PID\": 908103320, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2822, \"PID\": 908127050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 16133, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2823, \"PID\": 908128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2824, \"PID\": 908130020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 475.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 297.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117250}, {\"Order\": 2825, \"PID\": 908178050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1150.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1150, \"LowQualFinSF\": 0, \"GrLivArea\": 2314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2826, \"PID\": 908186060, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2827, \"PID\": 908186070, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 140000}, {\"Order\": 2828, \"PID\": 908186090, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 142500}, {\"Order\": 2829, \"PID\": 908188110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2830, \"PID\": 908188120, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2831, \"PID\": 908188130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2832, \"PID\": 908188140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2833, \"PID\": 908188150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 3363, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 976.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2834, \"PID\": 908225180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6956, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 312, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 265.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97900}, {\"Order\": 2835, \"PID\": 908227010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 846, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 92000}, {\"Order\": 2836, \"PID\": 908227030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1669, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 107000}, {\"Order\": 2837, \"PID\": 908227040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 658.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 658, \"2ndFlrSF\": 526, \"LowQualFinSF\": 0, \"GrLivArea\": 1184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 81000}, {\"Order\": 2838, \"PID\": 908228040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 2839, \"PID\": 908275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 167.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2840, \"PID\": 908275290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 16012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 691.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 609.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2841, \"PID\": 909101050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 207, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2842, \"PID\": 909101080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 450, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 2843, \"PID\": 909101190, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 795.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 795, \"LowQualFinSF\": 481, \"GrLivArea\": 2230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2844, \"PID\": 909101330, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8088, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1922, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 35000}, {\"Order\": 2845, \"PID\": 909103020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 218, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2846, \"PID\": 909131125, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 7082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 980, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2847, \"PID\": 909175030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1192, \"2ndFlrSF\": 403, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2848, \"PID\": 909176180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 128.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 493, \"LowQualFinSF\": 0, \"GrLivArea\": 1551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2849, \"PID\": 909201180, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 58.0, \"LotArea\": 6430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 816, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128000}, {\"Order\": 2850, \"PID\": 909250070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 424.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 743, \"2ndFlrSF\": 736, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 530, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2851, \"PID\": 909250120, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 892, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138887}, {\"Order\": 2852, \"PID\": 909250200, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 4899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 2853, \"PID\": 909250210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 514, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2854, \"PID\": 909253080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9399, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 818, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1919.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2855, \"PID\": 909254070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 901, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200100}, {\"Order\": 2856, \"PID\": 909256010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10164, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2857, \"PID\": 909256020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2858, \"PID\": 909275230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 272, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2859, \"PID\": 909275250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 940, \"2ndFlrSF\": 610, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 429, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2860, \"PID\": 909276010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 725, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2861, \"PID\": 909276070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 113, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2862, \"PID\": 909279040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 67, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2863, \"PID\": 909280030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2864, \"PID\": 909280070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 8170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 526.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 549, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 2865, \"PID\": 909281010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1175, \"LowQualFinSF\": 0, \"GrLivArea\": 2345, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2866, \"PID\": 909282060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 104, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 2867, \"PID\": 909282110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 14210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 697, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 365.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2868, \"PID\": 909425120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 296.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 547.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1811, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 230000}, {\"Order\": 2869, \"PID\": 909425180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 459.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1283.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2870, \"PID\": 909426060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 405.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2871, \"PID\": 909428110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 375.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2872, \"PID\": 909475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 734.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 2873, \"PID\": 910200020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 102000}, {\"Order\": 2874, \"PID\": 910200060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 132, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145400}, {\"Order\": 2875, \"PID\": 910203100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 61.0, \"LotArea\": 8534, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72000}, {\"Order\": 2876, \"PID\": 910203230, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 272.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 2877, \"PID\": 910207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8765, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 327.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 106500}, {\"Order\": 2878, \"PID\": 910226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 327.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2879, \"PID\": 911175360, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 439, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 47, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2880, \"PID\": 911175410, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 69.0, \"LotArea\": 12366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 23, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 51689}, {\"Order\": 2881, \"PID\": 911175430, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 35311}, {\"Order\": 2882, \"PID\": 911175440, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2883, \"PID\": 911225110, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 360, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 2884, \"PID\": 911370430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5748, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1778, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2885, \"PID\": 911370530, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2886, \"PID\": 913350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 23580, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242500}, {\"Order\": 2887, \"PID\": 914452060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1664.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2888, \"PID\": 914474020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9116, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 2889, \"PID\": 914476050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2890, \"PID\": 914476130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 11080, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 257.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2891, \"PID\": 914476500, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1907.0, \"TotalBsmtSF\": 1907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1959, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 766.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 171000}, {\"Order\": 2892, \"PID\": 916225130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 26178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 293.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1210.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 1281, \"LowQualFinSF\": 0, \"GrLivArea\": 2519, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 2893, \"PID\": 916252170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2894, \"PID\": 916325040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 50102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 909.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1650, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 250764}, {\"Order\": 2895, \"PID\": 916326010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 653.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1686.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 574, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2896, \"PID\": 916402125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 13811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2897, \"PID\": 916403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1309.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2898, \"PID\": 916403130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2514, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 693.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2899, \"PID\": 916460070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1136.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 129.0, \"TotalBsmtSF\": 1381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2900, \"PID\": 916475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 630.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 2901, \"PID\": 916477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13618, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2902, \"PID\": 921205030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11443, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2028, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 326, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 369900}, {\"Order\": 2903, \"PID\": 921205050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 382.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 225, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 359900}, {\"Order\": 2904, \"PID\": 923125030, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 125.0, \"LotArea\": 31250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81500}, {\"Order\": 2905, \"PID\": 923202025, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1243.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 45.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2906, \"PID\": 923203090, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 897.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 125, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2907, \"PID\": 923203100, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 443.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 405.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 199, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2908, \"PID\": 923205120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 17217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84500}, {\"Order\": 2909, \"PID\": 923225190, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2910, \"PID\": 923225240, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 173.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 757.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2911, \"PID\": 923225260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 3964, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 837.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 1230, \"LowQualFinSF\": 0, \"GrLivArea\": 2521, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 728, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151400}, {\"Order\": 2912, \"PID\": 923225510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 2913, \"PID\": 923226150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1503.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2914, \"PID\": 923226180, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 2915, \"PID\": 923226290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79400}, {\"Order\": 2916, \"PID\": 923227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2917, \"PID\": 923228130, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 92000}, {\"Order\": 2918, \"PID\": 923228180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 87550}, {\"Order\": 2919, \"PID\": 923228210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 2920, \"PID\": 923228260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90500}, {\"Order\": 2921, \"PID\": 923228310, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1894, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 71000}, {\"Order\": 2922, \"PID\": 923229110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 12640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 396.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150900}, {\"Order\": 2923, \"PID\": 923230040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9297, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 188000}, {\"Order\": 2924, \"PID\": 923250060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2925, \"PID\": 923251180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 20000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 131000}, {\"Order\": 2926, \"PID\": 923275080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 7937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1003.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1003, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1003, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2927, \"PID\": 923276100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 324.0, \"BsmtUnfSF\": 239.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2928, \"PID\": 923400125, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2929, \"PID\": 924100070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1071.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 123.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1389, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2930, \"PID\": 924151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 1004, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "alt.Chart(train).mark_rect().encode(\n",
        "    x='MSZoning',\n",
        "    y='ExterQual',\n",
        "    color='average(SalePrice)',\n",
        "    tooltip=['MSZoning', 'ExterQual', 'average(SalePrice)']\n",
        ").properties(\n",
        "    width=500,\n",
        "    height=300\n",
        ")"
      ],
      "id": "cell-11"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Bindings, Selections & Conditions\n",
        "\n",
        "Here you can **select the `KitchenQual` feature** from a **dropdown\n",
        "menu** and see how the graph changes color!"
      ],
      "id": "62f74d30-2e4c-4981-93a0-aee9e50dee4e"
    },
    {
      "cell_type": "code",
      "execution_count": 19,
      "metadata": {
        "cell_id": "36bab1327ccf45e9811fb0ae9e291fda",
        "deepnote_cell_type": "code",
        "deepnote_to_be_reexecuted": false,
        "execution_millis": 957,
        "execution_start": 1685107191371,
        "papermill": {
          "duration": 0.609003,
          "end_time": "2023-01-11T23:38:30.058601",
          "exception": false,
          "start_time": "2023-01-11T23:38:29.449598",
          "status": "completed"
        },
        "source_hash": "7079dbb5",
        "tags": []
      },
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-3490b0ee233d410ba1333743a2dd1a44.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-3490b0ee233d410ba1333743a2dd1a44.vega-embed details,\n",
              "  #altair-viz-3490b0ee233d410ba1333743a2dd1a44.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-3490b0ee233d410ba1333743a2dd1a44\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-3490b0ee233d410ba1333743a2dd1a44\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-3490b0ee233d410ba1333743a2dd1a44\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"axis\": {\"grid\": false}}, \"data\": {\"name\": \"data-bd4440f2bd659840503c9701cdb81363\"}, \"mark\": {\"type\": \"point\"}, \"encoding\": {\"color\": {\"condition\": {\"param\": \"param_6\", \"field\": \"KitchenQual\", \"legend\": null, \"type\": \"nominal\"}, \"value\": \"lightgray\"}, \"tooltip\": [{\"field\": \"GrLivArea\", \"type\": \"quantitative\"}, {\"field\": \"SalePrice\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"GrLivArea\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"SalePrice\", \"type\": \"quantitative\"}}, \"height\": 300, \"params\": [{\"name\": \"param_6\", \"select\": {\"type\": \"point\", \"fields\": [\"KitchenQual\"]}, \"bind\": {\"input\": \"select\", \"options\": [\"TA\", \"Gd\", \"Ex\", \"Fa\", \"Po\"], \"name\": \"Lot Shape\"}}], \"width\": 500, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-bd4440f2bd659840503c9701cdb81363\": [{\"Order\": 1, \"PID\": 526301100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 141.0, \"LotArea\": 31770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2, \"PID\": 526350040, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 80.0, \"LotArea\": 11622, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 3, \"PID\": 526351010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 393, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 12500, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 4, \"PID\": 526353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1045.0, \"TotalBsmtSF\": 2110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 5, \"PID\": 527105010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189900}, {\"Order\": 6, \"PID\": 527105030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 7, \"PID\": 527127150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 8, \"PID\": 527145080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 263.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191500}, {\"Order\": 9, \"PID\": 527146030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1180.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 10, \"PID\": 527162130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 776, \"LowQualFinSF\": 0, \"GrLivArea\": 1804, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 11, \"PID\": 527163010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 763, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1655, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 157, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 12, \"PID\": 527165230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1992, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 935.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 233.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 13, \"PID\": 527166040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180400}, {\"Order\": 14, \"PID\": 527180040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 15, \"PID\": 527182190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 1120.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 16, \"PID\": 527216070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 53504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 603.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1690, \"2ndFlrSF\": 1589, \"LowQualFinSF\": 0, \"GrLivArea\": 3279, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 841.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 503, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 538000}, {\"Order\": 17, \"PID\": 527225035, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 152.0, \"LotArea\": 12134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1988, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 427.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 325, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 18, \"PID\": 527258010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 2, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 1856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394432}, {\"Order\": 19, \"PID\": 527276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 19138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 20, \"PID\": 527302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 163.0, \"BsmtUnfSF\": 589.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 21, \"PID\": 527358140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 22, \"PID\": 527358200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 81.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 885.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1173, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 170000}, {\"Order\": 23, \"PID\": 527368020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 814, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 24, \"PID\": 527402200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11241, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 25, \"PID\": 527402250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12537, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 26, \"PID\": 527403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 27, \"PID\": 527404120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 78.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 28, \"PID\": 527425090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 29, \"PID\": 527427230, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 5858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1051.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 30, \"PID\": 527451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 327.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 31, \"PID\": 527451330, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 32, \"PID\": 527451410, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 381.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 88000}, {\"Order\": 33, \"PID\": 527452190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 709.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 34, \"PID\": 527453130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 514.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 35, \"PID\": 527453150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 836.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 36, \"PID\": 527454200, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 37, \"PID\": 528108120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1590.0, \"TotalBsmtSF\": 1590.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1627, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 2334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 376162}, {\"Order\": 38, \"PID\": 528112020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 39, \"PID\": 528120060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1940, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395192}, {\"Order\": 40, \"PID\": 528120090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1544.0, \"TotalBsmtSF\": 1544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290941}, {\"Order\": 41, \"PID\": 528120100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 220000}, {\"Order\": 42, \"PID\": 528120120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 615.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 43, \"PID\": 528138020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1794.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1822, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259000}, {\"Order\": 44, \"PID\": 528138060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1515.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 45, \"PID\": 528150070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12919, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 760.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 2330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 611657}, {\"Order\": 46, \"PID\": 528175010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6371, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224000}, {\"Order\": 47, \"PID\": 528176010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1095.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1473.0, \"TotalBsmtSF\": 2846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 958.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 500000}, {\"Order\": 48, \"PID\": 528176070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 563, \"LowQualFinSF\": 0, \"GrLivArea\": 2250, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 49, \"PID\": 528180070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 412.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1296.0, \"TotalBsmtSF\": 1752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 50, \"PID\": 528181050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 7132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 51, \"PID\": 528188120, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 52, \"PID\": 528218150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 18494, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1324.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 53, \"PID\": 528228285, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 54, \"PID\": 528228440, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 55, \"PID\": 528231020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 58.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 56, \"PID\": 528240070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 1100, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216500}, {\"Order\": 57, \"PID\": 528240130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185088}, {\"Order\": 58, \"PID\": 528250100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 59, \"PID\": 528292020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9505, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 1151, \"LowQualFinSF\": 0, \"GrLivArea\": 2035, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 60, \"PID\": 528328100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 14774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1393.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2599, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 668, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 333168}, {\"Order\": 61, \"PID\": 528344070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 17433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1629.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1645, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 2475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 962.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 23, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 62, \"PID\": 528358010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 919.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 56, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260400}, {\"Order\": 63, \"PID\": 528363130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 1122, \"LowQualFinSF\": 0, \"GrLivArea\": 2622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 64, \"PID\": 528382020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1999, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 348.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1106, \"LowQualFinSF\": 0, \"GrLivArea\": 2270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 671.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 65, \"PID\": 528382030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 66, \"PID\": 528386040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 14720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 579.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1217.0, \"TotalBsmtSF\": 2033.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2053, \"2ndFlrSF\": 1185, \"LowQualFinSF\": 0, \"GrLivArea\": 3238, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 283, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 67, \"PID\": 528445060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8987, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221500}, {\"Order\": 68, \"PID\": 528456160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 92.0, \"LotArea\": 9215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204500}, {\"Order\": 69, \"PID\": 528458070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1547, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215200}, {\"Order\": 70, \"PID\": 528458110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 488.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1566, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 71, \"PID\": 528477080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 12552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 222.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 956, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 72, \"PID\": 528480090, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271500}, {\"Order\": 73, \"PID\": 531367050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 956.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233000}, {\"Order\": 74, \"PID\": 531369060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 75, \"PID\": 531380080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 76, \"PID\": 531451110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 543.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 119.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 77, \"PID\": 531451280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 635, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 78, \"PID\": 531452020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 79, \"PID\": 531452050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 353, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 80, \"PID\": 531452180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1744, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 238, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 81, \"PID\": 531453010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 82, \"PID\": 531453040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 83, \"PID\": 531477050, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67500}, {\"Order\": 84, \"PID\": 532351140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1318, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 85, \"PID\": 532354090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 899.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1155, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1155, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 86, \"PID\": 532376160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 416, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 87, \"PID\": 532377060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 31.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 88, \"PID\": 532377100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 220, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 89, \"PID\": 532378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6897, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 90, \"PID\": 532479070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 15410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 126.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 859.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 169000}, {\"Order\": 91, \"PID\": 533130020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10186, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 92, \"PID\": 533130130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 981.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1231.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2349, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 362500}, {\"Order\": 93, \"PID\": 533130160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1129.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 823, \"LowQualFinSF\": 0, \"GrLivArea\": 2225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 713.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 94, \"PID\": 533205060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 25.0, \"LotArea\": 4835, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 95, \"PID\": 533208090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 39.0, \"LotArea\": 3515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 96, \"PID\": 533210060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3215, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 97, \"PID\": 533212010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 98, \"PID\": 533212020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 99, \"PID\": 533212060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 376.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 100, \"PID\": 533213030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 101, \"PID\": 533221090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 102, \"PID\": 533221110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1159.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 466.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 103, \"PID\": 533223020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 696, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 104, \"PID\": 533223100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 244.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147110}, {\"Order\": 105, \"PID\": 533238045, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 57.0, \"LotArea\": 12853, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 1642.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 224, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267916}, {\"Order\": 106, \"PID\": 533244030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 7379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 107, \"PID\": 533253060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 4420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 108, \"PID\": 533253210, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1052.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 223, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 109, \"PID\": 533352170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13517, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 475.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 110, \"PID\": 534102025, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 659.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 111, \"PID\": 534129040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1323.0, \"TotalBsmtSF\": 1829.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1829, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 535.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218500}, {\"Order\": 112, \"PID\": 534151175, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1137.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243500}, {\"Order\": 113, \"PID\": 534152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 114, \"PID\": 534152070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 687.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 46.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 1891, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 115, \"PID\": 534152100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10421, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 394.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 734, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 66, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 116, \"PID\": 534176060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 982.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 1161.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1381, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1381, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 117, \"PID\": 534176230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 715, \"LowQualFinSF\": 0, \"GrLivArea\": 1645, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 118, \"PID\": 534202160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142250}, {\"Order\": 119, \"PID\": 534251320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 451.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 81.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1328.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 120, \"PID\": 534276360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128950}, {\"Order\": 121, \"PID\": 534401110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1209, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 122, \"PID\": 534401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 9680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1510, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 123, \"PID\": 534403360, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10600, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136300}, {\"Order\": 124, \"PID\": 534403410, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14112, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1014.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 227, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 125, \"PID\": 534425310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 156.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 126, \"PID\": 534427010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 13260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 127, \"PID\": 534430080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 49.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1029.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142125}, {\"Order\": 128, \"PID\": 534431050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 670.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1929, \"2ndFlrSF\": 532, \"LowQualFinSF\": 0, \"GrLivArea\": 2461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197600}, {\"Order\": 129, \"PID\": 534431070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 17360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1019, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 130, \"PID\": 534450180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 131, \"PID\": 534451150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1940, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 263, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76500}, {\"Order\": 132, \"PID\": 534475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 133, \"PID\": 534476260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 132.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 189, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 134, \"PID\": 534479320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 244.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 135, \"PID\": 535101020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 136, \"PID\": 535106190, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 361.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1169, \"LowQualFinSF\": 0, \"GrLivArea\": 2274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154300}, {\"Order\": 137, \"PID\": 535125010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 287.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 912.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1947.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2207, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 301, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 138, \"PID\": 535126040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 137.0, \"LotArea\": 16492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 713.0, \"BsmtUnfSF\": 557.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 139, \"PID\": 535152010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1604.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 140, \"PID\": 535152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 300, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 141, \"PID\": 535152130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 142, \"PID\": 535152150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 143, \"PID\": 535152250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 144, \"PID\": 535153070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1194.0, \"TotalBsmtSF\": 1194.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 145, \"PID\": 535154050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142000}, {\"Order\": 146, \"PID\": 535175070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 324.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 571.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 143, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 147, \"PID\": 535175180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10725, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 91.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1206, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108538}, {\"Order\": 148, \"PID\": 535179020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 149, \"PID\": 535180130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 832, \"2ndFlrSF\": 505, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 263.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 150, \"PID\": 535302080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 339.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 151, \"PID\": 535302200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 119.0, \"LotArea\": 10895, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 152, \"PID\": 535304060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 153, \"PID\": 535304180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 731.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109000}, {\"Order\": 154, \"PID\": 535325400, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 155, \"PID\": 535327140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 156, \"PID\": 535350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 362.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 157, \"PID\": 535350040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 5868, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 158, \"PID\": 535353190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 17503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97500}, {\"Order\": 159, \"PID\": 535377090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 160, \"PID\": 535401080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 72.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 258.0, \"BsmtUnfSF\": 733.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 161, \"PID\": 535425010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 1080, \"LowQualFinSF\": 0, \"GrLivArea\": 2978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 162, \"PID\": 535450210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 481.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 163, \"PID\": 535453070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 906.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 164, \"PID\": 535454070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 475, \"LowQualFinSF\": 0, \"GrLivArea\": 1385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 165, \"PID\": 535456110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 486.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134800}, {\"Order\": 166, \"PID\": 535457010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1116.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 385, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 167, \"PID\": 535457090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 7635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 350.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 168, \"PID\": 535476350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 263.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1395, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 657, \"OpenPorchSF\": 0, \"EnclosedPorch\": 113, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 169, \"PID\": 535477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 170, \"PID\": 902102100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 771.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80400}, {\"Order\": 171, \"PID\": 902104060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 172, \"PID\": 902106130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4485, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 579.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 51, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 173, \"PID\": 902106140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1028, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 130, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 174, \"PID\": 902110090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 5805, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1073.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1347, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 175, \"PID\": 902125080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1605, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107400}, {\"Order\": 176, \"PID\": 902125160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 4608, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 177, \"PID\": 902128170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 294.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 804, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 178, \"PID\": 902206040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 692.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 390, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 179, \"PID\": 902206130, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 827.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 180, \"PID\": 902206220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 606, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 181, \"PID\": 902206240, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 185, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 334, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 182, \"PID\": 902207130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1923, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 780.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 12789}, {\"Order\": 183, \"PID\": 902207140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1928, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105900}, {\"Order\": 184, \"PID\": 902305110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 228, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 185, \"PID\": 902327040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 966, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 186, \"PID\": 902329030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 187, \"PID\": 902401060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 18, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 188, \"PID\": 902402010, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 7407, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 923.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149700}, {\"Order\": 189, \"PID\": 902402130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 622, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 190, \"PID\": 902402250, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1885, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 777.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 191, \"PID\": 902403070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140750}, {\"Order\": 192, \"PID\": 903204040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1030, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 363.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 193, \"PID\": 903206120, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 194, \"PID\": 903225150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 765, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 765, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 195, \"PID\": 903226160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 452.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 12.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 134000}, {\"Order\": 196, \"PID\": 903227020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 197, \"PID\": 903227150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 955, \"2ndFlrSF\": 498, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 148, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 198, \"PID\": 903228150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 221, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 199, \"PID\": 903232190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 548, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 200, \"PID\": 903233120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 928, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138400}, {\"Order\": 201, \"PID\": 903234050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 164.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 202, \"PID\": 903425110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 10300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 11, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 203, \"PID\": 903426180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 888.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 1074, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 364, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 204, \"PID\": 903426200, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 205, \"PID\": 903430080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 3068, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 662, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 206, \"PID\": 903450110, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 110.0, \"LotArea\": 8472, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 207, \"PID\": 903454060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 372, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3500, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 208, \"PID\": 903476030, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 7630, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 209, \"PID\": 904100140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1032.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 1196, \"LowQualFinSF\": 0, \"GrLivArea\": 2403, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 0, \"EnclosedPorch\": 318, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 244400}, {\"Order\": 210, \"PID\": 904101110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 365.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 211, \"PID\": 904300150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 499, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Po\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 212, \"PID\": 904302260, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1026.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 180, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 213, \"PID\": 904350045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 214, \"PID\": 904351040, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 6449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1907, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 73.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93369}, {\"Order\": 215, \"PID\": 904352190, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 6048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114900}, {\"Order\": 216, \"PID\": 905101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 6342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1875, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94000}, {\"Order\": 217, \"PID\": 905101300, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1832, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 218, \"PID\": 905101310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1768.0, \"TotalBsmtSF\": 1768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 219, \"PID\": 905102060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 1039.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 220, \"PID\": 905103060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11341, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1302.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 221, \"PID\": 905104210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8521, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 842.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 222, \"PID\": 905105070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 668.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 223, \"PID\": 905105200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 47.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 474.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 224, \"PID\": 905106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 663, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 379, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 225, \"PID\": 905106170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137250}, {\"Order\": 226, \"PID\": 905107110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7424, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1373, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1373, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160250}, {\"Order\": 227, \"PID\": 905107250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 453.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 228, \"PID\": 905107320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 328.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1386, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 229, \"PID\": 905109130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 954, \"LowQualFinSF\": 0, \"GrLivArea\": 2260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 328000}, {\"Order\": 230, \"PID\": 905109170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1092.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1483, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1483, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 496, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 231, \"PID\": 905201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 756, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 232, \"PID\": 905202090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 233, \"PID\": 905325030, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23595, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 74.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 192, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 234, \"PID\": 905352140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 336, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 235, \"PID\": 905378040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 18600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 684.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 558, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 236, \"PID\": 905426060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 108.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 835, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 237, \"PID\": 905426200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11479, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 387.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 238, \"PID\": 905451320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 44, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 239, \"PID\": 905452110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 362, \"GrLivArea\": 1531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 209.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 240, \"PID\": 905452160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 954.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 1172.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1172, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 241, \"PID\": 905453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1176.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 242, \"PID\": 905453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 17485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1508, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Partial\", \"SalePrice\": 308030}, {\"Order\": 243, \"PID\": 905475510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1250.0, \"TotalBsmtSF\": 1250.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 244, \"PID\": 905478190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 245, \"PID\": 906201030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 977, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1732, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 246, \"PID\": 906201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 11980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 177.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1433.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1433.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 278, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 247, \"PID\": 906204230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 12361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 86.0, \"TotalBsmtSF\": 946.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1017.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 450, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 248, \"PID\": 906223090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 750.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 249, \"PID\": 906225210, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 250, \"PID\": 906378100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245350}, {\"Order\": 251, \"PID\": 906380190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 252, \"PID\": 906385010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 10402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 740.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198900}, {\"Order\": 253, \"PID\": 906385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1222.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1222, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 254, \"PID\": 906402200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12376, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1470.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 1523, \"LowQualFinSF\": 0, \"GrLivArea\": 3222, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 367, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 255, \"PID\": 906425045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 14235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 614, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 256, \"PID\": 906477110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 257, \"PID\": 907125090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 71, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 258, \"PID\": 907180050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 878.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 259, \"PID\": 907185060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 260, \"PID\": 907200280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 15240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 688.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 261, \"PID\": 907200290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161750}, {\"Order\": 262, \"PID\": 907200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 365, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128200}, {\"Order\": 263, \"PID\": 907203070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 264, \"PID\": 907250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 296.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 265, \"PID\": 907252120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 479.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1581.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 266, \"PID\": 907262050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 9548, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 223.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 458.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 613.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 267, \"PID\": 907280040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 331, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 268, \"PID\": 907290040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1649.0, \"TotalBsmtSF\": 1649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 269, \"PID\": 907290170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 270, \"PID\": 907290240, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 271, \"PID\": 907401090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 10635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 972.0, \"BsmtUnfSF\": 315.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 262, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 272, \"PID\": 907410080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 109.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 761.0, \"TotalBsmtSF\": 1473.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 273, \"PID\": 907414030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185500}, {\"Order\": 274, \"PID\": 908102060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 84900}, {\"Order\": 275, \"PID\": 908102110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 155891}, {\"Order\": 276, \"PID\": 908102130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 277, \"PID\": 908102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 278, \"PID\": 908102300, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 792, \"2ndFlrSF\": 328, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 64000}, {\"Order\": 279, \"PID\": 908103350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125200}, {\"Order\": 280, \"PID\": 908152080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 7819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 422.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 281, \"PID\": 908203100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 282, \"PID\": 908208020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 8546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1121.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 283, \"PID\": 908225320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 94.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1487, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 284, \"PID\": 908226130, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 285, \"PID\": 908275300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1526, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 286, \"PID\": 909100080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 4853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 974.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 287, \"PID\": 909100110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 841, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 288, \"PID\": 909101070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 289, \"PID\": 909176140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 242, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 290, \"PID\": 909176150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 166, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 291, \"PID\": 909177100, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 862, \"2ndFlrSF\": 1788, \"LowQualFinSF\": 0, \"GrLivArea\": 2650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 292, \"PID\": 909250030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 293, \"PID\": 909250060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 804.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 2447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 294, \"PID\": 909281080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 371.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 86, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 295, \"PID\": 909426080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 657.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1075, \"LowQualFinSF\": 0, \"GrLivArea\": 2177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 296, \"PID\": 909427230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 877.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 1152, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266500}, {\"Order\": 297, \"PID\": 909428280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 207, \"EnclosedPorch\": 162, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 298, \"PID\": 909452114, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 423.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203135}, {\"Order\": 299, \"PID\": 909455030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 300, \"PID\": 909455040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 76.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1115.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1191, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1191, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 301, \"PID\": 909475140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15602, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1801, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 289000}, {\"Order\": 302, \"PID\": 910202060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 61.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 358, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 303, \"PID\": 910203250, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 540, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 304, \"PID\": 910205120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 727, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 305, \"PID\": 911128180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 68400}, {\"Order\": 306, \"PID\": 911202100, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 859.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 859, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 102776}, {\"Order\": 307, \"PID\": 911204090, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 54, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 55993}, {\"Order\": 308, \"PID\": 911204100, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1896, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1896.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 265, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 50138}, {\"Order\": 309, \"PID\": 911370510, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246000}, {\"Order\": 310, \"PID\": 914467040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 615.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1916, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 741.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 311, \"PID\": 914475090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9620, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1243.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 375, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 80, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 312, \"PID\": 914476520, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 9196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 313, \"PID\": 914478045, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 473.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169900}, {\"Order\": 314, \"PID\": 914478110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1958.0, \"TotalBsmtSF\": 1958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 315, \"PID\": 916125360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 57200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 334.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 50, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 316, \"PID\": 916386010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 78.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1346, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 317, \"PID\": 916386020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1214.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179781}, {\"Order\": 318, \"PID\": 916386060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 319, \"PID\": 916386090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 774.0, \"TotalBsmtSF\": 774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 1194, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 269500}, {\"Order\": 320, \"PID\": 916455170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 1894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214900}, {\"Order\": 321, \"PID\": 916475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202900}, {\"Order\": 322, \"PID\": 921128020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 13214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2002.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2018, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2018, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378500}, {\"Order\": 323, \"PID\": 923201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 42.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 324, \"PID\": 923202105, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10114, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1430.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 325, \"PID\": 923204150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 326, \"PID\": 923205015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1344.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166500}, {\"Order\": 327, \"PID\": 923225300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83500}, {\"Order\": 328, \"PID\": 923225390, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 31.0, \"LotArea\": 2394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 945, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 329, \"PID\": 923225440, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 2592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 129.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 232.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 536, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 330, \"PID\": 923226250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 331, \"PID\": 923226320, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1491, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75500}, {\"Order\": 332, \"PID\": 923228270, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88250}, {\"Order\": 333, \"PID\": 923228370, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 334, \"PID\": 923230190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 469.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 335, \"PID\": 923251080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 26142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 336, \"PID\": 923276030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 207.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 337, \"PID\": 923276250, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1985, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1216.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 338, \"PID\": 923426070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 22, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 339, \"PID\": 924100050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 388.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 615, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 287, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 340, \"PID\": 924151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1341.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 284.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1679.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 64, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 341, \"PID\": 924152030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12961, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 342, \"PID\": 526302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 343, \"PID\": 526351100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 440.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 844.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 344, \"PID\": 526355080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 542.0, \"TotalBsmtSF\": 1952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 2704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 269, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 345, \"PID\": 527105070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 346, \"PID\": 527105130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 1275, \"LowQualFinSF\": 0, \"GrLivArea\": 2283, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 347, \"PID\": 527107130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1628, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 490, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 348, \"PID\": 527108070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 14892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1746, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377500}, {\"Order\": 349, \"PID\": 527110020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 22.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 350, \"PID\": 527127100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 28.0, \"LotArea\": 7296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 243.0, \"TotalBsmtSF\": 2208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2522, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 351, \"PID\": 527131030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 5664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1659, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 352, \"PID\": 527132090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 353, \"PID\": 527146010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 354, \"PID\": 527161040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 355, \"PID\": 527162110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 94, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 291, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 356, \"PID\": 527162120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 357, \"PID\": 527163040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 799.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 799, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 358, \"PID\": 527163070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 359, \"PID\": 527163130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181316}, {\"Order\": 360, \"PID\": 527164020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 7250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 361, \"PID\": 527164060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 362, \"PID\": 527164090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 702, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1481, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 363, \"PID\": 527165130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 364, \"PID\": 527166010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 694.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 1983, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 365, \"PID\": 527180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1424.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 508, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 366, \"PID\": 527182110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 187500}, {\"Order\": 367, \"PID\": 527214050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 17423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 748.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 2216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1166.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 501837}, {\"Order\": 368, \"PID\": 527254020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 464.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2046.0, \"TotalBsmtSF\": 2046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372500}, {\"Order\": 369, \"PID\": 527258020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 16158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 370, \"PID\": 527276160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1934, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 371, \"PID\": 527301320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 692.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 1200, \"LowQualFinSF\": 0, \"GrLivArea\": 2353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 372, \"PID\": 527302175, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 17043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1586, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 373, \"PID\": 527326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 82500}, {\"Order\": 374, \"PID\": 527326150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 375, \"PID\": 527352150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 154000}, {\"Order\": 376, \"PID\": 527353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 363.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 377, \"PID\": 527353060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 229.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1539, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2673, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 378, \"PID\": 527354100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 225.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 379, \"PID\": 527354200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 380, \"PID\": 527355150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1420.0, \"TotalBsmtSF\": 2524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 381, \"PID\": 527356040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157000}, {\"Order\": 382, \"PID\": 527359050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 383, \"PID\": 527359180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 448, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 384, \"PID\": 527364030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1016, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 581.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240900}, {\"Order\": 385, \"PID\": 527365030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 8004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 1103, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 263435}, {\"Order\": 386, \"PID\": 527366030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1058.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 387, \"PID\": 527368010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 225.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 471.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 839, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 388, \"PID\": 527375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1333.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 490, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 389, \"PID\": 527375180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 888.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 390, \"PID\": 527375210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 391, \"PID\": 527376100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 392, \"PID\": 527378140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 333.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 2119, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158000}, {\"Order\": 393, \"PID\": 527401160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 394, \"PID\": 527402220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1002, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 902.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 395, \"PID\": 527403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 439.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 472.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 396, \"PID\": 527404020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1180.0, \"TotalBsmtSF\": 1180.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 397, \"PID\": 527404030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 398, \"PID\": 527405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 726.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 399, \"PID\": 527405160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 239.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 400, \"PID\": 527405180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 401, \"PID\": 527425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97000}, {\"Order\": 402, \"PID\": 527425110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 403, \"PID\": 527450280, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 254.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 404, \"PID\": 527451110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 312.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 405, \"PID\": 527451320, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 406, \"PID\": 527451540, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 79.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 407, \"PID\": 527451640, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 510.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 408, \"PID\": 527451650, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 409, \"PID\": 527452060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 410, \"PID\": 527453050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 411, \"PID\": 527453060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 87, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 412, \"PID\": 527453140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 622.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 413, \"PID\": 527454050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 260, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 414, \"PID\": 527454130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2349, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 389.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 415, \"PID\": 527455050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 416, \"PID\": 527455060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 586, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 417, \"PID\": 527455080, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 279.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 418, \"PID\": 527455090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 345.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 419, \"PID\": 527455240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 420, \"PID\": 527455280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 421, \"PID\": 528102040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1172.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337500}, {\"Order\": 422, \"PID\": 528102140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 726.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1794, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 462000}, {\"Order\": 423, \"PID\": 528104070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 13518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 860.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1926.0, \"TotalBsmtSF\": 1926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 1174, \"LowQualFinSF\": 0, \"GrLivArea\": 3140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 485000}, {\"Order\": 424, \"PID\": 528106020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1767.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 3094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2402, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 555000}, {\"Order\": 425, \"PID\": 528106070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 404, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 426, \"PID\": 528108010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 640.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1566.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 890.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256300}, {\"Order\": 427, \"PID\": 528108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2042.0, \"TotalBsmtSF\": 2042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 253293}, {\"Order\": 428, \"PID\": 528108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1365, \"2ndFlrSF\": 1325, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 197, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 398800}, {\"Order\": 429, \"PID\": 528108070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 154.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 430, \"PID\": 528108130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 2020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 404000}, {\"Order\": 431, \"PID\": 528108140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 2006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 402861}, {\"Order\": 432, \"PID\": 528110010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 13478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1722.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 2296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 842.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 451950}, {\"Order\": 433, \"PID\": 528110020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 2630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2674, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2674, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 610000}, {\"Order\": 434, \"PID\": 528110090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 424.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1734.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 1088, \"LowQualFinSF\": 0, \"GrLivArea\": 2822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1020.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 582933}, {\"Order\": 435, \"PID\": 528112040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1736.0, \"TotalBsmtSF\": 1736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1736, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1736, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 436, \"PID\": 528116010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 99, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 296000}, {\"Order\": 437, \"PID\": 528118060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 23303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 273, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 409900}, {\"Order\": 438, \"PID\": 528120020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1709.0, \"TotalBsmtSF\": 1709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1717, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255500}, {\"Order\": 439, \"PID\": 528120030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1015.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 1739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 927.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 440, \"PID\": 528120160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 262.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274900}, {\"Order\": 441, \"PID\": 528120170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1037.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1531, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 700.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 442, \"PID\": 528138010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 13514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 285.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1142.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 1774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1808, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 443, \"PID\": 528142040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8834, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1170.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1462, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 444, \"PID\": 528142090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 11362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 862.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 185, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 445, \"PID\": 528142130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1124.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 479.0, \"BsmtUnfSF\": 1603.0, \"TotalBsmtSF\": 3206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 446, \"PID\": 528142150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12878, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 418.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 1760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1760, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 190, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 447, \"PID\": 528144020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1502.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233170}, {\"Order\": 448, \"PID\": 528166060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 922.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2336.0, \"TotalBsmtSF\": 2392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 386250}, {\"Order\": 449, \"PID\": 528166090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 724.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1972.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 2452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 886.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 445000}, {\"Order\": 450, \"PID\": 528168030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1295, \"LowQualFinSF\": 0, \"GrLivArea\": 2400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 451, \"PID\": 528172060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1598.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1606, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1606, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 452, \"PID\": 528174050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 6904, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 453, \"PID\": 528174060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 900.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 454, \"PID\": 528174070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 455, \"PID\": 528175050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 456, \"PID\": 528175060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 457, \"PID\": 528176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 730.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2146.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 2492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 949.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 552000}, {\"Order\": 458, \"PID\": 528178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 117.0, \"LotArea\": 15262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 470.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 643.0, \"TotalBsmtSF\": 2200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 685.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 382500}, {\"Order\": 459, \"PID\": 528180120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 308.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1084.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 460, \"PID\": 528180130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 461, \"PID\": 528186010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 1712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 183, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286500}, {\"Order\": 462, \"PID\": 528186180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 863.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 463, \"PID\": 528188020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 464, \"PID\": 528188060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2268, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 465, \"PID\": 528218090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 466, \"PID\": 528220040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 745.0, \"TotalBsmtSF\": 745.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 745, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167800}, {\"Order\": 467, \"PID\": 528221060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 12589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 468, \"PID\": 528221070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 469, \"PID\": 528228290, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1373.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 470, \"PID\": 528228295, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1569, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1569, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 471, \"PID\": 528228435, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1357.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 472, \"PID\": 528228450, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 473, \"PID\": 528228455, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 474, \"PID\": 528228460, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 11.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160200}, {\"Order\": 475, \"PID\": 528235010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 476, \"PID\": 528235090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1010.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1010, \"2ndFlrSF\": 1257, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 477, \"PID\": 528235200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 478, \"PID\": 528240030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 479, \"PID\": 528240060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 779, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184100}, {\"Order\": 480, \"PID\": 528240150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 481, \"PID\": 528250020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 482, \"PID\": 528250040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8174, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 483, \"PID\": 528253010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 484, \"PID\": 528275070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 1276, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 485, \"PID\": 528275160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 1126, \"LowQualFinSF\": 0, \"GrLivArea\": 2004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 486, \"PID\": 528280230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 487, \"PID\": 528290030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9734, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 113.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 488, \"PID\": 528290120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8123, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 489, \"PID\": 528290180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 8433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 683.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1514, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 490, \"PID\": 528290190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 491, \"PID\": 528292030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1177.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2312, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 492, \"PID\": 528292040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 841.0, \"TotalBsmtSF\": 841.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 493, \"PID\": 528292070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 772.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1038, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 494, \"PID\": 528294050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7848, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 495, \"PID\": 528315090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 673.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1163.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337000}, {\"Order\": 496, \"PID\": 528321010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 15138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 689.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 773.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1490, \"2ndFlrSF\": 1304, \"LowQualFinSF\": 0, \"GrLivArea\": 2794, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 403000}, {\"Order\": 497, \"PID\": 528327070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 1455.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1221, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 327000}, {\"Order\": 498, \"PID\": 528344040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 731.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2450, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1069.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 499, \"PID\": 528344100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 975.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 854.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1225.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 1336, \"LowQualFinSF\": 0, \"GrLivArea\": 2612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 336000}, {\"Order\": 500, \"PID\": 528354050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10208, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 921.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1264.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 1067, \"LowQualFinSF\": 0, \"GrLivArea\": 2344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 889.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 501, \"PID\": 528363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 634.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1526.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 2024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 815.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 502, \"PID\": 528365070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 987.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 1274, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 60, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 503, \"PID\": 528385050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 967, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 102, \"EnclosedPorch\": 209, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 504, \"PID\": 528387030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 372.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 623.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263550}, {\"Order\": 505, \"PID\": 528390100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 46589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 528.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 517, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 402000}, {\"Order\": 506, \"PID\": 528390210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 29959, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 507, \"PID\": 528427020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 244600}, {\"Order\": 508, \"PID\": 528431020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1696.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 972.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 509, \"PID\": 528431070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 294.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1614.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1658, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 510, \"PID\": 528435030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1573.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287090}, {\"Order\": 511, \"PID\": 528435050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 512, \"PID\": 528439060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 513, \"PID\": 528441020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 772.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 689.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 514, \"PID\": 528441090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2490, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 226, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 468000}, {\"Order\": 515, \"PID\": 528456180, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 920, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252678}, {\"Order\": 516, \"PID\": 528456220, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 517, \"PID\": 528456240, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7862, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 27.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208300}, {\"Order\": 518, \"PID\": 528458020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 90.0, \"LotArea\": 7993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 519, \"PID\": 528458040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229456}, {\"Order\": 520, \"PID\": 528458060, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1402.0, \"TotalBsmtSF\": 1402.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 205, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229800}, {\"Order\": 521, \"PID\": 528458140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 984.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 522, \"PID\": 528458160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 645.0, \"TotalBsmtSF\": 1766.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 195, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370878}, {\"Order\": 523, \"PID\": 528458180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1348.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1448, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1448, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238500}, {\"Order\": 524, \"PID\": 528477050, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 981, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 310000}, {\"Order\": 525, \"PID\": 528477070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 121.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 526, \"PID\": 528480040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1043.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 527, \"PID\": 528480130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 438, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241000}, {\"Order\": 528, \"PID\": 528480170, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264500}, {\"Order\": 529, \"PID\": 528482040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1662, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1662, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 530, \"PID\": 528482130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 531, \"PID\": 528488100, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1221.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 532, \"PID\": 528490040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 8736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 771.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 360.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1553.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234500}, {\"Order\": 533, \"PID\": 528490070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8127, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 841, \"LowQualFinSF\": 0, \"GrLivArea\": 1653, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 534, \"PID\": 531363010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 178, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 535, \"PID\": 531363030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1087.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 536, \"PID\": 531363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 537, \"PID\": 531369010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 871, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 538, \"PID\": 531369020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 774.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1512.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 845.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 539, \"PID\": 531371050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10083, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 540, \"PID\": 531375040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 541, \"PID\": 531375090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 542, \"PID\": 531375130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 543, \"PID\": 531376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1450, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224243}, {\"Order\": 544, \"PID\": 531379050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 11492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 1209, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 559.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 545, \"PID\": 531382070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10994, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 366.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 257000}, {\"Order\": 546, \"PID\": 531385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1434.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 547, \"PID\": 531450120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 364.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1730, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 548, \"PID\": 531452010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 626, \"2ndFlrSF\": 591, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 549, \"PID\": 531452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1332.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1332, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 550, \"PID\": 531452260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 786, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 551, \"PID\": 531453100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 141.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 465.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 552, \"PID\": 531475220, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 553, \"PID\": 531477020, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 721.0, \"TotalBsmtSF\": 721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 841, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 841, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 554, \"PID\": 531479020, \"MSSubClass\": 45, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 91, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 555, \"PID\": 532353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 884.0, \"BsmtUnfSF\": 28.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 556, \"PID\": 532353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 557, \"PID\": 532354160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 558, \"PID\": 532354230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9079, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 559, \"PID\": 532376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Family\", \"SalePrice\": 124100}, {\"Order\": 560, \"PID\": 532376110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 561, \"PID\": 532377130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131400}, {\"Order\": 562, \"PID\": 532378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 311.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 62383}, {\"Order\": 563, \"PID\": 532378180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 140.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 564, \"PID\": 532478020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15676, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1733.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 92.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 2014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 462, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 255, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 565, \"PID\": 533135020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11949, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1991, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 601.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 216.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 502, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 566, \"PID\": 533206020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 2880, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1376.0, \"TotalBsmtSF\": 1376.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1376, \"2ndFlrSF\": 1629, \"LowQualFinSF\": 0, \"GrLivArea\": 3005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 177, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280750}, {\"Order\": 567, \"PID\": 533210010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164500}, {\"Order\": 568, \"PID\": 533210020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173733}, {\"Order\": 569, \"PID\": 533213010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 3830, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1726.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 254, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 570, \"PID\": 533213020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4217, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 183.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 571, \"PID\": 533213040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 894.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1471, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 572, \"PID\": 533221040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 249.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 573, \"PID\": 533223030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 574, \"PID\": 533236050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1739, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 172500}, {\"Order\": 575, \"PID\": 533252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1252.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 136.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 501, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 225, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318750}, {\"Order\": 576, \"PID\": 533253070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 3782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211500}, {\"Order\": 577, \"PID\": 533254050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15417, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1619.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 20, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241600}, {\"Order\": 578, \"PID\": 533254110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1487, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180500}, {\"Order\": 579, \"PID\": 533352150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1281.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 580, \"PID\": 534125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 727.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 829, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 581, \"PID\": 534127130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 571.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1442.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 371, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 582, \"PID\": 534127170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9156, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185750}, {\"Order\": 583, \"PID\": 534128010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 859.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 32.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 204, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 350, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 584, \"PID\": 534128020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 782, \"LowQualFinSF\": 0, \"GrLivArea\": 2067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 585, \"PID\": 534128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 735, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 586, \"PID\": 534128190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1369, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256900}, {\"Order\": 587, \"PID\": 534129080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1724, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 588, \"PID\": 534129370, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 589, \"PID\": 534129380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 955.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113000}, {\"Order\": 590, \"PID\": 534151120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 283.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 2288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 591, \"PID\": 534152120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 592, \"PID\": 534175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1127.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 78, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213250}, {\"Order\": 593, \"PID\": 534177230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 594, \"PID\": 534200030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 595, \"PID\": 534202170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 596, \"PID\": 534226120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 466.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 597, \"PID\": 534250400, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 168500}, {\"Order\": 598, \"PID\": 534251030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 509.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 599, \"PID\": 534252240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 251.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 630.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 197, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 600, \"PID\": 534275060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 360, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 601, \"PID\": 534275100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 602, \"PID\": 534276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 603, \"PID\": 534277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 604, \"PID\": 534278070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 201.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177625}, {\"Order\": 605, \"PID\": 534278230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 606, \"PID\": 534400050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 345.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 1516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 152, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 607, \"PID\": 534400290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 217.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 512.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1313, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 121, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 608, \"PID\": 534402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1292.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1292, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145100}, {\"Order\": 609, \"PID\": 534402140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 230.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1154.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 610, \"PID\": 534402170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 549.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 611, \"PID\": 534403370, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 563.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 612, \"PID\": 534426110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 991.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 50.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 613, \"PID\": 534429150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 614, \"PID\": 534431130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 100.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 613.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 615, \"PID\": 534450150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 616, \"PID\": 534451110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 185.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 224, \"LowQualFinSF\": 0, \"GrLivArea\": 1203, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 617, \"PID\": 534475185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 1505.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1505, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 162, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 618, \"PID\": 534475250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 260, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 619, \"PID\": 534476150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 1416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 620, \"PID\": 534476320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 621, \"PID\": 534477110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 556, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 622, \"PID\": 534478230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 607.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 623, \"PID\": 535101120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 624, \"PID\": 535104120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10573, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 3.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 625, \"PID\": 535105100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 247.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1394.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1394, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 185, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 626, \"PID\": 535125070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 1562.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 342, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 627, \"PID\": 535125090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 314.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1186, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 628, \"PID\": 535126010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 576.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 2142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 252, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 629, \"PID\": 535126100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1392.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 630, \"PID\": 535150070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1281, \"2ndFlrSF\": 457, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 631, \"PID\": 535151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 313.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 632, \"PID\": 535152230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 661.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 633, \"PID\": 535154060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 203, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 634, \"PID\": 535154130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 635, \"PID\": 535175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 620.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 636, \"PID\": 535175050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1215.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 234, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 637, \"PID\": 535178040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 565.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1202, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1202, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 638, \"PID\": 535178120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 172.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 727.0, \"TotalBsmtSF\": 1382.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 639, \"PID\": 535179160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 155.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 750.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144000}, {\"Order\": 640, \"PID\": 535300120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 19296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 399.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 690.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 641, \"PID\": 535301170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 1297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1297, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1297, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 642, \"PID\": 535302120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 657.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1866.0, \"TotalBsmtSF\": 1866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 643, \"PID\": 535303110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 8128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 644, \"PID\": 535303150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10634, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1319, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1319, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 645, \"PID\": 535304100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 631.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 646, \"PID\": 535325290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1005.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 647, \"PID\": 535351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 178.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 648, \"PID\": 535352090, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 793, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 649, \"PID\": 535353040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1952, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1031.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1031, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 650, \"PID\": 535353060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102900}, {\"Order\": 651, \"PID\": 535353140, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1699, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 95000}, {\"Order\": 652, \"PID\": 535353240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 699.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 801, \"2ndFlrSF\": 726, \"LowQualFinSF\": 0, \"GrLivArea\": 1527, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 653, \"PID\": 535354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 654, \"PID\": 535354100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 655, \"PID\": 535375010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 656, \"PID\": 535375050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 704, \"LowQualFinSF\": 144, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 140, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 657, \"PID\": 535376060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 658, \"PID\": 535377150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 717, \"2ndFlrSF\": 322, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 111, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 659, \"PID\": 535378020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 9022, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1924, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 660, \"PID\": 535378120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10230, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 661, \"PID\": 535381040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 1064, \"GrLivArea\": 2377, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 432, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142900}, {\"Order\": 662, \"PID\": 535382100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 760, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 663, \"PID\": 535383060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 599, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 599, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 59000}, {\"Order\": 664, \"PID\": 535383070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 198, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 665, \"PID\": 535383110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 666, \"PID\": 535383120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 725, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78500}, {\"Order\": 667, \"PID\": 535402010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1248.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 907.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 668, \"PID\": 535402090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 996.0, \"TotalBsmtSF\": 1380.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1380, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 669, \"PID\": 535402270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 670, \"PID\": 535402330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2634, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 671, \"PID\": 535403190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1958, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 672, \"PID\": 535403210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 559.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1105, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 673, \"PID\": 535403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 674, \"PID\": 535425070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1270.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 675, \"PID\": 535426150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 676, \"PID\": 535450070, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 232, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 677, \"PID\": 535450160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 92900}, {\"Order\": 678, \"PID\": 535450200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 231, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 679, \"PID\": 535451170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 680, \"PID\": 535451250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 352.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 681, \"PID\": 535452090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1041.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 682, \"PID\": 535452100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 683, \"PID\": 535452140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 102.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 732, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118900}, {\"Order\": 684, \"PID\": 535453100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 433.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 95.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1183, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 685, \"PID\": 535453200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 686, \"PID\": 535454100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 832, \"2ndFlrSF\": 629, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 687, \"PID\": 535454160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 431, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 688, \"PID\": 535475010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 7570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1806, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144750}, {\"Order\": 689, \"PID\": 535476110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 124.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 690, \"PID\": 535476240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 7936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 826.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 691, \"PID\": 535477150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 692, \"PID\": 902101010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3950, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 693, \"PID\": 902102080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 682, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 694, \"PID\": 902103100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 4080, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 695, \"PID\": 902103120, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 972, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 696, \"PID\": 902103170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 5720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 455, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 66500}, {\"Order\": 697, \"PID\": 902105050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 496, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 698, \"PID\": 902105060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 699, \"PID\": 902106010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6406, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 269.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 868, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 700, \"PID\": 902106060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1892, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 994, \"LowQualFinSF\": 0, \"GrLivArea\": 2372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 287, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 701, \"PID\": 902109130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94550}, {\"Order\": 702, \"PID\": 902109140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7596, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1000, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 703, \"PID\": 902110080, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3378, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1946, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 651.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 682, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 704, \"PID\": 902134120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 801, \"2ndFlrSF\": 646, \"LowQualFinSF\": 0, \"GrLivArea\": 1447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 705, \"PID\": 902135020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 706, \"PID\": 902201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 707, \"PID\": 902202150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 811.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 811, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 708, \"PID\": 902204080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 709, \"PID\": 902205010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 25, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 45000}, {\"Order\": 710, \"PID\": 902205030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 37900}, {\"Order\": 711, \"PID\": 902206260, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1938, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 886, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91300}, {\"Order\": 712, \"PID\": 902207170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 713, \"PID\": 902300090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 4456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 113000}, {\"Order\": 714, \"PID\": 902301060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 677.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 715, \"PID\": 902301080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 716, \"PID\": 902325070, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1898, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 849.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 1063, \"LowQualFinSF\": 0, \"GrLivArea\": 2138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 717, \"PID\": 902326030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 181, \"OpenPorchSF\": 0, \"EnclosedPorch\": 386, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265979}, {\"Order\": 718, \"PID\": 902327070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 917.0, \"TotalBsmtSF\": 917.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 719, \"PID\": 902329080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1917, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 720, \"PID\": 902330040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 121.0, \"LotArea\": 17671, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1882, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 826, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 424.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 721, \"PID\": 902331010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 3300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 722, \"PID\": 902401130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1920, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 26.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 723, \"PID\": 902402150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 226, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 724, \"PID\": 902405100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 98.0, \"LotArea\": 8820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 561, \"LowQualFinSF\": 120, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 725, \"PID\": 902405120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 436, \"GrLivArea\": 1480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 207.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 119000}, {\"Order\": 726, \"PID\": 902406070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 238, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 727, \"PID\": 902477120, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 523, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 34900}, {\"Order\": 728, \"PID\": 902477130, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 72.0, \"LotArea\": 9392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 245.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 44000}, {\"Order\": 729, \"PID\": 903200080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 144.0, \"LotArea\": 21384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 15.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 730, \"PID\": 903201020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1022.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 731, \"PID\": 903201080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 732, \"PID\": 903202170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 244, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 733, \"PID\": 903205040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 192.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 40, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 734, \"PID\": 903226130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 735, \"PID\": 903226170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 390, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 736, \"PID\": 903227070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 737, \"PID\": 903227090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 825, \"2ndFlrSF\": 587, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 45, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 738, \"PID\": 903228070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 444.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 320, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 739, \"PID\": 903228120, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 740, \"PID\": 903230100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 741, \"PID\": 903231010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 927.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 742, \"PID\": 903231030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 989, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 54, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 743, \"PID\": 903231060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 744, \"PID\": 903231130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1931, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 745, \"PID\": 903232060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 995, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 15, \"EnclosedPorch\": 51, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 746, \"PID\": 903234220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 679.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 994, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 189, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 150, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 747, \"PID\": 903236040, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 134.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 1072.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 5.0, \"GarageArea\": 1184.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 748, \"PID\": 903400220, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11888, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 2134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 268, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214500}, {\"Order\": 749, \"PID\": 903425245, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 883, \"LowQualFinSF\": 0, \"GrLivArea\": 2019, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 509, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 750, \"PID\": 903427120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 751, \"PID\": 903429080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 2500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 752, \"PID\": 903429110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 753, \"PID\": 903430060, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 92.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 929, \"LowQualFinSF\": 371, \"GrLivArea\": 2229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 198, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 104000}, {\"Order\": 754, \"PID\": 903430070, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Sev\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 62500}, {\"Order\": 755, \"PID\": 903451090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 316.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 213, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 756, \"PID\": 903458170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 757, \"PID\": 903475100, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 758, \"PID\": 903476090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1902, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 169.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 978, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 759, \"PID\": 903481120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 760, \"PID\": 903481130, \"MSSubClass\": 85, \"MSZoning\": \"RM\", \"LotFrontage\": 86.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 749.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 63.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 70000}, {\"Order\": 761, \"PID\": 903484110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 262.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 754, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 288, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 762, \"PID\": 904100190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1946, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 704, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88750}, {\"Order\": 763, \"PID\": 904301060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 764, \"PID\": 904301070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 765, \"PID\": 904301100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 766, \"PID\": 904301375, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61000}, {\"Order\": 767, \"PID\": 904351200, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 54.0, \"LotArea\": 6629, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 551.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103600}, {\"Order\": 768, \"PID\": 904351240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 687, \"2ndFlrSF\": 425, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 226.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63000}, {\"Order\": 769, \"PID\": 905101260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12886, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 770, \"PID\": 905101490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 771, \"PID\": 905103040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 92.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 500.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1683, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 772, \"PID\": 905103070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 215, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113500}, {\"Order\": 773, \"PID\": 905105190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 774, \"PID\": 905107310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 775, \"PID\": 905108190, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7252, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 776, \"PID\": 905108220, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 860, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 777, \"PID\": 905200220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 170.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 778, \"PID\": 905200260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 611, \"LowQualFinSF\": 259, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 779, \"PID\": 905200350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15312, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 780, \"PID\": 905225090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 366.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2071, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2071, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 781, \"PID\": 905228050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63900}, {\"Order\": 782, \"PID\": 905229040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1104.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 783, \"PID\": 905325020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 25095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1473, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1473, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 60, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 143000}, {\"Order\": 784, \"PID\": 905377010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 284.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 785, \"PID\": 905377130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 786, \"PID\": 905401100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10708, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 768.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1867, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1867, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 476, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 787, \"PID\": 905402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139600}, {\"Order\": 788, \"PID\": 905402070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 789, \"PID\": 905450020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 790, \"PID\": 905451300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 340.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 791, \"PID\": 905451340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1276, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 60000}, {\"Order\": 792, \"PID\": 905452040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 747, \"LowQualFinSF\": 0, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154400}, {\"Order\": 793, \"PID\": 905452050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 344.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 794, \"PID\": 905475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1089.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1089, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 795, \"PID\": 905475500, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 290.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84000}, {\"Order\": 796, \"PID\": 905476230, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 393.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1049, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 266.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 797, \"PID\": 905478030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11409, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 798, \"PID\": 905480030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 799, \"PID\": 905480210, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 800, \"PID\": 906201021, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 286.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 801, \"PID\": 906201050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 19255, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 450.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 802, \"PID\": 906201130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1983, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 2132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316600}, {\"Order\": 803, \"PID\": 906203120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 177.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 2158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271900}, {\"Order\": 804, \"PID\": 906223060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 137.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 227.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 769, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 425.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 234, \"OpenPorchSF\": 72, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 805, \"PID\": 906223080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1879, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 100, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 806, \"PID\": 906223210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 807, \"PID\": 906226060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 26400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 2016, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 808, \"PID\": 906226070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118964}, {\"Order\": 809, \"PID\": 906226080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1086.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 153337}, {\"Order\": 810, \"PID\": 906226090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 1114, \"LowQualFinSF\": 0, \"GrLivArea\": 2228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 73, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 147983}, {\"Order\": 811, \"PID\": 906226100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 812, \"PID\": 906226110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 813, \"PID\": 906226120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 1120, \"LowQualFinSF\": 0, \"GrLivArea\": 2240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 142953}, {\"Order\": 814, \"PID\": 906226130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1094.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 148325}, {\"Order\": 815, \"PID\": 906226140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 113722}, {\"Order\": 816, \"PID\": 906230010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 817, \"PID\": 906230020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7939, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 818, \"PID\": 906230030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 819, \"PID\": 906340100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10933, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1021.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1555.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1138.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 323262}, {\"Order\": 820, \"PID\": 906340110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 417.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 297000}, {\"Order\": 821, \"PID\": 906340120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1622.0, \"TotalBsmtSF\": 1622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 860.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295493}, {\"Order\": 822, \"PID\": 906340130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 364.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 332000}, {\"Order\": 823, \"PID\": 906378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 904.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 824, \"PID\": 906380050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 825, \"PID\": 906380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11422, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1359.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 222, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272500}, {\"Order\": 826, \"PID\": 906380100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 827, \"PID\": 906380130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 828, \"PID\": 906380210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1282.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 829, \"PID\": 906380220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 10324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 382.0, \"TotalBsmtSF\": 1254.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221800}, {\"Order\": 830, \"PID\": 906392070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 82.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 831, \"PID\": 906392110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1474.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 832, \"PID\": 906392130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 704, \"2ndFlrSF\": 718, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 833, \"PID\": 906402060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 396, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 834, \"PID\": 906426210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 1449.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 815, \"LowQualFinSF\": 0, \"GrLivArea\": 1759, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 193, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233500}, {\"Order\": 835, \"PID\": 906475070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 28698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 764.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 966, \"LowQualFinSF\": 0, \"GrLivArea\": 2126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 836, \"PID\": 907126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 837, \"PID\": 907126050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9757, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 838, \"PID\": 907130100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 15426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 836, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 839, \"PID\": 907131090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 834, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 840, \"PID\": 907131190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14753, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 950.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1463, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1463, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 841, \"PID\": 907135040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 10859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1097.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 392, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 842, \"PID\": 907135170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 746.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 843, \"PID\": 907175100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 866.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 913, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 844, \"PID\": 907180130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1490.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 845, \"PID\": 907181100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9017, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 871.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 846, \"PID\": 907185050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 847, \"PID\": 907192030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8935, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 848, \"PID\": 907192090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 9808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1573, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 849, \"PID\": 907194010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1840, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 850, \"PID\": 907194110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 16285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1413.0, \"TotalBsmtSF\": 1413.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187100}, {\"Order\": 851, \"PID\": 907194160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10739, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 852, \"PID\": 907196060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11166, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 201000}, {\"Order\": 853, \"PID\": 907200230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 854, \"PID\": 907201220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16269, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 855, \"PID\": 907201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 6950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 710.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 856, \"PID\": 907202050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150500}, {\"Order\": 857, \"PID\": 907202080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 858, \"PID\": 907202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1072.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 859, \"PID\": 907227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 15523, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 860, \"PID\": 907227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 215, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 861, \"PID\": 907227110, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 862, \"PID\": 907227290, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8445, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 863, \"PID\": 907250070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 335.0, \"TotalBsmtSF\": 1569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 864, \"PID\": 907252060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1068.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254750}, {\"Order\": 865, \"PID\": 907252210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 866, \"PID\": 907252220, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 990.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 309.0, \"TotalBsmtSF\": 1299.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 573, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 261500}, {\"Order\": 867, \"PID\": 907253130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 2153, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 313000}, {\"Order\": 868, \"PID\": 907260030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 869, \"PID\": 907265010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 944.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 926, \"LowQualFinSF\": 0, \"GrLivArea\": 1870, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 870, \"PID\": 907275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 871, \"PID\": 907275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 814.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 872, \"PID\": 907275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 873, \"PID\": 907280170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1111.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1417, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1417, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 117, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 874, \"PID\": 907285020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 573.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 977, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 576, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 875, \"PID\": 907285050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 876, \"PID\": 907290070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1212.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 877, \"PID\": 907290090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1630.0, \"TotalBsmtSF\": 1630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 878, \"PID\": 907290180, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 879, \"PID\": 907290210, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 880, \"PID\": 907410130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1478.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 293200}, {\"Order\": 881, \"PID\": 907412020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 882, \"PID\": 907414020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1480.0, \"TotalBsmtSF\": 1500.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 883, \"PID\": 907414080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 193.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 884, \"PID\": 907420040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 885, \"PID\": 908102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 886, \"PID\": 908102270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1486.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 887, \"PID\": 908102290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 888, \"PID\": 908128060, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 495, \"2ndFlrSF\": 1427, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 177, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 889, \"PID\": 908151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 155.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 890, \"PID\": 908152035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 615.0, \"TotalBsmtSF\": 1014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 891, \"PID\": 908152100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 255.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 631.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 892, \"PID\": 908154040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 13286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 464.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 327, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 893, \"PID\": 908186080, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 894, \"PID\": 908201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1947, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 895, \"PID\": 908203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 332.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 243.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 896, \"PID\": 908225290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 900, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 897, \"PID\": 908225370, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 441, \"LowQualFinSF\": 0, \"GrLivArea\": 1529, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 898, \"PID\": 908229020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 899, \"PID\": 908250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 900, \"PID\": 908275040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1678.0, \"TotalBsmtSF\": 1678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1678, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1678, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 901, \"PID\": 908275110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 902, \"PID\": 908276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 903, \"PID\": 909101010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12354, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 800, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 904, \"PID\": 909101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 444, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 905, \"PID\": 909101140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10998, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 420.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 906, \"PID\": 909129090, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 907, \"PID\": 909129100, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1932, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 159434}, {\"Order\": 908, \"PID\": 909175080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 438, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 438, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 909, \"PID\": 909178160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 545, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 910, \"PID\": 909179020, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 15863, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 3, \"YearBuilt\": 1920, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 998, \"LowQualFinSF\": 397, \"GrLivArea\": 3082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 911, \"PID\": 909250080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 583.0, \"TotalBsmtSF\": 583.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 647, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 329, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 912, \"PID\": 909250220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 913, \"PID\": 909251050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 914, \"PID\": 909251170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137450}, {\"Order\": 915, \"PID\": 909252020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1936, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 575, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1135, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 916, \"PID\": 909253010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7558, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1913, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 917, \"PID\": 909253180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 877, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1477, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 918, \"PID\": 909254010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 919, \"PID\": 909257050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 10918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 920, \"PID\": 909275080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 921, \"PID\": 909276110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 753, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 213.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 922, \"PID\": 909276200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 332, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 923, \"PID\": 909277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1273, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 307.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 924, \"PID\": 909277100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13360, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 713.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 44, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 925, \"PID\": 909278020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7681, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 731.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 523, \"LowQualFinSF\": 0, \"GrLivArea\": 1343, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 186.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154900}, {\"Order\": 926, \"PID\": 909279010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 674.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 13, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 57, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 927, \"PID\": 909282130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 154.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 694.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144800}, {\"Order\": 928, \"PID\": 909425060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 929, \"PID\": 909425130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 65.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 875.0, \"BsmtUnfSF\": 621.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 930, \"PID\": 909426090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 507.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 295.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 931, \"PID\": 909427200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 158500}, {\"Order\": 932, \"PID\": 909428240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 91.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1906, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1906, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 201, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 933, \"PID\": 909451040, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 279, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 934, \"PID\": 909451100, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 935, \"PID\": 909451140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 561.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 936, \"PID\": 909451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 937, \"PID\": 909452050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13607, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 118.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208000}, {\"Order\": 938, \"PID\": 909475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17597, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1971, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 419.0, \"BsmtUnfSF\": 581.0, \"TotalBsmtSF\": 1803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2365, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 939, \"PID\": 909475300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1988, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 808.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 182, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 940, \"PID\": 910202070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 10690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 941, \"PID\": 910204050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 760.0, \"TotalBsmtSF\": 760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 928, \"LowQualFinSF\": 312, \"GrLivArea\": 2168, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 160, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 942, \"PID\": 910205020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 596, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 189.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 943, \"PID\": 911103050, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 105.0, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1915, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1013.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 513, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85000}, {\"Order\": 944, \"PID\": 911104060, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 72, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 945, \"PID\": 911370500, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230000}, {\"Order\": 946, \"PID\": 912251110, \"MSSubClass\": 30, \"MSZoning\": \"I (all)\", \"LotFrontage\": 109.0, \"LotArea\": 21780, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 119, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 57625}, {\"Order\": 947, \"PID\": 914465020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 250.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 948, \"PID\": 914465040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 2149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 239686}, {\"Order\": 949, \"PID\": 914465055, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1710.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 950, \"PID\": 914474070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 12209, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 1157, \"LowQualFinSF\": 0, \"GrLivArea\": 1961, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 951, \"PID\": 914475010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 926, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156450}, {\"Order\": 952, \"PID\": 914475030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 953, \"PID\": 914476020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 954, \"PID\": 914476380, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9947, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 955, \"PID\": 914476430, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 55.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1527.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 152000}, {\"Order\": 956, \"PID\": 916176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSeWa\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 541.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 118, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 233, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 957, \"PID\": 916176125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 215245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 820.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 958, \"PID\": 916380070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1022.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315500}, {\"Order\": 959, \"PID\": 916382010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224500}, {\"Order\": 960, \"PID\": 916382100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 13438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 2190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 780.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 961, \"PID\": 916382110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 406.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1115.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316500}, {\"Order\": 962, \"PID\": 916386140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 963, \"PID\": 916403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 387.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1412, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 964, \"PID\": 916403200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2237, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 965, \"PID\": 916403250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 14419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 624.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 1645.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 966, \"PID\": 916455070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 967, \"PID\": 916460110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 968, \"PID\": 916475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14601, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 584.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 578.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 969, \"PID\": 921128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1640.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 308, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 425000}, {\"Order\": 970, \"PID\": 923201100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 971, \"PID\": 923202060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1771, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 972, \"PID\": 923203110, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 247, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 973, \"PID\": 923203190, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 883.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 974, \"PID\": 923225360, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 975, \"PID\": 923225490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 9858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 33, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 976, \"PID\": 923226270, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 515.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 977, \"PID\": 923227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13383, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1404, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 978, \"PID\": 923228110, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 979, \"PID\": 923228150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 980, \"PID\": 923228230, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 981, \"PID\": 923230200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7689, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 76.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131900}, {\"Order\": 982, \"PID\": 923252075, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7706, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131250}, {\"Order\": 983, \"PID\": 923275040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1097.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 602.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 303, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 984, \"PID\": 923275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 985, \"PID\": 923276260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 718.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 883, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 883, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 698.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 986, \"PID\": 923400025, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 566, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 320, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 987, \"PID\": 923400110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10429, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 988, \"PID\": 924100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1567.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 989, \"PID\": 924100060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 496.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 368, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 990, \"PID\": 526351030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 411.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 601.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 190, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 991, \"PID\": 526353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1205.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237500}, {\"Order\": 992, \"PID\": 526354070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 2112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206900}, {\"Order\": 993, \"PID\": 527105050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 994, \"PID\": 527106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 995, \"PID\": 527106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 996, \"PID\": 527106150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 997, \"PID\": 527107010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 998, \"PID\": 527107090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 898.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177900}, {\"Order\": 999, \"PID\": 527107210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 21872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1446, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 406.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1000, \"PID\": 527127140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1593.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1593, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 1001, \"PID\": 527131110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 6264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247900}, {\"Order\": 1002, \"PID\": 527140090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1003, \"PID\": 527145090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1280.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1004, \"PID\": 527161010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 926.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1005, \"PID\": 527162180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 183000}, {\"Order\": 1006, \"PID\": 527163100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1007, \"PID\": 527164120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1895, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 1008, \"PID\": 527165010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1009, \"PID\": 527183030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1010, \"PID\": 527183060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 5950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1011, \"PID\": 527208010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 13543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 1012, \"PID\": 527212050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1122.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 1370, \"LowQualFinSF\": 0, \"GrLivArea\": 2504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1013, \"PID\": 527214030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 15401, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 547.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 387000}, {\"Order\": 1014, \"PID\": 527226020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 31220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 2, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1474, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 750, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1015, \"PID\": 527252080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1034.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 557.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 1016, \"PID\": 527276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 47280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1488.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 133000}, {\"Order\": 1017, \"PID\": 527301170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 20544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 791.0, \"TotalBsmtSF\": 791.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 2093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1018, \"PID\": 527301245, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 983.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 1675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1688, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 141, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1019, \"PID\": 527302050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 228.0, \"BsmtUnfSF\": 606.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1020, \"PID\": 527302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1021, \"PID\": 527302185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 18559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 186.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 2048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1022, \"PID\": 527302210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 449.0, \"BsmtUnfSF\": 469.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 1023, \"PID\": 527325070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 424.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 896.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 550, \"OpenPorchSF\": 282, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 1024, \"PID\": 527325240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 48.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 1211.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 174, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1025, \"PID\": 527326130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1026, \"PID\": 527354160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 2044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1027, \"PID\": 527357110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9743, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146900}, {\"Order\": 1028, \"PID\": 527357180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12511, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1420, \"2ndFlrSF\": 1420, \"LowQualFinSF\": 0, \"GrLivArea\": 2840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1314.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 208, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 292500}, {\"Order\": 1029, \"PID\": 527358120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 11361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1193.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1523, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1030, \"PID\": 527359030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1444.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1031, \"PID\": 527359070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1032, \"PID\": 527378020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1033, \"PID\": 527380240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1236.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 787.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 180, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 1034, \"PID\": 527401130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1035, \"PID\": 527402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 438.0, \"BsmtUnfSF\": 14.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 80, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1036, \"PID\": 527402130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 16, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111900}, {\"Order\": 1037, \"PID\": 527403360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 613.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1038, \"PID\": 527425035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111250}, {\"Order\": 1039, \"PID\": 527427110, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1040, \"PID\": 527450110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103400}, {\"Order\": 1041, \"PID\": 527450250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1042, \"PID\": 527450520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 411, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100500}, {\"Order\": 1043, \"PID\": 527451060, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 127.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1044, \"PID\": 527451290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85400}, {\"Order\": 1045, \"PID\": 527451400, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 604.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1046, \"PID\": 527451550, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111750}, {\"Order\": 1047, \"PID\": 527452150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 559.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1048, \"PID\": 527453160, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 286.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 275.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1049, \"PID\": 527454120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 1050, \"PID\": 527455270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1051, \"PID\": 528102030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12444, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 426.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 304, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394617}, {\"Order\": 1052, \"PID\": 528102110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 590, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 426000}, {\"Order\": 1053, \"PID\": 528104050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 816.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 442.0, \"TotalBsmtSF\": 2078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2084, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 385000}, {\"Order\": 1054, \"PID\": 528104080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 14948, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 1237, \"LowQualFinSF\": 0, \"GrLivArea\": 2713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 858.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 446261}, {\"Order\": 1055, \"PID\": 528108150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 317500}, {\"Order\": 1056, \"PID\": 528110080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 436.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372402}, {\"Order\": 1057, \"PID\": 528110110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1728.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 2418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 358, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 417500}, {\"Order\": 1058, \"PID\": 528114040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 14418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 1950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 383000}, {\"Order\": 1059, \"PID\": 528118030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 2748, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 390000}, {\"Order\": 1060, \"PID\": 528118090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12539, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 468.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 1158, \"LowQualFinSF\": 0, \"GrLivArea\": 2790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1150.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 460000}, {\"Order\": 1061, \"PID\": 528120130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12151, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2331, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1003.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 379000}, {\"Order\": 1062, \"PID\": 528142020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 908.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1063, \"PID\": 528142140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1162, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316000}, {\"Order\": 1064, \"PID\": 528164060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 680.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 2535.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2470, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2470, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 144, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 615000}, {\"Order\": 1065, \"PID\": 528166120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 664.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 1096, \"LowQualFinSF\": 0, \"GrLivArea\": 2668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 412500}, {\"Order\": 1066, \"PID\": 528170070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1067, \"PID\": 528172080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 454.0, \"TotalBsmtSF\": 1603.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1068, \"PID\": 528178070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 16900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1075.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1515, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2649, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 421250}, {\"Order\": 1069, \"PID\": 528178090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 16451, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 221.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1765.0, \"TotalBsmtSF\": 1765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1804, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1070, \"PID\": 528180110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1486.0, \"TotalBsmtSF\": 1858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336860}, {\"Order\": 1071, \"PID\": 528180140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 766.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 367294}, {\"Order\": 1072, \"PID\": 528181010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 135.0, \"LotArea\": 12304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1347.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1367, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1073, \"PID\": 528186030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 12677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1074, \"PID\": 528186080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 616.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1684, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1684, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 495, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266000}, {\"Order\": 1075, \"PID\": 528186130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 8232, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 714.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370967}, {\"Order\": 1076, \"PID\": 528186160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234250}, {\"Order\": 1077, \"PID\": 528186170, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1318.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1078, \"PID\": 528188090, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1079, \"PID\": 528188150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 1080, \"PID\": 528190010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1081, \"PID\": 528228345, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1073.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 1415.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1455, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1455, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1082, \"PID\": 528228405, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1087.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219990}, {\"Order\": 1083, \"PID\": 528228445, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1084, \"PID\": 528228465, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159895}, {\"Order\": 1085, \"PID\": 528228540, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1146.0, \"TotalBsmtSF\": 1146.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 428.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187687}, {\"Order\": 1086, \"PID\": 528235020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1515, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1087, \"PID\": 528235120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7415, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 759.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 839.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1088, \"PID\": 528235180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1166, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1089, \"PID\": 528240040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 8029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1090, \"PID\": 528240050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1091, \"PID\": 528250030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8396, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1139, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1092, \"PID\": 528253020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 217300}, {\"Order\": 1093, \"PID\": 528280130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1094, \"PID\": 528280180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 647.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226750}, {\"Order\": 1095, \"PID\": 528290010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 15384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1096, \"PID\": 528290090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1097, \"PID\": 528292060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12460, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1098, \"PID\": 528294060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 873, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1099, \"PID\": 528315060, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1173.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284500}, {\"Order\": 1100, \"PID\": 528315110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1470, \"2ndFlrSF\": 1160, \"LowQualFinSF\": 0, \"GrLivArea\": 2630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 696.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 1101, \"PID\": 528326030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 14260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 1053, \"LowQualFinSF\": 0, \"GrLivArea\": 2198, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1102, \"PID\": 528326110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1519.0, \"TotalBsmtSF\": 1519.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 687.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 1103, \"PID\": 528346050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 136.0, \"LotArea\": 11675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 495.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2006, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1104, \"PID\": 528354100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 1061, \"LowQualFinSF\": 0, \"GrLivArea\": 2125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 1105, \"PID\": 528363020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1242.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1250, \"LowQualFinSF\": 0, \"GrLivArea\": 2501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1106, \"PID\": 528363110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10437, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 2109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 236, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1107, \"PID\": 528365060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 651.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1311.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 1093, \"LowQualFinSF\": 0, \"GrLivArea\": 2418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 983.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 154, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 341000}, {\"Order\": 1108, \"PID\": 528365080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 852.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2197, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 783.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 385, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287500}, {\"Order\": 1109, \"PID\": 528387050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 448.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 904, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1110, \"PID\": 528390020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 1986.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1987, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301500}, {\"Order\": 1111, \"PID\": 528427010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11932, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 830.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235128}, {\"Order\": 1112, \"PID\": 528427070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14598, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 74.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 1039, \"LowQualFinSF\": 0, \"GrLivArea\": 1933, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1113, \"PID\": 528429050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1574, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 824.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 1114, \"PID\": 528429070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13253, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1115, \"PID\": 528429080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264132}, {\"Order\": 1116, \"PID\": 528431060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 468.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 33.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1563.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1563, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1563, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1117, \"PID\": 528431080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 12274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1417.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227680}, {\"Order\": 1118, \"PID\": 528431120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1341.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 851.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 1119, \"PID\": 528435020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 919, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 297900}, {\"Order\": 1120, \"PID\": 528439010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1460.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1460, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1460, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247000}, {\"Order\": 1121, \"PID\": 528458030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1363.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212700}, {\"Order\": 1122, \"PID\": 528458050, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1372.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250580}, {\"Order\": 1123, \"PID\": 528462040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 95.0, \"LotArea\": 11639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1428.0, \"TotalBsmtSF\": 1428.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 182000}, {\"Order\": 1124, \"PID\": 528477040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226700}, {\"Order\": 1125, \"PID\": 528478030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 768.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1053.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 939, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1126, \"PID\": 528478040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 932, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1127, \"PID\": 528480060, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1034.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 1028, \"LowQualFinSF\": 0, \"GrLivArea\": 2078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 339750}, {\"Order\": 1128, \"PID\": 528480160, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 843, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 562.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205950}, {\"Order\": 1129, \"PID\": 528482020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1660.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1130, \"PID\": 528488140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230348}, {\"Order\": 1131, \"PID\": 528490080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 64.0, \"LotArea\": 8791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 361.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 673.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1132, \"PID\": 531363060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1133, \"PID\": 531371070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 555.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 861, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1134, \"PID\": 531373060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 1135, \"PID\": 531375050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1136, \"PID\": 531375110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1137, \"PID\": 531375120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1138, \"PID\": 531376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1139, \"PID\": 531376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1162.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1162, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1140, \"PID\": 531382090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 362.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1141, \"PID\": 531382110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 886.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 794, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1142, \"PID\": 531382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 258.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1679, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1679, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 1143, \"PID\": 531384030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 14565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 537.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1144, \"PID\": 531385060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1677, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190500}, {\"Order\": 1145, \"PID\": 531450030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 439.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1146, \"PID\": 531450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1147, \"PID\": 531450170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1148, \"PID\": 531451020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 165.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1617, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1617, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1149, \"PID\": 531452140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 899.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1199, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1150, \"PID\": 532351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 53.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 799.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1151, \"PID\": 532353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12968, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1152, \"PID\": 532354150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 764.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1153, \"PID\": 532376170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 890.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 890, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 890, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1154, \"PID\": 532377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119916}, {\"Order\": 1155, \"PID\": 532378200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1156, \"PID\": 532477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 19508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 108, \"EnclosedPorch\": 165, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1157, \"PID\": 532479020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 811.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 92, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1158, \"PID\": 533125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 1319, \"LowQualFinSF\": 0, \"GrLivArea\": 2683, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 251, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1159, \"PID\": 533125140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1328.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1827, \"2ndFlrSF\": 959, \"LowQualFinSF\": 0, \"GrLivArea\": 2786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372500}, {\"Order\": 1160, \"PID\": 533206050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 59.0, \"LotArea\": 4282, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1391, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 1161, \"PID\": 533208080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4017, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171900}, {\"Order\": 1162, \"PID\": 533208140, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3435, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1211.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 1163, \"PID\": 533212050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1164, \"PID\": 533212140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1165, \"PID\": 533212150, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3604, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1166, \"PID\": 533213070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179400}, {\"Order\": 1167, \"PID\": 533213120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 194.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 792, \"LowQualFinSF\": 0, \"GrLivArea\": 1549, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172900}, {\"Order\": 1168, \"PID\": 533215020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1027.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 587.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1638, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1169, \"PID\": 533215030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4538, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 179.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1170, \"PID\": 533215040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 42.0, \"LotArea\": 4385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1171, \"PID\": 533215070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1557.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1172, \"PID\": 533215080, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 50.0, \"LotArea\": 5119, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1709, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 97, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"CWD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 328900}, {\"Order\": 1173, \"PID\": 533217050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 628, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1174, \"PID\": 533217060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 20, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1175, \"PID\": 533234020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 79.0, \"LotArea\": 10646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 1789, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 1176, \"PID\": 533236060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1177, \"PID\": 533236070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 147.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1607, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1178, \"PID\": 533236090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 36.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 128.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 842.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1469, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2393, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 94, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 1179, \"PID\": 533250050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 14963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245500}, {\"Order\": 1180, \"PID\": 533250110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 22.0, \"LotArea\": 11064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1230.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1239, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1239, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 1181, \"PID\": 533250160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 32.0, \"LotArea\": 10846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1719.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1719, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1719, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 1182, \"PID\": 533251120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1183, \"PID\": 533350090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1050.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 584.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1599, \"2ndFlrSF\": 1345, \"LowQualFinSF\": 0, \"GrLivArea\": 2944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 70, \"EnclosedPorch\": 16, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1184, \"PID\": 533350120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 16280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1044.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 382.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1426.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1185, \"PID\": 534104100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 469.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1186, \"PID\": 534126090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1304.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 98, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1187, \"PID\": 534127210, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1427, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1188, \"PID\": 534127230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1439.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1189, \"PID\": 534128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1190, \"PID\": 534129060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 62, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1191, \"PID\": 534175140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1625.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1192, \"PID\": 534177180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1522.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 1066, \"LowQualFinSF\": 0, \"GrLivArea\": 2614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 243, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1193, \"PID\": 534201240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1194, \"PID\": 534202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1195, \"PID\": 534204030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 456.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1196, \"PID\": 534225110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1728.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1197, \"PID\": 534225120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1497.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142600}, {\"Order\": 1198, \"PID\": 534250010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 9246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 564.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1199, \"PID\": 534250335, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1200, \"PID\": 534250370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 1540, \"LowQualFinSF\": 0, \"GrLivArea\": 2715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 299800}, {\"Order\": 1201, \"PID\": 534250410, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 933, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1202, \"PID\": 534251280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 800, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1203, \"PID\": 534252090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 867.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178400}, {\"Order\": 1204, \"PID\": 534252270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1205, \"PID\": 534276190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7785, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 267.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1206, \"PID\": 534277060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 619.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109008}, {\"Order\": 1207, \"PID\": 534277070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135750}, {\"Order\": 1208, \"PID\": 534400030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 20, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1209, \"PID\": 534400060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 407, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 1210, \"PID\": 534401130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1165, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 129, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174900}, {\"Order\": 1211, \"PID\": 534401190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 892.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 426, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1212, \"PID\": 534403050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 305.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1213, \"PID\": 534403080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 1219.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1265, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 96, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1214, \"PID\": 534403100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 336.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1215, \"PID\": 534403260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 164, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1216, \"PID\": 534426040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 806.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 1217, \"PID\": 534427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10721, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 243.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1252.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1218, \"PID\": 534428020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12493, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 306.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1219, \"PID\": 534428100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1118.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1220, \"PID\": 534451080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Floor\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72500}, {\"Order\": 1221, \"PID\": 534451170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52000}, {\"Order\": 1222, \"PID\": 534452060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 4, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1223, \"PID\": 534453140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 453, \"2ndFlrSF\": 453, \"LowQualFinSF\": 0, \"GrLivArea\": 906, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 1224, \"PID\": 534455030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1225, \"PID\": 534477080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 220, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 1226, \"PID\": 534477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 32.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 308.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1227, \"PID\": 534477270, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 377.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 178, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1228, \"PID\": 534479150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 505.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112900}, {\"Order\": 1229, \"PID\": 535103050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 273, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201800}, {\"Order\": 1230, \"PID\": 535104020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 491.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1231, \"PID\": 535105030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139950}, {\"Order\": 1232, \"PID\": 535105060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1962, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 237.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1319.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1233, \"PID\": 535105090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 9150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1234, \"PID\": 535126140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 529.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 230, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1235, \"PID\": 535150210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 151.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 1098.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1236, \"PID\": 535150280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 25.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 872.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1237, \"PID\": 535151160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1283, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1283, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1238, \"PID\": 535152200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8856, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 52.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1239, \"PID\": 535153140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1240, \"PID\": 535153150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1261.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1261, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1261, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1400, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1241, \"PID\": 535176100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 187.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1570, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1570, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 490, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166800}, {\"Order\": 1242, \"PID\": 535178060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 580.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1243, \"PID\": 535179060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 387.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 458.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 1244, \"PID\": 535180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 135.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 130, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1245, \"PID\": 535180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1104, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1246, \"PID\": 535301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1247, \"PID\": 535302130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 196.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1248, \"PID\": 535302140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1249, \"PID\": 535303030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 14250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 998.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1250, \"PID\": 535305030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 852.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 1251, \"PID\": 535305160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 773, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 1252, \"PID\": 535327230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1253, \"PID\": 535352080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 1254, \"PID\": 535354200, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1255, \"PID\": 535375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 66, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89900}, {\"Order\": 1256, \"PID\": 535375160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 7506, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1257, \"PID\": 535380050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10930, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1258, \"PID\": 535380110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 1259, \"PID\": 535380140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 182, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 1488.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1260, \"PID\": 535383100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 694, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 114, \"EnclosedPorch\": 210, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106250}, {\"Order\": 1261, \"PID\": 535402120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9247, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 539.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1262, \"PID\": 535403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1263, \"PID\": 535425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Othr\", \"MiscVal\": 6500, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 1264, \"PID\": 535426260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1253.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 213, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1265, \"PID\": 535426350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 276.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1081.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1081, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 401.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1266, \"PID\": 535427070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 27650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2069, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 1267, \"PID\": 535451010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 910, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 414.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1268, \"PID\": 535451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 94000}, {\"Order\": 1269, \"PID\": 535451230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98300}, {\"Order\": 1270, \"PID\": 535452120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1507, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1507, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1271, \"PID\": 535453020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 488.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1272, \"PID\": 535453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 319.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125900}, {\"Order\": 1273, \"PID\": 535453210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 532.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1269.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1274, \"PID\": 535454150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 453.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 501, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1275, \"PID\": 535455060, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1276, \"PID\": 535455080, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 1277, \"PID\": 535455090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 181.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1278, \"PID\": 535456050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 8513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1279, \"PID\": 535456070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1280, \"PID\": 535456100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1281, \"PID\": 535475020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 415.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1282, \"PID\": 535476370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 106.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 1283, \"PID\": 535477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136870}, {\"Order\": 1284, \"PID\": 902100020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 96.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143000}, {\"Order\": 1285, \"PID\": 902100030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 30.0, \"LotArea\": 5232, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 1286, \"PID\": 902102060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1904, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 78, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1287, \"PID\": 902103150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9184, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 375, \"LowQualFinSF\": 0, \"GrLivArea\": 1323, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122600}, {\"Order\": 1288, \"PID\": 902105010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 680, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 1289, \"PID\": 902105020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 547, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 480, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1150, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1290, \"PID\": 902105130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1291, \"PID\": 902107030, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1292, \"PID\": 902109080, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 828.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 828, \"2ndFlrSF\": 658, \"LowQualFinSF\": 108, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 109, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1293, \"PID\": 902109110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 2082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1294, \"PID\": 902109120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 561, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119164}, {\"Order\": 1295, \"PID\": 902109160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 7308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122250}, {\"Order\": 1296, \"PID\": 902128075, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 931.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1297, \"PID\": 902128150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 590.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 552, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1298, \"PID\": 902134100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6756, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 481.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 1299, \"PID\": 902136110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 5914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 396, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 165, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1300, \"PID\": 902201120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 169.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 115000}, {\"Order\": 1301, \"PID\": 902201140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 608.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1302, \"PID\": 902202090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 904.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 869.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1303, \"PID\": 902205070, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 407.0, \"TotalBsmtSF\": 407.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 407, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 407, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 46500}, {\"Order\": 1304, \"PID\": 902205090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 620.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1305, \"PID\": 902205140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 901, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107900}, {\"Order\": 1306, \"PID\": 902207120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 103.0, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 1, \"YearBuilt\": 1949, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 65000}, {\"Order\": 1307, \"PID\": 902207220, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 87.0, \"LotArea\": 18386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1880, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1470.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 1818, \"LowQualFinSF\": 0, \"GrLivArea\": 3493, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295000}, {\"Order\": 1308, \"PID\": 902300110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 797.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 830, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1627, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1309, \"PID\": 902300215, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 540, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 418, \"OpenPorchSF\": 0, \"EnclosedPorch\": 194, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1310, \"PID\": 902300260, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 730, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1311, \"PID\": 902301140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 34.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 513.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98000}, {\"Order\": 1312, \"PID\": 902301150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9143, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 709, \"2ndFlrSF\": 308, \"LowQualFinSF\": 0, \"GrLivArea\": 1017, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 139, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1313, \"PID\": 902304060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 973, \"LowQualFinSF\": 0, \"GrLivArea\": 2350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 219, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1314, \"PID\": 902305080, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2058, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 259, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1315, \"PID\": 902306120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1905, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129400}, {\"Order\": 1316, \"PID\": 902306130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1928, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1317, \"PID\": 902326060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1905, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 691, \"LowQualFinSF\": 0, \"GrLivArea\": 1912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1318, \"PID\": 902328040, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 291, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1319, \"PID\": 902330010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5250, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1872, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 205, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 1320, \"PID\": 902401010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 572, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1321, \"PID\": 902401120, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1893, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1521, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 880.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 502, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1322, \"PID\": 902402260, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 2, \"OverallCond\": 1, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 723, \"2ndFlrSF\": 363, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1323, \"PID\": 902405070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 299, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1324, \"PID\": 902406020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1325, \"PID\": 902406090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1050.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 1326, \"PID\": 902427045, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 12702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 1327, \"PID\": 902427150, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8516, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 869.0, \"TotalBsmtSF\": 869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115500}, {\"Order\": 1328, \"PID\": 903201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7111, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1329, \"PID\": 903204010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 1330, \"PID\": 903204095, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 156, \"GrLivArea\": 935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 1331, \"PID\": 903206070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 175.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 594, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1332, \"PID\": 903225050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1333, \"PID\": 903225140, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1334, \"PID\": 903225160, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 554, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106900}, {\"Order\": 1335, \"PID\": 903226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 658, \"LowQualFinSF\": 0, \"GrLivArea\": 1672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 1336, \"PID\": 903226150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 949.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1337, \"PID\": 903227080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 862.0, \"TotalBsmtSF\": 862.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 208.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1338, \"PID\": 903228040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 201.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1497, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1339, \"PID\": 903228060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1340, \"PID\": 903228090, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 992.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1013, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 101, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1341, \"PID\": 903230110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 565, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1342, \"PID\": 903230120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 99.0, \"LotArea\": 5940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": null, \"BsmtFinType2\": null, \"BsmtFinSF2\": null, \"BsmtUnfSF\": null, \"TotalBsmtSF\": null, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79000}, {\"Order\": 1343, \"PID\": 903231080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 365, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1344, \"PID\": 903232030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81300}, {\"Order\": 1345, \"PID\": 903232090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1078.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 1346, \"PID\": 903233080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 989.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1347, \"PID\": 903234090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 897.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 139, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 1348, \"PID\": 903234100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129900}, {\"Order\": 1349, \"PID\": 903235010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 611.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1350, \"PID\": 903235100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 87, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68500}, {\"Order\": 1351, \"PID\": 903236010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 213, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1352, \"PID\": 903400180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 13053, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 220, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1353, \"PID\": 903401020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1354, \"PID\": 903401030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1355, \"PID\": 903401050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 883.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1356, \"PID\": 903425420, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 606.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1357, \"PID\": 903426160, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1000, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1358, \"PID\": 903427090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5100, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1359, \"PID\": 903429010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 4347, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1360, \"PID\": 903452025, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6291, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93850}, {\"Order\": 1361, \"PID\": 903453050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10266, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 216, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 136000}, {\"Order\": 1362, \"PID\": 903454100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1272.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 0, \"LowQualFinSF\": 697, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1363, \"PID\": 903455030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 428, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 117, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1364, \"PID\": 903455140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1365, \"PID\": 903456130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 647.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 127000}, {\"Order\": 1366, \"PID\": 903458110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 371, \"LowQualFinSF\": 0, \"GrLivArea\": 1406, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1367, \"PID\": 903475020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 645.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1368, \"PID\": 903476110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5586, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 110, \"LowQualFinSF\": 0, \"GrLivArea\": 1198, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79900}, {\"Order\": 1369, \"PID\": 903481010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 451.0, \"TotalBsmtSF\": 451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 759, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Family\", \"SalePrice\": 85000}, {\"Order\": 1370, \"PID\": 903481100, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 808, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 204, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82375}, {\"Order\": 1371, \"PID\": 903484020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1906, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 1469, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1906.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 57, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1372, \"PID\": 904100020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 122, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 1373, \"PID\": 904100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 1374, \"PID\": 904100160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 21286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1271, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1375, \"PID\": 904101170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134432}, {\"Order\": 1376, \"PID\": 904351280, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10106, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 181.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 547, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1377, \"PID\": 905100020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 64, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 148000}, {\"Order\": 1378, \"PID\": 905102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 906.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1379, \"PID\": 905103030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 39.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1380, \"PID\": 905104080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109900}, {\"Order\": 1381, \"PID\": 905104110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1382, \"PID\": 905104180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 702.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1383, \"PID\": 905107280, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 311, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1384, \"PID\": 905107380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9981, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 221.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 852.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1385, \"PID\": 905108170, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 956.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1386, \"PID\": 905200090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1198.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 108959}, {\"Order\": 1387, \"PID\": 905200100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 95541}, {\"Order\": 1388, \"PID\": 905200160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 1006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1006, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 1389, \"PID\": 905200510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149350}, {\"Order\": 1390, \"PID\": 905201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 634.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 1391, \"PID\": 905201110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 102, \"OpenPorchSF\": 89, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1392, \"PID\": 905201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1064.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 354.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 511, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1393, \"PID\": 905202230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 429.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1080.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 409, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1394, \"PID\": 905225040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1021, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1395, \"PID\": 905226030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1396, \"PID\": 905226110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1397, \"PID\": 905227050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 486, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152400}, {\"Order\": 1398, \"PID\": 905300020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1399, \"PID\": 905351089, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1003.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1291.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1291, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1400, \"PID\": 905352030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 299.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 2022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 117, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1401, \"PID\": 905352070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 20270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1402, \"PID\": 905401045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 39104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Membran\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1063.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1403, \"PID\": 905401060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1663, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1404, \"PID\": 905402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 11512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1019.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1357, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1357, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 163, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1405, \"PID\": 905403060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 617, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1079, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 249.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125600}, {\"Order\": 1406, \"PID\": 905403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 287, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1407, \"PID\": 905425125, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 45600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 907.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1307, \"2ndFlrSF\": 1051, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1908.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1408, \"PID\": 905426030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"PreCast\", \"Exterior2nd\": \"PreCast\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1035.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1409, \"PID\": 905427050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1163.0, \"TotalBsmtSF\": 1163.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 511, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1410, \"PID\": 905427070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 2108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1411, \"PID\": 905451330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1509.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 576, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1412, \"PID\": 905452070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99600}, {\"Order\": 1413, \"PID\": 905452120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 621, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1414, \"PID\": 905476120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1415, \"PID\": 905477050, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 969.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 527, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 1416, \"PID\": 905479110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1417, \"PID\": 905480150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 572, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 8, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 1418, \"PID\": 905480240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 380.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1419, \"PID\": 906204150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1475.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1532, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2329, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262280}, {\"Order\": 1420, \"PID\": 906204280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9771, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 1721, \"LowQualFinSF\": 0, \"GrLivArea\": 2814, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1421, \"PID\": 906223110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 251.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1626, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1422, \"PID\": 906223140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 355.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 1099, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1423, \"PID\": 906223220, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 735, \"LowQualFinSF\": 0, \"GrLivArea\": 2037, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 1424, \"PID\": 906378190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 628.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177439}, {\"Order\": 1425, \"PID\": 906380030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1615.0, \"TotalBsmtSF\": 1615.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1615, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1615, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 1426, \"PID\": 906412010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 2271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2276, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1348.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 475000}, {\"Order\": 1427, \"PID\": 906412050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1751.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395039}, {\"Order\": 1428, \"PID\": 906420130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 531.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 187, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 1429, \"PID\": 906424010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 631.0, \"TotalBsmtSF\": 1401.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 811.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1430, \"PID\": 906475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1182.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1643, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1643, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 339, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1431, \"PID\": 906476030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12798, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 154.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 1072, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 403, \"OpenPorchSF\": 114, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1432, \"PID\": 907126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 722.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1433, \"PID\": 907135020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1099.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1099, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1099, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1434, \"PID\": 907135260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1435, \"PID\": 907175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226001}, {\"Order\": 1436, \"PID\": 907176010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 688.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 899, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215700}, {\"Order\": 1437, \"PID\": 907181120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 782, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1438, \"PID\": 907181140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 873.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 193000}, {\"Order\": 1439, \"PID\": 907187030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1440, \"PID\": 907187080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 9382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1441, \"PID\": 907192130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 1442, \"PID\": 907194020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 963.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 963, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 245, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 1443, \"PID\": 907196040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1823, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 4500, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1444, \"PID\": 907196050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 1445, \"PID\": 907200110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 491.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 938, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130250}, {\"Order\": 1446, \"PID\": 907201060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 328.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 1447, \"PID\": 907202010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1174, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 211, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1448, \"PID\": 907202160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1449, \"PID\": 907202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1076, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143195}, {\"Order\": 1450, \"PID\": 907202240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 88.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1558, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1451, \"PID\": 907203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 7990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1452, \"PID\": 907227050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1453, \"PID\": 907227300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 780, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 1454, \"PID\": 907250020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1777.0, \"TotalBsmtSF\": 1777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 159, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1455, \"PID\": 907251090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9473, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 903, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 1456, \"PID\": 907253060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 257.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1457, \"PID\": 907253110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 1458, \"PID\": 907254020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9066, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 106, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1459, \"PID\": 907254090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 1460, \"PID\": 907255020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 396.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287000}, {\"Order\": 1461, \"PID\": 907255030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1357.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1366, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1462, \"PID\": 907255060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1786, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 715.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1463, \"PID\": 907260010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 1141, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 1464, \"PID\": 907262030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 334.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 1465, \"PID\": 907262060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 10905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1129.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1129, \"2ndFlrSF\": 1198, \"LowQualFinSF\": 0, \"GrLivArea\": 2327, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1466, \"PID\": 907262070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 595.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1467, \"PID\": 907265100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1468, \"PID\": 907285080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 642.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 933, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1469, \"PID\": 907290150, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1470, \"PID\": 907290250, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1471, \"PID\": 907295020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 215.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1493, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1493, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208900}, {\"Order\": 1472, \"PID\": 907295100, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 83.0, \"LotArea\": 10126, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1593.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 1473, \"PID\": 907405020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 726.0, \"TotalBsmtSF\": 1536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1536, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1474, \"PID\": 907405140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 854, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208500}, {\"Order\": 1475, \"PID\": 907412040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1421.0, \"TotalBsmtSF\": 1445.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1476, \"PID\": 907412070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 946.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 139, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1477, \"PID\": 907412080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 770, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1478, \"PID\": 907412090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1234, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1479, \"PID\": 907418010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1508.0, \"TotalBsmtSF\": 1564.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218836}, {\"Order\": 1480, \"PID\": 907418040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1327.0, \"TotalBsmtSF\": 1351.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1481, \"PID\": 907420080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1482, \"PID\": 907425010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149300}, {\"Order\": 1483, \"PID\": 907425015, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1484, \"PID\": 907425030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1485, \"PID\": 907425035, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 1486, \"PID\": 908102030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1487, \"PID\": 908102040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 928, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145900}, {\"Order\": 1488, \"PID\": 908102140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 259, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 123000}, {\"Order\": 1489, \"PID\": 908102260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 830.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 736, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1490, \"PID\": 908103260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 12102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 222.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1033, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1033, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 165000}, {\"Order\": 1491, \"PID\": 908103280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1033.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1127, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1492, \"PID\": 908127120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1493, \"PID\": 908128050, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 38.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1181, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1181, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1494, \"PID\": 908128110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 92.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165400}, {\"Order\": 1495, \"PID\": 908151040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 120.0, \"BsmtUnfSF\": 541.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1496, \"PID\": 908152110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1497, \"PID\": 908152270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1132.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1498, \"PID\": 908154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 123.0, \"LotArea\": 47007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3820, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3820, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 372, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284700}, {\"Order\": 1499, \"PID\": 908154235, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 63887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"ClyTile\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 796.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 5644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 6110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 4692, \"2ndFlrSF\": 950, \"LowQualFinSF\": 0, \"GrLivArea\": 5642, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 1418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 292, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 480, \"PoolQC\": \"Gd\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 160000}, {\"Order\": 1500, \"PID\": 908186040, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 459.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1501, \"PID\": 908201100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1502, \"PID\": 908201110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1503, \"PID\": 908201120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1307.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1504, \"PID\": 908204160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 1505, \"PID\": 908225170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91900}, {\"Order\": 1506, \"PID\": 908226120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 585, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 120000}, {\"Order\": 1507, \"PID\": 908250040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 1508, \"PID\": 908250090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 134, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Gar2\", \"MiscVal\": 3000, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1509, \"PID\": 908275130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1510, \"PID\": 908275180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1511, \"PID\": 908275280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 521, \"LowQualFinSF\": 0, \"GrLivArea\": 1393, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 265, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 1512, \"PID\": 908276140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1513, \"PID\": 909100150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 343, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1514, \"PID\": 909100170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1515, \"PID\": 909101060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 41.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 823.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67000}, {\"Order\": 1516, \"PID\": 909101180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5687, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135900}, {\"Order\": 1517, \"PID\": 909131170, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 254, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1518, \"PID\": 909175050, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 720, \"LowQualFinSF\": 420, \"GrLivArea\": 2192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179500}, {\"Order\": 1519, \"PID\": 909175100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 423.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 758.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 304, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1520, \"PID\": 909177120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1521, \"PID\": 909201110, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 8525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1911, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 940.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1522, \"PID\": 909250040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 1611, \"LowQualFinSF\": 0, \"GrLivArea\": 2601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 183, \"OpenPorchSF\": 0, \"EnclosedPorch\": 301, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1523, \"PID\": 909250230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 679.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 161900}, {\"Order\": 1524, \"PID\": 909251080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8969, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 369.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1525, \"PID\": 909251090, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1423, \"2ndFlrSF\": 748, \"LowQualFinSF\": 384, \"GrLivArea\": 2555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1526, \"PID\": 909252110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1527, \"PID\": 909252220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15564, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1528, \"PID\": 909253190, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 1529, \"PID\": 909254050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7609, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 16, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 1530, \"PID\": 909256060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 473, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1531, \"PID\": 909275040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 599.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 217, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1532, \"PID\": 909275050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1533, \"PID\": 909276170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1934, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 389.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 849, \"2ndFlrSF\": 811, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188700}, {\"Order\": 1534, \"PID\": 909277040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 673, \"LowQualFinSF\": 0, \"GrLivArea\": 1938, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 1535, \"PID\": 909277070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 932, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1536, \"PID\": 909281030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 7801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 591.0, \"TotalBsmtSF\": 1091.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 344.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 221, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 1537, \"PID\": 909281110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 786.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 207, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 257076}, {\"Order\": 1538, \"PID\": 909282030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1935, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1968, \"2ndFlrSF\": 1479, \"LowQualFinSF\": 0, \"GrLivArea\": 3447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1014.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 381000}, {\"Order\": 1539, \"PID\": 909425010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 817, \"LowQualFinSF\": 0, \"GrLivArea\": 1954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 311500}, {\"Order\": 1540, \"PID\": 909425085, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 943, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263400}, {\"Order\": 1541, \"PID\": 909428170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 26073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1898.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1898, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 1542, \"PID\": 909428190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 568.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 924.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 1543, \"PID\": 909451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 366.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 213, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 1544, \"PID\": 909451150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 612.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1545, \"PID\": 910200080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 555.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 919, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1546, \"PID\": 910201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 330, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1547, \"PID\": 910202050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1548, \"PID\": 910202100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1549, \"PID\": 910203020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 71.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 125.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 778, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 924.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1550, \"PID\": 910203090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 780, \"2ndFlrSF\": 420, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1551, \"PID\": 910205010, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1552, \"PID\": 910206110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 1553, \"PID\": 910226040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1955, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1554, \"PID\": 910251050, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 80.0, \"LotArea\": 14584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Po\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 13100}, {\"Order\": 1555, \"PID\": 911102090, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 5280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1895, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1895.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 185.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 1556, \"PID\": 911102170, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 649, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1317, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 172, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 40000}, {\"Order\": 1557, \"PID\": 911102180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 52.0, \"LotArea\": 5150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 671, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80900}, {\"Order\": 1558, \"PID\": 911226010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 120.0, \"LotArea\": 18000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 560, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1559, \"PID\": 911226030, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 432, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 65000}, {\"Order\": 1560, \"PID\": 911370410, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 5587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392500}, {\"Order\": 1561, \"PID\": 911370490, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294464}, {\"Order\": 1562, \"PID\": 911370520, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1563, \"PID\": 911370540, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 1564, \"PID\": 914453045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 668.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2032, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1565, \"PID\": 914465060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 857.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1566, \"PID\": 914467050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 910.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 318, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1567, \"PID\": 914475020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 574.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 358.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 576, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1568, \"PID\": 914476010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 83, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 1569, \"PID\": 914476080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1570, \"PID\": 914476450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 428, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 1571, \"PID\": 916125425, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 164660, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 1499.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1619, \"2ndFlrSF\": 167, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 670, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228950}, {\"Order\": 1572, \"PID\": 916226030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 893.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1573, \"PID\": 916325080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15498, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1165.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 665.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 174, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 287000}, {\"Order\": 1574, \"PID\": 916380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 258.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1575, \"PID\": 916382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293077}, {\"Order\": 1576, \"PID\": 916384100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264966}, {\"Order\": 1577, \"PID\": 916386040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 712, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 1578, \"PID\": 916386080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": null, \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 1579, \"PID\": 916386180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 12018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 218689}, {\"Order\": 1580, \"PID\": 916402015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1495.0, \"TotalBsmtSF\": 1495.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1495, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1581, \"PID\": 916402115, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 12416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1398.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 208.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1582, \"PID\": 916402215, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 18265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1583, \"PID\": 916403230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 219.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 783.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1584, \"PID\": 916455120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11202, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1029.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 1432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232500}, {\"Order\": 1585, \"PID\": 916460060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7915, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1586, \"PID\": 916477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 2262, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 749.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1587, \"PID\": 921126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1011.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 873.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 276, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 298751}, {\"Order\": 1588, \"PID\": 921201060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1571.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 393.0, \"TotalBsmtSF\": 1964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 892.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1589, \"PID\": 923202005, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 97.0, \"LotArea\": 8940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 209200}, {\"Order\": 1590, \"PID\": 923202015, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 206300}, {\"Order\": 1591, \"PID\": 923202137, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9278, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1592, \"PID\": 923203140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 197.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 1189.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1189, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1189, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1593, \"PID\": 923204040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 171, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1594, \"PID\": 923225080, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 271.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1595, \"PID\": 923225150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1596, \"PID\": 923225200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 318.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1597, \"PID\": 923225310, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 501.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 526.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1598, \"PID\": 923225370, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 120, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94900}, {\"Order\": 1599, \"PID\": 923227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1160, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 257.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 1600, \"PID\": 923228080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1970, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1601, \"PID\": 923228420, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1602, \"PID\": 923250210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 988.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1603, \"PID\": 923252100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 6490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1604, \"PID\": 923275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 6951, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 362, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1605, \"PID\": 923277030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1982, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1606, \"PID\": 923277040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1982, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1607, \"PID\": 923277080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1608, \"PID\": 923400040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 983.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1300, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1609, \"PID\": 923426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 647.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 889, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1610, \"PID\": 924100020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 562.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 193.0, \"BsmtUnfSF\": 29.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1611, \"PID\": 1007100110, \"MSSubClass\": 70, \"MSZoning\": \"I (all)\", \"LotFrontage\": null, \"LotArea\": 56600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1612, \"PID\": 526352080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 838.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 749.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1587, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1587, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167300}, {\"Order\": 1613, \"PID\": 526352090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1277, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 526.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 1614, \"PID\": 526355170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 2223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2223, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2223, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 1615, \"PID\": 526355190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 15865, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 823.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 2217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 1616, \"PID\": 527105140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 225000}, {\"Order\": 1617, \"PID\": 527107040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 373.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1618, \"PID\": 527110080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 794, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1619, \"PID\": 527110120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 1620, \"PID\": 527110130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 1621, \"PID\": 527126030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 1622, \"PID\": 527158090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 770, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1623, \"PID\": 527161090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 947, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1624, \"PID\": 527162080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178750}, {\"Order\": 1625, \"PID\": 527162090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1626, \"PID\": 527162140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 957, \"2ndFlrSF\": 1342, \"LowQualFinSF\": 0, \"GrLivArea\": 2299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1627, \"PID\": 527163080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1168.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1628, \"PID\": 527165020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1629, \"PID\": 527165100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163900}, {\"Order\": 1630, \"PID\": 527165170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 903.0, \"TotalBsmtSF\": 903.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1631, \"PID\": 527175130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 18160, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 154204}, {\"Order\": 1632, \"PID\": 527182040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1633, \"PID\": 527182170, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1634, \"PID\": 527184020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 4740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1166.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 135, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1635, \"PID\": 527184110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 5118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 926.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1321, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1321, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 1636, \"PID\": 527210060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377426}, {\"Order\": 1637, \"PID\": 527212060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1377, \"LowQualFinSF\": 0, \"GrLivArea\": 2541, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 729.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 349265}, {\"Order\": 1638, \"PID\": 527216080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 51974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 710.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1101.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1559.0, \"TotalBsmtSF\": 2660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1110.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 591587}, {\"Order\": 1639, \"PID\": 527226040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 195.0, \"LotArea\": 41600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1047.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 53.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1640, \"PID\": 527252050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8035, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 797.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 164, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 1641, \"PID\": 527252070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8089, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 1642, \"PID\": 527256030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 945.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1558.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 2220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 441929}, {\"Order\": 1643, \"PID\": 527256040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 13870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 174, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 455000}, {\"Order\": 1644, \"PID\": 527301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 99, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182900}, {\"Order\": 1645, \"PID\": 527301280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1028.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1646, \"PID\": 527302020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 178000}, {\"Order\": 1647, \"PID\": 527302060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 167, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1648, \"PID\": 527302090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1328.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 1529.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1649, \"PID\": 527325090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 11339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 549.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 22.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1650, \"PID\": 527325110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11952, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1161, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 276, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1651, \"PID\": 527327050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12046, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 2030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1652, \"PID\": 527328020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 605.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1653, \"PID\": 527328050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1177, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1654, \"PID\": 527353080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 539.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 1655, \"PID\": 527354050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 253.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1259.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1353, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192350}, {\"Order\": 1656, \"PID\": 527356050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 263.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1657, \"PID\": 527357020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 13001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 249, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1658, \"PID\": 527358060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1659, \"PID\": 527359010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 175.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1660, \"PID\": 527359080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 1661, \"PID\": 527359160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 604.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 585.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 407, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1662, \"PID\": 527377110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 153.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1877, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 1663, \"PID\": 527402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 349.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 533, \"LowQualFinSF\": 0, \"GrLivArea\": 1109, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 35, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1664, \"PID\": 527402150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 35.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143250}, {\"Order\": 1665, \"PID\": 527402240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1972, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1666, \"PID\": 527403310, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1667, \"PID\": 527404050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 619.0, \"BsmtUnfSF\": 214.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1668, \"PID\": 527404100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 412.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1669, \"PID\": 527404140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8294, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1670, \"PID\": 527404150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 322.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1671, \"PID\": 527425025, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1672, \"PID\": 527425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1673, \"PID\": 527427090, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 139.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 767, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 367.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1674, \"PID\": 527427160, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 33.0, \"LotArea\": 4113, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1337.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1675, \"PID\": 527427200, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 10943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1676, \"PID\": 527450030, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 1677, \"PID\": 527450150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 356.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1678, \"PID\": 527450220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113700}, {\"Order\": 1679, \"PID\": 527451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2016, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1680, \"PID\": 527451170, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 376.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 1681, \"PID\": 527452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 958.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 205, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1682, \"PID\": 527453010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 556.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1683, \"PID\": 527455030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 6.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 1061.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 1684, \"PID\": 527455250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 725.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129250}, {\"Order\": 1685, \"PID\": 528102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12469, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1151.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1790.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356000}, {\"Order\": 1686, \"PID\": 528102090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 452.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1774.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 260, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 314813}, {\"Order\": 1687, \"PID\": 528102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1688, \"PID\": 528102120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 322400}, {\"Order\": 1689, \"PID\": 528102130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 328.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 730.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1690, \"PID\": 528104010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 2108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345474}, {\"Order\": 1691, \"PID\": 528106040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 315.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2121.0, \"TotalBsmtSF\": 2121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 415298}, {\"Order\": 1692, \"PID\": 528106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13641, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1304.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1934.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1943, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 2656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1040.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 492000}, {\"Order\": 1693, \"PID\": 528106060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1108.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 1402, \"LowQualFinSF\": 0, \"GrLivArea\": 2550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338931}, {\"Order\": 1694, \"PID\": 528106110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 400.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 450000}, {\"Order\": 1695, \"PID\": 528108160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 14154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1063.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1071, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 947.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 280000}, {\"Order\": 1696, \"PID\": 528110040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 2552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 479069}, {\"Order\": 1697, \"PID\": 528110070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 375.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1935.0, \"TotalBsmtSF\": 1935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1973, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1973, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395000}, {\"Order\": 1698, \"PID\": 528110100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 772.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2153.0, \"TotalBsmtSF\": 2153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 2643, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 694.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 380000}, {\"Order\": 1699, \"PID\": 528112150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1626.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1634, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1634, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1700, \"PID\": 528114050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14977, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 1976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 440000}, {\"Order\": 1701, \"PID\": 528118040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13654, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1704.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1722, \"2ndFlrSF\": 1036, \"LowQualFinSF\": 0, \"GrLivArea\": 2758, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 418000}, {\"Order\": 1702, \"PID\": 528118050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 17169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 970.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 2320.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1174.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 500067}, {\"Order\": 1703, \"PID\": 528120010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1582.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 570, \"LowQualFinSF\": 0, \"GrLivArea\": 2152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 368, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260116}, {\"Order\": 1704, \"PID\": 528120150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 317000}, {\"Order\": 1705, \"PID\": 528142050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9709, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319500}, {\"Order\": 1706, \"PID\": 528144050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325624}, {\"Order\": 1707, \"PID\": 528150040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 510.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1802.0, \"TotalBsmtSF\": 1802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1802, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372000}, {\"Order\": 1708, \"PID\": 528150110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 13069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 502.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1706.0, \"TotalBsmtSF\": 1706.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 1238, \"LowQualFinSF\": 0, \"GrLivArea\": 2956, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 916.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 342000}, {\"Order\": 1709, \"PID\": 528150120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 388.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 970.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 872.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 354000}, {\"Order\": 1710, \"PID\": 528166150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14277, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1317.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1711, \"PID\": 528168040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11999, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1712, \"PID\": 528172030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 669.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 895.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 895, \"2ndFlrSF\": 923, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281500}, {\"Order\": 1713, \"PID\": 528172050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1178.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245700}, {\"Order\": 1714, \"PID\": 528172070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9254, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1602.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232698}, {\"Order\": 1715, \"PID\": 528172075, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1298.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 876.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 1716, \"PID\": 528174010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194700}, {\"Order\": 1717, \"PID\": 528174020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3901, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204000}, {\"Order\": 1718, \"PID\": 528174030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 272.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1719, \"PID\": 528174040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 6289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1720, \"PID\": 528181060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1721, \"PID\": 528181070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1722, \"PID\": 528181080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 1723, \"PID\": 528186050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 7841, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 394.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 848.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 729.0, \"TotalBsmtSF\": 1577.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1577, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 1724, \"PID\": 528186090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 1725, \"PID\": 528186120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1869.0, \"TotalBsmtSF\": 1869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318061}, {\"Order\": 1726, \"PID\": 528186190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1300.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221370}, {\"Order\": 1727, \"PID\": 528188160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 235.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1728, \"PID\": 528218010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 15810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181755}, {\"Order\": 1729, \"PID\": 528218020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1730, \"PID\": 528218050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 783, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 178900}, {\"Order\": 1731, \"PID\": 528218100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 13204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 168165}, {\"Order\": 1732, \"PID\": 528221030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8857, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 757, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 171925}, {\"Order\": 1733, \"PID\": 528221040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9729, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 1048, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198444}, {\"Order\": 1734, \"PID\": 528221050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 918.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 1735, \"PID\": 528221090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179540}, {\"Order\": 1736, \"PID\": 528222030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 176485}, {\"Order\": 1737, \"PID\": 528222040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1340.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181134}, {\"Order\": 1738, \"PID\": 528222050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 796, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156932}, {\"Order\": 1739, \"PID\": 528222060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8229, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 22.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1740, \"PID\": 528222080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7713, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177594}, {\"Order\": 1741, \"PID\": 528222090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1246.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173500}, {\"Order\": 1742, \"PID\": 528228270, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172500}, {\"Order\": 1743, \"PID\": 528228275, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194201}, {\"Order\": 1744, \"PID\": 528228375, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3621, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1589, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1745, \"PID\": 528228555, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185485}, {\"Order\": 1746, \"PID\": 528231010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 182.0, \"LotArea\": 14572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 259000}, {\"Order\": 1747, \"PID\": 528231030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 16219, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1119, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1119, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1748, \"PID\": 528235000, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 175000}, {\"Order\": 1749, \"PID\": 528235160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11796, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1112, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1750, \"PID\": 528235170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1510.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 206580}, {\"Order\": 1751, \"PID\": 528240020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 1752, \"PID\": 528250010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1753, \"PID\": 528250070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 1754, \"PID\": 528275035, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1755, \"PID\": 528275110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 1131, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1756, \"PID\": 528280110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 694, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1757, \"PID\": 528280150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1758, \"PID\": 528290060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 1759, \"PID\": 528290170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1760, \"PID\": 528294010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9649, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1761, \"PID\": 528320050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 15623, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2411, \"2ndFlrSF\": 2065, \"LowQualFinSF\": 0, \"GrLivArea\": 4476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 813.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 555, \"PoolQC\": \"Ex\", \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 745000}, {\"Order\": 1762, \"PID\": 528322020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 515.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 2551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 384500}, {\"Order\": 1763, \"PID\": 528326060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 1288, \"LowQualFinSF\": 0, \"GrLivArea\": 2285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 1764, \"PID\": 528327060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 705.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1351.0, \"TotalBsmtSF\": 2633.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2633, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2633, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 804.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 466500}, {\"Order\": 1765, \"PID\": 528340030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10557, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 1407, \"LowQualFinSF\": 0, \"GrLivArea\": 3078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 806.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 1766, \"PID\": 528344020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1048.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 1171, \"LowQualFinSF\": 0, \"GrLivArea\": 2582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 322500}, {\"Order\": 1767, \"PID\": 528348030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 275.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1066.0, \"TotalBsmtSF\": 1066.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1277, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 1768, \"PID\": 528351010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 21535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1170.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 989.0, \"TotalBsmtSF\": 2444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2444, \"2ndFlrSF\": 1872, \"LowQualFinSF\": 0, \"GrLivArea\": 4316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 832.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 755000}, {\"Order\": 1769, \"PID\": 528354060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 862.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2013, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 455.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269790}, {\"Order\": 1770, \"PID\": 528354110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11787, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 594.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 1379.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 1015, \"LowQualFinSF\": 0, \"GrLivArea\": 2398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315750}, {\"Order\": 1771, \"PID\": 528358040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1203.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 290000}, {\"Order\": 1772, \"PID\": 528364110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1318.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 752.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1773, \"PID\": 528366050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1969.0, \"TotalBsmtSF\": 3200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 75, \"EnclosedPorch\": 291, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 430000}, {\"Order\": 1774, \"PID\": 528366070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 335.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2202, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 1775, \"PID\": 528376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 526.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1225.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1325.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2538, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 933.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 1776, \"PID\": 528427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1369.0, \"TotalBsmtSF\": 1369.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1369, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 203, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 213133}, {\"Order\": 1777, \"PID\": 528427100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1542, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260261}, {\"Order\": 1778, \"PID\": 528429090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 11670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1905.0, \"TotalBsmtSF\": 1905.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1905, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1905, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 1779, \"PID\": 528429110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282922}, {\"Order\": 1780, \"PID\": 528431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1534, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 215000}, {\"Order\": 1781, \"PID\": 528431040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 754.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 394.0, \"TotalBsmtSF\": 1966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1966, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1092.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 419005}, {\"Order\": 1782, \"PID\": 528431050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13501, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 63.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1623.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1783, \"PID\": 528431110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9986, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 428.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1795.0, \"TotalBsmtSF\": 1795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 1784, \"PID\": 528435010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1528, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235876}, {\"Order\": 1785, \"PID\": 528435040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1126.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 311872}, {\"Order\": 1786, \"PID\": 528435060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 954.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248328}, {\"Order\": 1787, \"PID\": 528435070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 825.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1788, \"PID\": 528439040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8847, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 1538.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1538, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1538, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1789, \"PID\": 528439050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 1790, \"PID\": 528439080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8251, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 1791, \"PID\": 528441080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 255, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 307000}, {\"Order\": 1792, \"PID\": 528445020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 982, \"2ndFlrSF\": 995, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 250000}, {\"Order\": 1793, \"PID\": 528445070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 528, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 859.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221300}, {\"Order\": 1794, \"PID\": 528456190, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1314.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1795, \"PID\": 528456230, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1335.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1335, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210400}, {\"Order\": 1796, \"PID\": 528458080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 255000}, {\"Order\": 1797, \"PID\": 528458090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 10411, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212109}, {\"Order\": 1798, \"PID\": 528458120, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1025.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 1799, \"PID\": 528458130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 64.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1120.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1184, \"2ndFlrSF\": 1426, \"LowQualFinSF\": 0, \"GrLivArea\": 2610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 364, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 303477}, {\"Order\": 1800, \"PID\": 528458150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1880, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310013}, {\"Order\": 1801, \"PID\": 528477020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 11096, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249700}, {\"Order\": 1802, \"PID\": 528480020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 874.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1761, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227875}, {\"Order\": 1803, \"PID\": 528480180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1574.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 256, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 261329}, {\"Order\": 1804, \"PID\": 528482010, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 11824, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1685.0, \"TotalBsmtSF\": 1685.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1685, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1685, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 1805, \"PID\": 528482030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 353.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2443, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 744.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 1806, \"PID\": 528482090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 102.0, \"LotArea\": 11143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 159, \"OpenPorchSF\": 214, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 1807, \"PID\": 531363020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 146000}, {\"Order\": 1808, \"PID\": 531363040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1809, \"PID\": 531375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1810, \"PID\": 531376060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1461.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1811, \"PID\": 531380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 1812, \"PID\": 531384070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11613, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191750}, {\"Order\": 1813, \"PID\": 531385070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1349.0, \"TotalBsmtSF\": 1349.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1349, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1349, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1814, \"PID\": 531385130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 39.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 402, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1815, \"PID\": 531451030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1145.0, \"TotalBsmtSF\": 1575.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1816, \"PID\": 531451150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1817, \"PID\": 531453140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1818, \"PID\": 531477040, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1819, \"PID\": 532353120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 351.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120750}, {\"Order\": 1820, \"PID\": 532354010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1821, \"PID\": 532354060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1822, \"PID\": 532354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 999.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1823, \"PID\": 532376040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 6970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1824, \"PID\": 532376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 13673, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143900}, {\"Order\": 1825, \"PID\": 532377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 7476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1826, \"PID\": 532377140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 57.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 827.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1827, \"PID\": 532378240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1828, \"PID\": 532476080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1232, \"LowQualFinSF\": 0, \"GrLivArea\": 2503, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1829, \"PID\": 532477040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 125.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1031.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 2167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1830, \"PID\": 532479050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 10751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1037, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1831, \"PID\": 532479120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16647, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1701, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 611.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1832, \"PID\": 532479140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 968.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 455, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 147000}, {\"Order\": 1833, \"PID\": 533120030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 482.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 1357, \"LowQualFinSF\": 0, \"GrLivArea\": 2810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 500, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 1834, \"PID\": 533130170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10678, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 337.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 983.0, \"TotalBsmtSF\": 1683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2129, \"2ndFlrSF\": 743, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1835, \"PID\": 533205110, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 45.0, \"LotArea\": 4379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 527.0, \"TotalBsmtSF\": 1378.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1836, \"PID\": 533206060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 3523, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1081.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1151, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1837, \"PID\": 533206070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 3784, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1511.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193800}, {\"Order\": 1838, \"PID\": 533208010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 47.0, \"LotArea\": 4230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1352.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1839, \"PID\": 533208020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3606, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 937.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 1840, \"PID\": 533208030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1550, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 207500}, {\"Order\": 1841, \"PID\": 533208040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4274, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1106.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1241.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1241, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1241, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199900}, {\"Order\": 1842, \"PID\": 533208070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4251, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164700}, {\"Order\": 1843, \"PID\": 533213130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 1844, \"PID\": 533213140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1129.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1845, \"PID\": 533221030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1846, \"PID\": 533221060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1847, \"PID\": 533221100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1848, \"PID\": 533223050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 5105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 551.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 551, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 1849, \"PID\": 533236040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1850, \"PID\": 533241030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 66.0, \"LotArea\": 7399, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 1851, \"PID\": 533242080, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 73.0, \"LotArea\": 7321, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1339.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1852, \"PID\": 533242090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 1853, \"PID\": 533244040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 106.0, \"LotArea\": 8413, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 1105.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 1854, \"PID\": 533250190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1037.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 217, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279700}, {\"Order\": 1855, \"PID\": 533251110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1856, \"PID\": 533251130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 1857, \"PID\": 533252130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1157.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 1858, \"PID\": 533253180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 176.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 89, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213750}, {\"Order\": 1859, \"PID\": 533254100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 761, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1860, \"PID\": 533254130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 978.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181500}, {\"Order\": 1861, \"PID\": 533350020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 17778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1632.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 829.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 2461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2497, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2497, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 373000}, {\"Order\": 1862, \"PID\": 533352075, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAe\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 211.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 1361.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 1259, \"LowQualFinSF\": 0, \"GrLivArea\": 2620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 24, \"EnclosedPorch\": 145, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 8300, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1863, \"PID\": 534104090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 1929, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 1864, \"PID\": 534125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143450}, {\"Order\": 1865, \"PID\": 534127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 1008, \"LowQualFinSF\": 0, \"GrLivArea\": 2411, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240050}, {\"Order\": 1866, \"PID\": 534127140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 973.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1867, \"PID\": 534127260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 385.0, \"TotalBsmtSF\": 1295.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 194, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 1868, \"PID\": 534128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 11358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1869, \"PID\": 534151090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1594, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1870, \"PID\": 534151180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1871, \"PID\": 534175010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAn\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136905}, {\"Order\": 1872, \"PID\": 534176140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 792.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1873, \"PID\": 534177210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 916.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1874, \"PID\": 534178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1875, \"PID\": 534201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 38.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1876, \"PID\": 534202030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 519.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1877, \"PID\": 534204120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1878, \"PID\": 534252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1879, \"PID\": 534252060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10624, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1880, \"PID\": 534252070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1881, \"PID\": 534252110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 978.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 1882, \"PID\": 534275170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1960, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 15500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1883, \"PID\": 534275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 66.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1065, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 1884, \"PID\": 534276070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 63.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 81.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1885, \"PID\": 534276160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 285, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1886, \"PID\": 534276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 206.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1887, \"PID\": 534276290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 1888, \"PID\": 534278150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 167.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1889, \"PID\": 534278170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1890, \"PID\": 534278190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117600}, {\"Order\": 1891, \"PID\": 534401120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1174.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1892, \"PID\": 534401200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1893, \"PID\": 534403040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 270.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 580.0, \"BsmtUnfSF\": 452.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 309.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 333, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1894, \"PID\": 534403290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 1309, \"LowQualFinSF\": 0, \"GrLivArea\": 2154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 1895, \"PID\": 534403420, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 543.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1130.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1374, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1896, \"PID\": 534425015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 1592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 201, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1897, \"PID\": 534425080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 219.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1429, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1429, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1898, \"PID\": 534427140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1327, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1327, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150750}, {\"Order\": 1899, \"PID\": 534429030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101800}, {\"Order\": 1900, \"PID\": 534430090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 932, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 306.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 214, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1901, \"PID\": 534431020, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 259.0, \"BsmtUnfSF\": 433.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 908, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 1902, \"PID\": 534450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 2, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 39300}, {\"Order\": 1903, \"PID\": 534450110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1904, \"PID\": 534451020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 442, \"2ndFlrSF\": 228, \"LowQualFinSF\": 0, \"GrLivArea\": 670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1905, \"PID\": 534453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 404.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 1906, \"PID\": 534475170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1907, \"PID\": 534476080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1908, \"PID\": 534478140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Roll\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 708.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 992, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1909, \"PID\": 534479120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1910, \"PID\": 534479140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 1911, \"PID\": 535101150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1912, \"PID\": 535102010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 87.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1913, \"PID\": 535105110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 291.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1914, \"PID\": 535106140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 1915, \"PID\": 535106180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11344, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 874, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1916, \"PID\": 535126180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 1021.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1465, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Sev\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129000}, {\"Order\": 1917, \"PID\": 535151020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 873.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 63.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 219, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1918, \"PID\": 535151100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 908.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 1919, \"PID\": 535151110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 109, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142100}, {\"Order\": 1920, \"PID\": 535152060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1921, \"PID\": 535154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 243.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 834.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 275, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 1922, \"PID\": 535155110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 1923, \"PID\": 535176070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1244, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1244, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1924, \"PID\": 535177020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 69.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1144.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1925, \"PID\": 535177110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 138.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1331.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174850}, {\"Order\": 1926, \"PID\": 535179120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1927, \"PID\": 535180030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 586.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1928, \"PID\": 535181030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1237.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1657, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1929, \"PID\": 535181140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1930, \"PID\": 535300040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 928.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1931, \"PID\": 535301060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1932, \"PID\": 535301160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8078, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128600}, {\"Order\": 1933, \"PID\": 535302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1934, \"PID\": 535304170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 85.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 955.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 293.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1935, \"PID\": 535305180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1936, \"PID\": 535325090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 691.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1937, \"PID\": 535325280, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1938, \"PID\": 535325320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 500, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1939, \"PID\": 535327160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1940, \"PID\": 535327200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 377.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 551.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1941, \"PID\": 535353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 368, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1942, \"PID\": 535353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 324, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1943, \"PID\": 535353160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 14190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 544, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1944, \"PID\": 535354050, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 893, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 893, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1945, \"PID\": 535354260, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 512, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1946, \"PID\": 535355020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 21281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 1778, \"LowQualFinSF\": 0, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 208, \"EnclosedPorch\": 290, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 301600}, {\"Order\": 1947, \"PID\": 535375130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 735.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 735, \"2ndFlrSF\": 299, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 1948, \"PID\": 535376010, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 882.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103200}, {\"Order\": 1949, \"PID\": 535378080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 66.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 1950, \"PID\": 535379060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1951, \"PID\": 535379110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1895, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1952, \"PID\": 535382150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 691.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 86000}, {\"Order\": 1953, \"PID\": 535402140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 364.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 242.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1954, \"PID\": 535402180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 1955, \"PID\": 535403030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 952.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1956, \"PID\": 535426130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1957, \"PID\": 535450190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122900}, {\"Order\": 1958, \"PID\": 535450220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119200}, {\"Order\": 1959, \"PID\": 535450310, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10496, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1960, \"PID\": 535451040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 246.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1961, \"PID\": 535451100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1238, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 171, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 1962, \"PID\": 535451110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 398.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 149.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1963, \"PID\": 535452060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 254.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1964, \"PID\": 535453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1965, \"PID\": 535453150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7315, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1170.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1170, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1966, \"PID\": 535453180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 1967, \"PID\": 535457020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1098.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 154.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1377.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1377, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 1968, \"PID\": 535457040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1969, \"PID\": 535457050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1970, \"PID\": 535476360, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 831, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1971, \"PID\": 535477130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 1972, \"PID\": 535477180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 442.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1973, \"PID\": 535478040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 90, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1974, \"PID\": 902100010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1975, \"PID\": 902105110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 664, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 132000}, {\"Order\": 1976, \"PID\": 902106070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 175, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1977, \"PID\": 902106120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 782.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 184.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1978, \"PID\": 902107050, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1979, \"PID\": 902110010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 3153, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 26, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 1980, \"PID\": 902125120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1885, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1047, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1047, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1981, \"PID\": 902128160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 279.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1982, \"PID\": 902201090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 494, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 26, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1983, \"PID\": 902201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 679, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1984, \"PID\": 902202070, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 435.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 89471}, {\"Order\": 1985, \"PID\": 902205020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 122.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 448.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 761, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1986, \"PID\": 902205130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 1987, \"PID\": 902206270, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1075.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 642, \"LowQualFinSF\": 0, \"GrLivArea\": 1798, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1988, \"PID\": 902207010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1945, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 1989, \"PID\": 902207150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 968.0, \"TotalBsmtSF\": 968.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1990, \"PID\": 902300020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10337, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 1991, \"PID\": 902300040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 9863, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 374.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1992, \"PID\": 902301030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 842, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1993, \"PID\": 902301130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1994, \"PID\": 902302150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 1995, \"PID\": 902303100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 667.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 659, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144100}, {\"Order\": 1996, \"PID\": 902304040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1880, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 1997, \"PID\": 902305010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 316.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 687.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 687, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 124500}, {\"Order\": 1998, \"PID\": 902330090, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1879, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 819.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2454, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1999, \"PID\": 902332030, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1046.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 1031, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 99, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 2000, \"PID\": 902401030, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 779.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2001, \"PID\": 902404010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1221.0, \"TotalBsmtSF\": 1559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1559, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1559, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 230, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2002, \"PID\": 902408080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 718.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2003, \"PID\": 902427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 9439, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2004, \"PID\": 902427140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2005, \"PID\": 902427180, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2006, \"PID\": 903201090, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 6854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 227.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 916, \"2ndFlrSF\": 144, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 150, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2007, \"PID\": 903204030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8674, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1435, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128250}, {\"Order\": 2008, \"PID\": 903205085, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 8731, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 645.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2009, \"PID\": 903206170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 915, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2010, \"PID\": 903225040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2011, \"PID\": 903227140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 217.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 2012, \"PID\": 903228080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 349, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2013, \"PID\": 903231050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2014, \"PID\": 903231090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 809.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2015, \"PID\": 903231180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 423, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2016, \"PID\": 903232100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 966.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2017, \"PID\": 903233030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 903, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2018, \"PID\": 903233050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1933.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2019, \"PID\": 903233140, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 854, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2020, \"PID\": 903233180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 959, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 2021, \"PID\": 903234160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2022, \"PID\": 903236130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 7755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1164, \"LowQualFinSF\": 0, \"GrLivArea\": 2264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2023, \"PID\": 903400040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2024, \"PID\": 903401070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2025, \"PID\": 903425270, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 356, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2026, \"PID\": 903425280, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153575}, {\"Order\": 2027, \"PID\": 903426010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1929, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2028, \"PID\": 903427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 546.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 714.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 15, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136000}, {\"Order\": 2029, \"PID\": 903430040, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 933, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 113000}, {\"Order\": 2030, \"PID\": 903430050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 969, \"2ndFlrSF\": 245, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 117000}, {\"Order\": 2031, \"PID\": 903450060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 2032, \"PID\": 903451110, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 7449, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 2033, \"PID\": 903453080, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1497, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2034, \"PID\": 903454010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 0, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2035, \"PID\": 903454090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2036, \"PID\": 903456110, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 398.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 1952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 285, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212300}, {\"Order\": 2037, \"PID\": 903457040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 1042, \"LowQualFinSF\": 0, \"GrLivArea\": 2180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2038, \"PID\": 903457130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 4330, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 477, \"LowQualFinSF\": 0, \"GrLivArea\": 1315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 99500}, {\"Order\": 2039, \"PID\": 903458020, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 581, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101000}, {\"Order\": 2040, \"PID\": 903458060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 197.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 999.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2041, \"PID\": 903475040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 12358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 528, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2042, \"PID\": 903475060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 964, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2043, \"PID\": 903476100, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 4388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2044, \"PID\": 903484080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 771.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 504, \"LowQualFinSF\": 114, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 14, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 84, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 50000}, {\"Order\": 2045, \"PID\": 904100100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1937, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 1005, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 521, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219000}, {\"Order\": 2046, \"PID\": 904101070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 138.0, \"LotArea\": 18030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 977.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 971, \"LowQualFinSF\": 479, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 2047, \"PID\": 904301110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 756, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 126000}, {\"Order\": 2048, \"PID\": 904302010, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 4484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2049, \"PID\": 905100060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2050, \"PID\": 905100080, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158450}, {\"Order\": 2051, \"PID\": 905101070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 14299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115400}, {\"Order\": 2052, \"PID\": 905101200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1029, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 261.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2053, \"PID\": 905102010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 722.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2054, \"PID\": 905103110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 761.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2055, \"PID\": 905104030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 627.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 913, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2056, \"PID\": 905104090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 7094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2057, \"PID\": 905104170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 948.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 108000}, {\"Order\": 2058, \"PID\": 905104240, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 20.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2059, \"PID\": 905105040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 8665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 897, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2060, \"PID\": 905105170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 323.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 529.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2061, \"PID\": 905105260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 955, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2062, \"PID\": 905106150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 8724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2063, \"PID\": 905107140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 2064, \"PID\": 905200010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2065, \"PID\": 905201080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 522.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 323.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2066, \"PID\": 905225020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 16779, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 1087, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 570, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2067, \"PID\": 905226050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1416, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2068, \"PID\": 905226080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165250}, {\"Order\": 2069, \"PID\": 905226130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 231.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2070, \"PID\": 905226170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 873.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"VWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2071, \"PID\": 905228020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 998, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 998, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 2072, \"PID\": 905301050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 115149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 739.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 380, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 2073, \"PID\": 905352010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 891.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2074, \"PID\": 905352180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2075, \"PID\": 905376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 109.0, \"TotalBsmtSF\": 409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1325, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 2076, \"PID\": 905377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 587.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2077, \"PID\": 905377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 17808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2078, \"PID\": 905401020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2079, \"PID\": 905426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 12615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 477.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243000}, {\"Order\": 2080, \"PID\": 905451390, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 491.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 638, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 332.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 2081, \"PID\": 905475270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2082, \"PID\": 905475520, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11515, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2083, \"PID\": 905476160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 7711, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2084, \"PID\": 905476170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 605, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 605, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 2085, \"PID\": 905476225, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 3869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 755.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1038.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1038, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2086, \"PID\": 905478140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2087, \"PID\": 905478220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1080.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 400, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2088, \"PID\": 905480090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 951.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 376, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 2089, \"PID\": 905480180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2090, \"PID\": 906200230, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 23920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1105.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 1012, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 444, \"PoolQC\": \"TA\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2091, \"PID\": 906201022, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 10357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 719.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 244, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2092, \"PID\": 906201023, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 1121, \"LowQualFinSF\": 0, \"GrLivArea\": 2243, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 44, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2093, \"PID\": 906201200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1474.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2730, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 2094, \"PID\": 906203140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 634.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 833.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 192, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2095, \"PID\": 906204140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 807.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 196, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2096, \"PID\": 906223040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 497.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 929, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2097, \"PID\": 906340080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 984.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 1414, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 383970}, {\"Order\": 2098, \"PID\": 906340090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1362, \"LowQualFinSF\": 0, \"GrLivArea\": 2828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 424870}, {\"Order\": 2099, \"PID\": 906378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 2100, \"PID\": 906378150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10481, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2140.0, \"TotalBsmtSF\": 2140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 360000}, {\"Order\": 2101, \"PID\": 906378170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10652, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1494.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 279500}, {\"Order\": 2102, \"PID\": 906380010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 11175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 200141}, {\"Order\": 2103, \"PID\": 906380040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 10235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246500}, {\"Order\": 2104, \"PID\": 906380070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1482.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 1092, \"LowQualFinSF\": 0, \"GrLivArea\": 2574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 276000}, {\"Order\": 2105, \"PID\": 906380120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 349.0, \"TotalBsmtSF\": 1274.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1274, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203000}, {\"Order\": 2106, \"PID\": 906380140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11103, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155835}, {\"Order\": 2107, \"PID\": 906380160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2108, \"PID\": 906380200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 195400}, {\"Order\": 2109, \"PID\": 906382020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1526.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1546, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1546, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2110, \"PID\": 906382060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1453.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 674.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212999}, {\"Order\": 2111, \"PID\": 906392080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1270.0, \"TotalBsmtSF\": 1270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1270, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2112, \"PID\": 906394020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 916, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 2113, \"PID\": 906394050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176432}, {\"Order\": 2114, \"PID\": 906402070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1157.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 882, \"LowQualFinSF\": 0, \"GrLivArea\": 2062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 154, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2115, \"PID\": 906403060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 321.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 927, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2116, \"PID\": 906426060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 159000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 2144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2117, \"PID\": 906426195, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53107, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 985.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 874, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 231, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2118, \"PID\": 906475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2087, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2119, \"PID\": 906475170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 155.0, \"LotArea\": 20064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 51.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 915.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 646, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2120, \"PID\": 907125040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 472.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 747.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2121, \"PID\": 907125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2122, \"PID\": 907130060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11249, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 544.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 2123, \"PID\": 907131060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 10021, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 635.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 646, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2124, \"PID\": 907131120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9531, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 914, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2125, \"PID\": 907135050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2126, \"PID\": 907135080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 16561, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 242.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147900}, {\"Order\": 2127, \"PID\": 907135180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123600}, {\"Order\": 2128, \"PID\": 907180040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 905, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204750}, {\"Order\": 2129, \"PID\": 907187040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 646.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 597.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235500}, {\"Order\": 2130, \"PID\": 907187060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12352, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 853, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1753, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2131, \"PID\": 907192020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 845.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190550}, {\"Order\": 2132, \"PID\": 907192040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8826, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2133, \"PID\": 907192120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 167.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1013.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2134, \"PID\": 907192150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2135, \"PID\": 907200130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 131000}, {\"Order\": 2136, \"PID\": 907200190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 502.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2137, \"PID\": 907200250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1009, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2138, \"PID\": 907200270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 2139, \"PID\": 907202100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 16300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 417.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2140, \"PID\": 907202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 432.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2141, \"PID\": 907203060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 2142, \"PID\": 907203110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 10356, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 969, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2143, \"PID\": 907227060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 671.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2144, \"PID\": 907227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2145, \"PID\": 907250050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 2000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305900}, {\"Order\": 2146, \"PID\": 907252020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1284.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 2169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2147, \"PID\": 907252190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11354, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1412.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1673, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1673, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2148, \"PID\": 907260040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1459.0, \"TotalBsmtSF\": 1459.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1459, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1459, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 2149, \"PID\": 907260050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 2150, \"PID\": 907262020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 214.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2151, \"PID\": 907270040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 16226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 1242, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 267000}, {\"Order\": 2152, \"PID\": 907275080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 519.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 683.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1592, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1592, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2153, \"PID\": 907275150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 1531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2439, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2154, \"PID\": 907280090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2155, \"PID\": 907280100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 2156, \"PID\": 907285040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 438.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1079.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2157, \"PID\": 907290140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 2158, \"PID\": 907295040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 17227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246900}, {\"Order\": 2159, \"PID\": 907401060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1081, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2160, \"PID\": 907405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2161, \"PID\": 907410020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179400}, {\"Order\": 2162, \"PID\": 907410050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 639.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 2163, \"PID\": 907414060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1422.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179600}, {\"Order\": 2164, \"PID\": 907414070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 709.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 2165, \"PID\": 907420050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1330, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167840}, {\"Order\": 2166, \"PID\": 907420060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 753, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168675}, {\"Order\": 2167, \"PID\": 907420110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2168, \"PID\": 908102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2169, \"PID\": 908102160, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 405, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 2170, \"PID\": 908103090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 132.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2171, \"PID\": 908127040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 10921, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 48.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94750}, {\"Order\": 2172, \"PID\": 908127060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 16287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 450, \"LowQualFinSF\": 0, \"GrLivArea\": 1351, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 43, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2173, \"PID\": 908127070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1179.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2174, \"PID\": 908127100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 11841, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2175, \"PID\": 908152060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2176, \"PID\": 908152070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 751.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2177, \"PID\": 908152180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9555, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1133, \"LowQualFinSF\": 0, \"GrLivArea\": 2233, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2178, \"PID\": 908152260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1125.0, \"TotalBsmtSF\": 1125.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155000}, {\"Order\": 2179, \"PID\": 908152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2180, \"PID\": 908152290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 123.0, \"TotalBsmtSF\": 734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 674, \"LowQualFinSF\": 0, \"GrLivArea\": 1408, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 2181, \"PID\": 908154195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 39290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 4010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 5095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 5095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 5095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 15, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1154.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 546, \"OpenPorchSF\": 484, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Elev\", \"MiscVal\": 17000, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 183850}, {\"Order\": 2182, \"PID\": 908154205, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 40094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 762.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 3138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3138, \"2ndFlrSF\": 1538, \"LowQualFinSF\": 0, \"GrLivArea\": 4676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 406, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 184750}, {\"Order\": 2183, \"PID\": 908186050, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 467.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2184, \"PID\": 908204090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 77.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 831.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2185, \"PID\": 908204180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2186, \"PID\": 908225240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 2187, \"PID\": 908225310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1195, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 118, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98500}, {\"Order\": 2188, \"PID\": 908226180, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 4270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 286, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2189, \"PID\": 908228010, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 278.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 740, \"2ndFlrSF\": 125, \"LowQualFinSF\": 0, \"GrLivArea\": 865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2190, \"PID\": 908250100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 2191, \"PID\": 908275090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2192, \"PID\": 908275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2193, \"PID\": 908275240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 79275}, {\"Order\": 2194, \"PID\": 908276230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2195, \"PID\": 909176080, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 10896, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1184.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 1440, \"LowQualFinSF\": 515, \"GrLivArea\": 3395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 8, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 14, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 200000}, {\"Order\": 2196, \"PID\": 909176170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2592, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 742, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1512, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 150000}, {\"Order\": 2197, \"PID\": 909250150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 53, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2198, \"PID\": 909250160, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10594, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 2199, \"PID\": 909251030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7223, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2200, \"PID\": 909251040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6821, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 113.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2201, \"PID\": 909252010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 787, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2202, \"PID\": 909252150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 4000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 567, \"2ndFlrSF\": 531, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 2203, \"PID\": 909252170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 6720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 585, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 2204, \"PID\": 909254090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7642, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 514, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189950}, {\"Order\": 2205, \"PID\": 909254100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 775, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2206, \"PID\": 909254130, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 364.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2207, \"PID\": 909254140, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1913, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 365.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90350}, {\"Order\": 2208, \"PID\": 909254150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 661.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 661, \"2ndFlrSF\": 589, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 242, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2209, \"PID\": 909256120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 920.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119750}, {\"Order\": 2210, \"PID\": 909275020, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 7136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 979, \"2ndFlrSF\": 979, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2211, \"PID\": 909275030, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 6270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 1001, \"LowQualFinSF\": 0, \"GrLivArea\": 2002, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2212, \"PID\": 909275110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1927, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 867, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 291, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2213, \"PID\": 909275160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 126.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 24, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 228, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2214, \"PID\": 909275310, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 22420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1128.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2215, \"PID\": 909276160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12168, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 537.0, \"TotalBsmtSF\": 965.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 3194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 359100}, {\"Order\": 2216, \"PID\": 909276210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 7810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1230, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2217, \"PID\": 909279080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 557.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 19, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2218, \"PID\": 909281020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 6221, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2219, \"PID\": 909281130, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1549, \"2ndFlrSF\": 1178, \"LowQualFinSF\": 0, \"GrLivArea\": 2727, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2220, \"PID\": 909282020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1945, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 150.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 2320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259500}, {\"Order\": 2221, \"PID\": 909425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 1477.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1839, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 2222, \"PID\": 909425270, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2223, \"PID\": 909428120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 35.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 869.0, \"BsmtUnfSF\": 905.0, \"TotalBsmtSF\": 1809.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2259, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2259, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 217000}, {\"Order\": 2224, \"PID\": 909428180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1020.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 584, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 2225, \"PID\": 909428340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21579, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2226, \"PID\": 909451130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 529, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 2227, \"PID\": 909452102, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2228, \"PID\": 909455060, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 577.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2229, \"PID\": 909475050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 652.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 434.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1262.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 2230, \"PID\": 909475070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 2035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2515, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2515, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 200624}, {\"Order\": 2231, \"PID\": 909475230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 18044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 279.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 64, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 228, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2232, \"PID\": 910200040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 997, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2233, \"PID\": 910200110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2234, \"PID\": 910201020, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 803, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2235, \"PID\": 910201050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 176, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129850}, {\"Order\": 2236, \"PID\": 910201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 772, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1123, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 2237, \"PID\": 910201180, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": null, \"GarageArea\": null, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 150909}, {\"Order\": 2238, \"PID\": 910202030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 46.0, \"LotArea\": 3672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 100.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75200}, {\"Order\": 2239, \"PID\": 910203290, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118400}, {\"Order\": 2240, \"PID\": 910204090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 961.0, \"TotalBsmtSF\": 961.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"Mix\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 67000}, {\"Order\": 2241, \"PID\": 910205130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 910, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2242, \"PID\": 910206010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 11067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 205, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68104}, {\"Order\": 2243, \"PID\": 911103060, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1895, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 957.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 957, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 133, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119600}, {\"Order\": 2244, \"PID\": 911128010, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 65.0, \"LotArea\": 6565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 106.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 444, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2245, \"PID\": 911128020, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 837.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1001, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 86, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 2246, \"PID\": 911370450, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2247, \"PID\": 911370460, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 481.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 235000}, {\"Order\": 2248, \"PID\": 914452090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1001.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2249, \"PID\": 914452120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2250, \"PID\": 914452190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2251, \"PID\": 914460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 856.0, \"TotalBsmtSF\": 1441.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2252, \"PID\": 914460110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 12864, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 17.0, \"TotalBsmtSF\": 1409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1409, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 2253, \"PID\": 914476330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2254, \"PID\": 914478020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 530.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 852.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2255, \"PID\": 914478100, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 924.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2256, \"PID\": 916226090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 4054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 949.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 2257, \"PID\": 916253320, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 9763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 239.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1102.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 2258, \"PID\": 916326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 16905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2259, \"PID\": 916326090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 19958, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 274, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2260, \"PID\": 916384050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 231713}, {\"Order\": 2261, \"PID\": 916384070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8298, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 963.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2207.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267300}, {\"Order\": 2262, \"PID\": 916384080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1476.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265900}, {\"Order\": 2263, \"PID\": 916384150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1571.0, \"TotalBsmtSF\": 1571.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1571, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239000}, {\"Order\": 2264, \"PID\": 916386170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 274.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1638.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248900}, {\"Order\": 2265, \"PID\": 916403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 215.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 1265.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2266, \"PID\": 916403290, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2267, \"PID\": 916455010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 742.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1756, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 2268, \"PID\": 916455050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6718, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2269, \"PID\": 916455110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 82.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2270, \"PID\": 916455150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 886.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 593.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282000}, {\"Order\": 2271, \"PID\": 916460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2272, \"PID\": 916475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 808.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 252, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2273, \"PID\": 916477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 1340, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279900}, {\"Order\": 2274, \"PID\": 917425190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 35133, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 995.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 263, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 263, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186700}, {\"Order\": 2275, \"PID\": 921126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 15306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1652.0, \"TotalBsmtSF\": 1732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 283463}, {\"Order\": 2276, \"PID\": 921128030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 2277, \"PID\": 921205070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1094.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 1349, \"LowQualFinSF\": 0, \"GrLivArea\": 2482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 281213}, {\"Order\": 2278, \"PID\": 923202134, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 914.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 2279, \"PID\": 923202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 200.0, \"LotArea\": 43500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1041.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 561, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2280, \"PID\": 923203010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 6710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 904.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2281, \"PID\": 923204050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 25286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132250}, {\"Order\": 2282, \"PID\": 923204140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 25000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2283, \"PID\": 923205025, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 149.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1622, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 439, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2284, \"PID\": 923225040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 840.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2285, \"PID\": 923225050, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 874.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 536, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2286, \"PID\": 923226300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2287, \"PID\": 923228200, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 27.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 97, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 2288, \"PID\": 923228220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93900}, {\"Order\": 2289, \"PID\": 923228250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 2290, \"PID\": 923228290, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 131.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 499.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2291, \"PID\": 923228390, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 75190}, {\"Order\": 2292, \"PID\": 923229010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146800}, {\"Order\": 2293, \"PID\": 923229040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9129, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2294, \"PID\": 923229100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1356, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 1424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2295, \"PID\": 923229140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 33983, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1112.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1676, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 690, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2296, \"PID\": 923230010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 185.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2297, \"PID\": 923230120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 2298, \"PID\": 923230180, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 149.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2299, \"PID\": 923251160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 27697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"CBlock\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 811.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1608, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2300, \"PID\": 923252080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7599, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2301, \"PID\": 923275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1090.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 88, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2302, \"PID\": 923275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2303, \"PID\": 923276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 596.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 330, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2304, \"PID\": 923400150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 212.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 974.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 974, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 974, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93500}, {\"Order\": 2305, \"PID\": 923425030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 887, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2306, \"PID\": 526302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11027, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1178.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1293, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1293, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2307, \"PID\": 526302040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 280, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2308, \"PID\": 526302120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1127.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 963.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2309, \"PID\": 526303060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 39384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 902.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 252000}, {\"Order\": 2310, \"PID\": 526354020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11727, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 434.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1851.0, \"TotalBsmtSF\": 1851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1851, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192100}, {\"Order\": 2311, \"PID\": 527105060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8238, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2312, \"PID\": 527106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 964.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 1243, \"LowQualFinSF\": 0, \"GrLivArea\": 2236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2313, \"PID\": 527107020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 781, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2314, \"PID\": 527107030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13031, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 592.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2315, \"PID\": 527107120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 821.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 821, \"2ndFlrSF\": 955, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 443.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2316, \"PID\": 527107240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 714.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 413.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 95, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2317, \"PID\": 527108010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 19378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 2462, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2318, \"PID\": 527108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 14859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 27.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1670.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 240000}, {\"Order\": 2319, \"PID\": 527108030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 13128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 990, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2320, \"PID\": 527108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 893.0, \"TotalBsmtSF\": 893.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 2321, \"PID\": 527108060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 13751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1640.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 2212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 773.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 309000}, {\"Order\": 2322, \"PID\": 527108090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 168.0, \"LotArea\": 23257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2021, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 274725}, {\"Order\": 2323, \"PID\": 527146135, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2062.0, \"TotalBsmtSF\": 2062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2079, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2324, \"PID\": 527158020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8076, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2325, \"PID\": 527163020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165600}, {\"Order\": 2326, \"PID\": 527166030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 2327, \"PID\": 527182020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 3701, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2328, \"PID\": 527190050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 5306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 215.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 441, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2329, \"PID\": 527190220, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 28, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2330, \"PID\": 527210030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 1384, \"LowQualFinSF\": 0, \"GrLivArea\": 2798, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 37, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 457347}, {\"Order\": 2331, \"PID\": 527210040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 18062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 662.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 1862, \"LowQualFinSF\": 0, \"GrLivArea\": 3390, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 545224}, {\"Order\": 2332, \"PID\": 527210050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 205.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 889.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1371, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 246, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356383}, {\"Order\": 2333, \"PID\": 527212030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 16056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1752.0, \"TotalBsmtSF\": 1992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1992, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 2868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 716.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 556581}, {\"Order\": 2334, \"PID\": 527212040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 1312, \"LowQualFinSF\": 0, \"GrLivArea\": 2576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 361919}, {\"Order\": 2335, \"PID\": 527214060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 16052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 734.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 2698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 535000}, {\"Order\": 2336, \"PID\": 527216010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 15922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 550.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 1405, \"LowQualFinSF\": 0, \"GrLivArea\": 2795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 401179}, {\"Order\": 2337, \"PID\": 527216050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1031.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1410.0, \"TotalBsmtSF\": 1410.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 1519, \"LowQualFinSF\": 0, \"GrLivArea\": 2945, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 37, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 438780}, {\"Order\": 2338, \"PID\": 527226010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1547, \"2ndFlrSF\": 720, \"LowQualFinSF\": 53, \"GrLivArea\": 2320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2339, \"PID\": 527250040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 34650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2340, \"PID\": 527252090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 523.0, \"TotalBsmtSF\": 1714.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1714, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 2341, \"PID\": 527254070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11302, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Other\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1422.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1826, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319000}, {\"Order\": 2342, \"PID\": 527256120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 18261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 123, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 470000}, {\"Order\": 2343, \"PID\": 527301010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 995.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2344, \"PID\": 527302080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1002.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 2183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2345, \"PID\": 527325160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 34.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 795.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 250, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2346, \"PID\": 527327080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2347, \"PID\": 527328010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2348, \"PID\": 527354040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 604.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 2349, \"PID\": 527355060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1857, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188900}, {\"Order\": 2350, \"PID\": 527355280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 1061.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 384, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2351, \"PID\": 527356020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1392, \"LowQualFinSF\": 0, \"GrLivArea\": 2784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 440, \"PoolArea\": 519, \"PoolQC\": \"Fa\", \"Fence\": \"MnPrv\", \"MiscFeature\": \"TenC\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2352, \"PID\": 527356060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 811, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 208, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2353, \"PID\": 527358090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 42.0, \"TotalBsmtSF\": 1047.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1083, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1083, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 444, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2354, \"PID\": 527365010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1358, \"LowQualFinSF\": 0, \"GrLivArea\": 2318, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 246, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294323}, {\"Order\": 2355, \"PID\": 527375160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 127.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1109, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 485.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 2356, \"PID\": 527376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2357, \"PID\": 527376110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 2358, \"PID\": 527377030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 377.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1309, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1309, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 648, \"PoolQC\": \"Fa\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2359, \"PID\": 527378010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2360, \"PID\": 527402210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 75.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 791.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 138800}, {\"Order\": 2361, \"PID\": 527402380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9353, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 116050}, {\"Order\": 2362, \"PID\": 527403120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 614.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 2363, \"PID\": 527404180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 2364, \"PID\": 527427210, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 951.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1487.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2365, \"PID\": 527450010, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 514.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 2366, \"PID\": 527450080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2367, \"PID\": 527450210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 408.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83000}, {\"Order\": 2368, \"PID\": 527450460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 494, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2369, \"PID\": 527451200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 91500}, {\"Order\": 2370, \"PID\": 527451380, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2371, \"PID\": 527451450, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 465, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2372, \"PID\": 527451460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 382.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2373, \"PID\": 527451520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 297.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94500}, {\"Order\": 2374, \"PID\": 527452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 156.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146300}, {\"Order\": 2375, \"PID\": 527452290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 373.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1387, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2376, \"PID\": 527452310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 175, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2377, \"PID\": 527453070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2378, \"PID\": 527455100, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2379, \"PID\": 528102010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 66.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1447.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 770.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2380, \"PID\": 528102080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 16387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1738, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 2589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 412083}, {\"Order\": 2381, \"PID\": 528106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 111.0, \"LotArea\": 16259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 370.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1249.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1249, \"2ndFlrSF\": 1347, \"LowQualFinSF\": 0, \"GrLivArea\": 2596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 342643}, {\"Order\": 2382, \"PID\": 528106120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 16163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1618.0, \"TotalBsmtSF\": 1618.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1618, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1618, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 2383, \"PID\": 528110050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 690.0, \"TotalBsmtSF\": 2076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2076, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 229, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 465000}, {\"Order\": 2384, \"PID\": 528112010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 12228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1721.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293000}, {\"Order\": 2385, \"PID\": 528114010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 14780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1085.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 354, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2386, \"PID\": 528116030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 16033, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1261.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 519, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 326000}, {\"Order\": 2387, \"PID\": 528118010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 14215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1218, \"LowQualFinSF\": 0, \"GrLivArea\": 2376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 853.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325300}, {\"Order\": 2388, \"PID\": 528118020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 309000}, {\"Order\": 2389, \"PID\": 528118110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13975, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 300000}, {\"Order\": 2390, \"PID\": 528120110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1030.0, \"TotalBsmtSF\": 1030.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 1060, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 2391, \"PID\": 528120140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 385.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 466, \"LowQualFinSF\": 0, \"GrLivArea\": 2091, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338500}, {\"Order\": 2392, \"PID\": 528138030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345000}, {\"Order\": 2393, \"PID\": 528142010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 12867, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1209.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 344133}, {\"Order\": 2394, \"PID\": 528142060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 10672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 1335, \"LowQualFinSF\": 0, \"GrLivArea\": 2389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 298236}, {\"Order\": 2395, \"PID\": 528142070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 814, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 329900}, {\"Order\": 2396, \"PID\": 528142110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 1896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 708.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 2397, \"PID\": 528144030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11065, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 788.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 1085.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 753.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281000}, {\"Order\": 2398, \"PID\": 528150080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372397}, {\"Order\": 2399, \"PID\": 528150090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 131.0, \"LotArea\": 14828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 1780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378000}, {\"Order\": 2400, \"PID\": 528164040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 562.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 374000}, {\"Order\": 2401, \"PID\": 528170040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 20431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 870.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1848, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 2728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 437154}, {\"Order\": 2402, \"PID\": 528172020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 512.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 179, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2403, \"PID\": 528172150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 488, \"LowQualFinSF\": 0, \"GrLivArea\": 1914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2404, \"PID\": 528174080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 705.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185850}, {\"Order\": 2405, \"PID\": 528180080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 5911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282500}, {\"Order\": 2406, \"PID\": 528181030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6955, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202500}, {\"Order\": 2407, \"PID\": 528181040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 6792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202665}, {\"Order\": 2408, \"PID\": 528186100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 518.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 899.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 332200}, {\"Order\": 2409, \"PID\": 528186110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 572.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1251.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310090}, {\"Order\": 2410, \"PID\": 528188040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171750}, {\"Order\": 2411, \"PID\": 528218030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 23, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169990}, {\"Order\": 2412, \"PID\": 528218060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 170440}, {\"Order\": 2413, \"PID\": 528218080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169985}, {\"Order\": 2414, \"PID\": 528218130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 17104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 426.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179665}, {\"Order\": 2415, \"PID\": 528218140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 14054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 1863, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 219210}, {\"Order\": 2416, \"PID\": 528221010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 11660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1326.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 174190}, {\"Order\": 2417, \"PID\": 528221100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172785}, {\"Order\": 2418, \"PID\": 528222010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11631, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1052.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 1321, \"LowQualFinSF\": 0, \"GrLivArea\": 2373, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 258000}, {\"Order\": 2419, \"PID\": 528222020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185101}, {\"Order\": 2420, \"PID\": 528228280, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3087, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 767.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210250}, {\"Order\": 2421, \"PID\": 528228325, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1374.0, \"TotalBsmtSF\": 1374.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 2422, \"PID\": 528228340, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1273.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2423, \"PID\": 528228360, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1038.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246990}, {\"Order\": 2424, \"PID\": 528228415, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1375.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178740}, {\"Order\": 2425, \"PID\": 528228430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2426, \"PID\": 528228545, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167240}, {\"Order\": 2427, \"PID\": 528228550, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1126.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156820}, {\"Order\": 2428, \"PID\": 528228565, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213490}, {\"Order\": 2429, \"PID\": 528228575, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1154.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 1520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264561}, {\"Order\": 2430, \"PID\": 528228580, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246578}, {\"Order\": 2431, \"PID\": 528231050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 21930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192140}, {\"Order\": 2432, \"PID\": 528235050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7861, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183200}, {\"Order\": 2433, \"PID\": 528235130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2434, \"PID\": 528235190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1598, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201490}, {\"Order\": 2435, \"PID\": 528240080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1406.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1454, \"2ndFlrSF\": 482, \"LowQualFinSF\": 0, \"GrLivArea\": 1936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 2436, \"PID\": 528250060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2437, \"PID\": 528275060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8121, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 711, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172400}, {\"Order\": 2438, \"PID\": 528275080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2439, \"PID\": 528280100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 930, \"LowQualFinSF\": 0, \"GrLivArea\": 1886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 89, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199900}, {\"Order\": 2440, \"PID\": 528290140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 959.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 2441, \"PID\": 528292080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287602}, {\"Order\": 2442, \"PID\": 528294070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 1286, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2443, \"PID\": 528315030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1074.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1407, \"2ndFlrSF\": 985, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 348000}, {\"Order\": 2444, \"PID\": 528315070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 31, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 2445, \"PID\": 528315080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 322.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 655.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1205, \"2ndFlrSF\": 1029, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2446, \"PID\": 528320060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 35760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1831, \"2ndFlrSF\": 1796, \"LowQualFinSF\": 0, \"GrLivArea\": 3627, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 807.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 361, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 625000}, {\"Order\": 2447, \"PID\": 528327010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9233, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 877.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 358.0, \"TotalBsmtSF\": 1540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1540, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2855, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 247, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 405000}, {\"Order\": 2448, \"PID\": 528344060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 530.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 374, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2449, \"PID\": 528348010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 258000}, {\"Order\": 2450, \"PID\": 528358030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 397.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 1368, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 169, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 2451, \"PID\": 528360050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 17242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 738.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1393.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1733.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1933, \"2ndFlrSF\": 1567, \"LowQualFinSF\": 0, \"GrLivArea\": 3500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 959.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 870, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 584500}, {\"Order\": 2452, \"PID\": 528363070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 501.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1305, \"2ndFlrSF\": 1189, \"LowQualFinSF\": 0, \"GrLivArea\": 2494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 803.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 321000}, {\"Order\": 2453, \"PID\": 528365090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 391.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1203, \"2ndFlrSF\": 1323, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 309, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 2454, \"PID\": 528366040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1039.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 1234, \"LowQualFinSF\": 0, \"GrLivArea\": 2799, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 432, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2455, \"PID\": 528429060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 760.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252000}, {\"Order\": 2456, \"PID\": 528429100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1562.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336820}, {\"Order\": 2457, \"PID\": 528429120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 20896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1721.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 2077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1134.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 267, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 423000}, {\"Order\": 2458, \"PID\": 528429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290000}, {\"Order\": 2459, \"PID\": 528439030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1616.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 2460, \"PID\": 528445010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1504.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199000}, {\"Order\": 2461, \"PID\": 528456200, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1254.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 584.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198600}, {\"Order\": 2462, \"PID\": 528477010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 13162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 2036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 405749}, {\"Order\": 2463, \"PID\": 528477030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 11216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 232600}, {\"Order\": 2464, \"PID\": 528480070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1053.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 266000}, {\"Order\": 2465, \"PID\": 528480100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186500}, {\"Order\": 2466, \"PID\": 528480110, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200825}, {\"Order\": 2467, \"PID\": 528480150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 798, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 197000}, {\"Order\": 2468, \"PID\": 528488110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 905.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185000}, {\"Order\": 2469, \"PID\": 528488120, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2470, \"PID\": 528488130, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1293.0, \"TotalBsmtSF\": 1293.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187750}, {\"Order\": 2471, \"PID\": 531363080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1118.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 4, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2472, \"PID\": 531367010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 118.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1400.0, \"TotalBsmtSF\": 1400.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1400, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186800}, {\"Order\": 2473, \"PID\": 531375060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1131.0, \"TotalBsmtSF\": 1131.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 132000}, {\"Order\": 2474, \"PID\": 531375070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2475, \"PID\": 531375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 158000}, {\"Order\": 2476, \"PID\": 531376030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 891.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 891, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 2477, \"PID\": 531376050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1585, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 449.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 2478, \"PID\": 531379030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1837, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 688.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2479, \"PID\": 531450040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 761.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2480, \"PID\": 531451290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1731, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3000, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 248500}, {\"Order\": 2481, \"PID\": 531452080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1398, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2482, \"PID\": 531452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 278.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 1217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2483, \"PID\": 531452210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 362.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 636, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2484, \"PID\": 531478010, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 8900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107000}, {\"Order\": 2485, \"PID\": 531479030, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2486, \"PID\": 532351060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2487, \"PID\": 532351090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1332.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2488, \"PID\": 532351150, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1286, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2489, \"PID\": 532353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2490, \"PID\": 532353180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 8471, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 46.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 506.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2491, \"PID\": 532376080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2492, \"PID\": 532376180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2493, \"PID\": 532376250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2494, \"PID\": 532378050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120875}, {\"Order\": 2495, \"PID\": 532378070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 375.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 935, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2496, \"PID\": 532378130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2497, \"PID\": 532378160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 465.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 447.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2498, \"PID\": 532378220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8789, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129200}, {\"Order\": 2499, \"PID\": 532476050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 497.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1748.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2151, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 4, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 641, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 800, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2500, \"PID\": 533110130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 16059, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2417, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2501, \"PID\": 533125120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 692.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1118.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 208, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 2502, \"PID\": 533127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 310000}, {\"Order\": 2503, \"PID\": 533128030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13346, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 1129, \"LowQualFinSF\": 0, \"GrLivArea\": 2295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 2504, \"PID\": 533128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"ImStucc\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 757.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262000}, {\"Order\": 2505, \"PID\": 533206040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3628, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176400}, {\"Order\": 2506, \"PID\": 533208050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3316, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1247.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1247, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1247, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2507, \"PID\": 533212100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2508, \"PID\": 533212110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147400}, {\"Order\": 2509, \"PID\": 533212120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2510, \"PID\": 533212130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 144152}, {\"Order\": 2511, \"PID\": 533221080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 2512, \"PID\": 533223010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 241.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183900}, {\"Order\": 2513, \"PID\": 533223080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 673, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 153, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2514, \"PID\": 533223110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2515, \"PID\": 533241010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 114.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 382, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2516, \"PID\": 533242030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 2517, \"PID\": 533250130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 9549, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1057.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2518, \"PID\": 533252020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2519, \"PID\": 533253030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1009.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 44.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2520, \"PID\": 533253050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 3640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2521, \"PID\": 533253090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3874, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 807.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 419.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2522, \"PID\": 533253160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 526.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2523, \"PID\": 533350050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 50271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 1842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1842, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 857, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 385000}, {\"Order\": 2524, \"PID\": 534125210, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 13110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2525, \"PID\": 534126060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 10192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2526, \"PID\": 534127190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 1203.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2156, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2156, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 290, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 2527, \"PID\": 534127270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 404.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 708.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 708, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 119, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2528, \"PID\": 534128210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 435.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 222, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2529, \"PID\": 534129230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165150}, {\"Order\": 2530, \"PID\": 534175100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 264, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164500}, {\"Order\": 2531, \"PID\": 534176250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1164.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2532, \"PID\": 534201130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2533, \"PID\": 534201230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2534, \"PID\": 534201250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1770, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 270, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 455, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2535, \"PID\": 534201260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 94, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157500}, {\"Order\": 2536, \"PID\": 534201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 2537, \"PID\": 534201300, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2538, \"PID\": 534202020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124400}, {\"Order\": 2539, \"PID\": 534202180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 402.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 568.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2540, \"PID\": 534226060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 661.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2541, \"PID\": 534250300, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1993, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2542, \"PID\": 534275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 319, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2543, \"PID\": 534276010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2544, \"PID\": 534276230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1098.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 145000}, {\"Order\": 2545, \"PID\": 534400120, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 34.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 25, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 460, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185900}, {\"Order\": 2546, \"PID\": 534403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2547, \"PID\": 534403400, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 748.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2548, \"PID\": 534403440, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2549, \"PID\": 534427090, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2550, \"PID\": 534428060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 8973, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 28.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2551, \"PID\": 534429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 2552, \"PID\": 534430050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129800}, {\"Order\": 2553, \"PID\": 534430110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2554, \"PID\": 534431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1043, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1043, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2555, \"PID\": 534451050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 4712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 456, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 63, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 121600}, {\"Order\": 2556, \"PID\": 534451120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 5900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2557, \"PID\": 534451130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 5825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79900}, {\"Order\": 2558, \"PID\": 534453150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 7438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 316, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2559, \"PID\": 534455080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2560, \"PID\": 534475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1404.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 324, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 146500}, {\"Order\": 2561, \"PID\": 534476100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2562, \"PID\": 534477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 756.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1380.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 2136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 2563, \"PID\": 534479130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 165.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 958, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2564, \"PID\": 534479240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2565, \"PID\": 534479300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2566, \"PID\": 535101110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2567, \"PID\": 535103070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 939.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 307.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2568, \"PID\": 535105160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98600}, {\"Order\": 2569, \"PID\": 535125060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 2157, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2570, \"PID\": 535150240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 118000}, {\"Order\": 2571, \"PID\": 535150300, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 25419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 4, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 184.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 1360, \"LowQualFinSF\": 392, \"GrLivArea\": 3112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 552, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 512, \"PoolQC\": \"Ex\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 235000}, {\"Order\": 2572, \"PID\": 535151080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 9723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 332.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2573, \"PID\": 535151130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 303.0, \"TotalBsmtSF\": 1106.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2574, \"PID\": 535152070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 86, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2575, \"PID\": 535152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2576, \"PID\": 535176050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 175.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145250}, {\"Order\": 2577, \"PID\": 535177100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9610, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 2578, \"PID\": 535178100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 281.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 191, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2579, \"PID\": 535179050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 14850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 895.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 122, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2580, \"PID\": 535180020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 914.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 353.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 2581, \"PID\": 535180070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 64.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134450}, {\"Order\": 2582, \"PID\": 535301010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 943.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135960}, {\"Order\": 2583, \"PID\": 535301150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8092, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 156000}, {\"Order\": 2584, \"PID\": 535303050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1367.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2585, \"PID\": 535304020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2586, \"PID\": 535305120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 522.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2587, \"PID\": 535325130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 301.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2588, \"PID\": 535325340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 488.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 517.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2589, \"PID\": 535325350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 912.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2590, \"PID\": 535325450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2591, \"PID\": 535325460, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 21299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 929.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 791.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2592, \"PID\": 535327210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 521.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 75, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 323, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2593, \"PID\": 535353180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 22136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1153.0, \"TotalBsmtSF\": 2171.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1248, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1008.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 631, \"OpenPorchSF\": 48, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2594, \"PID\": 535354130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 900, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2595, \"PID\": 535355100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 865, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2596, \"PID\": 535375040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 713, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 161, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99800}, {\"Order\": 2597, \"PID\": 535376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 418.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2598, \"PID\": 535376100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1073.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108480}, {\"Order\": 2599, \"PID\": 535377070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 715, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 75, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68000}, {\"Order\": 2600, \"PID\": 535377100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 448, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 2601, \"PID\": 535379100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1130, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 229, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2602, \"PID\": 535380010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 821, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155500}, {\"Order\": 2603, \"PID\": 535380130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10818, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 981, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2604, \"PID\": 535381060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 105000}, {\"Order\": 2605, \"PID\": 535382020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 2414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2606, \"PID\": 535382130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1936, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 370, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 436, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2607, \"PID\": 535401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 445.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 2608, \"PID\": 535402070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1047.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159950}, {\"Order\": 2609, \"PID\": 535402100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 379.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1083.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 345, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2610, \"PID\": 535402220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 128, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2611, \"PID\": 535402230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 701.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1135.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1207, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 2612, \"PID\": 535403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 600.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2613, \"PID\": 535403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 8910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 655.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2614, \"PID\": 535403200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 207.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 2615, \"PID\": 535404080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 7100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2616, \"PID\": 535425040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1773, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 2617, \"PID\": 535425050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2618, \"PID\": 535425080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 802.0, \"TotalBsmtSF\": 1438.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1900, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 520, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 2619, \"PID\": 535426195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 16321, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1277.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 258, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2620, \"PID\": 535450100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 597.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 2621, \"PID\": 535450180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 2622, \"PID\": 535451190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 2623, \"PID\": 535451210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2624, \"PID\": 535453160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133700}, {\"Order\": 2625, \"PID\": 535454030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81400}, {\"Order\": 2626, \"PID\": 535454050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 2627, \"PID\": 535454060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2628, \"PID\": 535456010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1556.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1556, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2629, \"PID\": 535456020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 179.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 506.0, \"BsmtUnfSF\": 465.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2630, \"PID\": 535457070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 162, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2631, \"PID\": 535477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2632, \"PID\": 535478010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 10205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2633, \"PID\": 535478070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 809.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 236.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2634, \"PID\": 535478090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2635, \"PID\": 535478110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 953.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 1025.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2636, \"PID\": 902100110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 9856, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 1007, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 167, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2637, \"PID\": 902100130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9906, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 518, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 107000}, {\"Order\": 2638, \"PID\": 902101050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2639, \"PID\": 902103090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 863.0, \"TotalBsmtSF\": 1147.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1147, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2640, \"PID\": 902104020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 476, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2641, \"PID\": 902106040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2642, \"PID\": 902106090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6451, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 208.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 2643, \"PID\": 902108060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 66.0, \"LotArea\": 3960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 502.0, \"TotalBsmtSF\": 502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 502, \"2ndFlrSF\": 502, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2644, \"PID\": 902109010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 813, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 813, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2645, \"PID\": 902110120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7745, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 867, \"LowQualFinSF\": 0, \"GrLivArea\": 1951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 6, \"EnclosedPorch\": 28, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2646, \"PID\": 902110130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7741, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 143.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 2647, \"PID\": 902111010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5633, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 81, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2648, \"PID\": 902125020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1880, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 661, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 293, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 2649, \"PID\": 902128020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2650, \"PID\": 902128100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 648.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 734, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2651, \"PID\": 902134060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 7614, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1905, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 714, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 104, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96900}, {\"Order\": 2652, \"PID\": 902204060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2653, \"PID\": 902204120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 296, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2654, \"PID\": 902206020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2655, \"PID\": 902206090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 297, \"LowQualFinSF\": 0, \"GrLivArea\": 1182, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 378.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2656, \"PID\": 902207080, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 5820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 906.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1163, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126175}, {\"Order\": 2657, \"PID\": 902207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 48.0, \"LotArea\": 5747, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 2658, \"PID\": 902301120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 908, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2659, \"PID\": 902305090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 2, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 679, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2660, \"PID\": 902325050, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 2661, \"PID\": 902325100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2104, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2662, \"PID\": 902325160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 889, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2663, \"PID\": 902328100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 815.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 815, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 330, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2664, \"PID\": 902329070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 684, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114504}, {\"Order\": 2665, \"PID\": 902329090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 998, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 0, \"EnclosedPorch\": 221, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2666, \"PID\": 902400090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 84.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1200.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 125000}, {\"Order\": 2667, \"PID\": 902400110, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 22950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1892, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1107.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 1518, \"LowQualFinSF\": 572, \"GrLivArea\": 3608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 260, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 410, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 475000}, {\"Order\": 2668, \"PID\": 902401090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 5976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 624, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 256, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2669, \"PID\": 902406030, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 4500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2670, \"PID\": 902456015, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 63.0, \"LotArea\": 4761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 2671, \"PID\": 903200050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7446, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 2672, \"PID\": 903202120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 605, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140200}, {\"Order\": 2673, \"PID\": 903206160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1017, \"2ndFlrSF\": 810, \"LowQualFinSF\": 0, \"GrLivArea\": 1827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1943.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 27, \"OpenPorchSF\": 36, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2674, \"PID\": 903225090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2675, \"PID\": 903229040, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 325, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 271, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2676, \"PID\": 903231070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 2677, \"PID\": 903231190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2678, \"PID\": 903231220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 347.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 434, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 258.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 75000}, {\"Order\": 2679, \"PID\": 903231240, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1015, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1015, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 620, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 88000}, {\"Order\": 2680, \"PID\": 903232170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80500}, {\"Order\": 2681, \"PID\": 903233100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1042.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 149000}, {\"Order\": 2682, \"PID\": 903233220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 583, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2683, \"PID\": 903234030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 2684, \"PID\": 903235020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 129, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2685, \"PID\": 903236200, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 993.0, \"TotalBsmtSF\": 993.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2686, \"PID\": 903400030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 11672, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 2687, \"PID\": 903425190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 33120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2688, \"PID\": 903425340, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9873, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 288, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2689, \"PID\": 903430090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 634, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 255.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 394, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2690, \"PID\": 903430130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 153.0, \"LotArea\": 4118, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 693.0, \"TotalBsmtSF\": 693.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 693, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 693, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52500}, {\"Order\": 2691, \"PID\": 903451050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 834, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 2692, \"PID\": 903452090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 665, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 2693, \"PID\": 903454020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 819, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 819, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 72000}, {\"Order\": 2694, \"PID\": 903454080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 198.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2695, \"PID\": 903455090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 803.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 803, \"2ndFlrSF\": 557, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2696, \"PID\": 903456060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1007.0, \"TotalBsmtSF\": 1007.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 2697, \"PID\": 903456090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 234, \"GrLivArea\": 754, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 53, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2698, \"PID\": 903458010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2699, \"PID\": 904100030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 477.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 341, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2700, \"PID\": 904100090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 11136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1921.0, \"TotalBsmtSF\": 1921.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1921, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1921, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2701, \"PID\": 904100170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 225, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2702, \"PID\": 904101040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 6930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 294, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 2703, \"PID\": 904301410, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2704, \"PID\": 904302020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 830.0, \"TotalBsmtSF\": 830.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2705, \"PID\": 904302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 373.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2706, \"PID\": 905100030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 459.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2707, \"PID\": 905101330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 2708, \"PID\": 905101450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154500}, {\"Order\": 2709, \"PID\": 905103130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153600}, {\"Order\": 2710, \"PID\": 905103140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 97.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 328.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 68, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 164500}, {\"Order\": 2711, \"PID\": 905103180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 934, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 934, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 77, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2712, \"PID\": 905105010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1059, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1059, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2713, \"PID\": 905106210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11553, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1159, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 466, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2714, \"PID\": 905107070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 463.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 2715, \"PID\": 905107220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 982.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1458, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2716, \"PID\": 905107240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2717, \"PID\": 905107300, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 794.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 2718, \"PID\": 905108090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9662, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1967.0, \"TotalBsmtSF\": 1967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2719, \"PID\": 905108120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1466.0, \"TotalBsmtSF\": 1949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2720, \"PID\": 905200280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 441.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 2721, \"PID\": 905200290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 682.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2722, \"PID\": 905200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 17920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1085.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 418, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 312, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 2723, \"PID\": 905200380, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2724, \"PID\": 905200490, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1965, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2725, \"PID\": 905201090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 304, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2726, \"PID\": 905202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 826.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 1865.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1830, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 115, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 2727, \"PID\": 905202210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 13050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 850.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2728, \"PID\": 905225080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 15593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 701.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1304, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 667.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2729, \"PID\": 905300010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2730, \"PID\": 905300080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 241, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2731, \"PID\": 905351045, \"MSSubClass\": 150, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 1700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 33.0, \"TotalBsmtSF\": 430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 680, \"LowQualFinSF\": 140, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148400}, {\"Order\": 2732, \"PID\": 905351150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 445.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 190000}, {\"Order\": 2733, \"PID\": 905402110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2734, \"PID\": 905403050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 6488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 799, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 128000}, {\"Order\": 2735, \"PID\": 905426100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 103, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2736, \"PID\": 905426150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 626, \"LowQualFinSF\": 0, \"GrLivArea\": 2201, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 586, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 738, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 274970}, {\"Order\": 2737, \"PID\": 905427010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 19950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2738, \"PID\": 905427030, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 19800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1411.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 1836, \"LowQualFinSF\": 0, \"GrLivArea\": 3672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 684, \"OpenPorchSF\": 80, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2739, \"PID\": 905427140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11679, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1164.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 453, \"OpenPorchSF\": 253, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2740, \"PID\": 905451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 348, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2741, \"PID\": 905451410, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10519, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1057.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2742, \"PID\": 905452140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 325.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136900}, {\"Order\": 2743, \"PID\": 905452150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 532.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 541, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2744, \"PID\": 905475150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 6420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 2745, \"PID\": 905477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 2746, \"PID\": 905480160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 454, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91500}, {\"Order\": 2747, \"PID\": 906202040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 40.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2748, \"PID\": 906204180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1246, \"LowQualFinSF\": 0, \"GrLivArea\": 2559, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 245, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 209000}, {\"Order\": 2749, \"PID\": 906223180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9554, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1911, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2750, \"PID\": 906225180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 261.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1083.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 2751, \"PID\": 906380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 133.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1308.0, \"TotalBsmtSF\": 1308.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 848.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229800}, {\"Order\": 2752, \"PID\": 906380150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 393.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 183600}, {\"Order\": 2753, \"PID\": 906380170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7406, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 515.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 2754, \"PID\": 906380180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193879}, {\"Order\": 2755, \"PID\": 906382030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221500}, {\"Order\": 2756, \"PID\": 906382040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204900}, {\"Order\": 2757, \"PID\": 906382050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 571, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239799}, {\"Order\": 2758, \"PID\": 906392090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13377, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 260.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233555}, {\"Order\": 2759, \"PID\": 906392100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2760, \"PID\": 906392120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1122.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 1570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1590, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294900}, {\"Order\": 2761, \"PID\": 906394010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1809, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 209700}, {\"Order\": 2762, \"PID\": 906394040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1558.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2763, \"PID\": 906394060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 532.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2764, \"PID\": 906420020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 119.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 927, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1915, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 2765, \"PID\": 906426090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 36500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 812.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 198, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2766, \"PID\": 906475050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Metal\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 130, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2767, \"PID\": 906475200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 70761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 1533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1533, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2768, \"PID\": 906476140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 853.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 535.0, \"TotalBsmtSF\": 1388.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1388, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 2769, \"PID\": 907125020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2770, \"PID\": 907125080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2771, \"PID\": 907130110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 795, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 413, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2772, \"PID\": 907131070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 579.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 2773, \"PID\": 907135230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 13568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 274.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2774, \"PID\": 907175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2775, \"PID\": 907175060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2776, \"PID\": 907180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2777, \"PID\": 907181090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9272, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1749, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2778, \"PID\": 907187010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 13426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 57.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 107, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2779, \"PID\": 907192010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2780, \"PID\": 907194130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 2781, \"PID\": 907196020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1541.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 468, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 2782, \"PID\": 907200170, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 428.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2783, \"PID\": 907201160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 62.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 317.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2784, \"PID\": 907201230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2785, \"PID\": 907202140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 971.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 971, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2786, \"PID\": 907203010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 9560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2787, \"PID\": 907203040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 149900}, {\"Order\": 2788, \"PID\": 907227090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2789, \"PID\": 907230240, \"MSSubClass\": 160, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 3612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Landmrk\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2790, \"PID\": 907251100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 1989, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2791, \"PID\": 907252050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 199.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 826.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2792, \"PID\": 907254050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 9468, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2793, \"PID\": 907255010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2794, \"PID\": 907255050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1787, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1787, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2795, \"PID\": 907262080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8726, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 1909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2796, \"PID\": 907265030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 668.0, \"TotalBsmtSF\": 1654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1654, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2797, \"PID\": 907270050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10566, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 1124, \"LowQualFinSF\": 0, \"GrLivArea\": 2214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 646.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268500}, {\"Order\": 2798, \"PID\": 907275030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210900}, {\"Order\": 2799, \"PID\": 907285010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 258.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1070, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 2800, \"PID\": 907285100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 1045, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 2801, \"PID\": 907290020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 989, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274300}, {\"Order\": 2802, \"PID\": 907290080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216837}, {\"Order\": 2803, \"PID\": 907290160, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2804, \"PID\": 907290230, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155900}, {\"Order\": 2805, \"PID\": 907290260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1079.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 685.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233230}, {\"Order\": 2806, \"PID\": 907401050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2807, \"PID\": 907401080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2808, \"PID\": 907405030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2809, \"PID\": 907410040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8581, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203160}, {\"Order\": 2810, \"PID\": 907410100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 827, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195800}, {\"Order\": 2811, \"PID\": 907410110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212900}, {\"Order\": 2812, \"PID\": 907412010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2813, \"PID\": 907414040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198000}, {\"Order\": 2814, \"PID\": 907418020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 750, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173900}, {\"Order\": 2815, \"PID\": 907420070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 163990}, {\"Order\": 2816, \"PID\": 907420090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164990}, {\"Order\": 2817, \"PID\": 908102020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 337.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 420, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 2818, \"PID\": 908102320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 17755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2819, \"PID\": 908102330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2820, \"PID\": 908103310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 7840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 355.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2821, \"PID\": 908103320, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2822, \"PID\": 908127050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 16133, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2823, \"PID\": 908128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2824, \"PID\": 908130020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 475.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 297.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117250}, {\"Order\": 2825, \"PID\": 908178050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1150.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1150, \"LowQualFinSF\": 0, \"GrLivArea\": 2314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2826, \"PID\": 908186060, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2827, \"PID\": 908186070, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 140000}, {\"Order\": 2828, \"PID\": 908186090, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 142500}, {\"Order\": 2829, \"PID\": 908188110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2830, \"PID\": 908188120, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2831, \"PID\": 908188130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2832, \"PID\": 908188140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2833, \"PID\": 908188150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 3363, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 976.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2834, \"PID\": 908225180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6956, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 312, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 265.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97900}, {\"Order\": 2835, \"PID\": 908227010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 846, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 92000}, {\"Order\": 2836, \"PID\": 908227030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1669, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 107000}, {\"Order\": 2837, \"PID\": 908227040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 658.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 658, \"2ndFlrSF\": 526, \"LowQualFinSF\": 0, \"GrLivArea\": 1184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 81000}, {\"Order\": 2838, \"PID\": 908228040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 2839, \"PID\": 908275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 167.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2840, \"PID\": 908275290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 16012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 691.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 609.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2841, \"PID\": 909101050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 207, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2842, \"PID\": 909101080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 450, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 2843, \"PID\": 909101190, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 795.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 795, \"LowQualFinSF\": 481, \"GrLivArea\": 2230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2844, \"PID\": 909101330, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8088, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1922, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 35000}, {\"Order\": 2845, \"PID\": 909103020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 218, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2846, \"PID\": 909131125, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 7082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 980, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2847, \"PID\": 909175030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1192, \"2ndFlrSF\": 403, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2848, \"PID\": 909176180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 128.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 493, \"LowQualFinSF\": 0, \"GrLivArea\": 1551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2849, \"PID\": 909201180, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 58.0, \"LotArea\": 6430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 816, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128000}, {\"Order\": 2850, \"PID\": 909250070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 424.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 743, \"2ndFlrSF\": 736, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 530, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2851, \"PID\": 909250120, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 892, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138887}, {\"Order\": 2852, \"PID\": 909250200, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 4899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 2853, \"PID\": 909250210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 514, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2854, \"PID\": 909253080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9399, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 818, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1919.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2855, \"PID\": 909254070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 901, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200100}, {\"Order\": 2856, \"PID\": 909256010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10164, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2857, \"PID\": 909256020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2858, \"PID\": 909275230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 272, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2859, \"PID\": 909275250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 940, \"2ndFlrSF\": 610, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 429, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2860, \"PID\": 909276010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 725, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2861, \"PID\": 909276070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 113, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2862, \"PID\": 909279040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 67, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2863, \"PID\": 909280030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2864, \"PID\": 909280070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 8170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 526.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 549, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 2865, \"PID\": 909281010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1175, \"LowQualFinSF\": 0, \"GrLivArea\": 2345, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2866, \"PID\": 909282060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 104, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 2867, \"PID\": 909282110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 14210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 697, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 365.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2868, \"PID\": 909425120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 296.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 547.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1811, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 230000}, {\"Order\": 2869, \"PID\": 909425180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 459.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1283.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2870, \"PID\": 909426060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 405.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2871, \"PID\": 909428110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 375.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2872, \"PID\": 909475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 734.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 2873, \"PID\": 910200020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 102000}, {\"Order\": 2874, \"PID\": 910200060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 132, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145400}, {\"Order\": 2875, \"PID\": 910203100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 61.0, \"LotArea\": 8534, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72000}, {\"Order\": 2876, \"PID\": 910203230, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 272.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 2877, \"PID\": 910207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8765, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 327.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 106500}, {\"Order\": 2878, \"PID\": 910226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 327.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2879, \"PID\": 911175360, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 439, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 47, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2880, \"PID\": 911175410, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 69.0, \"LotArea\": 12366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 23, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 51689}, {\"Order\": 2881, \"PID\": 911175430, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 35311}, {\"Order\": 2882, \"PID\": 911175440, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2883, \"PID\": 911225110, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 360, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 2884, \"PID\": 911370430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5748, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1778, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2885, \"PID\": 911370530, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2886, \"PID\": 913350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 23580, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242500}, {\"Order\": 2887, \"PID\": 914452060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1664.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2888, \"PID\": 914474020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9116, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 2889, \"PID\": 914476050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2890, \"PID\": 914476130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 11080, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 257.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2891, \"PID\": 914476500, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1907.0, \"TotalBsmtSF\": 1907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1959, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 766.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 171000}, {\"Order\": 2892, \"PID\": 916225130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 26178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 293.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1210.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 1281, \"LowQualFinSF\": 0, \"GrLivArea\": 2519, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 2893, \"PID\": 916252170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2894, \"PID\": 916325040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 50102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 909.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1650, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 250764}, {\"Order\": 2895, \"PID\": 916326010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 653.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1686.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 574, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2896, \"PID\": 916402125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 13811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2897, \"PID\": 916403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1309.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2898, \"PID\": 916403130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2514, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 693.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2899, \"PID\": 916460070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1136.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 129.0, \"TotalBsmtSF\": 1381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2900, \"PID\": 916475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 630.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 2901, \"PID\": 916477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13618, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2902, \"PID\": 921205030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11443, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2028, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 326, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 369900}, {\"Order\": 2903, \"PID\": 921205050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 382.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 225, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 359900}, {\"Order\": 2904, \"PID\": 923125030, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 125.0, \"LotArea\": 31250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81500}, {\"Order\": 2905, \"PID\": 923202025, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1243.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 45.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2906, \"PID\": 923203090, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 897.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 125, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2907, \"PID\": 923203100, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 443.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 405.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 199, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2908, \"PID\": 923205120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 17217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84500}, {\"Order\": 2909, \"PID\": 923225190, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2910, \"PID\": 923225240, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 173.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 757.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2911, \"PID\": 923225260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 3964, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 837.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 1230, \"LowQualFinSF\": 0, \"GrLivArea\": 2521, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 728, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151400}, {\"Order\": 2912, \"PID\": 923225510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 2913, \"PID\": 923226150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1503.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2914, \"PID\": 923226180, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 2915, \"PID\": 923226290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79400}, {\"Order\": 2916, \"PID\": 923227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2917, \"PID\": 923228130, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 92000}, {\"Order\": 2918, \"PID\": 923228180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 87550}, {\"Order\": 2919, \"PID\": 923228210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 2920, \"PID\": 923228260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90500}, {\"Order\": 2921, \"PID\": 923228310, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1894, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 71000}, {\"Order\": 2922, \"PID\": 923229110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 12640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 396.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150900}, {\"Order\": 2923, \"PID\": 923230040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9297, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 188000}, {\"Order\": 2924, \"PID\": 923250060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2925, \"PID\": 923251180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 20000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 131000}, {\"Order\": 2926, \"PID\": 923275080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 7937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1003.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1003, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1003, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2927, \"PID\": 923276100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 324.0, \"BsmtUnfSF\": 239.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2928, \"PID\": 923400125, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2929, \"PID\": 924100070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1071.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 123.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1389, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2930, \"PID\": 924151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 1004, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "input_dropdown = alt.binding_select(options=list(train['KitchenQual'].unique()), name='Lot Shape')\n",
        "selection = alt.selection_point(fields=['KitchenQual'], bind=input_dropdown)\n",
        "color = alt.condition(selection,\n",
        "                      alt.Color('KitchenQual:N', legend=None),\n",
        "                      alt.value('lightgray'))\n",
        "\n",
        "alt.Chart(train).mark_point().encode(\n",
        "    x='GrLivArea',\n",
        "    y='SalePrice',\n",
        "    color=color,\n",
        "    tooltip=['GrLivArea', 'SalePrice']\n",
        ").properties(\n",
        "    width=500,\n",
        "    height=300\n",
        ").add_params(\n",
        "    selection\n",
        ").configure_axis(\n",
        "    grid=False\n",
        ")"
      ],
      "id": "cell-14"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Interactive Chart with Cross-Highlight\n",
        "\n",
        "In this more advanced example, I use the `ExterQual` feature as a filter\n",
        "for a **binned heatmap**.\n",
        "\n",
        "**Click** on the bar chart **bars to change the heatmap**!"
      ],
      "id": "5c724455-bbcc-4daa-852d-05853846f353"
    },
    {
      "cell_type": "code",
      "execution_count": 20,
      "metadata": {
        "cell_id": "25897f77e03944b7943fba581e026667",
        "deepnote_cell_type": "code",
        "deepnote_to_be_reexecuted": false,
        "execution_millis": 448,
        "execution_start": 1685107099575,
        "papermill": {
          "duration": 0.64424,
          "end_time": "2023-01-11T23:38:31.479623",
          "exception": false,
          "start_time": "2023-01-11T23:38:30.835383",
          "status": "completed"
        },
        "source_hash": "37c53526",
        "tags": []
      },
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-5f12132c29b84fe1b6fc15e58d5ccd6b.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-5f12132c29b84fe1b6fc15e58d5ccd6b.vega-embed details,\n",
              "  #altair-viz-5f12132c29b84fe1b6fc15e58d5ccd6b.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-5f12132c29b84fe1b6fc15e58d5ccd6b\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-5f12132c29b84fe1b6fc15e58d5ccd6b\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-5f12132c29b84fe1b6fc15e58d5ccd6b\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"axis\": {\"grid\": false}}, \"vconcat\": [{\"mark\": {\"type\": \"rect\"}, \"encoding\": {\"color\": {\"aggregate\": \"average\", \"field\": \"SalePrice\", \"type\": \"quantitative\"}, \"x\": {\"bin\": {\"maxbins\": 40}, \"field\": \"GrLivArea\", \"type\": \"quantitative\"}, \"y\": {\"bin\": {\"maxbins\": 40}, \"field\": \"GarageArea\", \"type\": \"quantitative\"}}, \"height\": 300, \"transform\": [{\"filter\": {\"param\": \"param_7\"}}], \"width\": 500}, {\"mark\": {\"type\": \"bar\"}, \"encoding\": {\"color\": {\"condition\": {\"param\": \"param_7\", \"value\": \"steelblue\"}, \"value\": \"grey\"}, \"tooltip\": [{\"field\": \"ExterQual\", \"type\": \"nominal\"}, {\"aggregate\": \"count\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"ExterQual\", \"type\": \"nominal\"}, \"y\": {\"aggregate\": \"count\", \"type\": \"quantitative\"}}, \"height\": 200, \"name\": \"view_5\", \"width\": 550}], \"data\": {\"name\": \"data-bd4440f2bd659840503c9701cdb81363\"}, \"params\": [{\"name\": \"param_7\", \"select\": {\"type\": \"point\", \"encodings\": [\"x\"]}, \"views\": [\"view_5\"]}], \"resolve\": {\"legend\": {\"color\": \"independent\", \"size\": \"independent\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-bd4440f2bd659840503c9701cdb81363\": [{\"Order\": 1, \"PID\": 526301100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 141.0, \"LotArea\": 31770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2, \"PID\": 526350040, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 80.0, \"LotArea\": 11622, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 3, \"PID\": 526351010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 393, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 12500, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 4, \"PID\": 526353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1045.0, \"TotalBsmtSF\": 2110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 5, \"PID\": 527105010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189900}, {\"Order\": 6, \"PID\": 527105030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 7, \"PID\": 527127150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 8, \"PID\": 527145080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 263.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191500}, {\"Order\": 9, \"PID\": 527146030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1180.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 10, \"PID\": 527162130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 776, \"LowQualFinSF\": 0, \"GrLivArea\": 1804, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 11, \"PID\": 527163010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 763, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1655, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 157, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 12, \"PID\": 527165230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1992, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 935.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 233.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 13, \"PID\": 527166040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180400}, {\"Order\": 14, \"PID\": 527180040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 15, \"PID\": 527182190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 1120.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 16, \"PID\": 527216070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 53504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 603.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1690, \"2ndFlrSF\": 1589, \"LowQualFinSF\": 0, \"GrLivArea\": 3279, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 841.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 503, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 538000}, {\"Order\": 17, \"PID\": 527225035, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 152.0, \"LotArea\": 12134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1988, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 427.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 325, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 18, \"PID\": 527258010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 2, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 1856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394432}, {\"Order\": 19, \"PID\": 527276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 19138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 20, \"PID\": 527302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 163.0, \"BsmtUnfSF\": 589.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 21, \"PID\": 527358140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 22, \"PID\": 527358200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 81.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 885.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1173, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 170000}, {\"Order\": 23, \"PID\": 527368020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 814, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 24, \"PID\": 527402200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11241, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 25, \"PID\": 527402250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12537, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 26, \"PID\": 527403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 27, \"PID\": 527404120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 78.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 28, \"PID\": 527425090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 29, \"PID\": 527427230, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 5858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1051.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 30, \"PID\": 527451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 327.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 31, \"PID\": 527451330, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 32, \"PID\": 527451410, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 381.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 88000}, {\"Order\": 33, \"PID\": 527452190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 709.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 34, \"PID\": 527453130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 514.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 35, \"PID\": 527453150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 836.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 36, \"PID\": 527454200, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 37, \"PID\": 528108120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1590.0, \"TotalBsmtSF\": 1590.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1627, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 2334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 376162}, {\"Order\": 38, \"PID\": 528112020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 39, \"PID\": 528120060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1940, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395192}, {\"Order\": 40, \"PID\": 528120090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1544.0, \"TotalBsmtSF\": 1544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290941}, {\"Order\": 41, \"PID\": 528120100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 220000}, {\"Order\": 42, \"PID\": 528120120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 615.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 43, \"PID\": 528138020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1794.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1822, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259000}, {\"Order\": 44, \"PID\": 528138060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1515.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 45, \"PID\": 528150070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12919, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 760.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 2330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 611657}, {\"Order\": 46, \"PID\": 528175010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6371, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224000}, {\"Order\": 47, \"PID\": 528176010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1095.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1473.0, \"TotalBsmtSF\": 2846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 958.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 500000}, {\"Order\": 48, \"PID\": 528176070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 563, \"LowQualFinSF\": 0, \"GrLivArea\": 2250, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 49, \"PID\": 528180070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 412.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1296.0, \"TotalBsmtSF\": 1752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 50, \"PID\": 528181050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 7132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 51, \"PID\": 528188120, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 52, \"PID\": 528218150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 18494, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1324.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 53, \"PID\": 528228285, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 54, \"PID\": 528228440, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 55, \"PID\": 528231020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 58.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 56, \"PID\": 528240070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 1100, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216500}, {\"Order\": 57, \"PID\": 528240130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185088}, {\"Order\": 58, \"PID\": 528250100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 59, \"PID\": 528292020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9505, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 1151, \"LowQualFinSF\": 0, \"GrLivArea\": 2035, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 60, \"PID\": 528328100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 14774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1393.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2599, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 668, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 333168}, {\"Order\": 61, \"PID\": 528344070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 17433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1629.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1645, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 2475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 962.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 23, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 62, \"PID\": 528358010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 919.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 56, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260400}, {\"Order\": 63, \"PID\": 528363130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 1122, \"LowQualFinSF\": 0, \"GrLivArea\": 2622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 64, \"PID\": 528382020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1999, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 348.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1106, \"LowQualFinSF\": 0, \"GrLivArea\": 2270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 671.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 65, \"PID\": 528382030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 66, \"PID\": 528386040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 14720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 579.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1217.0, \"TotalBsmtSF\": 2033.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2053, \"2ndFlrSF\": 1185, \"LowQualFinSF\": 0, \"GrLivArea\": 3238, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 283, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 67, \"PID\": 528445060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8987, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221500}, {\"Order\": 68, \"PID\": 528456160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 92.0, \"LotArea\": 9215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204500}, {\"Order\": 69, \"PID\": 528458070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1547, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215200}, {\"Order\": 70, \"PID\": 528458110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 488.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1566, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 71, \"PID\": 528477080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 12552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 222.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 956, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 72, \"PID\": 528480090, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271500}, {\"Order\": 73, \"PID\": 531367050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 956.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233000}, {\"Order\": 74, \"PID\": 531369060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 75, \"PID\": 531380080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 76, \"PID\": 531451110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 543.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 119.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 77, \"PID\": 531451280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 635, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 78, \"PID\": 531452020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 79, \"PID\": 531452050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 353, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 80, \"PID\": 531452180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1744, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 238, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 81, \"PID\": 531453010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 82, \"PID\": 531453040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 83, \"PID\": 531477050, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67500}, {\"Order\": 84, \"PID\": 532351140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1318, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 85, \"PID\": 532354090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 899.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1155, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1155, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 86, \"PID\": 532376160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 416, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 87, \"PID\": 532377060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 31.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 88, \"PID\": 532377100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 220, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 89, \"PID\": 532378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6897, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 90, \"PID\": 532479070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 15410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 126.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 859.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 169000}, {\"Order\": 91, \"PID\": 533130020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10186, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 92, \"PID\": 533130130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 981.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1231.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2349, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 362500}, {\"Order\": 93, \"PID\": 533130160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1129.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 823, \"LowQualFinSF\": 0, \"GrLivArea\": 2225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 713.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 94, \"PID\": 533205060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 25.0, \"LotArea\": 4835, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 95, \"PID\": 533208090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 39.0, \"LotArea\": 3515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 96, \"PID\": 533210060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3215, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 97, \"PID\": 533212010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 98, \"PID\": 533212020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 99, \"PID\": 533212060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 376.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 100, \"PID\": 533213030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 101, \"PID\": 533221090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 102, \"PID\": 533221110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1159.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 466.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 103, \"PID\": 533223020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 696, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 104, \"PID\": 533223100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 244.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147110}, {\"Order\": 105, \"PID\": 533238045, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 57.0, \"LotArea\": 12853, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 1642.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 224, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267916}, {\"Order\": 106, \"PID\": 533244030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 7379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 107, \"PID\": 533253060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 4420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 108, \"PID\": 533253210, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1052.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 223, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 109, \"PID\": 533352170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13517, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 475.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 110, \"PID\": 534102025, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 659.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 111, \"PID\": 534129040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1323.0, \"TotalBsmtSF\": 1829.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1829, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 535.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218500}, {\"Order\": 112, \"PID\": 534151175, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1137.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243500}, {\"Order\": 113, \"PID\": 534152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 114, \"PID\": 534152070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 687.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 46.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 1891, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 115, \"PID\": 534152100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10421, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 394.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 734, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 66, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 116, \"PID\": 534176060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 982.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 1161.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1381, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1381, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 117, \"PID\": 534176230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 715, \"LowQualFinSF\": 0, \"GrLivArea\": 1645, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 118, \"PID\": 534202160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142250}, {\"Order\": 119, \"PID\": 534251320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 451.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 81.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1328.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 120, \"PID\": 534276360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128950}, {\"Order\": 121, \"PID\": 534401110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1209, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 122, \"PID\": 534401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 9680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1510, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 123, \"PID\": 534403360, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10600, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136300}, {\"Order\": 124, \"PID\": 534403410, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14112, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1014.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 227, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 125, \"PID\": 534425310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 156.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 126, \"PID\": 534427010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 13260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 127, \"PID\": 534430080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 49.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1029.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142125}, {\"Order\": 128, \"PID\": 534431050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 670.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1929, \"2ndFlrSF\": 532, \"LowQualFinSF\": 0, \"GrLivArea\": 2461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197600}, {\"Order\": 129, \"PID\": 534431070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 17360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1019, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 130, \"PID\": 534450180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 131, \"PID\": 534451150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1940, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 263, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76500}, {\"Order\": 132, \"PID\": 534475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 133, \"PID\": 534476260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 132.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 189, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 134, \"PID\": 534479320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 244.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 135, \"PID\": 535101020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 136, \"PID\": 535106190, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 361.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1169, \"LowQualFinSF\": 0, \"GrLivArea\": 2274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154300}, {\"Order\": 137, \"PID\": 535125010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 287.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 912.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1947.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2207, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 301, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 138, \"PID\": 535126040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 137.0, \"LotArea\": 16492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 713.0, \"BsmtUnfSF\": 557.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 139, \"PID\": 535152010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1604.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 140, \"PID\": 535152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 300, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 141, \"PID\": 535152130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 142, \"PID\": 535152150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 143, \"PID\": 535152250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 144, \"PID\": 535153070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1194.0, \"TotalBsmtSF\": 1194.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 145, \"PID\": 535154050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142000}, {\"Order\": 146, \"PID\": 535175070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 324.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 571.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 143, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 147, \"PID\": 535175180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10725, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 91.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1206, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108538}, {\"Order\": 148, \"PID\": 535179020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 149, \"PID\": 535180130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 832, \"2ndFlrSF\": 505, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 263.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 150, \"PID\": 535302080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 339.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 151, \"PID\": 535302200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 119.0, \"LotArea\": 10895, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 152, \"PID\": 535304060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 153, \"PID\": 535304180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 731.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109000}, {\"Order\": 154, \"PID\": 535325400, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 155, \"PID\": 535327140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 156, \"PID\": 535350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 362.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 157, \"PID\": 535350040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 5868, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 158, \"PID\": 535353190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 17503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97500}, {\"Order\": 159, \"PID\": 535377090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 160, \"PID\": 535401080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 72.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 258.0, \"BsmtUnfSF\": 733.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 161, \"PID\": 535425010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 1080, \"LowQualFinSF\": 0, \"GrLivArea\": 2978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 162, \"PID\": 535450210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 481.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 163, \"PID\": 535453070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 906.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 164, \"PID\": 535454070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 475, \"LowQualFinSF\": 0, \"GrLivArea\": 1385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 165, \"PID\": 535456110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 486.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134800}, {\"Order\": 166, \"PID\": 535457010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1116.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 385, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 167, \"PID\": 535457090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 7635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 350.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 168, \"PID\": 535476350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 263.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1395, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 657, \"OpenPorchSF\": 0, \"EnclosedPorch\": 113, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 169, \"PID\": 535477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 170, \"PID\": 902102100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 771.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80400}, {\"Order\": 171, \"PID\": 902104060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 172, \"PID\": 902106130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4485, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 579.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 51, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 173, \"PID\": 902106140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1028, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 130, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 174, \"PID\": 902110090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 5805, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1073.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1347, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 175, \"PID\": 902125080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1605, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107400}, {\"Order\": 176, \"PID\": 902125160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 4608, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 177, \"PID\": 902128170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 294.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 804, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 178, \"PID\": 902206040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 692.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 390, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 179, \"PID\": 902206130, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 827.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 180, \"PID\": 902206220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 606, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 181, \"PID\": 902206240, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 185, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 334, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 182, \"PID\": 902207130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1923, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 780.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 12789}, {\"Order\": 183, \"PID\": 902207140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1928, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105900}, {\"Order\": 184, \"PID\": 902305110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 228, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 185, \"PID\": 902327040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 966, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 186, \"PID\": 902329030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 187, \"PID\": 902401060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 18, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 188, \"PID\": 902402010, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 7407, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 923.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149700}, {\"Order\": 189, \"PID\": 902402130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 622, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 190, \"PID\": 902402250, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1885, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 777.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 191, \"PID\": 902403070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140750}, {\"Order\": 192, \"PID\": 903204040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1030, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 363.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 193, \"PID\": 903206120, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 194, \"PID\": 903225150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 765, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 765, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 195, \"PID\": 903226160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 452.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 12.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 134000}, {\"Order\": 196, \"PID\": 903227020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 197, \"PID\": 903227150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 955, \"2ndFlrSF\": 498, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 148, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 198, \"PID\": 903228150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 221, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 199, \"PID\": 903232190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 548, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 200, \"PID\": 903233120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 928, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138400}, {\"Order\": 201, \"PID\": 903234050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 164.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 202, \"PID\": 903425110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 10300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 11, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 203, \"PID\": 903426180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 888.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 1074, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 364, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 204, \"PID\": 903426200, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 205, \"PID\": 903430080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 3068, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 662, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 206, \"PID\": 903450110, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 110.0, \"LotArea\": 8472, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 207, \"PID\": 903454060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 372, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3500, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 208, \"PID\": 903476030, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 7630, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 209, \"PID\": 904100140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1032.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 1196, \"LowQualFinSF\": 0, \"GrLivArea\": 2403, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 0, \"EnclosedPorch\": 318, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 244400}, {\"Order\": 210, \"PID\": 904101110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 365.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 211, \"PID\": 904300150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 499, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Po\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 212, \"PID\": 904302260, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1026.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 180, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 213, \"PID\": 904350045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 214, \"PID\": 904351040, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 6449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1907, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 73.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93369}, {\"Order\": 215, \"PID\": 904352190, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 6048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114900}, {\"Order\": 216, \"PID\": 905101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 6342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1875, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94000}, {\"Order\": 217, \"PID\": 905101300, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1832, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 218, \"PID\": 905101310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1768.0, \"TotalBsmtSF\": 1768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 219, \"PID\": 905102060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 1039.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 220, \"PID\": 905103060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11341, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1302.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 221, \"PID\": 905104210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8521, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 842.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 222, \"PID\": 905105070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 668.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 223, \"PID\": 905105200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 47.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 474.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 224, \"PID\": 905106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 663, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 379, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 225, \"PID\": 905106170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137250}, {\"Order\": 226, \"PID\": 905107110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7424, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1373, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1373, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160250}, {\"Order\": 227, \"PID\": 905107250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 453.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 228, \"PID\": 905107320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 328.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1386, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 229, \"PID\": 905109130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 954, \"LowQualFinSF\": 0, \"GrLivArea\": 2260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 328000}, {\"Order\": 230, \"PID\": 905109170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1092.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1483, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1483, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 496, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 231, \"PID\": 905201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 756, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 232, \"PID\": 905202090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 233, \"PID\": 905325030, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23595, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 74.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 192, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 234, \"PID\": 905352140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 336, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 235, \"PID\": 905378040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 18600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 684.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 558, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 236, \"PID\": 905426060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 108.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 835, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 237, \"PID\": 905426200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11479, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 387.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 238, \"PID\": 905451320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 44, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 239, \"PID\": 905452110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 362, \"GrLivArea\": 1531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 209.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 240, \"PID\": 905452160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 954.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 1172.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1172, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 241, \"PID\": 905453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1176.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 242, \"PID\": 905453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 17485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1508, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Partial\", \"SalePrice\": 308030}, {\"Order\": 243, \"PID\": 905475510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1250.0, \"TotalBsmtSF\": 1250.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 244, \"PID\": 905478190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 245, \"PID\": 906201030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 977, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1732, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 246, \"PID\": 906201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 11980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 177.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1433.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1433.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 278, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 247, \"PID\": 906204230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 12361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 86.0, \"TotalBsmtSF\": 946.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1017.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 450, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 248, \"PID\": 906223090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 750.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 249, \"PID\": 906225210, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 250, \"PID\": 906378100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245350}, {\"Order\": 251, \"PID\": 906380190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 252, \"PID\": 906385010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 10402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 740.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198900}, {\"Order\": 253, \"PID\": 906385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1222.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1222, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 254, \"PID\": 906402200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12376, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1470.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 1523, \"LowQualFinSF\": 0, \"GrLivArea\": 3222, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 367, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 255, \"PID\": 906425045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 14235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 614, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 256, \"PID\": 906477110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 257, \"PID\": 907125090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 71, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 258, \"PID\": 907180050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 878.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 259, \"PID\": 907185060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 260, \"PID\": 907200280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 15240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 688.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 261, \"PID\": 907200290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161750}, {\"Order\": 262, \"PID\": 907200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 365, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128200}, {\"Order\": 263, \"PID\": 907203070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 264, \"PID\": 907250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 296.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 265, \"PID\": 907252120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 479.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1581.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 266, \"PID\": 907262050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 9548, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 223.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 458.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 613.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 267, \"PID\": 907280040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 331, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 268, \"PID\": 907290040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1649.0, \"TotalBsmtSF\": 1649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 269, \"PID\": 907290170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 270, \"PID\": 907290240, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 271, \"PID\": 907401090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 10635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 972.0, \"BsmtUnfSF\": 315.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 262, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 272, \"PID\": 907410080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 109.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 761.0, \"TotalBsmtSF\": 1473.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 273, \"PID\": 907414030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185500}, {\"Order\": 274, \"PID\": 908102060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 84900}, {\"Order\": 275, \"PID\": 908102110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 155891}, {\"Order\": 276, \"PID\": 908102130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 277, \"PID\": 908102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 278, \"PID\": 908102300, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 792, \"2ndFlrSF\": 328, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 64000}, {\"Order\": 279, \"PID\": 908103350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125200}, {\"Order\": 280, \"PID\": 908152080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 7819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 422.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 281, \"PID\": 908203100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 282, \"PID\": 908208020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 8546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1121.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 283, \"PID\": 908225320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 94.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1487, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 284, \"PID\": 908226130, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 285, \"PID\": 908275300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1526, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 286, \"PID\": 909100080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 4853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 974.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 287, \"PID\": 909100110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 841, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 288, \"PID\": 909101070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 289, \"PID\": 909176140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 242, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 290, \"PID\": 909176150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 166, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 291, \"PID\": 909177100, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 862, \"2ndFlrSF\": 1788, \"LowQualFinSF\": 0, \"GrLivArea\": 2650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 292, \"PID\": 909250030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 293, \"PID\": 909250060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 804.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 2447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 294, \"PID\": 909281080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 371.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 86, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 295, \"PID\": 909426080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 657.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1075, \"LowQualFinSF\": 0, \"GrLivArea\": 2177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 296, \"PID\": 909427230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 877.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 1152, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266500}, {\"Order\": 297, \"PID\": 909428280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 207, \"EnclosedPorch\": 162, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 298, \"PID\": 909452114, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 423.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203135}, {\"Order\": 299, \"PID\": 909455030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 300, \"PID\": 909455040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 76.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1115.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1191, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1191, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 301, \"PID\": 909475140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15602, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1801, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 289000}, {\"Order\": 302, \"PID\": 910202060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 61.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 358, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 303, \"PID\": 910203250, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 540, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 304, \"PID\": 910205120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 727, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 305, \"PID\": 911128180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 68400}, {\"Order\": 306, \"PID\": 911202100, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 859.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 859, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 102776}, {\"Order\": 307, \"PID\": 911204090, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 54, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 55993}, {\"Order\": 308, \"PID\": 911204100, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1896, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1896.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 265, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 50138}, {\"Order\": 309, \"PID\": 911370510, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246000}, {\"Order\": 310, \"PID\": 914467040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 615.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1916, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 741.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 311, \"PID\": 914475090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9620, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1243.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 375, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 80, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 312, \"PID\": 914476520, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 9196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 313, \"PID\": 914478045, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 473.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169900}, {\"Order\": 314, \"PID\": 914478110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1958.0, \"TotalBsmtSF\": 1958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 315, \"PID\": 916125360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 57200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 334.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 50, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 316, \"PID\": 916386010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 78.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1346, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 317, \"PID\": 916386020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1214.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179781}, {\"Order\": 318, \"PID\": 916386060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 319, \"PID\": 916386090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 774.0, \"TotalBsmtSF\": 774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 1194, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 269500}, {\"Order\": 320, \"PID\": 916455170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 1894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214900}, {\"Order\": 321, \"PID\": 916475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202900}, {\"Order\": 322, \"PID\": 921128020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 13214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2002.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2018, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2018, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378500}, {\"Order\": 323, \"PID\": 923201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 42.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 324, \"PID\": 923202105, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10114, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1430.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 325, \"PID\": 923204150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 326, \"PID\": 923205015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1344.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166500}, {\"Order\": 327, \"PID\": 923225300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83500}, {\"Order\": 328, \"PID\": 923225390, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 31.0, \"LotArea\": 2394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 945, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 329, \"PID\": 923225440, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 2592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 129.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 232.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 536, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 330, \"PID\": 923226250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 331, \"PID\": 923226320, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1491, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75500}, {\"Order\": 332, \"PID\": 923228270, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88250}, {\"Order\": 333, \"PID\": 923228370, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 334, \"PID\": 923230190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 469.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 335, \"PID\": 923251080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 26142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 336, \"PID\": 923276030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 207.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 337, \"PID\": 923276250, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1985, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1216.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 338, \"PID\": 923426070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 22, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 339, \"PID\": 924100050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 388.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 615, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 287, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 340, \"PID\": 924151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1341.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 284.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1679.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 64, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 341, \"PID\": 924152030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12961, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 342, \"PID\": 526302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 343, \"PID\": 526351100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 440.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 844.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 344, \"PID\": 526355080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 542.0, \"TotalBsmtSF\": 1952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 2704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 269, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 345, \"PID\": 527105070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 346, \"PID\": 527105130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 1275, \"LowQualFinSF\": 0, \"GrLivArea\": 2283, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 347, \"PID\": 527107130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1628, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 490, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 348, \"PID\": 527108070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 14892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1746, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377500}, {\"Order\": 349, \"PID\": 527110020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 22.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 350, \"PID\": 527127100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 28.0, \"LotArea\": 7296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 243.0, \"TotalBsmtSF\": 2208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2522, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 351, \"PID\": 527131030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 5664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1659, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 352, \"PID\": 527132090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 353, \"PID\": 527146010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 354, \"PID\": 527161040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 355, \"PID\": 527162110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 94, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 291, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 356, \"PID\": 527162120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 357, \"PID\": 527163040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 799.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 799, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 358, \"PID\": 527163070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 359, \"PID\": 527163130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181316}, {\"Order\": 360, \"PID\": 527164020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 7250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 361, \"PID\": 527164060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 362, \"PID\": 527164090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 702, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1481, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 363, \"PID\": 527165130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 364, \"PID\": 527166010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 694.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 1983, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 365, \"PID\": 527180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1424.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 508, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 366, \"PID\": 527182110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 187500}, {\"Order\": 367, \"PID\": 527214050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 17423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 748.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 2216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1166.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 501837}, {\"Order\": 368, \"PID\": 527254020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 464.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2046.0, \"TotalBsmtSF\": 2046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372500}, {\"Order\": 369, \"PID\": 527258020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 16158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 370, \"PID\": 527276160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1934, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 371, \"PID\": 527301320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 692.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 1200, \"LowQualFinSF\": 0, \"GrLivArea\": 2353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 372, \"PID\": 527302175, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 17043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1586, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 373, \"PID\": 527326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 82500}, {\"Order\": 374, \"PID\": 527326150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 375, \"PID\": 527352150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 154000}, {\"Order\": 376, \"PID\": 527353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 363.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 377, \"PID\": 527353060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 229.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1539, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2673, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 378, \"PID\": 527354100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 225.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 379, \"PID\": 527354200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 380, \"PID\": 527355150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1420.0, \"TotalBsmtSF\": 2524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 381, \"PID\": 527356040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157000}, {\"Order\": 382, \"PID\": 527359050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 383, \"PID\": 527359180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 448, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 384, \"PID\": 527364030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1016, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 581.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240900}, {\"Order\": 385, \"PID\": 527365030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 8004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 1103, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 263435}, {\"Order\": 386, \"PID\": 527366030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1058.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 387, \"PID\": 527368010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 225.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 471.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 839, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 388, \"PID\": 527375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1333.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 490, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 389, \"PID\": 527375180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 888.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 390, \"PID\": 527375210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 391, \"PID\": 527376100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 392, \"PID\": 527378140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 333.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 2119, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158000}, {\"Order\": 393, \"PID\": 527401160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 394, \"PID\": 527402220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1002, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 902.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 395, \"PID\": 527403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 439.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 472.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 396, \"PID\": 527404020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1180.0, \"TotalBsmtSF\": 1180.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 397, \"PID\": 527404030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 398, \"PID\": 527405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 726.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 399, \"PID\": 527405160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 239.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 400, \"PID\": 527405180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 401, \"PID\": 527425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97000}, {\"Order\": 402, \"PID\": 527425110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 403, \"PID\": 527450280, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 254.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 404, \"PID\": 527451110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 312.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 405, \"PID\": 527451320, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 406, \"PID\": 527451540, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 79.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 407, \"PID\": 527451640, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 510.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 408, \"PID\": 527451650, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 409, \"PID\": 527452060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 410, \"PID\": 527453050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 411, \"PID\": 527453060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 87, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 412, \"PID\": 527453140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 622.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 413, \"PID\": 527454050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 260, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 414, \"PID\": 527454130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2349, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 389.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 415, \"PID\": 527455050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 416, \"PID\": 527455060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 586, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 417, \"PID\": 527455080, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 279.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 418, \"PID\": 527455090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 345.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 419, \"PID\": 527455240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 420, \"PID\": 527455280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 421, \"PID\": 528102040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1172.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337500}, {\"Order\": 422, \"PID\": 528102140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 726.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1794, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 462000}, {\"Order\": 423, \"PID\": 528104070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 13518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 860.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1926.0, \"TotalBsmtSF\": 1926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 1174, \"LowQualFinSF\": 0, \"GrLivArea\": 3140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 485000}, {\"Order\": 424, \"PID\": 528106020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1767.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 3094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2402, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 555000}, {\"Order\": 425, \"PID\": 528106070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 404, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 426, \"PID\": 528108010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 640.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1566.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 890.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256300}, {\"Order\": 427, \"PID\": 528108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2042.0, \"TotalBsmtSF\": 2042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 253293}, {\"Order\": 428, \"PID\": 528108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1365, \"2ndFlrSF\": 1325, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 197, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 398800}, {\"Order\": 429, \"PID\": 528108070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 154.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 430, \"PID\": 528108130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 2020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 404000}, {\"Order\": 431, \"PID\": 528108140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 2006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 402861}, {\"Order\": 432, \"PID\": 528110010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 13478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1722.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 2296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 842.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 451950}, {\"Order\": 433, \"PID\": 528110020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 2630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2674, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2674, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 610000}, {\"Order\": 434, \"PID\": 528110090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 424.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1734.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 1088, \"LowQualFinSF\": 0, \"GrLivArea\": 2822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1020.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 582933}, {\"Order\": 435, \"PID\": 528112040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1736.0, \"TotalBsmtSF\": 1736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1736, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1736, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 436, \"PID\": 528116010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 99, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 296000}, {\"Order\": 437, \"PID\": 528118060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 23303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 273, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 409900}, {\"Order\": 438, \"PID\": 528120020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1709.0, \"TotalBsmtSF\": 1709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1717, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255500}, {\"Order\": 439, \"PID\": 528120030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1015.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 1739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 927.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 440, \"PID\": 528120160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 262.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274900}, {\"Order\": 441, \"PID\": 528120170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1037.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1531, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 700.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 442, \"PID\": 528138010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 13514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 285.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1142.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 1774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1808, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 443, \"PID\": 528142040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8834, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1170.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1462, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 444, \"PID\": 528142090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 11362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 862.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 185, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 445, \"PID\": 528142130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1124.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 479.0, \"BsmtUnfSF\": 1603.0, \"TotalBsmtSF\": 3206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 446, \"PID\": 528142150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12878, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 418.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 1760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1760, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 190, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 447, \"PID\": 528144020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1502.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233170}, {\"Order\": 448, \"PID\": 528166060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 922.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2336.0, \"TotalBsmtSF\": 2392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 386250}, {\"Order\": 449, \"PID\": 528166090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 724.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1972.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 2452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 886.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 445000}, {\"Order\": 450, \"PID\": 528168030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1295, \"LowQualFinSF\": 0, \"GrLivArea\": 2400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 451, \"PID\": 528172060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1598.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1606, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1606, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 452, \"PID\": 528174050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 6904, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 453, \"PID\": 528174060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 900.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 454, \"PID\": 528174070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 455, \"PID\": 528175050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 456, \"PID\": 528175060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 457, \"PID\": 528176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 730.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2146.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 2492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 949.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 552000}, {\"Order\": 458, \"PID\": 528178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 117.0, \"LotArea\": 15262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 470.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 643.0, \"TotalBsmtSF\": 2200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 685.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 382500}, {\"Order\": 459, \"PID\": 528180120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 308.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1084.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 460, \"PID\": 528180130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 461, \"PID\": 528186010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 1712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 183, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286500}, {\"Order\": 462, \"PID\": 528186180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 863.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 463, \"PID\": 528188020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 464, \"PID\": 528188060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2268, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 465, \"PID\": 528218090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 466, \"PID\": 528220040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 745.0, \"TotalBsmtSF\": 745.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 745, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167800}, {\"Order\": 467, \"PID\": 528221060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 12589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 468, \"PID\": 528221070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 469, \"PID\": 528228290, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1373.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 470, \"PID\": 528228295, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1569, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1569, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 471, \"PID\": 528228435, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1357.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 472, \"PID\": 528228450, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 473, \"PID\": 528228455, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 474, \"PID\": 528228460, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 11.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160200}, {\"Order\": 475, \"PID\": 528235010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 476, \"PID\": 528235090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1010.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1010, \"2ndFlrSF\": 1257, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 477, \"PID\": 528235200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 478, \"PID\": 528240030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 479, \"PID\": 528240060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 779, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184100}, {\"Order\": 480, \"PID\": 528240150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 481, \"PID\": 528250020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 482, \"PID\": 528250040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8174, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 483, \"PID\": 528253010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 484, \"PID\": 528275070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 1276, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 485, \"PID\": 528275160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 1126, \"LowQualFinSF\": 0, \"GrLivArea\": 2004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 486, \"PID\": 528280230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 487, \"PID\": 528290030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9734, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 113.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 488, \"PID\": 528290120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8123, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 489, \"PID\": 528290180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 8433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 683.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1514, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 490, \"PID\": 528290190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 491, \"PID\": 528292030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1177.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2312, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 492, \"PID\": 528292040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 841.0, \"TotalBsmtSF\": 841.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 493, \"PID\": 528292070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 772.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1038, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 494, \"PID\": 528294050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7848, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 495, \"PID\": 528315090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 673.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1163.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337000}, {\"Order\": 496, \"PID\": 528321010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 15138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 689.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 773.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1490, \"2ndFlrSF\": 1304, \"LowQualFinSF\": 0, \"GrLivArea\": 2794, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 403000}, {\"Order\": 497, \"PID\": 528327070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 1455.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1221, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 327000}, {\"Order\": 498, \"PID\": 528344040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 731.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2450, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1069.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 499, \"PID\": 528344100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 975.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 854.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1225.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 1336, \"LowQualFinSF\": 0, \"GrLivArea\": 2612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 336000}, {\"Order\": 500, \"PID\": 528354050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10208, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 921.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1264.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 1067, \"LowQualFinSF\": 0, \"GrLivArea\": 2344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 889.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 501, \"PID\": 528363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 634.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1526.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 2024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 815.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 502, \"PID\": 528365070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 987.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 1274, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 60, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 503, \"PID\": 528385050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 967, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 102, \"EnclosedPorch\": 209, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 504, \"PID\": 528387030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 372.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 623.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263550}, {\"Order\": 505, \"PID\": 528390100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 46589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 528.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 517, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 402000}, {\"Order\": 506, \"PID\": 528390210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 29959, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 507, \"PID\": 528427020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 244600}, {\"Order\": 508, \"PID\": 528431020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1696.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 972.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 509, \"PID\": 528431070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 294.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1614.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1658, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 510, \"PID\": 528435030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1573.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287090}, {\"Order\": 511, \"PID\": 528435050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 512, \"PID\": 528439060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 513, \"PID\": 528441020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 772.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 689.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 514, \"PID\": 528441090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2490, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 226, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 468000}, {\"Order\": 515, \"PID\": 528456180, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 920, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252678}, {\"Order\": 516, \"PID\": 528456220, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 517, \"PID\": 528456240, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7862, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 27.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208300}, {\"Order\": 518, \"PID\": 528458020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 90.0, \"LotArea\": 7993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 519, \"PID\": 528458040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229456}, {\"Order\": 520, \"PID\": 528458060, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1402.0, \"TotalBsmtSF\": 1402.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 205, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229800}, {\"Order\": 521, \"PID\": 528458140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 984.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 522, \"PID\": 528458160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 645.0, \"TotalBsmtSF\": 1766.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 195, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370878}, {\"Order\": 523, \"PID\": 528458180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1348.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1448, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1448, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238500}, {\"Order\": 524, \"PID\": 528477050, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 981, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 310000}, {\"Order\": 525, \"PID\": 528477070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 121.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 526, \"PID\": 528480040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1043.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 527, \"PID\": 528480130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 438, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241000}, {\"Order\": 528, \"PID\": 528480170, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264500}, {\"Order\": 529, \"PID\": 528482040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1662, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1662, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 530, \"PID\": 528482130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 531, \"PID\": 528488100, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1221.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 532, \"PID\": 528490040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 8736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 771.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 360.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1553.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234500}, {\"Order\": 533, \"PID\": 528490070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8127, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 841, \"LowQualFinSF\": 0, \"GrLivArea\": 1653, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 534, \"PID\": 531363010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 178, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 535, \"PID\": 531363030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1087.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 536, \"PID\": 531363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 537, \"PID\": 531369010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 871, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 538, \"PID\": 531369020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 774.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1512.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 845.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 539, \"PID\": 531371050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10083, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 540, \"PID\": 531375040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 541, \"PID\": 531375090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 542, \"PID\": 531375130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 543, \"PID\": 531376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1450, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224243}, {\"Order\": 544, \"PID\": 531379050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 11492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 1209, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 559.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 545, \"PID\": 531382070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10994, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 366.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 257000}, {\"Order\": 546, \"PID\": 531385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1434.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 547, \"PID\": 531450120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 364.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1730, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 548, \"PID\": 531452010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 626, \"2ndFlrSF\": 591, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 549, \"PID\": 531452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1332.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1332, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 550, \"PID\": 531452260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 786, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 551, \"PID\": 531453100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 141.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 465.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 552, \"PID\": 531475220, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 553, \"PID\": 531477020, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 721.0, \"TotalBsmtSF\": 721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 841, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 841, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 554, \"PID\": 531479020, \"MSSubClass\": 45, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 91, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 555, \"PID\": 532353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 884.0, \"BsmtUnfSF\": 28.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 556, \"PID\": 532353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 557, \"PID\": 532354160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 558, \"PID\": 532354230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9079, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 559, \"PID\": 532376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Family\", \"SalePrice\": 124100}, {\"Order\": 560, \"PID\": 532376110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 561, \"PID\": 532377130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131400}, {\"Order\": 562, \"PID\": 532378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 311.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 62383}, {\"Order\": 563, \"PID\": 532378180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 140.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 564, \"PID\": 532478020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15676, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1733.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 92.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 2014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 462, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 255, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 565, \"PID\": 533135020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11949, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1991, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 601.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 216.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 502, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 566, \"PID\": 533206020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 2880, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1376.0, \"TotalBsmtSF\": 1376.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1376, \"2ndFlrSF\": 1629, \"LowQualFinSF\": 0, \"GrLivArea\": 3005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 177, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280750}, {\"Order\": 567, \"PID\": 533210010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164500}, {\"Order\": 568, \"PID\": 533210020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173733}, {\"Order\": 569, \"PID\": 533213010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 3830, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1726.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 254, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 570, \"PID\": 533213020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4217, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 183.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 571, \"PID\": 533213040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 894.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1471, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 572, \"PID\": 533221040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 249.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 573, \"PID\": 533223030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 574, \"PID\": 533236050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1739, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 172500}, {\"Order\": 575, \"PID\": 533252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1252.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 136.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 501, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 225, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318750}, {\"Order\": 576, \"PID\": 533253070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 3782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211500}, {\"Order\": 577, \"PID\": 533254050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15417, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1619.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 20, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241600}, {\"Order\": 578, \"PID\": 533254110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1487, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180500}, {\"Order\": 579, \"PID\": 533352150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1281.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 580, \"PID\": 534125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 727.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 829, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 581, \"PID\": 534127130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 571.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1442.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 371, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 582, \"PID\": 534127170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9156, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185750}, {\"Order\": 583, \"PID\": 534128010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 859.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 32.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 204, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 350, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 584, \"PID\": 534128020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 782, \"LowQualFinSF\": 0, \"GrLivArea\": 2067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 585, \"PID\": 534128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 735, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 586, \"PID\": 534128190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1369, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256900}, {\"Order\": 587, \"PID\": 534129080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1724, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 588, \"PID\": 534129370, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 589, \"PID\": 534129380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 955.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113000}, {\"Order\": 590, \"PID\": 534151120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 283.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 2288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 591, \"PID\": 534152120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 592, \"PID\": 534175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1127.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 78, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213250}, {\"Order\": 593, \"PID\": 534177230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 594, \"PID\": 534200030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 595, \"PID\": 534202170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 596, \"PID\": 534226120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 466.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 597, \"PID\": 534250400, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 168500}, {\"Order\": 598, \"PID\": 534251030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 509.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 599, \"PID\": 534252240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 251.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 630.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 197, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 600, \"PID\": 534275060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 360, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 601, \"PID\": 534275100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 602, \"PID\": 534276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 603, \"PID\": 534277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 604, \"PID\": 534278070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 201.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177625}, {\"Order\": 605, \"PID\": 534278230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 606, \"PID\": 534400050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 345.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 1516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 152, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 607, \"PID\": 534400290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 217.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 512.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1313, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 121, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 608, \"PID\": 534402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1292.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1292, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145100}, {\"Order\": 609, \"PID\": 534402140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 230.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1154.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 610, \"PID\": 534402170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 549.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 611, \"PID\": 534403370, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 563.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 612, \"PID\": 534426110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 991.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 50.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 613, \"PID\": 534429150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 614, \"PID\": 534431130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 100.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 613.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 615, \"PID\": 534450150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 616, \"PID\": 534451110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 185.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 224, \"LowQualFinSF\": 0, \"GrLivArea\": 1203, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 617, \"PID\": 534475185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 1505.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1505, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 162, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 618, \"PID\": 534475250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 260, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 619, \"PID\": 534476150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 1416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 620, \"PID\": 534476320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 621, \"PID\": 534477110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 556, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 622, \"PID\": 534478230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 607.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 623, \"PID\": 535101120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 624, \"PID\": 535104120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10573, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 3.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 625, \"PID\": 535105100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 247.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1394.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1394, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 185, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 626, \"PID\": 535125070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 1562.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 342, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 627, \"PID\": 535125090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 314.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1186, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 628, \"PID\": 535126010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 576.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 2142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 252, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 629, \"PID\": 535126100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1392.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 630, \"PID\": 535150070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1281, \"2ndFlrSF\": 457, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 631, \"PID\": 535151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 313.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 632, \"PID\": 535152230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 661.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 633, \"PID\": 535154060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 203, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 634, \"PID\": 535154130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 635, \"PID\": 535175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 620.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 636, \"PID\": 535175050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1215.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 234, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 637, \"PID\": 535178040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 565.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1202, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1202, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 638, \"PID\": 535178120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 172.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 727.0, \"TotalBsmtSF\": 1382.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 639, \"PID\": 535179160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 155.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 750.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144000}, {\"Order\": 640, \"PID\": 535300120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 19296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 399.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 690.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 641, \"PID\": 535301170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 1297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1297, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1297, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 642, \"PID\": 535302120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 657.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1866.0, \"TotalBsmtSF\": 1866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 643, \"PID\": 535303110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 8128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 644, \"PID\": 535303150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10634, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1319, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1319, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 645, \"PID\": 535304100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 631.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 646, \"PID\": 535325290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1005.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 647, \"PID\": 535351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 178.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 648, \"PID\": 535352090, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 793, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 649, \"PID\": 535353040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1952, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1031.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1031, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 650, \"PID\": 535353060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102900}, {\"Order\": 651, \"PID\": 535353140, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1699, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 95000}, {\"Order\": 652, \"PID\": 535353240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 699.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 801, \"2ndFlrSF\": 726, \"LowQualFinSF\": 0, \"GrLivArea\": 1527, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 653, \"PID\": 535354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 654, \"PID\": 535354100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 655, \"PID\": 535375010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 656, \"PID\": 535375050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 704, \"LowQualFinSF\": 144, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 140, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 657, \"PID\": 535376060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 658, \"PID\": 535377150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 717, \"2ndFlrSF\": 322, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 111, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 659, \"PID\": 535378020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 9022, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1924, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 660, \"PID\": 535378120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10230, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 661, \"PID\": 535381040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 1064, \"GrLivArea\": 2377, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 432, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142900}, {\"Order\": 662, \"PID\": 535382100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 760, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 663, \"PID\": 535383060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 599, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 599, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 59000}, {\"Order\": 664, \"PID\": 535383070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 198, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 665, \"PID\": 535383110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 666, \"PID\": 535383120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 725, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78500}, {\"Order\": 667, \"PID\": 535402010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1248.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 907.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 668, \"PID\": 535402090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 996.0, \"TotalBsmtSF\": 1380.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1380, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 669, \"PID\": 535402270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 670, \"PID\": 535402330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2634, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 671, \"PID\": 535403190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1958, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 672, \"PID\": 535403210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 559.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1105, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 673, \"PID\": 535403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 674, \"PID\": 535425070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1270.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 675, \"PID\": 535426150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 676, \"PID\": 535450070, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 232, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 677, \"PID\": 535450160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 92900}, {\"Order\": 678, \"PID\": 535450200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 231, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 679, \"PID\": 535451170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 680, \"PID\": 535451250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 352.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 681, \"PID\": 535452090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1041.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 682, \"PID\": 535452100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 683, \"PID\": 535452140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 102.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 732, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118900}, {\"Order\": 684, \"PID\": 535453100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 433.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 95.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1183, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 685, \"PID\": 535453200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 686, \"PID\": 535454100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 832, \"2ndFlrSF\": 629, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 687, \"PID\": 535454160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 431, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 688, \"PID\": 535475010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 7570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1806, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144750}, {\"Order\": 689, \"PID\": 535476110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 124.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 690, \"PID\": 535476240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 7936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 826.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 691, \"PID\": 535477150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 692, \"PID\": 902101010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3950, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 693, \"PID\": 902102080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 682, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 694, \"PID\": 902103100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 4080, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 695, \"PID\": 902103120, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 972, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 696, \"PID\": 902103170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 5720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 455, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 66500}, {\"Order\": 697, \"PID\": 902105050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 496, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 698, \"PID\": 902105060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 699, \"PID\": 902106010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6406, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 269.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 868, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 700, \"PID\": 902106060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1892, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 994, \"LowQualFinSF\": 0, \"GrLivArea\": 2372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 287, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 701, \"PID\": 902109130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94550}, {\"Order\": 702, \"PID\": 902109140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7596, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1000, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 703, \"PID\": 902110080, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3378, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1946, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 651.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 682, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 704, \"PID\": 902134120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 801, \"2ndFlrSF\": 646, \"LowQualFinSF\": 0, \"GrLivArea\": 1447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 705, \"PID\": 902135020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 706, \"PID\": 902201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 707, \"PID\": 902202150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 811.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 811, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 708, \"PID\": 902204080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 709, \"PID\": 902205010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 25, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 45000}, {\"Order\": 710, \"PID\": 902205030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 37900}, {\"Order\": 711, \"PID\": 902206260, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1938, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 886, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91300}, {\"Order\": 712, \"PID\": 902207170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 713, \"PID\": 902300090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 4456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 113000}, {\"Order\": 714, \"PID\": 902301060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 677.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 715, \"PID\": 902301080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 716, \"PID\": 902325070, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1898, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 849.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 1063, \"LowQualFinSF\": 0, \"GrLivArea\": 2138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 717, \"PID\": 902326030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 181, \"OpenPorchSF\": 0, \"EnclosedPorch\": 386, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265979}, {\"Order\": 718, \"PID\": 902327070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 917.0, \"TotalBsmtSF\": 917.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 719, \"PID\": 902329080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1917, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 720, \"PID\": 902330040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 121.0, \"LotArea\": 17671, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1882, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 826, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 424.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 721, \"PID\": 902331010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 3300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 722, \"PID\": 902401130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1920, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 26.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 723, \"PID\": 902402150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 226, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 724, \"PID\": 902405100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 98.0, \"LotArea\": 8820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 561, \"LowQualFinSF\": 120, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 725, \"PID\": 902405120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 436, \"GrLivArea\": 1480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 207.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 119000}, {\"Order\": 726, \"PID\": 902406070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 238, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 727, \"PID\": 902477120, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 523, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 34900}, {\"Order\": 728, \"PID\": 902477130, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 72.0, \"LotArea\": 9392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 245.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 44000}, {\"Order\": 729, \"PID\": 903200080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 144.0, \"LotArea\": 21384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 15.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 730, \"PID\": 903201020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1022.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 731, \"PID\": 903201080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 732, \"PID\": 903202170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 244, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 733, \"PID\": 903205040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 192.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 40, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 734, \"PID\": 903226130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 735, \"PID\": 903226170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 390, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 736, \"PID\": 903227070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 737, \"PID\": 903227090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 825, \"2ndFlrSF\": 587, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 45, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 738, \"PID\": 903228070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 444.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 320, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 739, \"PID\": 903228120, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 740, \"PID\": 903230100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 741, \"PID\": 903231010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 927.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 742, \"PID\": 903231030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 989, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 54, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 743, \"PID\": 903231060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 744, \"PID\": 903231130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1931, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 745, \"PID\": 903232060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 995, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 15, \"EnclosedPorch\": 51, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 746, \"PID\": 903234220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 679.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 994, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 189, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 150, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 747, \"PID\": 903236040, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 134.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 1072.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 5.0, \"GarageArea\": 1184.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 748, \"PID\": 903400220, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11888, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 2134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 268, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214500}, {\"Order\": 749, \"PID\": 903425245, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 883, \"LowQualFinSF\": 0, \"GrLivArea\": 2019, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 509, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 750, \"PID\": 903427120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 751, \"PID\": 903429080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 2500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 752, \"PID\": 903429110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 753, \"PID\": 903430060, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 92.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 929, \"LowQualFinSF\": 371, \"GrLivArea\": 2229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 198, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 104000}, {\"Order\": 754, \"PID\": 903430070, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Sev\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 62500}, {\"Order\": 755, \"PID\": 903451090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 316.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 213, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 756, \"PID\": 903458170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 757, \"PID\": 903475100, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 758, \"PID\": 903476090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1902, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 169.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 978, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 759, \"PID\": 903481120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 760, \"PID\": 903481130, \"MSSubClass\": 85, \"MSZoning\": \"RM\", \"LotFrontage\": 86.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 749.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 63.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 70000}, {\"Order\": 761, \"PID\": 903484110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 262.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 754, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 288, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 762, \"PID\": 904100190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1946, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 704, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88750}, {\"Order\": 763, \"PID\": 904301060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 764, \"PID\": 904301070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 765, \"PID\": 904301100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 766, \"PID\": 904301375, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61000}, {\"Order\": 767, \"PID\": 904351200, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 54.0, \"LotArea\": 6629, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 551.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103600}, {\"Order\": 768, \"PID\": 904351240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 687, \"2ndFlrSF\": 425, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 226.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63000}, {\"Order\": 769, \"PID\": 905101260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12886, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 770, \"PID\": 905101490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 771, \"PID\": 905103040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 92.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 500.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1683, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 772, \"PID\": 905103070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 215, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113500}, {\"Order\": 773, \"PID\": 905105190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 774, \"PID\": 905107310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 775, \"PID\": 905108190, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7252, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 776, \"PID\": 905108220, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 860, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 777, \"PID\": 905200220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 170.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 778, \"PID\": 905200260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 611, \"LowQualFinSF\": 259, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 779, \"PID\": 905200350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15312, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 780, \"PID\": 905225090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 366.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2071, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2071, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 781, \"PID\": 905228050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63900}, {\"Order\": 782, \"PID\": 905229040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1104.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 783, \"PID\": 905325020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 25095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1473, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1473, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 60, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 143000}, {\"Order\": 784, \"PID\": 905377010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 284.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 785, \"PID\": 905377130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 786, \"PID\": 905401100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10708, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 768.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1867, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1867, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 476, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 787, \"PID\": 905402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139600}, {\"Order\": 788, \"PID\": 905402070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 789, \"PID\": 905450020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 790, \"PID\": 905451300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 340.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 791, \"PID\": 905451340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1276, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 60000}, {\"Order\": 792, \"PID\": 905452040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 747, \"LowQualFinSF\": 0, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154400}, {\"Order\": 793, \"PID\": 905452050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 344.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 794, \"PID\": 905475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1089.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1089, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 795, \"PID\": 905475500, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 290.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84000}, {\"Order\": 796, \"PID\": 905476230, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 393.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1049, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 266.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 797, \"PID\": 905478030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11409, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 798, \"PID\": 905480030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 799, \"PID\": 905480210, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 800, \"PID\": 906201021, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 286.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 801, \"PID\": 906201050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 19255, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 450.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 802, \"PID\": 906201130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1983, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 2132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316600}, {\"Order\": 803, \"PID\": 906203120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 177.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 2158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271900}, {\"Order\": 804, \"PID\": 906223060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 137.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 227.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 769, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 425.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 234, \"OpenPorchSF\": 72, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 805, \"PID\": 906223080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1879, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 100, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 806, \"PID\": 906223210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 807, \"PID\": 906226060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 26400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 2016, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 808, \"PID\": 906226070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118964}, {\"Order\": 809, \"PID\": 906226080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1086.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 153337}, {\"Order\": 810, \"PID\": 906226090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 1114, \"LowQualFinSF\": 0, \"GrLivArea\": 2228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 73, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 147983}, {\"Order\": 811, \"PID\": 906226100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 812, \"PID\": 906226110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 813, \"PID\": 906226120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 1120, \"LowQualFinSF\": 0, \"GrLivArea\": 2240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 142953}, {\"Order\": 814, \"PID\": 906226130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1094.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 148325}, {\"Order\": 815, \"PID\": 906226140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 113722}, {\"Order\": 816, \"PID\": 906230010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 817, \"PID\": 906230020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7939, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 818, \"PID\": 906230030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 819, \"PID\": 906340100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10933, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1021.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1555.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1138.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 323262}, {\"Order\": 820, \"PID\": 906340110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 417.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 297000}, {\"Order\": 821, \"PID\": 906340120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1622.0, \"TotalBsmtSF\": 1622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 860.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295493}, {\"Order\": 822, \"PID\": 906340130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 364.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 332000}, {\"Order\": 823, \"PID\": 906378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 904.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 824, \"PID\": 906380050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 825, \"PID\": 906380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11422, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1359.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 222, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272500}, {\"Order\": 826, \"PID\": 906380100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 827, \"PID\": 906380130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 828, \"PID\": 906380210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1282.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 829, \"PID\": 906380220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 10324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 382.0, \"TotalBsmtSF\": 1254.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221800}, {\"Order\": 830, \"PID\": 906392070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 82.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 831, \"PID\": 906392110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1474.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 832, \"PID\": 906392130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 704, \"2ndFlrSF\": 718, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 833, \"PID\": 906402060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 396, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 834, \"PID\": 906426210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 1449.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 815, \"LowQualFinSF\": 0, \"GrLivArea\": 1759, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 193, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233500}, {\"Order\": 835, \"PID\": 906475070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 28698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 764.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 966, \"LowQualFinSF\": 0, \"GrLivArea\": 2126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 836, \"PID\": 907126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 837, \"PID\": 907126050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9757, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 838, \"PID\": 907130100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 15426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 836, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 839, \"PID\": 907131090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 834, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 840, \"PID\": 907131190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14753, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 950.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1463, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1463, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 841, \"PID\": 907135040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 10859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1097.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 392, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 842, \"PID\": 907135170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 746.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 843, \"PID\": 907175100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 866.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 913, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 844, \"PID\": 907180130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1490.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 845, \"PID\": 907181100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9017, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 871.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 846, \"PID\": 907185050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 847, \"PID\": 907192030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8935, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 848, \"PID\": 907192090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 9808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1573, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 849, \"PID\": 907194010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1840, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 850, \"PID\": 907194110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 16285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1413.0, \"TotalBsmtSF\": 1413.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187100}, {\"Order\": 851, \"PID\": 907194160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10739, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 852, \"PID\": 907196060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11166, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 201000}, {\"Order\": 853, \"PID\": 907200230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 854, \"PID\": 907201220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16269, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 855, \"PID\": 907201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 6950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 710.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 856, \"PID\": 907202050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150500}, {\"Order\": 857, \"PID\": 907202080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 858, \"PID\": 907202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1072.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 859, \"PID\": 907227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 15523, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 860, \"PID\": 907227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 215, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 861, \"PID\": 907227110, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 862, \"PID\": 907227290, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8445, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 863, \"PID\": 907250070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 335.0, \"TotalBsmtSF\": 1569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 864, \"PID\": 907252060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1068.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254750}, {\"Order\": 865, \"PID\": 907252210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 866, \"PID\": 907252220, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 990.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 309.0, \"TotalBsmtSF\": 1299.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 573, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 261500}, {\"Order\": 867, \"PID\": 907253130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 2153, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 313000}, {\"Order\": 868, \"PID\": 907260030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 869, \"PID\": 907265010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 944.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 926, \"LowQualFinSF\": 0, \"GrLivArea\": 1870, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 870, \"PID\": 907275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 871, \"PID\": 907275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 814.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 872, \"PID\": 907275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 873, \"PID\": 907280170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1111.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1417, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1417, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 117, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 874, \"PID\": 907285020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 573.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 977, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 576, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 875, \"PID\": 907285050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 876, \"PID\": 907290070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1212.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 877, \"PID\": 907290090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1630.0, \"TotalBsmtSF\": 1630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 878, \"PID\": 907290180, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 879, \"PID\": 907290210, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 880, \"PID\": 907410130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1478.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 293200}, {\"Order\": 881, \"PID\": 907412020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 882, \"PID\": 907414020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1480.0, \"TotalBsmtSF\": 1500.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 883, \"PID\": 907414080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 193.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 884, \"PID\": 907420040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 885, \"PID\": 908102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 886, \"PID\": 908102270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1486.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 887, \"PID\": 908102290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 888, \"PID\": 908128060, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 495, \"2ndFlrSF\": 1427, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 177, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 889, \"PID\": 908151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 155.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 890, \"PID\": 908152035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 615.0, \"TotalBsmtSF\": 1014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 891, \"PID\": 908152100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 255.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 631.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 892, \"PID\": 908154040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 13286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 464.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 327, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 893, \"PID\": 908186080, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 894, \"PID\": 908201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1947, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 895, \"PID\": 908203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 332.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 243.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 896, \"PID\": 908225290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 900, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 897, \"PID\": 908225370, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 441, \"LowQualFinSF\": 0, \"GrLivArea\": 1529, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 898, \"PID\": 908229020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 899, \"PID\": 908250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 900, \"PID\": 908275040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1678.0, \"TotalBsmtSF\": 1678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1678, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1678, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 901, \"PID\": 908275110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 902, \"PID\": 908276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 903, \"PID\": 909101010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12354, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 800, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 904, \"PID\": 909101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 444, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 905, \"PID\": 909101140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10998, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 420.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 906, \"PID\": 909129090, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 907, \"PID\": 909129100, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1932, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 159434}, {\"Order\": 908, \"PID\": 909175080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 438, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 438, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 909, \"PID\": 909178160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 545, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 910, \"PID\": 909179020, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 15863, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 3, \"YearBuilt\": 1920, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 998, \"LowQualFinSF\": 397, \"GrLivArea\": 3082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 911, \"PID\": 909250080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 583.0, \"TotalBsmtSF\": 583.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 647, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 329, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 912, \"PID\": 909250220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 913, \"PID\": 909251050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 914, \"PID\": 909251170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137450}, {\"Order\": 915, \"PID\": 909252020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1936, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 575, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1135, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 916, \"PID\": 909253010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7558, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1913, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 917, \"PID\": 909253180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 877, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1477, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 918, \"PID\": 909254010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 919, \"PID\": 909257050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 10918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 920, \"PID\": 909275080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 921, \"PID\": 909276110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 753, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 213.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 922, \"PID\": 909276200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 332, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 923, \"PID\": 909277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1273, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 307.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 924, \"PID\": 909277100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13360, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 713.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 44, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 925, \"PID\": 909278020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7681, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 731.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 523, \"LowQualFinSF\": 0, \"GrLivArea\": 1343, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 186.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154900}, {\"Order\": 926, \"PID\": 909279010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 674.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 13, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 57, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 927, \"PID\": 909282130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 154.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 694.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144800}, {\"Order\": 928, \"PID\": 909425060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 929, \"PID\": 909425130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 65.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 875.0, \"BsmtUnfSF\": 621.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 930, \"PID\": 909426090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 507.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 295.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 931, \"PID\": 909427200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 158500}, {\"Order\": 932, \"PID\": 909428240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 91.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1906, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1906, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 201, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 933, \"PID\": 909451040, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 279, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 934, \"PID\": 909451100, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 935, \"PID\": 909451140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 561.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 936, \"PID\": 909451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 937, \"PID\": 909452050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13607, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 118.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208000}, {\"Order\": 938, \"PID\": 909475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17597, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1971, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 419.0, \"BsmtUnfSF\": 581.0, \"TotalBsmtSF\": 1803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2365, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 939, \"PID\": 909475300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1988, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 808.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 182, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 940, \"PID\": 910202070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 10690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 941, \"PID\": 910204050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 760.0, \"TotalBsmtSF\": 760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 928, \"LowQualFinSF\": 312, \"GrLivArea\": 2168, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 160, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 942, \"PID\": 910205020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 596, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 189.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 943, \"PID\": 911103050, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 105.0, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1915, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1013.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 513, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85000}, {\"Order\": 944, \"PID\": 911104060, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 72, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 945, \"PID\": 911370500, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230000}, {\"Order\": 946, \"PID\": 912251110, \"MSSubClass\": 30, \"MSZoning\": \"I (all)\", \"LotFrontage\": 109.0, \"LotArea\": 21780, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 119, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 57625}, {\"Order\": 947, \"PID\": 914465020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 250.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 948, \"PID\": 914465040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 2149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 239686}, {\"Order\": 949, \"PID\": 914465055, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1710.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 950, \"PID\": 914474070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 12209, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 1157, \"LowQualFinSF\": 0, \"GrLivArea\": 1961, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 951, \"PID\": 914475010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 926, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156450}, {\"Order\": 952, \"PID\": 914475030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 953, \"PID\": 914476020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 954, \"PID\": 914476380, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9947, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 955, \"PID\": 914476430, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 55.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1527.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 152000}, {\"Order\": 956, \"PID\": 916176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSeWa\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 541.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 118, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 233, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 957, \"PID\": 916176125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 215245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 820.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 958, \"PID\": 916380070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1022.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315500}, {\"Order\": 959, \"PID\": 916382010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224500}, {\"Order\": 960, \"PID\": 916382100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 13438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 2190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 780.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 961, \"PID\": 916382110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 406.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1115.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316500}, {\"Order\": 962, \"PID\": 916386140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 963, \"PID\": 916403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 387.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1412, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 964, \"PID\": 916403200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2237, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 965, \"PID\": 916403250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 14419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 624.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 1645.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 966, \"PID\": 916455070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 967, \"PID\": 916460110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 968, \"PID\": 916475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14601, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 584.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 578.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 969, \"PID\": 921128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1640.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 308, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 425000}, {\"Order\": 970, \"PID\": 923201100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 971, \"PID\": 923202060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1771, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 972, \"PID\": 923203110, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 247, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 973, \"PID\": 923203190, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 883.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 974, \"PID\": 923225360, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 975, \"PID\": 923225490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 9858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 33, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 976, \"PID\": 923226270, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 515.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 977, \"PID\": 923227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13383, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1404, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 978, \"PID\": 923228110, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 979, \"PID\": 923228150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 980, \"PID\": 923228230, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 981, \"PID\": 923230200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7689, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 76.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131900}, {\"Order\": 982, \"PID\": 923252075, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7706, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131250}, {\"Order\": 983, \"PID\": 923275040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1097.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 602.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 303, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 984, \"PID\": 923275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 985, \"PID\": 923276260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 718.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 883, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 883, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 698.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 986, \"PID\": 923400025, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 566, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 320, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 987, \"PID\": 923400110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10429, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 988, \"PID\": 924100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1567.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 989, \"PID\": 924100060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 496.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 368, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 990, \"PID\": 526351030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 411.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 601.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 190, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 991, \"PID\": 526353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1205.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237500}, {\"Order\": 992, \"PID\": 526354070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 2112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206900}, {\"Order\": 993, \"PID\": 527105050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 994, \"PID\": 527106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 995, \"PID\": 527106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 996, \"PID\": 527106150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 997, \"PID\": 527107010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 998, \"PID\": 527107090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 898.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177900}, {\"Order\": 999, \"PID\": 527107210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 21872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1446, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 406.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1000, \"PID\": 527127140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1593.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1593, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 1001, \"PID\": 527131110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 6264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247900}, {\"Order\": 1002, \"PID\": 527140090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1003, \"PID\": 527145090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1280.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1004, \"PID\": 527161010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 926.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1005, \"PID\": 527162180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 183000}, {\"Order\": 1006, \"PID\": 527163100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1007, \"PID\": 527164120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1895, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 1008, \"PID\": 527165010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1009, \"PID\": 527183030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1010, \"PID\": 527183060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 5950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1011, \"PID\": 527208010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 13543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 1012, \"PID\": 527212050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1122.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 1370, \"LowQualFinSF\": 0, \"GrLivArea\": 2504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1013, \"PID\": 527214030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 15401, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 547.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 387000}, {\"Order\": 1014, \"PID\": 527226020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 31220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 2, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1474, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 750, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1015, \"PID\": 527252080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1034.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 557.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 1016, \"PID\": 527276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 47280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1488.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 133000}, {\"Order\": 1017, \"PID\": 527301170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 20544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 791.0, \"TotalBsmtSF\": 791.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 2093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1018, \"PID\": 527301245, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 983.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 1675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1688, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 141, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1019, \"PID\": 527302050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 228.0, \"BsmtUnfSF\": 606.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1020, \"PID\": 527302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1021, \"PID\": 527302185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 18559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 186.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 2048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1022, \"PID\": 527302210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 449.0, \"BsmtUnfSF\": 469.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 1023, \"PID\": 527325070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 424.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 896.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 550, \"OpenPorchSF\": 282, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 1024, \"PID\": 527325240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 48.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 1211.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 174, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1025, \"PID\": 527326130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1026, \"PID\": 527354160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 2044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1027, \"PID\": 527357110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9743, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146900}, {\"Order\": 1028, \"PID\": 527357180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12511, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1420, \"2ndFlrSF\": 1420, \"LowQualFinSF\": 0, \"GrLivArea\": 2840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1314.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 208, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 292500}, {\"Order\": 1029, \"PID\": 527358120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 11361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1193.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1523, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1030, \"PID\": 527359030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1444.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1031, \"PID\": 527359070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1032, \"PID\": 527378020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1033, \"PID\": 527380240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1236.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 787.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 180, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 1034, \"PID\": 527401130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1035, \"PID\": 527402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 438.0, \"BsmtUnfSF\": 14.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 80, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1036, \"PID\": 527402130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 16, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111900}, {\"Order\": 1037, \"PID\": 527403360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 613.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1038, \"PID\": 527425035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111250}, {\"Order\": 1039, \"PID\": 527427110, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1040, \"PID\": 527450110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103400}, {\"Order\": 1041, \"PID\": 527450250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1042, \"PID\": 527450520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 411, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100500}, {\"Order\": 1043, \"PID\": 527451060, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 127.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1044, \"PID\": 527451290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85400}, {\"Order\": 1045, \"PID\": 527451400, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 604.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1046, \"PID\": 527451550, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111750}, {\"Order\": 1047, \"PID\": 527452150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 559.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1048, \"PID\": 527453160, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 286.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 275.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1049, \"PID\": 527454120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 1050, \"PID\": 527455270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1051, \"PID\": 528102030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12444, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 426.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 304, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394617}, {\"Order\": 1052, \"PID\": 528102110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 590, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 426000}, {\"Order\": 1053, \"PID\": 528104050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 816.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 442.0, \"TotalBsmtSF\": 2078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2084, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 385000}, {\"Order\": 1054, \"PID\": 528104080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 14948, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 1237, \"LowQualFinSF\": 0, \"GrLivArea\": 2713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 858.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 446261}, {\"Order\": 1055, \"PID\": 528108150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 317500}, {\"Order\": 1056, \"PID\": 528110080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 436.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372402}, {\"Order\": 1057, \"PID\": 528110110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1728.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 2418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 358, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 417500}, {\"Order\": 1058, \"PID\": 528114040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 14418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 1950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 383000}, {\"Order\": 1059, \"PID\": 528118030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 2748, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 390000}, {\"Order\": 1060, \"PID\": 528118090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12539, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 468.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 1158, \"LowQualFinSF\": 0, \"GrLivArea\": 2790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1150.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 460000}, {\"Order\": 1061, \"PID\": 528120130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12151, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2331, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1003.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 379000}, {\"Order\": 1062, \"PID\": 528142020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 908.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1063, \"PID\": 528142140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1162, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316000}, {\"Order\": 1064, \"PID\": 528164060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 680.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 2535.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2470, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2470, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 144, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 615000}, {\"Order\": 1065, \"PID\": 528166120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 664.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 1096, \"LowQualFinSF\": 0, \"GrLivArea\": 2668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 412500}, {\"Order\": 1066, \"PID\": 528170070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1067, \"PID\": 528172080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 454.0, \"TotalBsmtSF\": 1603.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1068, \"PID\": 528178070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 16900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1075.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1515, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2649, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 421250}, {\"Order\": 1069, \"PID\": 528178090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 16451, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 221.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1765.0, \"TotalBsmtSF\": 1765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1804, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1070, \"PID\": 528180110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1486.0, \"TotalBsmtSF\": 1858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336860}, {\"Order\": 1071, \"PID\": 528180140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 766.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 367294}, {\"Order\": 1072, \"PID\": 528181010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 135.0, \"LotArea\": 12304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1347.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1367, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1073, \"PID\": 528186030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 12677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1074, \"PID\": 528186080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 616.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1684, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1684, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 495, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266000}, {\"Order\": 1075, \"PID\": 528186130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 8232, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 714.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370967}, {\"Order\": 1076, \"PID\": 528186160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234250}, {\"Order\": 1077, \"PID\": 528186170, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1318.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1078, \"PID\": 528188090, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1079, \"PID\": 528188150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 1080, \"PID\": 528190010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1081, \"PID\": 528228345, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1073.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 1415.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1455, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1455, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1082, \"PID\": 528228405, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1087.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219990}, {\"Order\": 1083, \"PID\": 528228445, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1084, \"PID\": 528228465, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159895}, {\"Order\": 1085, \"PID\": 528228540, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1146.0, \"TotalBsmtSF\": 1146.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 428.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187687}, {\"Order\": 1086, \"PID\": 528235020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1515, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1087, \"PID\": 528235120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7415, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 759.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 839.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1088, \"PID\": 528235180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1166, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1089, \"PID\": 528240040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 8029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1090, \"PID\": 528240050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1091, \"PID\": 528250030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8396, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1139, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1092, \"PID\": 528253020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 217300}, {\"Order\": 1093, \"PID\": 528280130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1094, \"PID\": 528280180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 647.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226750}, {\"Order\": 1095, \"PID\": 528290010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 15384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1096, \"PID\": 528290090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1097, \"PID\": 528292060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12460, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1098, \"PID\": 528294060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 873, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1099, \"PID\": 528315060, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1173.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284500}, {\"Order\": 1100, \"PID\": 528315110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1470, \"2ndFlrSF\": 1160, \"LowQualFinSF\": 0, \"GrLivArea\": 2630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 696.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 1101, \"PID\": 528326030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 14260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 1053, \"LowQualFinSF\": 0, \"GrLivArea\": 2198, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1102, \"PID\": 528326110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1519.0, \"TotalBsmtSF\": 1519.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 687.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 1103, \"PID\": 528346050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 136.0, \"LotArea\": 11675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 495.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2006, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1104, \"PID\": 528354100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 1061, \"LowQualFinSF\": 0, \"GrLivArea\": 2125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 1105, \"PID\": 528363020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1242.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1250, \"LowQualFinSF\": 0, \"GrLivArea\": 2501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1106, \"PID\": 528363110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10437, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 2109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 236, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1107, \"PID\": 528365060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 651.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1311.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 1093, \"LowQualFinSF\": 0, \"GrLivArea\": 2418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 983.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 154, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 341000}, {\"Order\": 1108, \"PID\": 528365080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 852.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2197, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 783.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 385, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287500}, {\"Order\": 1109, \"PID\": 528387050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 448.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 904, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1110, \"PID\": 528390020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 1986.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1987, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301500}, {\"Order\": 1111, \"PID\": 528427010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11932, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 830.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235128}, {\"Order\": 1112, \"PID\": 528427070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14598, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 74.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 1039, \"LowQualFinSF\": 0, \"GrLivArea\": 1933, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1113, \"PID\": 528429050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1574, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 824.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 1114, \"PID\": 528429070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13253, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1115, \"PID\": 528429080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264132}, {\"Order\": 1116, \"PID\": 528431060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 468.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 33.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1563.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1563, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1563, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1117, \"PID\": 528431080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 12274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1417.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227680}, {\"Order\": 1118, \"PID\": 528431120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1341.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 851.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 1119, \"PID\": 528435020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 919, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 297900}, {\"Order\": 1120, \"PID\": 528439010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1460.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1460, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1460, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247000}, {\"Order\": 1121, \"PID\": 528458030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1363.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212700}, {\"Order\": 1122, \"PID\": 528458050, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1372.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250580}, {\"Order\": 1123, \"PID\": 528462040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 95.0, \"LotArea\": 11639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1428.0, \"TotalBsmtSF\": 1428.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 182000}, {\"Order\": 1124, \"PID\": 528477040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226700}, {\"Order\": 1125, \"PID\": 528478030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 768.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1053.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 939, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1126, \"PID\": 528478040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 932, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1127, \"PID\": 528480060, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1034.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 1028, \"LowQualFinSF\": 0, \"GrLivArea\": 2078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 339750}, {\"Order\": 1128, \"PID\": 528480160, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 843, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 562.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205950}, {\"Order\": 1129, \"PID\": 528482020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1660.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1130, \"PID\": 528488140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230348}, {\"Order\": 1131, \"PID\": 528490080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 64.0, \"LotArea\": 8791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 361.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 673.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1132, \"PID\": 531363060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1133, \"PID\": 531371070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 555.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 861, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1134, \"PID\": 531373060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 1135, \"PID\": 531375050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1136, \"PID\": 531375110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1137, \"PID\": 531375120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1138, \"PID\": 531376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1139, \"PID\": 531376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1162.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1162, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1140, \"PID\": 531382090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 362.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1141, \"PID\": 531382110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 886.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 794, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1142, \"PID\": 531382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 258.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1679, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1679, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 1143, \"PID\": 531384030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 14565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 537.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1144, \"PID\": 531385060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1677, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190500}, {\"Order\": 1145, \"PID\": 531450030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 439.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1146, \"PID\": 531450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1147, \"PID\": 531450170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1148, \"PID\": 531451020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 165.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1617, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1617, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1149, \"PID\": 531452140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 899.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1199, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1150, \"PID\": 532351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 53.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 799.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1151, \"PID\": 532353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12968, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1152, \"PID\": 532354150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 764.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1153, \"PID\": 532376170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 890.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 890, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 890, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1154, \"PID\": 532377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119916}, {\"Order\": 1155, \"PID\": 532378200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1156, \"PID\": 532477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 19508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 108, \"EnclosedPorch\": 165, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1157, \"PID\": 532479020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 811.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 92, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1158, \"PID\": 533125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 1319, \"LowQualFinSF\": 0, \"GrLivArea\": 2683, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 251, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1159, \"PID\": 533125140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1328.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1827, \"2ndFlrSF\": 959, \"LowQualFinSF\": 0, \"GrLivArea\": 2786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372500}, {\"Order\": 1160, \"PID\": 533206050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 59.0, \"LotArea\": 4282, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1391, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 1161, \"PID\": 533208080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4017, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171900}, {\"Order\": 1162, \"PID\": 533208140, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3435, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1211.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 1163, \"PID\": 533212050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1164, \"PID\": 533212140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1165, \"PID\": 533212150, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3604, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1166, \"PID\": 533213070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179400}, {\"Order\": 1167, \"PID\": 533213120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 194.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 792, \"LowQualFinSF\": 0, \"GrLivArea\": 1549, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172900}, {\"Order\": 1168, \"PID\": 533215020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1027.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 587.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1638, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1169, \"PID\": 533215030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4538, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 179.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1170, \"PID\": 533215040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 42.0, \"LotArea\": 4385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1171, \"PID\": 533215070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1557.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1172, \"PID\": 533215080, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 50.0, \"LotArea\": 5119, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1709, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 97, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"CWD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 328900}, {\"Order\": 1173, \"PID\": 533217050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 628, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1174, \"PID\": 533217060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 20, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1175, \"PID\": 533234020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 79.0, \"LotArea\": 10646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 1789, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 1176, \"PID\": 533236060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1177, \"PID\": 533236070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 147.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1607, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1178, \"PID\": 533236090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 36.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 128.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 842.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1469, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2393, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 94, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 1179, \"PID\": 533250050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 14963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245500}, {\"Order\": 1180, \"PID\": 533250110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 22.0, \"LotArea\": 11064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1230.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1239, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1239, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 1181, \"PID\": 533250160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 32.0, \"LotArea\": 10846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1719.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1719, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1719, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 1182, \"PID\": 533251120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1183, \"PID\": 533350090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1050.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 584.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1599, \"2ndFlrSF\": 1345, \"LowQualFinSF\": 0, \"GrLivArea\": 2944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 70, \"EnclosedPorch\": 16, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1184, \"PID\": 533350120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 16280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1044.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 382.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1426.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1185, \"PID\": 534104100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 469.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1186, \"PID\": 534126090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1304.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 98, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1187, \"PID\": 534127210, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1427, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1188, \"PID\": 534127230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1439.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1189, \"PID\": 534128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1190, \"PID\": 534129060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 62, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1191, \"PID\": 534175140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1625.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1192, \"PID\": 534177180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1522.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 1066, \"LowQualFinSF\": 0, \"GrLivArea\": 2614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 243, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1193, \"PID\": 534201240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1194, \"PID\": 534202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1195, \"PID\": 534204030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 456.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1196, \"PID\": 534225110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1728.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1197, \"PID\": 534225120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1497.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142600}, {\"Order\": 1198, \"PID\": 534250010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 9246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 564.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1199, \"PID\": 534250335, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1200, \"PID\": 534250370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 1540, \"LowQualFinSF\": 0, \"GrLivArea\": 2715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 299800}, {\"Order\": 1201, \"PID\": 534250410, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 933, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1202, \"PID\": 534251280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 800, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1203, \"PID\": 534252090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 867.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178400}, {\"Order\": 1204, \"PID\": 534252270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1205, \"PID\": 534276190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7785, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 267.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1206, \"PID\": 534277060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 619.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109008}, {\"Order\": 1207, \"PID\": 534277070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135750}, {\"Order\": 1208, \"PID\": 534400030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 20, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1209, \"PID\": 534400060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 407, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 1210, \"PID\": 534401130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1165, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 129, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174900}, {\"Order\": 1211, \"PID\": 534401190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 892.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 426, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1212, \"PID\": 534403050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 305.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1213, \"PID\": 534403080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 1219.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1265, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 96, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1214, \"PID\": 534403100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 336.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1215, \"PID\": 534403260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 164, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1216, \"PID\": 534426040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 806.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 1217, \"PID\": 534427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10721, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 243.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1252.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1218, \"PID\": 534428020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12493, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 306.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1219, \"PID\": 534428100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1118.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1220, \"PID\": 534451080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Floor\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72500}, {\"Order\": 1221, \"PID\": 534451170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52000}, {\"Order\": 1222, \"PID\": 534452060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 4, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1223, \"PID\": 534453140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 453, \"2ndFlrSF\": 453, \"LowQualFinSF\": 0, \"GrLivArea\": 906, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 1224, \"PID\": 534455030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1225, \"PID\": 534477080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 220, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 1226, \"PID\": 534477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 32.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 308.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1227, \"PID\": 534477270, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 377.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 178, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1228, \"PID\": 534479150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 505.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112900}, {\"Order\": 1229, \"PID\": 535103050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 273, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201800}, {\"Order\": 1230, \"PID\": 535104020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 491.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1231, \"PID\": 535105030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139950}, {\"Order\": 1232, \"PID\": 535105060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1962, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 237.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1319.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1233, \"PID\": 535105090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 9150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1234, \"PID\": 535126140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 529.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 230, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1235, \"PID\": 535150210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 151.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 1098.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1236, \"PID\": 535150280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 25.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 872.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1237, \"PID\": 535151160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1283, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1283, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1238, \"PID\": 535152200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8856, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 52.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1239, \"PID\": 535153140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1240, \"PID\": 535153150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1261.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1261, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1261, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1400, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1241, \"PID\": 535176100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 187.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1570, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1570, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 490, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166800}, {\"Order\": 1242, \"PID\": 535178060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 580.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1243, \"PID\": 535179060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 387.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 458.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 1244, \"PID\": 535180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 135.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 130, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1245, \"PID\": 535180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1104, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1246, \"PID\": 535301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1247, \"PID\": 535302130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 196.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1248, \"PID\": 535302140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1249, \"PID\": 535303030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 14250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 998.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1250, \"PID\": 535305030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 852.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 1251, \"PID\": 535305160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 773, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 1252, \"PID\": 535327230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1253, \"PID\": 535352080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 1254, \"PID\": 535354200, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1255, \"PID\": 535375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 66, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89900}, {\"Order\": 1256, \"PID\": 535375160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 7506, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1257, \"PID\": 535380050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10930, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1258, \"PID\": 535380110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 1259, \"PID\": 535380140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 182, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 1488.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1260, \"PID\": 535383100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 694, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 114, \"EnclosedPorch\": 210, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106250}, {\"Order\": 1261, \"PID\": 535402120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9247, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 539.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1262, \"PID\": 535403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1263, \"PID\": 535425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Othr\", \"MiscVal\": 6500, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 1264, \"PID\": 535426260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1253.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 213, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1265, \"PID\": 535426350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 276.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1081.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1081, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 401.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1266, \"PID\": 535427070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 27650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2069, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 1267, \"PID\": 535451010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 910, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 414.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1268, \"PID\": 535451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 94000}, {\"Order\": 1269, \"PID\": 535451230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98300}, {\"Order\": 1270, \"PID\": 535452120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1507, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1507, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1271, \"PID\": 535453020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 488.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1272, \"PID\": 535453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 319.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125900}, {\"Order\": 1273, \"PID\": 535453210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 532.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1269.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1274, \"PID\": 535454150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 453.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 501, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1275, \"PID\": 535455060, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1276, \"PID\": 535455080, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 1277, \"PID\": 535455090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 181.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1278, \"PID\": 535456050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 8513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1279, \"PID\": 535456070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1280, \"PID\": 535456100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1281, \"PID\": 535475020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 415.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1282, \"PID\": 535476370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 106.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 1283, \"PID\": 535477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136870}, {\"Order\": 1284, \"PID\": 902100020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 96.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143000}, {\"Order\": 1285, \"PID\": 902100030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 30.0, \"LotArea\": 5232, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 1286, \"PID\": 902102060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1904, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 78, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1287, \"PID\": 902103150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9184, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 375, \"LowQualFinSF\": 0, \"GrLivArea\": 1323, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122600}, {\"Order\": 1288, \"PID\": 902105010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 680, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 1289, \"PID\": 902105020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 547, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 480, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1150, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1290, \"PID\": 902105130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1291, \"PID\": 902107030, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1292, \"PID\": 902109080, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 828.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 828, \"2ndFlrSF\": 658, \"LowQualFinSF\": 108, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 109, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1293, \"PID\": 902109110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 2082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1294, \"PID\": 902109120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 561, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119164}, {\"Order\": 1295, \"PID\": 902109160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 7308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122250}, {\"Order\": 1296, \"PID\": 902128075, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 931.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1297, \"PID\": 902128150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 590.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 552, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1298, \"PID\": 902134100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6756, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 481.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 1299, \"PID\": 902136110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 5914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 396, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 165, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1300, \"PID\": 902201120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 169.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 115000}, {\"Order\": 1301, \"PID\": 902201140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 608.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1302, \"PID\": 902202090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 904.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 869.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1303, \"PID\": 902205070, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 407.0, \"TotalBsmtSF\": 407.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 407, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 407, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 46500}, {\"Order\": 1304, \"PID\": 902205090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 620.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1305, \"PID\": 902205140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 901, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107900}, {\"Order\": 1306, \"PID\": 902207120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 103.0, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 1, \"YearBuilt\": 1949, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 65000}, {\"Order\": 1307, \"PID\": 902207220, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 87.0, \"LotArea\": 18386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1880, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1470.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 1818, \"LowQualFinSF\": 0, \"GrLivArea\": 3493, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295000}, {\"Order\": 1308, \"PID\": 902300110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 797.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 830, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1627, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1309, \"PID\": 902300215, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 540, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 418, \"OpenPorchSF\": 0, \"EnclosedPorch\": 194, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1310, \"PID\": 902300260, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 730, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1311, \"PID\": 902301140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 34.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 513.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98000}, {\"Order\": 1312, \"PID\": 902301150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9143, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 709, \"2ndFlrSF\": 308, \"LowQualFinSF\": 0, \"GrLivArea\": 1017, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 139, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1313, \"PID\": 902304060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 973, \"LowQualFinSF\": 0, \"GrLivArea\": 2350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 219, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1314, \"PID\": 902305080, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2058, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 259, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1315, \"PID\": 902306120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1905, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129400}, {\"Order\": 1316, \"PID\": 902306130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1928, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1317, \"PID\": 902326060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1905, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 691, \"LowQualFinSF\": 0, \"GrLivArea\": 1912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1318, \"PID\": 902328040, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 291, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1319, \"PID\": 902330010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5250, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1872, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 205, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 1320, \"PID\": 902401010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 572, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1321, \"PID\": 902401120, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1893, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1521, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 880.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 502, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1322, \"PID\": 902402260, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 2, \"OverallCond\": 1, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 723, \"2ndFlrSF\": 363, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1323, \"PID\": 902405070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 299, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1324, \"PID\": 902406020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1325, \"PID\": 902406090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1050.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 1326, \"PID\": 902427045, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 12702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 1327, \"PID\": 902427150, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8516, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 869.0, \"TotalBsmtSF\": 869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115500}, {\"Order\": 1328, \"PID\": 903201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7111, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1329, \"PID\": 903204010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 1330, \"PID\": 903204095, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 156, \"GrLivArea\": 935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 1331, \"PID\": 903206070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 175.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 594, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1332, \"PID\": 903225050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1333, \"PID\": 903225140, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1334, \"PID\": 903225160, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 554, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106900}, {\"Order\": 1335, \"PID\": 903226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 658, \"LowQualFinSF\": 0, \"GrLivArea\": 1672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 1336, \"PID\": 903226150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 949.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1337, \"PID\": 903227080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 862.0, \"TotalBsmtSF\": 862.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 208.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1338, \"PID\": 903228040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 201.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1497, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1339, \"PID\": 903228060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1340, \"PID\": 903228090, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 992.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1013, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 101, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1341, \"PID\": 903230110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 565, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1342, \"PID\": 903230120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 99.0, \"LotArea\": 5940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": null, \"BsmtFinType2\": null, \"BsmtFinSF2\": null, \"BsmtUnfSF\": null, \"TotalBsmtSF\": null, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79000}, {\"Order\": 1343, \"PID\": 903231080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 365, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1344, \"PID\": 903232030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81300}, {\"Order\": 1345, \"PID\": 903232090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1078.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 1346, \"PID\": 903233080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 989.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1347, \"PID\": 903234090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 897.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 139, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 1348, \"PID\": 903234100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129900}, {\"Order\": 1349, \"PID\": 903235010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 611.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1350, \"PID\": 903235100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 87, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68500}, {\"Order\": 1351, \"PID\": 903236010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 213, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1352, \"PID\": 903400180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 13053, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 220, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1353, \"PID\": 903401020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1354, \"PID\": 903401030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1355, \"PID\": 903401050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 883.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1356, \"PID\": 903425420, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 606.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1357, \"PID\": 903426160, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1000, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1358, \"PID\": 903427090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5100, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1359, \"PID\": 903429010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 4347, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1360, \"PID\": 903452025, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6291, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93850}, {\"Order\": 1361, \"PID\": 903453050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10266, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 216, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 136000}, {\"Order\": 1362, \"PID\": 903454100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1272.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 0, \"LowQualFinSF\": 697, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1363, \"PID\": 903455030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 428, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 117, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1364, \"PID\": 903455140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1365, \"PID\": 903456130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 647.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 127000}, {\"Order\": 1366, \"PID\": 903458110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 371, \"LowQualFinSF\": 0, \"GrLivArea\": 1406, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1367, \"PID\": 903475020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 645.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1368, \"PID\": 903476110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5586, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 110, \"LowQualFinSF\": 0, \"GrLivArea\": 1198, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79900}, {\"Order\": 1369, \"PID\": 903481010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 451.0, \"TotalBsmtSF\": 451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 759, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Family\", \"SalePrice\": 85000}, {\"Order\": 1370, \"PID\": 903481100, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 808, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 204, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82375}, {\"Order\": 1371, \"PID\": 903484020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1906, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 1469, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1906.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 57, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1372, \"PID\": 904100020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 122, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 1373, \"PID\": 904100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 1374, \"PID\": 904100160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 21286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1271, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1375, \"PID\": 904101170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134432}, {\"Order\": 1376, \"PID\": 904351280, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10106, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 181.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 547, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1377, \"PID\": 905100020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 64, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 148000}, {\"Order\": 1378, \"PID\": 905102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 906.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1379, \"PID\": 905103030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 39.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1380, \"PID\": 905104080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109900}, {\"Order\": 1381, \"PID\": 905104110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1382, \"PID\": 905104180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 702.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1383, \"PID\": 905107280, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 311, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1384, \"PID\": 905107380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9981, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 221.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 852.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1385, \"PID\": 905108170, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 956.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1386, \"PID\": 905200090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1198.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 108959}, {\"Order\": 1387, \"PID\": 905200100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 95541}, {\"Order\": 1388, \"PID\": 905200160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 1006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1006, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 1389, \"PID\": 905200510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149350}, {\"Order\": 1390, \"PID\": 905201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 634.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 1391, \"PID\": 905201110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 102, \"OpenPorchSF\": 89, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1392, \"PID\": 905201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1064.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 354.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 511, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1393, \"PID\": 905202230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 429.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1080.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 409, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1394, \"PID\": 905225040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1021, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1395, \"PID\": 905226030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1396, \"PID\": 905226110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1397, \"PID\": 905227050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 486, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152400}, {\"Order\": 1398, \"PID\": 905300020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1399, \"PID\": 905351089, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1003.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1291.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1291, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1400, \"PID\": 905352030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 299.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 2022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 117, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1401, \"PID\": 905352070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 20270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1402, \"PID\": 905401045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 39104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Membran\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1063.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1403, \"PID\": 905401060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1663, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1404, \"PID\": 905402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 11512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1019.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1357, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1357, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 163, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1405, \"PID\": 905403060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 617, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1079, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 249.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125600}, {\"Order\": 1406, \"PID\": 905403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 287, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1407, \"PID\": 905425125, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 45600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 907.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1307, \"2ndFlrSF\": 1051, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1908.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1408, \"PID\": 905426030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"PreCast\", \"Exterior2nd\": \"PreCast\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1035.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1409, \"PID\": 905427050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1163.0, \"TotalBsmtSF\": 1163.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 511, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1410, \"PID\": 905427070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 2108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1411, \"PID\": 905451330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1509.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 576, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1412, \"PID\": 905452070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99600}, {\"Order\": 1413, \"PID\": 905452120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 621, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1414, \"PID\": 905476120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1415, \"PID\": 905477050, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 969.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 527, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 1416, \"PID\": 905479110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1417, \"PID\": 905480150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 572, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 8, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 1418, \"PID\": 905480240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 380.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1419, \"PID\": 906204150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1475.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1532, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2329, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262280}, {\"Order\": 1420, \"PID\": 906204280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9771, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 1721, \"LowQualFinSF\": 0, \"GrLivArea\": 2814, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1421, \"PID\": 906223110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 251.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1626, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1422, \"PID\": 906223140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 355.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 1099, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1423, \"PID\": 906223220, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 735, \"LowQualFinSF\": 0, \"GrLivArea\": 2037, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 1424, \"PID\": 906378190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 628.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177439}, {\"Order\": 1425, \"PID\": 906380030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1615.0, \"TotalBsmtSF\": 1615.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1615, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1615, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 1426, \"PID\": 906412010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 2271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2276, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1348.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 475000}, {\"Order\": 1427, \"PID\": 906412050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1751.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395039}, {\"Order\": 1428, \"PID\": 906420130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 531.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 187, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 1429, \"PID\": 906424010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 631.0, \"TotalBsmtSF\": 1401.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 811.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1430, \"PID\": 906475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1182.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1643, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1643, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 339, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1431, \"PID\": 906476030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12798, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 154.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 1072, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 403, \"OpenPorchSF\": 114, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1432, \"PID\": 907126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 722.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1433, \"PID\": 907135020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1099.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1099, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1099, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1434, \"PID\": 907135260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1435, \"PID\": 907175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226001}, {\"Order\": 1436, \"PID\": 907176010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 688.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 899, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215700}, {\"Order\": 1437, \"PID\": 907181120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 782, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1438, \"PID\": 907181140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 873.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 193000}, {\"Order\": 1439, \"PID\": 907187030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1440, \"PID\": 907187080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 9382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1441, \"PID\": 907192130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 1442, \"PID\": 907194020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 963.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 963, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 245, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 1443, \"PID\": 907196040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1823, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 4500, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1444, \"PID\": 907196050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 1445, \"PID\": 907200110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 491.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 938, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130250}, {\"Order\": 1446, \"PID\": 907201060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 328.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 1447, \"PID\": 907202010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1174, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 211, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1448, \"PID\": 907202160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1449, \"PID\": 907202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1076, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143195}, {\"Order\": 1450, \"PID\": 907202240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 88.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1558, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1451, \"PID\": 907203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 7990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1452, \"PID\": 907227050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1453, \"PID\": 907227300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 780, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 1454, \"PID\": 907250020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1777.0, \"TotalBsmtSF\": 1777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 159, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1455, \"PID\": 907251090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9473, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 903, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 1456, \"PID\": 907253060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 257.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1457, \"PID\": 907253110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 1458, \"PID\": 907254020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9066, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 106, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1459, \"PID\": 907254090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 1460, \"PID\": 907255020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 396.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287000}, {\"Order\": 1461, \"PID\": 907255030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1357.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1366, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1462, \"PID\": 907255060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1786, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 715.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1463, \"PID\": 907260010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 1141, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 1464, \"PID\": 907262030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 334.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 1465, \"PID\": 907262060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 10905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1129.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1129, \"2ndFlrSF\": 1198, \"LowQualFinSF\": 0, \"GrLivArea\": 2327, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1466, \"PID\": 907262070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 595.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1467, \"PID\": 907265100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1468, \"PID\": 907285080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 642.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 933, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1469, \"PID\": 907290150, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1470, \"PID\": 907290250, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1471, \"PID\": 907295020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 215.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1493, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1493, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208900}, {\"Order\": 1472, \"PID\": 907295100, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 83.0, \"LotArea\": 10126, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1593.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 1473, \"PID\": 907405020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 726.0, \"TotalBsmtSF\": 1536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1536, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1474, \"PID\": 907405140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 854, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208500}, {\"Order\": 1475, \"PID\": 907412040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1421.0, \"TotalBsmtSF\": 1445.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1476, \"PID\": 907412070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 946.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 139, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1477, \"PID\": 907412080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 770, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1478, \"PID\": 907412090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1234, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1479, \"PID\": 907418010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1508.0, \"TotalBsmtSF\": 1564.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218836}, {\"Order\": 1480, \"PID\": 907418040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1327.0, \"TotalBsmtSF\": 1351.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1481, \"PID\": 907420080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1482, \"PID\": 907425010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149300}, {\"Order\": 1483, \"PID\": 907425015, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1484, \"PID\": 907425030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1485, \"PID\": 907425035, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 1486, \"PID\": 908102030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1487, \"PID\": 908102040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 928, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145900}, {\"Order\": 1488, \"PID\": 908102140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 259, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 123000}, {\"Order\": 1489, \"PID\": 908102260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 830.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 736, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1490, \"PID\": 908103260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 12102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 222.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1033, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1033, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 165000}, {\"Order\": 1491, \"PID\": 908103280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1033.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1127, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1492, \"PID\": 908127120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1493, \"PID\": 908128050, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 38.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1181, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1181, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1494, \"PID\": 908128110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 92.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165400}, {\"Order\": 1495, \"PID\": 908151040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 120.0, \"BsmtUnfSF\": 541.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1496, \"PID\": 908152110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1497, \"PID\": 908152270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1132.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1498, \"PID\": 908154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 123.0, \"LotArea\": 47007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3820, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3820, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 372, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284700}, {\"Order\": 1499, \"PID\": 908154235, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 63887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"ClyTile\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 796.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 5644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 6110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 4692, \"2ndFlrSF\": 950, \"LowQualFinSF\": 0, \"GrLivArea\": 5642, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 1418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 292, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 480, \"PoolQC\": \"Gd\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 160000}, {\"Order\": 1500, \"PID\": 908186040, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 459.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1501, \"PID\": 908201100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1502, \"PID\": 908201110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1503, \"PID\": 908201120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1307.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1504, \"PID\": 908204160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 1505, \"PID\": 908225170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91900}, {\"Order\": 1506, \"PID\": 908226120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 585, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 120000}, {\"Order\": 1507, \"PID\": 908250040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 1508, \"PID\": 908250090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 134, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Gar2\", \"MiscVal\": 3000, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1509, \"PID\": 908275130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1510, \"PID\": 908275180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1511, \"PID\": 908275280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 521, \"LowQualFinSF\": 0, \"GrLivArea\": 1393, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 265, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 1512, \"PID\": 908276140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1513, \"PID\": 909100150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 343, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1514, \"PID\": 909100170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1515, \"PID\": 909101060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 41.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 823.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67000}, {\"Order\": 1516, \"PID\": 909101180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5687, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135900}, {\"Order\": 1517, \"PID\": 909131170, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 254, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1518, \"PID\": 909175050, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 720, \"LowQualFinSF\": 420, \"GrLivArea\": 2192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179500}, {\"Order\": 1519, \"PID\": 909175100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 423.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 758.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 304, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1520, \"PID\": 909177120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1521, \"PID\": 909201110, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 8525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1911, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 940.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1522, \"PID\": 909250040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 1611, \"LowQualFinSF\": 0, \"GrLivArea\": 2601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 183, \"OpenPorchSF\": 0, \"EnclosedPorch\": 301, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1523, \"PID\": 909250230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 679.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 161900}, {\"Order\": 1524, \"PID\": 909251080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8969, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 369.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1525, \"PID\": 909251090, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1423, \"2ndFlrSF\": 748, \"LowQualFinSF\": 384, \"GrLivArea\": 2555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1526, \"PID\": 909252110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1527, \"PID\": 909252220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15564, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1528, \"PID\": 909253190, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 1529, \"PID\": 909254050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7609, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 16, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 1530, \"PID\": 909256060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 473, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1531, \"PID\": 909275040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 599.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 217, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1532, \"PID\": 909275050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1533, \"PID\": 909276170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1934, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 389.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 849, \"2ndFlrSF\": 811, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188700}, {\"Order\": 1534, \"PID\": 909277040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 673, \"LowQualFinSF\": 0, \"GrLivArea\": 1938, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 1535, \"PID\": 909277070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 932, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1536, \"PID\": 909281030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 7801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 591.0, \"TotalBsmtSF\": 1091.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 344.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 221, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 1537, \"PID\": 909281110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 786.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 207, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 257076}, {\"Order\": 1538, \"PID\": 909282030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1935, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1968, \"2ndFlrSF\": 1479, \"LowQualFinSF\": 0, \"GrLivArea\": 3447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1014.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 381000}, {\"Order\": 1539, \"PID\": 909425010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 817, \"LowQualFinSF\": 0, \"GrLivArea\": 1954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 311500}, {\"Order\": 1540, \"PID\": 909425085, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 943, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263400}, {\"Order\": 1541, \"PID\": 909428170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 26073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1898.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1898, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 1542, \"PID\": 909428190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 568.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 924.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 1543, \"PID\": 909451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 366.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 213, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 1544, \"PID\": 909451150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 612.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1545, \"PID\": 910200080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 555.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 919, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1546, \"PID\": 910201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 330, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1547, \"PID\": 910202050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1548, \"PID\": 910202100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1549, \"PID\": 910203020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 71.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 125.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 778, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 924.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1550, \"PID\": 910203090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 780, \"2ndFlrSF\": 420, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1551, \"PID\": 910205010, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1552, \"PID\": 910206110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 1553, \"PID\": 910226040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1955, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1554, \"PID\": 910251050, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 80.0, \"LotArea\": 14584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Po\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 13100}, {\"Order\": 1555, \"PID\": 911102090, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 5280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1895, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1895.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 185.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 1556, \"PID\": 911102170, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 649, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1317, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 172, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 40000}, {\"Order\": 1557, \"PID\": 911102180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 52.0, \"LotArea\": 5150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 671, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80900}, {\"Order\": 1558, \"PID\": 911226010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 120.0, \"LotArea\": 18000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 560, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1559, \"PID\": 911226030, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 432, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 65000}, {\"Order\": 1560, \"PID\": 911370410, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 5587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392500}, {\"Order\": 1561, \"PID\": 911370490, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294464}, {\"Order\": 1562, \"PID\": 911370520, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1563, \"PID\": 911370540, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 1564, \"PID\": 914453045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 668.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2032, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1565, \"PID\": 914465060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 857.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1566, \"PID\": 914467050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 910.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 318, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1567, \"PID\": 914475020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 574.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 358.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 576, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1568, \"PID\": 914476010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 83, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 1569, \"PID\": 914476080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1570, \"PID\": 914476450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 428, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 1571, \"PID\": 916125425, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 164660, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 1499.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1619, \"2ndFlrSF\": 167, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 670, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228950}, {\"Order\": 1572, \"PID\": 916226030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 893.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1573, \"PID\": 916325080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15498, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1165.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 665.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 174, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 287000}, {\"Order\": 1574, \"PID\": 916380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 258.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1575, \"PID\": 916382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293077}, {\"Order\": 1576, \"PID\": 916384100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264966}, {\"Order\": 1577, \"PID\": 916386040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 712, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 1578, \"PID\": 916386080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": null, \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 1579, \"PID\": 916386180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 12018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 218689}, {\"Order\": 1580, \"PID\": 916402015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1495.0, \"TotalBsmtSF\": 1495.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1495, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1581, \"PID\": 916402115, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 12416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1398.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 208.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1582, \"PID\": 916402215, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 18265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1583, \"PID\": 916403230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 219.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 783.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1584, \"PID\": 916455120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11202, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1029.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 1432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232500}, {\"Order\": 1585, \"PID\": 916460060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7915, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1586, \"PID\": 916477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 2262, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 749.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1587, \"PID\": 921126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1011.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 873.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 276, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 298751}, {\"Order\": 1588, \"PID\": 921201060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1571.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 393.0, \"TotalBsmtSF\": 1964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 892.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1589, \"PID\": 923202005, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 97.0, \"LotArea\": 8940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 209200}, {\"Order\": 1590, \"PID\": 923202015, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 206300}, {\"Order\": 1591, \"PID\": 923202137, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9278, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1592, \"PID\": 923203140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 197.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 1189.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1189, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1189, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1593, \"PID\": 923204040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 171, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1594, \"PID\": 923225080, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 271.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1595, \"PID\": 923225150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1596, \"PID\": 923225200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 318.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1597, \"PID\": 923225310, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 501.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 526.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1598, \"PID\": 923225370, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 120, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94900}, {\"Order\": 1599, \"PID\": 923227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1160, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 257.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 1600, \"PID\": 923228080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1970, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1601, \"PID\": 923228420, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1602, \"PID\": 923250210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 988.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1603, \"PID\": 923252100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 6490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1604, \"PID\": 923275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 6951, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 362, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1605, \"PID\": 923277030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1982, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1606, \"PID\": 923277040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1982, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1607, \"PID\": 923277080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1608, \"PID\": 923400040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 983.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1300, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1609, \"PID\": 923426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 647.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 889, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1610, \"PID\": 924100020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 562.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 193.0, \"BsmtUnfSF\": 29.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1611, \"PID\": 1007100110, \"MSSubClass\": 70, \"MSZoning\": \"I (all)\", \"LotFrontage\": null, \"LotArea\": 56600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1612, \"PID\": 526352080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 838.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 749.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1587, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1587, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167300}, {\"Order\": 1613, \"PID\": 526352090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1277, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 526.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 1614, \"PID\": 526355170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 2223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2223, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2223, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 1615, \"PID\": 526355190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 15865, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 823.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 2217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 1616, \"PID\": 527105140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 225000}, {\"Order\": 1617, \"PID\": 527107040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 373.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1618, \"PID\": 527110080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 794, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1619, \"PID\": 527110120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 1620, \"PID\": 527110130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 1621, \"PID\": 527126030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 1622, \"PID\": 527158090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 770, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1623, \"PID\": 527161090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 947, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1624, \"PID\": 527162080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178750}, {\"Order\": 1625, \"PID\": 527162090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1626, \"PID\": 527162140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 957, \"2ndFlrSF\": 1342, \"LowQualFinSF\": 0, \"GrLivArea\": 2299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1627, \"PID\": 527163080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1168.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1628, \"PID\": 527165020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1629, \"PID\": 527165100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163900}, {\"Order\": 1630, \"PID\": 527165170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 903.0, \"TotalBsmtSF\": 903.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1631, \"PID\": 527175130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 18160, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 154204}, {\"Order\": 1632, \"PID\": 527182040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1633, \"PID\": 527182170, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1634, \"PID\": 527184020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 4740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1166.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 135, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1635, \"PID\": 527184110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 5118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 926.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1321, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1321, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 1636, \"PID\": 527210060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377426}, {\"Order\": 1637, \"PID\": 527212060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1377, \"LowQualFinSF\": 0, \"GrLivArea\": 2541, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 729.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 349265}, {\"Order\": 1638, \"PID\": 527216080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 51974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 710.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1101.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1559.0, \"TotalBsmtSF\": 2660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1110.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 591587}, {\"Order\": 1639, \"PID\": 527226040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 195.0, \"LotArea\": 41600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1047.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 53.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1640, \"PID\": 527252050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8035, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 797.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 164, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 1641, \"PID\": 527252070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8089, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 1642, \"PID\": 527256030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 945.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1558.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 2220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 441929}, {\"Order\": 1643, \"PID\": 527256040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 13870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 174, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 455000}, {\"Order\": 1644, \"PID\": 527301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 99, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182900}, {\"Order\": 1645, \"PID\": 527301280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1028.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1646, \"PID\": 527302020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 178000}, {\"Order\": 1647, \"PID\": 527302060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 167, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1648, \"PID\": 527302090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1328.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 1529.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1649, \"PID\": 527325090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 11339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 549.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 22.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1650, \"PID\": 527325110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11952, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1161, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 276, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1651, \"PID\": 527327050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12046, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 2030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1652, \"PID\": 527328020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 605.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1653, \"PID\": 527328050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1177, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1654, \"PID\": 527353080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 539.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 1655, \"PID\": 527354050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 253.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1259.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1353, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192350}, {\"Order\": 1656, \"PID\": 527356050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 263.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1657, \"PID\": 527357020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 13001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 249, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1658, \"PID\": 527358060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1659, \"PID\": 527359010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 175.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1660, \"PID\": 527359080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 1661, \"PID\": 527359160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 604.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 585.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 407, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1662, \"PID\": 527377110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 153.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1877, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 1663, \"PID\": 527402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 349.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 533, \"LowQualFinSF\": 0, \"GrLivArea\": 1109, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 35, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1664, \"PID\": 527402150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 35.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143250}, {\"Order\": 1665, \"PID\": 527402240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1972, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1666, \"PID\": 527403310, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1667, \"PID\": 527404050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 619.0, \"BsmtUnfSF\": 214.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1668, \"PID\": 527404100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 412.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1669, \"PID\": 527404140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8294, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1670, \"PID\": 527404150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 322.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1671, \"PID\": 527425025, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1672, \"PID\": 527425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1673, \"PID\": 527427090, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 139.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 767, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 367.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1674, \"PID\": 527427160, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 33.0, \"LotArea\": 4113, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1337.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1675, \"PID\": 527427200, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 10943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1676, \"PID\": 527450030, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 1677, \"PID\": 527450150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 356.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1678, \"PID\": 527450220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113700}, {\"Order\": 1679, \"PID\": 527451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2016, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1680, \"PID\": 527451170, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 376.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 1681, \"PID\": 527452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 958.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 205, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1682, \"PID\": 527453010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 556.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1683, \"PID\": 527455030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 6.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 1061.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 1684, \"PID\": 527455250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 725.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129250}, {\"Order\": 1685, \"PID\": 528102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12469, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1151.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1790.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356000}, {\"Order\": 1686, \"PID\": 528102090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 452.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1774.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 260, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 314813}, {\"Order\": 1687, \"PID\": 528102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1688, \"PID\": 528102120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 322400}, {\"Order\": 1689, \"PID\": 528102130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 328.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 730.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1690, \"PID\": 528104010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 2108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345474}, {\"Order\": 1691, \"PID\": 528106040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 315.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2121.0, \"TotalBsmtSF\": 2121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 415298}, {\"Order\": 1692, \"PID\": 528106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13641, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1304.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1934.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1943, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 2656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1040.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 492000}, {\"Order\": 1693, \"PID\": 528106060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1108.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 1402, \"LowQualFinSF\": 0, \"GrLivArea\": 2550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338931}, {\"Order\": 1694, \"PID\": 528106110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 400.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 450000}, {\"Order\": 1695, \"PID\": 528108160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 14154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1063.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1071, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 947.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 280000}, {\"Order\": 1696, \"PID\": 528110040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 2552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 479069}, {\"Order\": 1697, \"PID\": 528110070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 375.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1935.0, \"TotalBsmtSF\": 1935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1973, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1973, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395000}, {\"Order\": 1698, \"PID\": 528110100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 772.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2153.0, \"TotalBsmtSF\": 2153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 2643, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 694.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 380000}, {\"Order\": 1699, \"PID\": 528112150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1626.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1634, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1634, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1700, \"PID\": 528114050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14977, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 1976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 440000}, {\"Order\": 1701, \"PID\": 528118040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13654, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1704.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1722, \"2ndFlrSF\": 1036, \"LowQualFinSF\": 0, \"GrLivArea\": 2758, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 418000}, {\"Order\": 1702, \"PID\": 528118050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 17169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 970.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 2320.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1174.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 500067}, {\"Order\": 1703, \"PID\": 528120010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1582.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 570, \"LowQualFinSF\": 0, \"GrLivArea\": 2152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 368, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260116}, {\"Order\": 1704, \"PID\": 528120150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 317000}, {\"Order\": 1705, \"PID\": 528142050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9709, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319500}, {\"Order\": 1706, \"PID\": 528144050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325624}, {\"Order\": 1707, \"PID\": 528150040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 510.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1802.0, \"TotalBsmtSF\": 1802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1802, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372000}, {\"Order\": 1708, \"PID\": 528150110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 13069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 502.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1706.0, \"TotalBsmtSF\": 1706.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 1238, \"LowQualFinSF\": 0, \"GrLivArea\": 2956, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 916.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 342000}, {\"Order\": 1709, \"PID\": 528150120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 388.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 970.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 872.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 354000}, {\"Order\": 1710, \"PID\": 528166150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14277, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1317.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1711, \"PID\": 528168040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11999, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1712, \"PID\": 528172030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 669.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 895.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 895, \"2ndFlrSF\": 923, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281500}, {\"Order\": 1713, \"PID\": 528172050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1178.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245700}, {\"Order\": 1714, \"PID\": 528172070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9254, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1602.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232698}, {\"Order\": 1715, \"PID\": 528172075, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1298.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 876.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 1716, \"PID\": 528174010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194700}, {\"Order\": 1717, \"PID\": 528174020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3901, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204000}, {\"Order\": 1718, \"PID\": 528174030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 272.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1719, \"PID\": 528174040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 6289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1720, \"PID\": 528181060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1721, \"PID\": 528181070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1722, \"PID\": 528181080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 1723, \"PID\": 528186050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 7841, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 394.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 848.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 729.0, \"TotalBsmtSF\": 1577.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1577, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 1724, \"PID\": 528186090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 1725, \"PID\": 528186120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1869.0, \"TotalBsmtSF\": 1869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318061}, {\"Order\": 1726, \"PID\": 528186190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1300.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221370}, {\"Order\": 1727, \"PID\": 528188160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 235.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1728, \"PID\": 528218010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 15810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181755}, {\"Order\": 1729, \"PID\": 528218020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1730, \"PID\": 528218050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 783, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 178900}, {\"Order\": 1731, \"PID\": 528218100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 13204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 168165}, {\"Order\": 1732, \"PID\": 528221030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8857, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 757, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 171925}, {\"Order\": 1733, \"PID\": 528221040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9729, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 1048, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198444}, {\"Order\": 1734, \"PID\": 528221050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 918.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 1735, \"PID\": 528221090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179540}, {\"Order\": 1736, \"PID\": 528222030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 176485}, {\"Order\": 1737, \"PID\": 528222040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1340.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181134}, {\"Order\": 1738, \"PID\": 528222050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 796, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156932}, {\"Order\": 1739, \"PID\": 528222060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8229, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 22.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1740, \"PID\": 528222080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7713, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177594}, {\"Order\": 1741, \"PID\": 528222090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1246.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173500}, {\"Order\": 1742, \"PID\": 528228270, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172500}, {\"Order\": 1743, \"PID\": 528228275, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194201}, {\"Order\": 1744, \"PID\": 528228375, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3621, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1589, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1745, \"PID\": 528228555, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185485}, {\"Order\": 1746, \"PID\": 528231010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 182.0, \"LotArea\": 14572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 259000}, {\"Order\": 1747, \"PID\": 528231030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 16219, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1119, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1119, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1748, \"PID\": 528235000, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 175000}, {\"Order\": 1749, \"PID\": 528235160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11796, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1112, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1750, \"PID\": 528235170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1510.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 206580}, {\"Order\": 1751, \"PID\": 528240020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 1752, \"PID\": 528250010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1753, \"PID\": 528250070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 1754, \"PID\": 528275035, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1755, \"PID\": 528275110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 1131, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1756, \"PID\": 528280110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 694, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1757, \"PID\": 528280150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1758, \"PID\": 528290060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 1759, \"PID\": 528290170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1760, \"PID\": 528294010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9649, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1761, \"PID\": 528320050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 15623, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2411, \"2ndFlrSF\": 2065, \"LowQualFinSF\": 0, \"GrLivArea\": 4476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 813.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 555, \"PoolQC\": \"Ex\", \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 745000}, {\"Order\": 1762, \"PID\": 528322020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 515.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 2551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 384500}, {\"Order\": 1763, \"PID\": 528326060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 1288, \"LowQualFinSF\": 0, \"GrLivArea\": 2285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 1764, \"PID\": 528327060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 705.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1351.0, \"TotalBsmtSF\": 2633.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2633, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2633, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 804.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 466500}, {\"Order\": 1765, \"PID\": 528340030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10557, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 1407, \"LowQualFinSF\": 0, \"GrLivArea\": 3078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 806.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 1766, \"PID\": 528344020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1048.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 1171, \"LowQualFinSF\": 0, \"GrLivArea\": 2582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 322500}, {\"Order\": 1767, \"PID\": 528348030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 275.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1066.0, \"TotalBsmtSF\": 1066.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1277, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 1768, \"PID\": 528351010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 21535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1170.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 989.0, \"TotalBsmtSF\": 2444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2444, \"2ndFlrSF\": 1872, \"LowQualFinSF\": 0, \"GrLivArea\": 4316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 832.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 755000}, {\"Order\": 1769, \"PID\": 528354060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 862.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2013, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 455.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269790}, {\"Order\": 1770, \"PID\": 528354110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11787, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 594.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 1379.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 1015, \"LowQualFinSF\": 0, \"GrLivArea\": 2398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315750}, {\"Order\": 1771, \"PID\": 528358040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1203.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 290000}, {\"Order\": 1772, \"PID\": 528364110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1318.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 752.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1773, \"PID\": 528366050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1969.0, \"TotalBsmtSF\": 3200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 75, \"EnclosedPorch\": 291, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 430000}, {\"Order\": 1774, \"PID\": 528366070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 335.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2202, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 1775, \"PID\": 528376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 526.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1225.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1325.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2538, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 933.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 1776, \"PID\": 528427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1369.0, \"TotalBsmtSF\": 1369.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1369, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 203, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 213133}, {\"Order\": 1777, \"PID\": 528427100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1542, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260261}, {\"Order\": 1778, \"PID\": 528429090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 11670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1905.0, \"TotalBsmtSF\": 1905.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1905, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1905, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 1779, \"PID\": 528429110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282922}, {\"Order\": 1780, \"PID\": 528431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1534, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 215000}, {\"Order\": 1781, \"PID\": 528431040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 754.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 394.0, \"TotalBsmtSF\": 1966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1966, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1092.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 419005}, {\"Order\": 1782, \"PID\": 528431050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13501, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 63.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1623.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1783, \"PID\": 528431110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9986, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 428.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1795.0, \"TotalBsmtSF\": 1795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 1784, \"PID\": 528435010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1528, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235876}, {\"Order\": 1785, \"PID\": 528435040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1126.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 311872}, {\"Order\": 1786, \"PID\": 528435060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 954.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248328}, {\"Order\": 1787, \"PID\": 528435070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 825.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1788, \"PID\": 528439040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8847, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 1538.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1538, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1538, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1789, \"PID\": 528439050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 1790, \"PID\": 528439080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8251, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 1791, \"PID\": 528441080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 255, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 307000}, {\"Order\": 1792, \"PID\": 528445020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 982, \"2ndFlrSF\": 995, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 250000}, {\"Order\": 1793, \"PID\": 528445070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 528, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 859.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221300}, {\"Order\": 1794, \"PID\": 528456190, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1314.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1795, \"PID\": 528456230, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1335.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1335, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210400}, {\"Order\": 1796, \"PID\": 528458080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 255000}, {\"Order\": 1797, \"PID\": 528458090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 10411, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212109}, {\"Order\": 1798, \"PID\": 528458120, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1025.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 1799, \"PID\": 528458130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 64.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1120.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1184, \"2ndFlrSF\": 1426, \"LowQualFinSF\": 0, \"GrLivArea\": 2610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 364, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 303477}, {\"Order\": 1800, \"PID\": 528458150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1880, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310013}, {\"Order\": 1801, \"PID\": 528477020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 11096, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249700}, {\"Order\": 1802, \"PID\": 528480020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 874.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1761, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227875}, {\"Order\": 1803, \"PID\": 528480180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1574.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 256, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 261329}, {\"Order\": 1804, \"PID\": 528482010, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 11824, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1685.0, \"TotalBsmtSF\": 1685.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1685, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1685, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 1805, \"PID\": 528482030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 353.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2443, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 744.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 1806, \"PID\": 528482090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 102.0, \"LotArea\": 11143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 159, \"OpenPorchSF\": 214, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 1807, \"PID\": 531363020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 146000}, {\"Order\": 1808, \"PID\": 531363040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1809, \"PID\": 531375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1810, \"PID\": 531376060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1461.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1811, \"PID\": 531380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 1812, \"PID\": 531384070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11613, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191750}, {\"Order\": 1813, \"PID\": 531385070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1349.0, \"TotalBsmtSF\": 1349.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1349, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1349, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1814, \"PID\": 531385130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 39.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 402, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1815, \"PID\": 531451030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1145.0, \"TotalBsmtSF\": 1575.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1816, \"PID\": 531451150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1817, \"PID\": 531453140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1818, \"PID\": 531477040, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1819, \"PID\": 532353120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 351.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120750}, {\"Order\": 1820, \"PID\": 532354010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1821, \"PID\": 532354060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1822, \"PID\": 532354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 999.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1823, \"PID\": 532376040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 6970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1824, \"PID\": 532376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 13673, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143900}, {\"Order\": 1825, \"PID\": 532377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 7476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1826, \"PID\": 532377140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 57.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 827.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1827, \"PID\": 532378240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1828, \"PID\": 532476080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1232, \"LowQualFinSF\": 0, \"GrLivArea\": 2503, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1829, \"PID\": 532477040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 125.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1031.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 2167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1830, \"PID\": 532479050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 10751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1037, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1831, \"PID\": 532479120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16647, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1701, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 611.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1832, \"PID\": 532479140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 968.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 455, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 147000}, {\"Order\": 1833, \"PID\": 533120030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 482.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 1357, \"LowQualFinSF\": 0, \"GrLivArea\": 2810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 500, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 1834, \"PID\": 533130170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10678, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 337.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 983.0, \"TotalBsmtSF\": 1683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2129, \"2ndFlrSF\": 743, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1835, \"PID\": 533205110, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 45.0, \"LotArea\": 4379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 527.0, \"TotalBsmtSF\": 1378.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1836, \"PID\": 533206060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 3523, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1081.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1151, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1837, \"PID\": 533206070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 3784, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1511.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193800}, {\"Order\": 1838, \"PID\": 533208010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 47.0, \"LotArea\": 4230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1352.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1839, \"PID\": 533208020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3606, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 937.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 1840, \"PID\": 533208030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1550, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 207500}, {\"Order\": 1841, \"PID\": 533208040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4274, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1106.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1241.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1241, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1241, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199900}, {\"Order\": 1842, \"PID\": 533208070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4251, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164700}, {\"Order\": 1843, \"PID\": 533213130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 1844, \"PID\": 533213140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1129.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1845, \"PID\": 533221030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1846, \"PID\": 533221060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1847, \"PID\": 533221100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1848, \"PID\": 533223050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 5105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 551.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 551, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 1849, \"PID\": 533236040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1850, \"PID\": 533241030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 66.0, \"LotArea\": 7399, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 1851, \"PID\": 533242080, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 73.0, \"LotArea\": 7321, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1339.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1852, \"PID\": 533242090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 1853, \"PID\": 533244040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 106.0, \"LotArea\": 8413, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 1105.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 1854, \"PID\": 533250190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1037.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 217, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279700}, {\"Order\": 1855, \"PID\": 533251110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1856, \"PID\": 533251130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 1857, \"PID\": 533252130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1157.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 1858, \"PID\": 533253180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 176.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 89, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213750}, {\"Order\": 1859, \"PID\": 533254100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 761, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1860, \"PID\": 533254130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 978.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181500}, {\"Order\": 1861, \"PID\": 533350020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 17778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1632.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 829.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 2461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2497, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2497, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 373000}, {\"Order\": 1862, \"PID\": 533352075, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAe\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 211.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 1361.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 1259, \"LowQualFinSF\": 0, \"GrLivArea\": 2620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 24, \"EnclosedPorch\": 145, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 8300, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1863, \"PID\": 534104090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 1929, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 1864, \"PID\": 534125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143450}, {\"Order\": 1865, \"PID\": 534127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 1008, \"LowQualFinSF\": 0, \"GrLivArea\": 2411, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240050}, {\"Order\": 1866, \"PID\": 534127140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 973.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1867, \"PID\": 534127260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 385.0, \"TotalBsmtSF\": 1295.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 194, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 1868, \"PID\": 534128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 11358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1869, \"PID\": 534151090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1594, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1870, \"PID\": 534151180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1871, \"PID\": 534175010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAn\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136905}, {\"Order\": 1872, \"PID\": 534176140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 792.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1873, \"PID\": 534177210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 916.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1874, \"PID\": 534178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1875, \"PID\": 534201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 38.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1876, \"PID\": 534202030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 519.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1877, \"PID\": 534204120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1878, \"PID\": 534252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1879, \"PID\": 534252060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10624, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1880, \"PID\": 534252070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1881, \"PID\": 534252110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 978.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 1882, \"PID\": 534275170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1960, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 15500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1883, \"PID\": 534275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 66.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1065, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 1884, \"PID\": 534276070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 63.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 81.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1885, \"PID\": 534276160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 285, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1886, \"PID\": 534276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 206.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1887, \"PID\": 534276290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 1888, \"PID\": 534278150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 167.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1889, \"PID\": 534278170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1890, \"PID\": 534278190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117600}, {\"Order\": 1891, \"PID\": 534401120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1174.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1892, \"PID\": 534401200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1893, \"PID\": 534403040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 270.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 580.0, \"BsmtUnfSF\": 452.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 309.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 333, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1894, \"PID\": 534403290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 1309, \"LowQualFinSF\": 0, \"GrLivArea\": 2154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 1895, \"PID\": 534403420, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 543.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1130.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1374, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1896, \"PID\": 534425015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 1592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 201, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1897, \"PID\": 534425080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 219.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1429, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1429, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1898, \"PID\": 534427140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1327, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1327, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150750}, {\"Order\": 1899, \"PID\": 534429030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101800}, {\"Order\": 1900, \"PID\": 534430090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 932, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 306.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 214, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1901, \"PID\": 534431020, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 259.0, \"BsmtUnfSF\": 433.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 908, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 1902, \"PID\": 534450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 2, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 39300}, {\"Order\": 1903, \"PID\": 534450110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1904, \"PID\": 534451020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 442, \"2ndFlrSF\": 228, \"LowQualFinSF\": 0, \"GrLivArea\": 670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1905, \"PID\": 534453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 404.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 1906, \"PID\": 534475170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1907, \"PID\": 534476080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1908, \"PID\": 534478140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Roll\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 708.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 992, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1909, \"PID\": 534479120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1910, \"PID\": 534479140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 1911, \"PID\": 535101150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1912, \"PID\": 535102010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 87.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1913, \"PID\": 535105110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 291.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1914, \"PID\": 535106140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 1915, \"PID\": 535106180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11344, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 874, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1916, \"PID\": 535126180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 1021.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1465, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Sev\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129000}, {\"Order\": 1917, \"PID\": 535151020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 873.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 63.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 219, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1918, \"PID\": 535151100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 908.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 1919, \"PID\": 535151110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 109, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142100}, {\"Order\": 1920, \"PID\": 535152060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1921, \"PID\": 535154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 243.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 834.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 275, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 1922, \"PID\": 535155110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 1923, \"PID\": 535176070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1244, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1244, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1924, \"PID\": 535177020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 69.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1144.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1925, \"PID\": 535177110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 138.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1331.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174850}, {\"Order\": 1926, \"PID\": 535179120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1927, \"PID\": 535180030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 586.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1928, \"PID\": 535181030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1237.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1657, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1929, \"PID\": 535181140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1930, \"PID\": 535300040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 928.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1931, \"PID\": 535301060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1932, \"PID\": 535301160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8078, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128600}, {\"Order\": 1933, \"PID\": 535302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1934, \"PID\": 535304170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 85.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 955.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 293.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1935, \"PID\": 535305180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1936, \"PID\": 535325090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 691.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1937, \"PID\": 535325280, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1938, \"PID\": 535325320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 500, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1939, \"PID\": 535327160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1940, \"PID\": 535327200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 377.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 551.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1941, \"PID\": 535353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 368, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1942, \"PID\": 535353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 324, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1943, \"PID\": 535353160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 14190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 544, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1944, \"PID\": 535354050, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 893, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 893, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1945, \"PID\": 535354260, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 512, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1946, \"PID\": 535355020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 21281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 1778, \"LowQualFinSF\": 0, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 208, \"EnclosedPorch\": 290, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 301600}, {\"Order\": 1947, \"PID\": 535375130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 735.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 735, \"2ndFlrSF\": 299, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 1948, \"PID\": 535376010, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 882.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103200}, {\"Order\": 1949, \"PID\": 535378080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 66.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 1950, \"PID\": 535379060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1951, \"PID\": 535379110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1895, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1952, \"PID\": 535382150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 691.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 86000}, {\"Order\": 1953, \"PID\": 535402140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 364.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 242.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1954, \"PID\": 535402180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 1955, \"PID\": 535403030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 952.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1956, \"PID\": 535426130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1957, \"PID\": 535450190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122900}, {\"Order\": 1958, \"PID\": 535450220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119200}, {\"Order\": 1959, \"PID\": 535450310, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10496, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1960, \"PID\": 535451040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 246.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1961, \"PID\": 535451100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1238, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 171, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 1962, \"PID\": 535451110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 398.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 149.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1963, \"PID\": 535452060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 254.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1964, \"PID\": 535453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1965, \"PID\": 535453150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7315, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1170.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1170, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1966, \"PID\": 535453180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 1967, \"PID\": 535457020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1098.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 154.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1377.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1377, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 1968, \"PID\": 535457040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1969, \"PID\": 535457050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1970, \"PID\": 535476360, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 831, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1971, \"PID\": 535477130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 1972, \"PID\": 535477180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 442.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1973, \"PID\": 535478040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 90, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1974, \"PID\": 902100010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1975, \"PID\": 902105110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 664, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 132000}, {\"Order\": 1976, \"PID\": 902106070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 175, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1977, \"PID\": 902106120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 782.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 184.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1978, \"PID\": 902107050, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1979, \"PID\": 902110010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 3153, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 26, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 1980, \"PID\": 902125120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1885, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1047, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1047, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1981, \"PID\": 902128160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 279.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1982, \"PID\": 902201090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 494, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 26, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1983, \"PID\": 902201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 679, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1984, \"PID\": 902202070, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 435.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 89471}, {\"Order\": 1985, \"PID\": 902205020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 122.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 448.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 761, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1986, \"PID\": 902205130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 1987, \"PID\": 902206270, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1075.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 642, \"LowQualFinSF\": 0, \"GrLivArea\": 1798, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1988, \"PID\": 902207010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1945, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 1989, \"PID\": 902207150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 968.0, \"TotalBsmtSF\": 968.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1990, \"PID\": 902300020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10337, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 1991, \"PID\": 902300040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 9863, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 374.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1992, \"PID\": 902301030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 842, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1993, \"PID\": 902301130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1994, \"PID\": 902302150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 1995, \"PID\": 902303100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 667.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 659, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144100}, {\"Order\": 1996, \"PID\": 902304040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1880, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 1997, \"PID\": 902305010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 316.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 687.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 687, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 124500}, {\"Order\": 1998, \"PID\": 902330090, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1879, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 819.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2454, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1999, \"PID\": 902332030, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1046.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 1031, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 99, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 2000, \"PID\": 902401030, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 779.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2001, \"PID\": 902404010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1221.0, \"TotalBsmtSF\": 1559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1559, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1559, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 230, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2002, \"PID\": 902408080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 718.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2003, \"PID\": 902427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 9439, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2004, \"PID\": 902427140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2005, \"PID\": 902427180, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2006, \"PID\": 903201090, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 6854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 227.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 916, \"2ndFlrSF\": 144, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 150, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2007, \"PID\": 903204030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8674, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1435, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128250}, {\"Order\": 2008, \"PID\": 903205085, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 8731, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 645.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2009, \"PID\": 903206170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 915, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2010, \"PID\": 903225040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2011, \"PID\": 903227140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 217.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 2012, \"PID\": 903228080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 349, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2013, \"PID\": 903231050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2014, \"PID\": 903231090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 809.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2015, \"PID\": 903231180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 423, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2016, \"PID\": 903232100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 966.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2017, \"PID\": 903233030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 903, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2018, \"PID\": 903233050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1933.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2019, \"PID\": 903233140, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 854, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2020, \"PID\": 903233180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 959, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 2021, \"PID\": 903234160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2022, \"PID\": 903236130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 7755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1164, \"LowQualFinSF\": 0, \"GrLivArea\": 2264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2023, \"PID\": 903400040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2024, \"PID\": 903401070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2025, \"PID\": 903425270, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 356, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2026, \"PID\": 903425280, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153575}, {\"Order\": 2027, \"PID\": 903426010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1929, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2028, \"PID\": 903427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 546.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 714.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 15, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136000}, {\"Order\": 2029, \"PID\": 903430040, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 933, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 113000}, {\"Order\": 2030, \"PID\": 903430050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 969, \"2ndFlrSF\": 245, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 117000}, {\"Order\": 2031, \"PID\": 903450060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 2032, \"PID\": 903451110, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 7449, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 2033, \"PID\": 903453080, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1497, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2034, \"PID\": 903454010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 0, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2035, \"PID\": 903454090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2036, \"PID\": 903456110, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 398.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 1952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 285, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212300}, {\"Order\": 2037, \"PID\": 903457040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 1042, \"LowQualFinSF\": 0, \"GrLivArea\": 2180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2038, \"PID\": 903457130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 4330, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 477, \"LowQualFinSF\": 0, \"GrLivArea\": 1315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 99500}, {\"Order\": 2039, \"PID\": 903458020, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 581, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101000}, {\"Order\": 2040, \"PID\": 903458060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 197.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 999.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2041, \"PID\": 903475040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 12358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 528, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2042, \"PID\": 903475060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 964, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2043, \"PID\": 903476100, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 4388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2044, \"PID\": 903484080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 771.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 504, \"LowQualFinSF\": 114, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 14, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 84, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 50000}, {\"Order\": 2045, \"PID\": 904100100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1937, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 1005, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 521, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219000}, {\"Order\": 2046, \"PID\": 904101070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 138.0, \"LotArea\": 18030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 977.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 971, \"LowQualFinSF\": 479, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 2047, \"PID\": 904301110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 756, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 126000}, {\"Order\": 2048, \"PID\": 904302010, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 4484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2049, \"PID\": 905100060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2050, \"PID\": 905100080, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158450}, {\"Order\": 2051, \"PID\": 905101070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 14299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115400}, {\"Order\": 2052, \"PID\": 905101200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1029, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 261.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2053, \"PID\": 905102010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 722.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2054, \"PID\": 905103110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 761.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2055, \"PID\": 905104030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 627.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 913, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2056, \"PID\": 905104090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 7094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2057, \"PID\": 905104170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 948.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 108000}, {\"Order\": 2058, \"PID\": 905104240, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 20.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2059, \"PID\": 905105040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 8665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 897, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2060, \"PID\": 905105170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 323.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 529.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2061, \"PID\": 905105260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 955, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2062, \"PID\": 905106150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 8724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2063, \"PID\": 905107140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 2064, \"PID\": 905200010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2065, \"PID\": 905201080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 522.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 323.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2066, \"PID\": 905225020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 16779, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 1087, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 570, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2067, \"PID\": 905226050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1416, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2068, \"PID\": 905226080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165250}, {\"Order\": 2069, \"PID\": 905226130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 231.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2070, \"PID\": 905226170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 873.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"VWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2071, \"PID\": 905228020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 998, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 998, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 2072, \"PID\": 905301050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 115149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 739.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 380, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 2073, \"PID\": 905352010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 891.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2074, \"PID\": 905352180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2075, \"PID\": 905376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 109.0, \"TotalBsmtSF\": 409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1325, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 2076, \"PID\": 905377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 587.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2077, \"PID\": 905377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 17808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2078, \"PID\": 905401020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2079, \"PID\": 905426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 12615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 477.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243000}, {\"Order\": 2080, \"PID\": 905451390, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 491.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 638, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 332.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 2081, \"PID\": 905475270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2082, \"PID\": 905475520, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11515, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2083, \"PID\": 905476160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 7711, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2084, \"PID\": 905476170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 605, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 605, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 2085, \"PID\": 905476225, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 3869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 755.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1038.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1038, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2086, \"PID\": 905478140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2087, \"PID\": 905478220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1080.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 400, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2088, \"PID\": 905480090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 951.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 376, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 2089, \"PID\": 905480180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2090, \"PID\": 906200230, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 23920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1105.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 1012, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 444, \"PoolQC\": \"TA\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2091, \"PID\": 906201022, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 10357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 719.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 244, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2092, \"PID\": 906201023, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 1121, \"LowQualFinSF\": 0, \"GrLivArea\": 2243, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 44, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2093, \"PID\": 906201200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1474.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2730, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 2094, \"PID\": 906203140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 634.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 833.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 192, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2095, \"PID\": 906204140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 807.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 196, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2096, \"PID\": 906223040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 497.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 929, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2097, \"PID\": 906340080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 984.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 1414, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 383970}, {\"Order\": 2098, \"PID\": 906340090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1362, \"LowQualFinSF\": 0, \"GrLivArea\": 2828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 424870}, {\"Order\": 2099, \"PID\": 906378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 2100, \"PID\": 906378150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10481, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2140.0, \"TotalBsmtSF\": 2140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 360000}, {\"Order\": 2101, \"PID\": 906378170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10652, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1494.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 279500}, {\"Order\": 2102, \"PID\": 906380010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 11175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 200141}, {\"Order\": 2103, \"PID\": 906380040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 10235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246500}, {\"Order\": 2104, \"PID\": 906380070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1482.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 1092, \"LowQualFinSF\": 0, \"GrLivArea\": 2574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 276000}, {\"Order\": 2105, \"PID\": 906380120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 349.0, \"TotalBsmtSF\": 1274.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1274, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203000}, {\"Order\": 2106, \"PID\": 906380140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11103, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155835}, {\"Order\": 2107, \"PID\": 906380160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2108, \"PID\": 906380200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 195400}, {\"Order\": 2109, \"PID\": 906382020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1526.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1546, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1546, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2110, \"PID\": 906382060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1453.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 674.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212999}, {\"Order\": 2111, \"PID\": 906392080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1270.0, \"TotalBsmtSF\": 1270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1270, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2112, \"PID\": 906394020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 916, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 2113, \"PID\": 906394050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176432}, {\"Order\": 2114, \"PID\": 906402070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1157.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 882, \"LowQualFinSF\": 0, \"GrLivArea\": 2062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 154, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2115, \"PID\": 906403060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 321.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 927, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2116, \"PID\": 906426060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 159000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 2144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2117, \"PID\": 906426195, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53107, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 985.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 874, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 231, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2118, \"PID\": 906475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2087, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2119, \"PID\": 906475170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 155.0, \"LotArea\": 20064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 51.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 915.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 646, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2120, \"PID\": 907125040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 472.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 747.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2121, \"PID\": 907125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2122, \"PID\": 907130060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11249, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 544.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 2123, \"PID\": 907131060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 10021, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 635.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 646, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2124, \"PID\": 907131120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9531, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 914, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2125, \"PID\": 907135050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2126, \"PID\": 907135080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 16561, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 242.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147900}, {\"Order\": 2127, \"PID\": 907135180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123600}, {\"Order\": 2128, \"PID\": 907180040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 905, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204750}, {\"Order\": 2129, \"PID\": 907187040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 646.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 597.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235500}, {\"Order\": 2130, \"PID\": 907187060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12352, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 853, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1753, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2131, \"PID\": 907192020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 845.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190550}, {\"Order\": 2132, \"PID\": 907192040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8826, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2133, \"PID\": 907192120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 167.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1013.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2134, \"PID\": 907192150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2135, \"PID\": 907200130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 131000}, {\"Order\": 2136, \"PID\": 907200190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 502.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2137, \"PID\": 907200250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1009, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2138, \"PID\": 907200270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 2139, \"PID\": 907202100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 16300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 417.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2140, \"PID\": 907202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 432.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2141, \"PID\": 907203060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 2142, \"PID\": 907203110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 10356, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 969, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2143, \"PID\": 907227060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 671.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2144, \"PID\": 907227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2145, \"PID\": 907250050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 2000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305900}, {\"Order\": 2146, \"PID\": 907252020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1284.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 2169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2147, \"PID\": 907252190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11354, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1412.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1673, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1673, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2148, \"PID\": 907260040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1459.0, \"TotalBsmtSF\": 1459.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1459, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1459, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 2149, \"PID\": 907260050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 2150, \"PID\": 907262020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 214.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2151, \"PID\": 907270040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 16226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 1242, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 267000}, {\"Order\": 2152, \"PID\": 907275080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 519.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 683.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1592, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1592, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2153, \"PID\": 907275150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 1531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2439, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2154, \"PID\": 907280090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2155, \"PID\": 907280100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 2156, \"PID\": 907285040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 438.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1079.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2157, \"PID\": 907290140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 2158, \"PID\": 907295040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 17227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246900}, {\"Order\": 2159, \"PID\": 907401060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1081, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2160, \"PID\": 907405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2161, \"PID\": 907410020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179400}, {\"Order\": 2162, \"PID\": 907410050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 639.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 2163, \"PID\": 907414060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1422.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179600}, {\"Order\": 2164, \"PID\": 907414070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 709.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 2165, \"PID\": 907420050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1330, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167840}, {\"Order\": 2166, \"PID\": 907420060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 753, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168675}, {\"Order\": 2167, \"PID\": 907420110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2168, \"PID\": 908102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2169, \"PID\": 908102160, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 405, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 2170, \"PID\": 908103090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 132.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2171, \"PID\": 908127040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 10921, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 48.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94750}, {\"Order\": 2172, \"PID\": 908127060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 16287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 450, \"LowQualFinSF\": 0, \"GrLivArea\": 1351, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 43, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2173, \"PID\": 908127070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1179.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2174, \"PID\": 908127100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 11841, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2175, \"PID\": 908152060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2176, \"PID\": 908152070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 751.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2177, \"PID\": 908152180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9555, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1133, \"LowQualFinSF\": 0, \"GrLivArea\": 2233, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2178, \"PID\": 908152260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1125.0, \"TotalBsmtSF\": 1125.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155000}, {\"Order\": 2179, \"PID\": 908152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2180, \"PID\": 908152290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 123.0, \"TotalBsmtSF\": 734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 674, \"LowQualFinSF\": 0, \"GrLivArea\": 1408, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 2181, \"PID\": 908154195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 39290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 4010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 5095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 5095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 5095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 15, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1154.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 546, \"OpenPorchSF\": 484, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Elev\", \"MiscVal\": 17000, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 183850}, {\"Order\": 2182, \"PID\": 908154205, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 40094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 762.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 3138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3138, \"2ndFlrSF\": 1538, \"LowQualFinSF\": 0, \"GrLivArea\": 4676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 406, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 184750}, {\"Order\": 2183, \"PID\": 908186050, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 467.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2184, \"PID\": 908204090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 77.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 831.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2185, \"PID\": 908204180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2186, \"PID\": 908225240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 2187, \"PID\": 908225310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1195, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 118, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98500}, {\"Order\": 2188, \"PID\": 908226180, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 4270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 286, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2189, \"PID\": 908228010, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 278.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 740, \"2ndFlrSF\": 125, \"LowQualFinSF\": 0, \"GrLivArea\": 865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2190, \"PID\": 908250100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 2191, \"PID\": 908275090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2192, \"PID\": 908275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2193, \"PID\": 908275240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 79275}, {\"Order\": 2194, \"PID\": 908276230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2195, \"PID\": 909176080, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 10896, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1184.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 1440, \"LowQualFinSF\": 515, \"GrLivArea\": 3395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 8, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 14, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 200000}, {\"Order\": 2196, \"PID\": 909176170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2592, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 742, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1512, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 150000}, {\"Order\": 2197, \"PID\": 909250150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 53, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2198, \"PID\": 909250160, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10594, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 2199, \"PID\": 909251030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7223, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2200, \"PID\": 909251040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6821, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 113.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2201, \"PID\": 909252010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 787, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2202, \"PID\": 909252150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 4000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 567, \"2ndFlrSF\": 531, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 2203, \"PID\": 909252170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 6720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 585, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 2204, \"PID\": 909254090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7642, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 514, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189950}, {\"Order\": 2205, \"PID\": 909254100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 775, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2206, \"PID\": 909254130, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 364.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2207, \"PID\": 909254140, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1913, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 365.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90350}, {\"Order\": 2208, \"PID\": 909254150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 661.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 661, \"2ndFlrSF\": 589, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 242, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2209, \"PID\": 909256120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 920.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119750}, {\"Order\": 2210, \"PID\": 909275020, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 7136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 979, \"2ndFlrSF\": 979, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2211, \"PID\": 909275030, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 6270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 1001, \"LowQualFinSF\": 0, \"GrLivArea\": 2002, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2212, \"PID\": 909275110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1927, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 867, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 291, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2213, \"PID\": 909275160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 126.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 24, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 228, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2214, \"PID\": 909275310, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 22420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1128.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2215, \"PID\": 909276160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12168, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 537.0, \"TotalBsmtSF\": 965.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 3194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 359100}, {\"Order\": 2216, \"PID\": 909276210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 7810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1230, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2217, \"PID\": 909279080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 557.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 19, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2218, \"PID\": 909281020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 6221, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2219, \"PID\": 909281130, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1549, \"2ndFlrSF\": 1178, \"LowQualFinSF\": 0, \"GrLivArea\": 2727, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2220, \"PID\": 909282020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1945, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 150.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 2320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259500}, {\"Order\": 2221, \"PID\": 909425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 1477.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1839, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 2222, \"PID\": 909425270, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2223, \"PID\": 909428120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 35.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 869.0, \"BsmtUnfSF\": 905.0, \"TotalBsmtSF\": 1809.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2259, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2259, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 217000}, {\"Order\": 2224, \"PID\": 909428180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1020.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 584, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 2225, \"PID\": 909428340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21579, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2226, \"PID\": 909451130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 529, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 2227, \"PID\": 909452102, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2228, \"PID\": 909455060, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 577.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2229, \"PID\": 909475050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 652.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 434.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1262.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 2230, \"PID\": 909475070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 2035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2515, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2515, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 200624}, {\"Order\": 2231, \"PID\": 909475230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 18044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 279.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 64, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 228, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2232, \"PID\": 910200040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 997, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2233, \"PID\": 910200110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2234, \"PID\": 910201020, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 803, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2235, \"PID\": 910201050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 176, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129850}, {\"Order\": 2236, \"PID\": 910201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 772, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1123, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 2237, \"PID\": 910201180, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": null, \"GarageArea\": null, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 150909}, {\"Order\": 2238, \"PID\": 910202030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 46.0, \"LotArea\": 3672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 100.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75200}, {\"Order\": 2239, \"PID\": 910203290, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118400}, {\"Order\": 2240, \"PID\": 910204090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 961.0, \"TotalBsmtSF\": 961.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"Mix\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 67000}, {\"Order\": 2241, \"PID\": 910205130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 910, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2242, \"PID\": 910206010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 11067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 205, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68104}, {\"Order\": 2243, \"PID\": 911103060, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1895, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 957.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 957, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 133, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119600}, {\"Order\": 2244, \"PID\": 911128010, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 65.0, \"LotArea\": 6565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 106.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 444, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2245, \"PID\": 911128020, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 837.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1001, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 86, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 2246, \"PID\": 911370450, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2247, \"PID\": 911370460, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 481.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 235000}, {\"Order\": 2248, \"PID\": 914452090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1001.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2249, \"PID\": 914452120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2250, \"PID\": 914452190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2251, \"PID\": 914460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 856.0, \"TotalBsmtSF\": 1441.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2252, \"PID\": 914460110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 12864, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 17.0, \"TotalBsmtSF\": 1409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1409, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 2253, \"PID\": 914476330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2254, \"PID\": 914478020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 530.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 852.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2255, \"PID\": 914478100, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 924.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2256, \"PID\": 916226090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 4054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 949.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 2257, \"PID\": 916253320, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 9763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 239.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1102.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 2258, \"PID\": 916326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 16905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2259, \"PID\": 916326090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 19958, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 274, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2260, \"PID\": 916384050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 231713}, {\"Order\": 2261, \"PID\": 916384070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8298, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 963.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2207.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267300}, {\"Order\": 2262, \"PID\": 916384080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1476.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265900}, {\"Order\": 2263, \"PID\": 916384150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1571.0, \"TotalBsmtSF\": 1571.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1571, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239000}, {\"Order\": 2264, \"PID\": 916386170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 274.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1638.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248900}, {\"Order\": 2265, \"PID\": 916403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 215.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 1265.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2266, \"PID\": 916403290, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2267, \"PID\": 916455010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 742.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1756, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 2268, \"PID\": 916455050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6718, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2269, \"PID\": 916455110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 82.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2270, \"PID\": 916455150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 886.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 593.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282000}, {\"Order\": 2271, \"PID\": 916460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2272, \"PID\": 916475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 808.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 252, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2273, \"PID\": 916477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 1340, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279900}, {\"Order\": 2274, \"PID\": 917425190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 35133, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 995.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 263, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 263, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186700}, {\"Order\": 2275, \"PID\": 921126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 15306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1652.0, \"TotalBsmtSF\": 1732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 283463}, {\"Order\": 2276, \"PID\": 921128030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 2277, \"PID\": 921205070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1094.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 1349, \"LowQualFinSF\": 0, \"GrLivArea\": 2482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 281213}, {\"Order\": 2278, \"PID\": 923202134, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 914.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 2279, \"PID\": 923202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 200.0, \"LotArea\": 43500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1041.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 561, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2280, \"PID\": 923203010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 6710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 904.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2281, \"PID\": 923204050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 25286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132250}, {\"Order\": 2282, \"PID\": 923204140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 25000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2283, \"PID\": 923205025, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 149.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1622, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 439, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2284, \"PID\": 923225040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 840.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2285, \"PID\": 923225050, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 874.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 536, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2286, \"PID\": 923226300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2287, \"PID\": 923228200, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 27.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 97, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 2288, \"PID\": 923228220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93900}, {\"Order\": 2289, \"PID\": 923228250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 2290, \"PID\": 923228290, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 131.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 499.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2291, \"PID\": 923228390, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 75190}, {\"Order\": 2292, \"PID\": 923229010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146800}, {\"Order\": 2293, \"PID\": 923229040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9129, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2294, \"PID\": 923229100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1356, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 1424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2295, \"PID\": 923229140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 33983, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1112.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1676, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 690, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2296, \"PID\": 923230010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 185.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2297, \"PID\": 923230120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 2298, \"PID\": 923230180, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 149.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2299, \"PID\": 923251160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 27697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"CBlock\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 811.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1608, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2300, \"PID\": 923252080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7599, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2301, \"PID\": 923275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1090.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 88, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2302, \"PID\": 923275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2303, \"PID\": 923276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 596.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 330, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2304, \"PID\": 923400150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 212.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 974.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 974, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 974, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93500}, {\"Order\": 2305, \"PID\": 923425030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 887, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2306, \"PID\": 526302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11027, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1178.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1293, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1293, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2307, \"PID\": 526302040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 280, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2308, \"PID\": 526302120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1127.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 963.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2309, \"PID\": 526303060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 39384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 902.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 252000}, {\"Order\": 2310, \"PID\": 526354020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11727, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 434.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1851.0, \"TotalBsmtSF\": 1851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1851, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192100}, {\"Order\": 2311, \"PID\": 527105060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8238, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2312, \"PID\": 527106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 964.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 1243, \"LowQualFinSF\": 0, \"GrLivArea\": 2236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2313, \"PID\": 527107020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 781, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2314, \"PID\": 527107030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13031, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 592.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2315, \"PID\": 527107120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 821.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 821, \"2ndFlrSF\": 955, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 443.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2316, \"PID\": 527107240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 714.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 413.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 95, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2317, \"PID\": 527108010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 19378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 2462, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2318, \"PID\": 527108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 14859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 27.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1670.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 240000}, {\"Order\": 2319, \"PID\": 527108030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 13128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 990, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2320, \"PID\": 527108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 893.0, \"TotalBsmtSF\": 893.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 2321, \"PID\": 527108060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 13751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1640.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 2212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 773.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 309000}, {\"Order\": 2322, \"PID\": 527108090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 168.0, \"LotArea\": 23257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2021, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 274725}, {\"Order\": 2323, \"PID\": 527146135, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2062.0, \"TotalBsmtSF\": 2062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2079, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2324, \"PID\": 527158020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8076, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2325, \"PID\": 527163020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165600}, {\"Order\": 2326, \"PID\": 527166030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 2327, \"PID\": 527182020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 3701, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2328, \"PID\": 527190050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 5306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 215.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 441, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2329, \"PID\": 527190220, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 28, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2330, \"PID\": 527210030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 1384, \"LowQualFinSF\": 0, \"GrLivArea\": 2798, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 37, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 457347}, {\"Order\": 2331, \"PID\": 527210040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 18062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 662.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 1862, \"LowQualFinSF\": 0, \"GrLivArea\": 3390, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 545224}, {\"Order\": 2332, \"PID\": 527210050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 205.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 889.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1371, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 246, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356383}, {\"Order\": 2333, \"PID\": 527212030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 16056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1752.0, \"TotalBsmtSF\": 1992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1992, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 2868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 716.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 556581}, {\"Order\": 2334, \"PID\": 527212040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 1312, \"LowQualFinSF\": 0, \"GrLivArea\": 2576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 361919}, {\"Order\": 2335, \"PID\": 527214060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 16052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 734.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 2698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 535000}, {\"Order\": 2336, \"PID\": 527216010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 15922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 550.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 1405, \"LowQualFinSF\": 0, \"GrLivArea\": 2795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 401179}, {\"Order\": 2337, \"PID\": 527216050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1031.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1410.0, \"TotalBsmtSF\": 1410.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 1519, \"LowQualFinSF\": 0, \"GrLivArea\": 2945, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 37, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 438780}, {\"Order\": 2338, \"PID\": 527226010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1547, \"2ndFlrSF\": 720, \"LowQualFinSF\": 53, \"GrLivArea\": 2320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2339, \"PID\": 527250040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 34650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2340, \"PID\": 527252090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 523.0, \"TotalBsmtSF\": 1714.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1714, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 2341, \"PID\": 527254070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11302, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Other\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1422.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1826, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319000}, {\"Order\": 2342, \"PID\": 527256120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 18261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 123, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 470000}, {\"Order\": 2343, \"PID\": 527301010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 995.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2344, \"PID\": 527302080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1002.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 2183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2345, \"PID\": 527325160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 34.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 795.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 250, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2346, \"PID\": 527327080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2347, \"PID\": 527328010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2348, \"PID\": 527354040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 604.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 2349, \"PID\": 527355060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1857, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188900}, {\"Order\": 2350, \"PID\": 527355280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 1061.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 384, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2351, \"PID\": 527356020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1392, \"LowQualFinSF\": 0, \"GrLivArea\": 2784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 440, \"PoolArea\": 519, \"PoolQC\": \"Fa\", \"Fence\": \"MnPrv\", \"MiscFeature\": \"TenC\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2352, \"PID\": 527356060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 811, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 208, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2353, \"PID\": 527358090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 42.0, \"TotalBsmtSF\": 1047.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1083, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1083, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 444, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2354, \"PID\": 527365010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1358, \"LowQualFinSF\": 0, \"GrLivArea\": 2318, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 246, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294323}, {\"Order\": 2355, \"PID\": 527375160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 127.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1109, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 485.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 2356, \"PID\": 527376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2357, \"PID\": 527376110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 2358, \"PID\": 527377030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 377.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1309, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1309, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 648, \"PoolQC\": \"Fa\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2359, \"PID\": 527378010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2360, \"PID\": 527402210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 75.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 791.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 138800}, {\"Order\": 2361, \"PID\": 527402380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9353, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 116050}, {\"Order\": 2362, \"PID\": 527403120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 614.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 2363, \"PID\": 527404180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 2364, \"PID\": 527427210, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 951.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1487.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2365, \"PID\": 527450010, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 514.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 2366, \"PID\": 527450080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2367, \"PID\": 527450210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 408.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83000}, {\"Order\": 2368, \"PID\": 527450460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 494, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2369, \"PID\": 527451200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 91500}, {\"Order\": 2370, \"PID\": 527451380, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2371, \"PID\": 527451450, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 465, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2372, \"PID\": 527451460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 382.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2373, \"PID\": 527451520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 297.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94500}, {\"Order\": 2374, \"PID\": 527452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 156.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146300}, {\"Order\": 2375, \"PID\": 527452290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 373.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1387, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2376, \"PID\": 527452310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 175, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2377, \"PID\": 527453070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2378, \"PID\": 527455100, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2379, \"PID\": 528102010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 66.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1447.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 770.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2380, \"PID\": 528102080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 16387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1738, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 2589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 412083}, {\"Order\": 2381, \"PID\": 528106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 111.0, \"LotArea\": 16259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 370.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1249.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1249, \"2ndFlrSF\": 1347, \"LowQualFinSF\": 0, \"GrLivArea\": 2596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 342643}, {\"Order\": 2382, \"PID\": 528106120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 16163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1618.0, \"TotalBsmtSF\": 1618.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1618, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1618, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 2383, \"PID\": 528110050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 690.0, \"TotalBsmtSF\": 2076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2076, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 229, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 465000}, {\"Order\": 2384, \"PID\": 528112010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 12228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1721.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293000}, {\"Order\": 2385, \"PID\": 528114010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 14780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1085.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 354, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2386, \"PID\": 528116030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 16033, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1261.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 519, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 326000}, {\"Order\": 2387, \"PID\": 528118010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 14215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1218, \"LowQualFinSF\": 0, \"GrLivArea\": 2376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 853.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325300}, {\"Order\": 2388, \"PID\": 528118020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 309000}, {\"Order\": 2389, \"PID\": 528118110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13975, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 300000}, {\"Order\": 2390, \"PID\": 528120110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1030.0, \"TotalBsmtSF\": 1030.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 1060, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 2391, \"PID\": 528120140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 385.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 466, \"LowQualFinSF\": 0, \"GrLivArea\": 2091, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338500}, {\"Order\": 2392, \"PID\": 528138030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345000}, {\"Order\": 2393, \"PID\": 528142010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 12867, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1209.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 344133}, {\"Order\": 2394, \"PID\": 528142060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 10672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 1335, \"LowQualFinSF\": 0, \"GrLivArea\": 2389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 298236}, {\"Order\": 2395, \"PID\": 528142070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 814, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 329900}, {\"Order\": 2396, \"PID\": 528142110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 1896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 708.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 2397, \"PID\": 528144030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11065, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 788.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 1085.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 753.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281000}, {\"Order\": 2398, \"PID\": 528150080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372397}, {\"Order\": 2399, \"PID\": 528150090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 131.0, \"LotArea\": 14828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 1780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378000}, {\"Order\": 2400, \"PID\": 528164040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 562.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 374000}, {\"Order\": 2401, \"PID\": 528170040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 20431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 870.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1848, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 2728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 437154}, {\"Order\": 2402, \"PID\": 528172020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 512.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 179, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2403, \"PID\": 528172150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 488, \"LowQualFinSF\": 0, \"GrLivArea\": 1914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2404, \"PID\": 528174080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 705.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185850}, {\"Order\": 2405, \"PID\": 528180080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 5911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282500}, {\"Order\": 2406, \"PID\": 528181030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6955, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202500}, {\"Order\": 2407, \"PID\": 528181040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 6792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202665}, {\"Order\": 2408, \"PID\": 528186100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 518.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 899.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 332200}, {\"Order\": 2409, \"PID\": 528186110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 572.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1251.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310090}, {\"Order\": 2410, \"PID\": 528188040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171750}, {\"Order\": 2411, \"PID\": 528218030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 23, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169990}, {\"Order\": 2412, \"PID\": 528218060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 170440}, {\"Order\": 2413, \"PID\": 528218080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169985}, {\"Order\": 2414, \"PID\": 528218130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 17104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 426.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179665}, {\"Order\": 2415, \"PID\": 528218140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 14054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 1863, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 219210}, {\"Order\": 2416, \"PID\": 528221010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 11660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1326.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 174190}, {\"Order\": 2417, \"PID\": 528221100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172785}, {\"Order\": 2418, \"PID\": 528222010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11631, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1052.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 1321, \"LowQualFinSF\": 0, \"GrLivArea\": 2373, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 258000}, {\"Order\": 2419, \"PID\": 528222020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185101}, {\"Order\": 2420, \"PID\": 528228280, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3087, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 767.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210250}, {\"Order\": 2421, \"PID\": 528228325, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1374.0, \"TotalBsmtSF\": 1374.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 2422, \"PID\": 528228340, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1273.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2423, \"PID\": 528228360, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1038.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246990}, {\"Order\": 2424, \"PID\": 528228415, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1375.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178740}, {\"Order\": 2425, \"PID\": 528228430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2426, \"PID\": 528228545, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167240}, {\"Order\": 2427, \"PID\": 528228550, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1126.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156820}, {\"Order\": 2428, \"PID\": 528228565, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213490}, {\"Order\": 2429, \"PID\": 528228575, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1154.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 1520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264561}, {\"Order\": 2430, \"PID\": 528228580, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246578}, {\"Order\": 2431, \"PID\": 528231050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 21930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192140}, {\"Order\": 2432, \"PID\": 528235050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7861, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183200}, {\"Order\": 2433, \"PID\": 528235130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2434, \"PID\": 528235190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1598, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201490}, {\"Order\": 2435, \"PID\": 528240080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1406.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1454, \"2ndFlrSF\": 482, \"LowQualFinSF\": 0, \"GrLivArea\": 1936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 2436, \"PID\": 528250060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2437, \"PID\": 528275060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8121, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 711, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172400}, {\"Order\": 2438, \"PID\": 528275080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2439, \"PID\": 528280100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 930, \"LowQualFinSF\": 0, \"GrLivArea\": 1886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 89, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199900}, {\"Order\": 2440, \"PID\": 528290140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 959.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 2441, \"PID\": 528292080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287602}, {\"Order\": 2442, \"PID\": 528294070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 1286, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2443, \"PID\": 528315030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1074.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1407, \"2ndFlrSF\": 985, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 348000}, {\"Order\": 2444, \"PID\": 528315070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 31, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 2445, \"PID\": 528315080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 322.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 655.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1205, \"2ndFlrSF\": 1029, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2446, \"PID\": 528320060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 35760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1831, \"2ndFlrSF\": 1796, \"LowQualFinSF\": 0, \"GrLivArea\": 3627, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 807.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 361, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 625000}, {\"Order\": 2447, \"PID\": 528327010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9233, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 877.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 358.0, \"TotalBsmtSF\": 1540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1540, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2855, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 247, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 405000}, {\"Order\": 2448, \"PID\": 528344060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 530.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 374, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2449, \"PID\": 528348010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 258000}, {\"Order\": 2450, \"PID\": 528358030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 397.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 1368, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 169, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 2451, \"PID\": 528360050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 17242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 738.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1393.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1733.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1933, \"2ndFlrSF\": 1567, \"LowQualFinSF\": 0, \"GrLivArea\": 3500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 959.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 870, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 584500}, {\"Order\": 2452, \"PID\": 528363070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 501.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1305, \"2ndFlrSF\": 1189, \"LowQualFinSF\": 0, \"GrLivArea\": 2494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 803.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 321000}, {\"Order\": 2453, \"PID\": 528365090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 391.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1203, \"2ndFlrSF\": 1323, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 309, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 2454, \"PID\": 528366040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1039.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 1234, \"LowQualFinSF\": 0, \"GrLivArea\": 2799, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 432, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2455, \"PID\": 528429060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 760.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252000}, {\"Order\": 2456, \"PID\": 528429100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1562.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336820}, {\"Order\": 2457, \"PID\": 528429120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 20896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1721.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 2077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1134.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 267, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 423000}, {\"Order\": 2458, \"PID\": 528429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290000}, {\"Order\": 2459, \"PID\": 528439030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1616.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 2460, \"PID\": 528445010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1504.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199000}, {\"Order\": 2461, \"PID\": 528456200, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1254.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 584.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198600}, {\"Order\": 2462, \"PID\": 528477010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 13162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 2036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 405749}, {\"Order\": 2463, \"PID\": 528477030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 11216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 232600}, {\"Order\": 2464, \"PID\": 528480070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1053.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 266000}, {\"Order\": 2465, \"PID\": 528480100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186500}, {\"Order\": 2466, \"PID\": 528480110, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200825}, {\"Order\": 2467, \"PID\": 528480150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 798, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 197000}, {\"Order\": 2468, \"PID\": 528488110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 905.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185000}, {\"Order\": 2469, \"PID\": 528488120, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2470, \"PID\": 528488130, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1293.0, \"TotalBsmtSF\": 1293.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187750}, {\"Order\": 2471, \"PID\": 531363080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1118.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 4, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2472, \"PID\": 531367010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 118.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1400.0, \"TotalBsmtSF\": 1400.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1400, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186800}, {\"Order\": 2473, \"PID\": 531375060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1131.0, \"TotalBsmtSF\": 1131.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 132000}, {\"Order\": 2474, \"PID\": 531375070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2475, \"PID\": 531375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 158000}, {\"Order\": 2476, \"PID\": 531376030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 891.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 891, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 2477, \"PID\": 531376050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1585, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 449.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 2478, \"PID\": 531379030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1837, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 688.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2479, \"PID\": 531450040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 761.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2480, \"PID\": 531451290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1731, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3000, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 248500}, {\"Order\": 2481, \"PID\": 531452080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1398, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2482, \"PID\": 531452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 278.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 1217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2483, \"PID\": 531452210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 362.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 636, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2484, \"PID\": 531478010, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 8900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107000}, {\"Order\": 2485, \"PID\": 531479030, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2486, \"PID\": 532351060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2487, \"PID\": 532351090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1332.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2488, \"PID\": 532351150, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1286, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2489, \"PID\": 532353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2490, \"PID\": 532353180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 8471, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 46.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 506.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2491, \"PID\": 532376080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2492, \"PID\": 532376180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2493, \"PID\": 532376250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2494, \"PID\": 532378050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120875}, {\"Order\": 2495, \"PID\": 532378070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 375.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 935, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2496, \"PID\": 532378130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2497, \"PID\": 532378160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 465.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 447.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2498, \"PID\": 532378220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8789, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129200}, {\"Order\": 2499, \"PID\": 532476050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 497.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1748.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2151, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 4, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 641, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 800, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2500, \"PID\": 533110130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 16059, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2417, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2501, \"PID\": 533125120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 692.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1118.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 208, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 2502, \"PID\": 533127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 310000}, {\"Order\": 2503, \"PID\": 533128030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13346, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 1129, \"LowQualFinSF\": 0, \"GrLivArea\": 2295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 2504, \"PID\": 533128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"ImStucc\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 757.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262000}, {\"Order\": 2505, \"PID\": 533206040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3628, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176400}, {\"Order\": 2506, \"PID\": 533208050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3316, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1247.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1247, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1247, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2507, \"PID\": 533212100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2508, \"PID\": 533212110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147400}, {\"Order\": 2509, \"PID\": 533212120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2510, \"PID\": 533212130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 144152}, {\"Order\": 2511, \"PID\": 533221080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 2512, \"PID\": 533223010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 241.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183900}, {\"Order\": 2513, \"PID\": 533223080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 673, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 153, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2514, \"PID\": 533223110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2515, \"PID\": 533241010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 114.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 382, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2516, \"PID\": 533242030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 2517, \"PID\": 533250130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 9549, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1057.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2518, \"PID\": 533252020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2519, \"PID\": 533253030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1009.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 44.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2520, \"PID\": 533253050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 3640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2521, \"PID\": 533253090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3874, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 807.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 419.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2522, \"PID\": 533253160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 526.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2523, \"PID\": 533350050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 50271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 1842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1842, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 857, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 385000}, {\"Order\": 2524, \"PID\": 534125210, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 13110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2525, \"PID\": 534126060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 10192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2526, \"PID\": 534127190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 1203.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2156, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2156, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 290, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 2527, \"PID\": 534127270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 404.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 708.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 708, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 119, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2528, \"PID\": 534128210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 435.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 222, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2529, \"PID\": 534129230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165150}, {\"Order\": 2530, \"PID\": 534175100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 264, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164500}, {\"Order\": 2531, \"PID\": 534176250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1164.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2532, \"PID\": 534201130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2533, \"PID\": 534201230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2534, \"PID\": 534201250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1770, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 270, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 455, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2535, \"PID\": 534201260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 94, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157500}, {\"Order\": 2536, \"PID\": 534201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 2537, \"PID\": 534201300, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2538, \"PID\": 534202020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124400}, {\"Order\": 2539, \"PID\": 534202180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 402.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 568.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2540, \"PID\": 534226060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 661.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2541, \"PID\": 534250300, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1993, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2542, \"PID\": 534275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 319, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2543, \"PID\": 534276010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2544, \"PID\": 534276230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1098.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 145000}, {\"Order\": 2545, \"PID\": 534400120, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 34.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 25, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 460, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185900}, {\"Order\": 2546, \"PID\": 534403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2547, \"PID\": 534403400, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 748.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2548, \"PID\": 534403440, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2549, \"PID\": 534427090, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2550, \"PID\": 534428060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 8973, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 28.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2551, \"PID\": 534429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 2552, \"PID\": 534430050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129800}, {\"Order\": 2553, \"PID\": 534430110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2554, \"PID\": 534431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1043, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1043, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2555, \"PID\": 534451050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 4712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 456, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 63, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 121600}, {\"Order\": 2556, \"PID\": 534451120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 5900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2557, \"PID\": 534451130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 5825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79900}, {\"Order\": 2558, \"PID\": 534453150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 7438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 316, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2559, \"PID\": 534455080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2560, \"PID\": 534475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1404.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 324, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 146500}, {\"Order\": 2561, \"PID\": 534476100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2562, \"PID\": 534477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 756.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1380.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 2136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 2563, \"PID\": 534479130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 165.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 958, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2564, \"PID\": 534479240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2565, \"PID\": 534479300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2566, \"PID\": 535101110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2567, \"PID\": 535103070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 939.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 307.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2568, \"PID\": 535105160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98600}, {\"Order\": 2569, \"PID\": 535125060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 2157, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2570, \"PID\": 535150240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 118000}, {\"Order\": 2571, \"PID\": 535150300, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 25419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 4, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 184.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 1360, \"LowQualFinSF\": 392, \"GrLivArea\": 3112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 552, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 512, \"PoolQC\": \"Ex\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 235000}, {\"Order\": 2572, \"PID\": 535151080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 9723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 332.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2573, \"PID\": 535151130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 303.0, \"TotalBsmtSF\": 1106.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2574, \"PID\": 535152070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 86, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2575, \"PID\": 535152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2576, \"PID\": 535176050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 175.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145250}, {\"Order\": 2577, \"PID\": 535177100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9610, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 2578, \"PID\": 535178100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 281.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 191, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2579, \"PID\": 535179050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 14850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 895.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 122, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2580, \"PID\": 535180020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 914.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 353.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 2581, \"PID\": 535180070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 64.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134450}, {\"Order\": 2582, \"PID\": 535301010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 943.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135960}, {\"Order\": 2583, \"PID\": 535301150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8092, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 156000}, {\"Order\": 2584, \"PID\": 535303050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1367.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2585, \"PID\": 535304020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2586, \"PID\": 535305120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 522.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2587, \"PID\": 535325130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 301.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2588, \"PID\": 535325340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 488.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 517.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2589, \"PID\": 535325350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 912.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2590, \"PID\": 535325450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2591, \"PID\": 535325460, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 21299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 929.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 791.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2592, \"PID\": 535327210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 521.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 75, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 323, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2593, \"PID\": 535353180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 22136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1153.0, \"TotalBsmtSF\": 2171.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1248, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1008.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 631, \"OpenPorchSF\": 48, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2594, \"PID\": 535354130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 900, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2595, \"PID\": 535355100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 865, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2596, \"PID\": 535375040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 713, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 161, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99800}, {\"Order\": 2597, \"PID\": 535376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 418.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2598, \"PID\": 535376100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1073.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108480}, {\"Order\": 2599, \"PID\": 535377070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 715, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 75, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68000}, {\"Order\": 2600, \"PID\": 535377100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 448, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 2601, \"PID\": 535379100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1130, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 229, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2602, \"PID\": 535380010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 821, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155500}, {\"Order\": 2603, \"PID\": 535380130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10818, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 981, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2604, \"PID\": 535381060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 105000}, {\"Order\": 2605, \"PID\": 535382020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 2414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2606, \"PID\": 535382130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1936, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 370, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 436, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2607, \"PID\": 535401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 445.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 2608, \"PID\": 535402070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1047.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159950}, {\"Order\": 2609, \"PID\": 535402100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 379.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1083.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 345, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2610, \"PID\": 535402220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 128, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2611, \"PID\": 535402230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 701.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1135.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1207, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 2612, \"PID\": 535403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 600.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2613, \"PID\": 535403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 8910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 655.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2614, \"PID\": 535403200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 207.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 2615, \"PID\": 535404080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 7100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2616, \"PID\": 535425040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1773, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 2617, \"PID\": 535425050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2618, \"PID\": 535425080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 802.0, \"TotalBsmtSF\": 1438.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1900, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 520, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 2619, \"PID\": 535426195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 16321, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1277.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 258, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2620, \"PID\": 535450100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 597.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 2621, \"PID\": 535450180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 2622, \"PID\": 535451190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 2623, \"PID\": 535451210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2624, \"PID\": 535453160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133700}, {\"Order\": 2625, \"PID\": 535454030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81400}, {\"Order\": 2626, \"PID\": 535454050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 2627, \"PID\": 535454060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2628, \"PID\": 535456010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1556.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1556, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2629, \"PID\": 535456020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 179.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 506.0, \"BsmtUnfSF\": 465.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2630, \"PID\": 535457070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 162, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2631, \"PID\": 535477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2632, \"PID\": 535478010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 10205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2633, \"PID\": 535478070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 809.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 236.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2634, \"PID\": 535478090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2635, \"PID\": 535478110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 953.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 1025.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2636, \"PID\": 902100110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 9856, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 1007, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 167, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2637, \"PID\": 902100130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9906, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 518, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 107000}, {\"Order\": 2638, \"PID\": 902101050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2639, \"PID\": 902103090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 863.0, \"TotalBsmtSF\": 1147.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1147, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2640, \"PID\": 902104020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 476, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2641, \"PID\": 902106040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2642, \"PID\": 902106090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6451, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 208.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 2643, \"PID\": 902108060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 66.0, \"LotArea\": 3960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 502.0, \"TotalBsmtSF\": 502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 502, \"2ndFlrSF\": 502, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2644, \"PID\": 902109010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 813, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 813, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2645, \"PID\": 902110120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7745, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 867, \"LowQualFinSF\": 0, \"GrLivArea\": 1951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 6, \"EnclosedPorch\": 28, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2646, \"PID\": 902110130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7741, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 143.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 2647, \"PID\": 902111010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5633, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 81, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2648, \"PID\": 902125020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1880, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 661, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 293, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 2649, \"PID\": 902128020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2650, \"PID\": 902128100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 648.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 734, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2651, \"PID\": 902134060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 7614, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1905, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 714, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 104, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96900}, {\"Order\": 2652, \"PID\": 902204060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2653, \"PID\": 902204120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 296, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2654, \"PID\": 902206020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2655, \"PID\": 902206090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 297, \"LowQualFinSF\": 0, \"GrLivArea\": 1182, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 378.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2656, \"PID\": 902207080, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 5820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 906.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1163, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126175}, {\"Order\": 2657, \"PID\": 902207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 48.0, \"LotArea\": 5747, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 2658, \"PID\": 902301120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 908, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2659, \"PID\": 902305090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 2, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 679, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2660, \"PID\": 902325050, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 2661, \"PID\": 902325100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2104, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2662, \"PID\": 902325160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 889, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2663, \"PID\": 902328100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 815.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 815, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 330, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2664, \"PID\": 902329070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 684, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114504}, {\"Order\": 2665, \"PID\": 902329090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 998, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 0, \"EnclosedPorch\": 221, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2666, \"PID\": 902400090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 84.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1200.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 125000}, {\"Order\": 2667, \"PID\": 902400110, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 22950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1892, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1107.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 1518, \"LowQualFinSF\": 572, \"GrLivArea\": 3608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 260, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 410, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 475000}, {\"Order\": 2668, \"PID\": 902401090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 5976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 624, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 256, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2669, \"PID\": 902406030, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 4500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2670, \"PID\": 902456015, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 63.0, \"LotArea\": 4761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 2671, \"PID\": 903200050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7446, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 2672, \"PID\": 903202120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 605, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140200}, {\"Order\": 2673, \"PID\": 903206160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1017, \"2ndFlrSF\": 810, \"LowQualFinSF\": 0, \"GrLivArea\": 1827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1943.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 27, \"OpenPorchSF\": 36, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2674, \"PID\": 903225090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2675, \"PID\": 903229040, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 325, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 271, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2676, \"PID\": 903231070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 2677, \"PID\": 903231190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2678, \"PID\": 903231220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 347.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 434, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 258.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 75000}, {\"Order\": 2679, \"PID\": 903231240, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1015, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1015, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 620, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 88000}, {\"Order\": 2680, \"PID\": 903232170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80500}, {\"Order\": 2681, \"PID\": 903233100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1042.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 149000}, {\"Order\": 2682, \"PID\": 903233220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 583, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2683, \"PID\": 903234030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 2684, \"PID\": 903235020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 129, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2685, \"PID\": 903236200, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 993.0, \"TotalBsmtSF\": 993.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2686, \"PID\": 903400030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 11672, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 2687, \"PID\": 903425190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 33120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2688, \"PID\": 903425340, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9873, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 288, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2689, \"PID\": 903430090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 634, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 255.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 394, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2690, \"PID\": 903430130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 153.0, \"LotArea\": 4118, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 693.0, \"TotalBsmtSF\": 693.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 693, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 693, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52500}, {\"Order\": 2691, \"PID\": 903451050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 834, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 2692, \"PID\": 903452090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 665, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 2693, \"PID\": 903454020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 819, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 819, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 72000}, {\"Order\": 2694, \"PID\": 903454080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 198.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2695, \"PID\": 903455090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 803.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 803, \"2ndFlrSF\": 557, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2696, \"PID\": 903456060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1007.0, \"TotalBsmtSF\": 1007.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 2697, \"PID\": 903456090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 234, \"GrLivArea\": 754, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 53, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2698, \"PID\": 903458010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2699, \"PID\": 904100030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 477.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 341, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2700, \"PID\": 904100090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 11136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1921.0, \"TotalBsmtSF\": 1921.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1921, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1921, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2701, \"PID\": 904100170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 225, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2702, \"PID\": 904101040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 6930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 294, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 2703, \"PID\": 904301410, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2704, \"PID\": 904302020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 830.0, \"TotalBsmtSF\": 830.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2705, \"PID\": 904302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 373.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2706, \"PID\": 905100030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 459.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2707, \"PID\": 905101330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 2708, \"PID\": 905101450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154500}, {\"Order\": 2709, \"PID\": 905103130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153600}, {\"Order\": 2710, \"PID\": 905103140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 97.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 328.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 68, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 164500}, {\"Order\": 2711, \"PID\": 905103180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 934, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 934, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 77, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2712, \"PID\": 905105010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1059, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1059, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2713, \"PID\": 905106210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11553, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1159, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 466, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2714, \"PID\": 905107070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 463.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 2715, \"PID\": 905107220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 982.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1458, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2716, \"PID\": 905107240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2717, \"PID\": 905107300, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 794.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 2718, \"PID\": 905108090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9662, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1967.0, \"TotalBsmtSF\": 1967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2719, \"PID\": 905108120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1466.0, \"TotalBsmtSF\": 1949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2720, \"PID\": 905200280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 441.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 2721, \"PID\": 905200290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 682.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2722, \"PID\": 905200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 17920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1085.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 418, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 312, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 2723, \"PID\": 905200380, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2724, \"PID\": 905200490, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1965, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2725, \"PID\": 905201090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 304, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2726, \"PID\": 905202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 826.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 1865.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1830, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 115, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 2727, \"PID\": 905202210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 13050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 850.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2728, \"PID\": 905225080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 15593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 701.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1304, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 667.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2729, \"PID\": 905300010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2730, \"PID\": 905300080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 241, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2731, \"PID\": 905351045, \"MSSubClass\": 150, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 1700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 33.0, \"TotalBsmtSF\": 430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 680, \"LowQualFinSF\": 140, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148400}, {\"Order\": 2732, \"PID\": 905351150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 445.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 190000}, {\"Order\": 2733, \"PID\": 905402110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2734, \"PID\": 905403050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 6488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 799, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 128000}, {\"Order\": 2735, \"PID\": 905426100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 103, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2736, \"PID\": 905426150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 626, \"LowQualFinSF\": 0, \"GrLivArea\": 2201, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 586, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 738, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 274970}, {\"Order\": 2737, \"PID\": 905427010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 19950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2738, \"PID\": 905427030, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 19800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1411.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 1836, \"LowQualFinSF\": 0, \"GrLivArea\": 3672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 684, \"OpenPorchSF\": 80, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2739, \"PID\": 905427140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11679, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1164.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 453, \"OpenPorchSF\": 253, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2740, \"PID\": 905451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 348, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2741, \"PID\": 905451410, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10519, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1057.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2742, \"PID\": 905452140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 325.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136900}, {\"Order\": 2743, \"PID\": 905452150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 532.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 541, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2744, \"PID\": 905475150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 6420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 2745, \"PID\": 905477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 2746, \"PID\": 905480160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 454, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91500}, {\"Order\": 2747, \"PID\": 906202040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 40.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2748, \"PID\": 906204180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1246, \"LowQualFinSF\": 0, \"GrLivArea\": 2559, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 245, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 209000}, {\"Order\": 2749, \"PID\": 906223180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9554, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1911, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2750, \"PID\": 906225180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 261.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1083.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 2751, \"PID\": 906380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 133.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1308.0, \"TotalBsmtSF\": 1308.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 848.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229800}, {\"Order\": 2752, \"PID\": 906380150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 393.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 183600}, {\"Order\": 2753, \"PID\": 906380170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7406, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 515.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 2754, \"PID\": 906380180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193879}, {\"Order\": 2755, \"PID\": 906382030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221500}, {\"Order\": 2756, \"PID\": 906382040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204900}, {\"Order\": 2757, \"PID\": 906382050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 571, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239799}, {\"Order\": 2758, \"PID\": 906392090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13377, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 260.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233555}, {\"Order\": 2759, \"PID\": 906392100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2760, \"PID\": 906392120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1122.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 1570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1590, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294900}, {\"Order\": 2761, \"PID\": 906394010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1809, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 209700}, {\"Order\": 2762, \"PID\": 906394040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1558.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2763, \"PID\": 906394060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 532.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2764, \"PID\": 906420020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 119.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 927, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1915, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 2765, \"PID\": 906426090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 36500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 812.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 198, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2766, \"PID\": 906475050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Metal\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 130, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2767, \"PID\": 906475200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 70761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 1533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1533, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2768, \"PID\": 906476140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 853.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 535.0, \"TotalBsmtSF\": 1388.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1388, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 2769, \"PID\": 907125020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2770, \"PID\": 907125080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2771, \"PID\": 907130110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 795, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 413, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2772, \"PID\": 907131070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 579.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 2773, \"PID\": 907135230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 13568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 274.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2774, \"PID\": 907175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2775, \"PID\": 907175060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2776, \"PID\": 907180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2777, \"PID\": 907181090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9272, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1749, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2778, \"PID\": 907187010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 13426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 57.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 107, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2779, \"PID\": 907192010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2780, \"PID\": 907194130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 2781, \"PID\": 907196020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1541.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 468, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 2782, \"PID\": 907200170, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 428.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2783, \"PID\": 907201160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 62.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 317.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2784, \"PID\": 907201230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2785, \"PID\": 907202140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 971.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 971, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2786, \"PID\": 907203010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 9560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2787, \"PID\": 907203040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 149900}, {\"Order\": 2788, \"PID\": 907227090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2789, \"PID\": 907230240, \"MSSubClass\": 160, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 3612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Landmrk\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2790, \"PID\": 907251100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 1989, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2791, \"PID\": 907252050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 199.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 826.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2792, \"PID\": 907254050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 9468, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2793, \"PID\": 907255010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2794, \"PID\": 907255050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1787, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1787, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2795, \"PID\": 907262080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8726, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 1909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2796, \"PID\": 907265030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 668.0, \"TotalBsmtSF\": 1654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1654, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2797, \"PID\": 907270050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10566, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 1124, \"LowQualFinSF\": 0, \"GrLivArea\": 2214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 646.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268500}, {\"Order\": 2798, \"PID\": 907275030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210900}, {\"Order\": 2799, \"PID\": 907285010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 258.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1070, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 2800, \"PID\": 907285100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 1045, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 2801, \"PID\": 907290020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 989, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274300}, {\"Order\": 2802, \"PID\": 907290080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216837}, {\"Order\": 2803, \"PID\": 907290160, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2804, \"PID\": 907290230, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155900}, {\"Order\": 2805, \"PID\": 907290260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1079.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 685.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233230}, {\"Order\": 2806, \"PID\": 907401050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2807, \"PID\": 907401080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2808, \"PID\": 907405030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2809, \"PID\": 907410040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8581, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203160}, {\"Order\": 2810, \"PID\": 907410100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 827, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195800}, {\"Order\": 2811, \"PID\": 907410110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212900}, {\"Order\": 2812, \"PID\": 907412010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2813, \"PID\": 907414040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198000}, {\"Order\": 2814, \"PID\": 907418020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 750, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173900}, {\"Order\": 2815, \"PID\": 907420070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 163990}, {\"Order\": 2816, \"PID\": 907420090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164990}, {\"Order\": 2817, \"PID\": 908102020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 337.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 420, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 2818, \"PID\": 908102320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 17755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2819, \"PID\": 908102330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2820, \"PID\": 908103310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 7840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 355.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2821, \"PID\": 908103320, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2822, \"PID\": 908127050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 16133, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2823, \"PID\": 908128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2824, \"PID\": 908130020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 475.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 297.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117250}, {\"Order\": 2825, \"PID\": 908178050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1150.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1150, \"LowQualFinSF\": 0, \"GrLivArea\": 2314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2826, \"PID\": 908186060, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2827, \"PID\": 908186070, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 140000}, {\"Order\": 2828, \"PID\": 908186090, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 142500}, {\"Order\": 2829, \"PID\": 908188110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2830, \"PID\": 908188120, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2831, \"PID\": 908188130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2832, \"PID\": 908188140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2833, \"PID\": 908188150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 3363, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 976.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2834, \"PID\": 908225180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6956, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 312, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 265.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97900}, {\"Order\": 2835, \"PID\": 908227010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 846, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 92000}, {\"Order\": 2836, \"PID\": 908227030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1669, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 107000}, {\"Order\": 2837, \"PID\": 908227040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 658.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 658, \"2ndFlrSF\": 526, \"LowQualFinSF\": 0, \"GrLivArea\": 1184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 81000}, {\"Order\": 2838, \"PID\": 908228040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 2839, \"PID\": 908275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 167.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2840, \"PID\": 908275290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 16012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 691.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 609.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2841, \"PID\": 909101050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 207, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2842, \"PID\": 909101080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 450, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 2843, \"PID\": 909101190, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 795.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 795, \"LowQualFinSF\": 481, \"GrLivArea\": 2230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2844, \"PID\": 909101330, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8088, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1922, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 35000}, {\"Order\": 2845, \"PID\": 909103020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 218, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2846, \"PID\": 909131125, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 7082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 980, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2847, \"PID\": 909175030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1192, \"2ndFlrSF\": 403, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2848, \"PID\": 909176180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 128.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 493, \"LowQualFinSF\": 0, \"GrLivArea\": 1551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2849, \"PID\": 909201180, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 58.0, \"LotArea\": 6430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 816, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128000}, {\"Order\": 2850, \"PID\": 909250070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 424.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 743, \"2ndFlrSF\": 736, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 530, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2851, \"PID\": 909250120, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 892, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138887}, {\"Order\": 2852, \"PID\": 909250200, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 4899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 2853, \"PID\": 909250210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 514, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2854, \"PID\": 909253080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9399, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 818, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1919.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2855, \"PID\": 909254070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 901, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200100}, {\"Order\": 2856, \"PID\": 909256010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10164, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2857, \"PID\": 909256020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2858, \"PID\": 909275230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 272, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2859, \"PID\": 909275250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 940, \"2ndFlrSF\": 610, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 429, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2860, \"PID\": 909276010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 725, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2861, \"PID\": 909276070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 113, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2862, \"PID\": 909279040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 67, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2863, \"PID\": 909280030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2864, \"PID\": 909280070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 8170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 526.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 549, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 2865, \"PID\": 909281010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1175, \"LowQualFinSF\": 0, \"GrLivArea\": 2345, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2866, \"PID\": 909282060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 104, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 2867, \"PID\": 909282110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 14210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 697, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 365.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2868, \"PID\": 909425120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 296.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 547.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1811, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 230000}, {\"Order\": 2869, \"PID\": 909425180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 459.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1283.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2870, \"PID\": 909426060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 405.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2871, \"PID\": 909428110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 375.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2872, \"PID\": 909475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 734.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 2873, \"PID\": 910200020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 102000}, {\"Order\": 2874, \"PID\": 910200060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 132, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145400}, {\"Order\": 2875, \"PID\": 910203100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 61.0, \"LotArea\": 8534, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72000}, {\"Order\": 2876, \"PID\": 910203230, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 272.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 2877, \"PID\": 910207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8765, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 327.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 106500}, {\"Order\": 2878, \"PID\": 910226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 327.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2879, \"PID\": 911175360, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 439, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 47, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2880, \"PID\": 911175410, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 69.0, \"LotArea\": 12366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 23, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 51689}, {\"Order\": 2881, \"PID\": 911175430, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 35311}, {\"Order\": 2882, \"PID\": 911175440, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2883, \"PID\": 911225110, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 360, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 2884, \"PID\": 911370430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5748, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1778, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2885, \"PID\": 911370530, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2886, \"PID\": 913350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 23580, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242500}, {\"Order\": 2887, \"PID\": 914452060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1664.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2888, \"PID\": 914474020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9116, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 2889, \"PID\": 914476050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2890, \"PID\": 914476130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 11080, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 257.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2891, \"PID\": 914476500, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1907.0, \"TotalBsmtSF\": 1907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1959, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 766.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 171000}, {\"Order\": 2892, \"PID\": 916225130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 26178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 293.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1210.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 1281, \"LowQualFinSF\": 0, \"GrLivArea\": 2519, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 2893, \"PID\": 916252170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2894, \"PID\": 916325040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 50102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 909.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1650, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 250764}, {\"Order\": 2895, \"PID\": 916326010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 653.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1686.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 574, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2896, \"PID\": 916402125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 13811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2897, \"PID\": 916403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1309.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2898, \"PID\": 916403130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2514, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 693.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2899, \"PID\": 916460070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1136.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 129.0, \"TotalBsmtSF\": 1381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2900, \"PID\": 916475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 630.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 2901, \"PID\": 916477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13618, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2902, \"PID\": 921205030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11443, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2028, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 326, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 369900}, {\"Order\": 2903, \"PID\": 921205050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 382.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 225, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 359900}, {\"Order\": 2904, \"PID\": 923125030, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 125.0, \"LotArea\": 31250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81500}, {\"Order\": 2905, \"PID\": 923202025, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1243.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 45.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2906, \"PID\": 923203090, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 897.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 125, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2907, \"PID\": 923203100, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 443.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 405.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 199, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2908, \"PID\": 923205120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 17217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84500}, {\"Order\": 2909, \"PID\": 923225190, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2910, \"PID\": 923225240, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 173.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 757.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2911, \"PID\": 923225260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 3964, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 837.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 1230, \"LowQualFinSF\": 0, \"GrLivArea\": 2521, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 728, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151400}, {\"Order\": 2912, \"PID\": 923225510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 2913, \"PID\": 923226150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1503.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2914, \"PID\": 923226180, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 2915, \"PID\": 923226290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79400}, {\"Order\": 2916, \"PID\": 923227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2917, \"PID\": 923228130, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 92000}, {\"Order\": 2918, \"PID\": 923228180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 87550}, {\"Order\": 2919, \"PID\": 923228210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 2920, \"PID\": 923228260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90500}, {\"Order\": 2921, \"PID\": 923228310, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1894, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 71000}, {\"Order\": 2922, \"PID\": 923229110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 12640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 396.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150900}, {\"Order\": 2923, \"PID\": 923230040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9297, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 188000}, {\"Order\": 2924, \"PID\": 923250060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2925, \"PID\": 923251180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 20000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 131000}, {\"Order\": 2926, \"PID\": 923275080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 7937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1003.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1003, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1003, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2927, \"PID\": 923276100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 324.0, \"BsmtUnfSF\": 239.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2928, \"PID\": 923400125, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2929, \"PID\": 924100070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1071.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 123.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1389, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2930, \"PID\": 924151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 1004, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "pts = alt.selection_point(encodings=['x'])\n",
        "\n",
        "rect = alt.Chart(train).mark_rect().encode(\n",
        "    x=alt.X('GrLivArea', bin=alt.Bin(maxbins=40)),\n",
        "    y=alt.Y('GarageArea', bin=alt.Bin(maxbins=40)),\n",
        "    color='average(SalePrice)'\n",
        ").properties(\n",
        "    width=500,\n",
        "    height=300\n",
        ").transform_filter(\n",
        "    pts\n",
        ")\n",
        "\n",
        "bar = alt.Chart(train).mark_bar().encode(\n",
        "    x='ExterQual:N',\n",
        "    y='count()',\n",
        "    color=alt.condition(pts, alt.ColorValue(\"steelblue\"), alt.ColorValue(\"grey\")),\n",
        "    tooltip=['ExterQual', 'count()']\n",
        ").properties(\n",
        "    width=550,\n",
        "    height=200\n",
        ").add_params(\n",
        "    pts\n",
        ")\n",
        "\n",
        "\n",
        "alt.vconcat(\n",
        "    rect,\n",
        "    bar\n",
        ").resolve_legend(\n",
        "    color=\"independent\",\n",
        "    size=\"independent\"\n",
        ").configure_axis(\n",
        "    grid=False\n",
        ")"
      ],
      "id": "cell-17"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Dot Dash Plot\n",
        "\n",
        "A Dot Dash Plot is basically a **scatter plot** with **both axis\n",
        "removed** and replaced with **barcode plots** (aka strip plots), which\n",
        "allow you to **see the distribution of values** of each measure used in\n",
        "the scatter plot."
      ],
      "id": "45e20ba1-abf3-472c-abb8-5fb193938f27"
    },
    {
      "cell_type": "code",
      "execution_count": 21,
      "metadata": {
        "cell_id": "9532731b358e44dc8feaf4601c8eed91",
        "deepnote_cell_type": "code",
        "deepnote_to_be_reexecuted": false,
        "execution_millis": 903,
        "execution_start": 1685107229478,
        "papermill": {
          "duration": 0.696026,
          "end_time": "2023-01-11T23:38:32.807553",
          "exception": false,
          "start_time": "2023-01-11T23:38:32.111527",
          "status": "completed"
        },
        "source_hash": "53a2c964",
        "tags": []
      },
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-0c4880ec95dc4f4184dec2e0a0783df1.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-0c4880ec95dc4f4184dec2e0a0783df1.vega-embed details,\n",
              "  #altair-viz-0c4880ec95dc4f4184dec2e0a0783df1.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-0c4880ec95dc4f4184dec2e0a0783df1\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-0c4880ec95dc4f4184dec2e0a0783df1\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-0c4880ec95dc4f4184dec2e0a0783df1\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"axis\": {\"grid\": false}}, \"hconcat\": [{\"mark\": {\"type\": \"tick\"}, \"encoding\": {\"color\": {\"condition\": {\"param\": \"param_8\", \"field\": \"KitchenQual\"}, \"value\": \"lightgrey\"}, \"x\": {\"axis\": {\"domain\": false, \"labels\": false, \"ticks\": false}, \"field\": \"KitchenQual\", \"title\": \"\", \"type\": \"nominal\"}, \"y\": {\"axis\": {\"domain\": false, \"labels\": false, \"ticks\": false}, \"field\": \"SalePrice\", \"type\": \"quantitative\"}}, \"name\": \"view_8\"}, {\"vconcat\": [{\"mark\": {\"type\": \"point\"}, \"encoding\": {\"color\": {\"condition\": {\"param\": \"param_8\", \"field\": \"KitchenQual\"}, \"value\": \"grey\"}, \"x\": {\"field\": \"GrLivArea\", \"title\": \"\", \"type\": \"quantitative\"}, \"y\": {\"field\": \"SalePrice\", \"title\": \"\", \"type\": \"quantitative\"}}, \"name\": \"view_6\"}, {\"mark\": {\"type\": \"tick\"}, \"encoding\": {\"color\": {\"condition\": {\"param\": \"param_8\", \"field\": \"KitchenQual\"}, \"value\": \"lightgrey\"}, \"x\": {\"axis\": {\"domain\": false, \"labels\": false, \"ticks\": false}, \"field\": \"GrLivArea\", \"type\": \"quantitative\"}, \"y\": {\"axis\": {\"domain\": false, \"labels\": false, \"ticks\": false}, \"field\": \"KitchenQual\", \"title\": \"\", \"type\": \"nominal\"}}, \"name\": \"view_7\"}]}], \"data\": {\"name\": \"data-bd4440f2bd659840503c9701cdb81363\"}, \"params\": [{\"name\": \"param_8\", \"select\": {\"type\": \"interval\"}, \"views\": [\"view_8\", \"view_6\", \"view_7\"]}], \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-bd4440f2bd659840503c9701cdb81363\": [{\"Order\": 1, \"PID\": 526301100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 141.0, \"LotArea\": 31770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2, \"PID\": 526350040, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 80.0, \"LotArea\": 11622, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 3, \"PID\": 526351010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 393, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 12500, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 4, \"PID\": 526353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1045.0, \"TotalBsmtSF\": 2110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 5, \"PID\": 527105010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189900}, {\"Order\": 6, \"PID\": 527105030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 7, \"PID\": 527127150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 8, \"PID\": 527145080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 263.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191500}, {\"Order\": 9, \"PID\": 527146030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1180.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 10, \"PID\": 527162130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 776, \"LowQualFinSF\": 0, \"GrLivArea\": 1804, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 11, \"PID\": 527163010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 763, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1655, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 157, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 12, \"PID\": 527165230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1992, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 935.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 233.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 13, \"PID\": 527166040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180400}, {\"Order\": 14, \"PID\": 527180040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 15, \"PID\": 527182190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 1120.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 16, \"PID\": 527216070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 53504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 603.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1690, \"2ndFlrSF\": 1589, \"LowQualFinSF\": 0, \"GrLivArea\": 3279, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 841.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 503, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 538000}, {\"Order\": 17, \"PID\": 527225035, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 152.0, \"LotArea\": 12134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1988, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 427.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 325, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 18, \"PID\": 527258010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 2, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 1856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394432}, {\"Order\": 19, \"PID\": 527276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 19138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 20, \"PID\": 527302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 163.0, \"BsmtUnfSF\": 589.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 21, \"PID\": 527358140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 22, \"PID\": 527358200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 81.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 885.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1173, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 170000}, {\"Order\": 23, \"PID\": 527368020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 814, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 24, \"PID\": 527402200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11241, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 25, \"PID\": 527402250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12537, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 26, \"PID\": 527403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 27, \"PID\": 527404120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 78.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 28, \"PID\": 527425090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 29, \"PID\": 527427230, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 5858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1051.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 30, \"PID\": 527451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 327.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 31, \"PID\": 527451330, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 32, \"PID\": 527451410, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 381.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 88000}, {\"Order\": 33, \"PID\": 527452190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 709.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 34, \"PID\": 527453130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 514.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 35, \"PID\": 527453150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 836.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 36, \"PID\": 527454200, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 37, \"PID\": 528108120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1590.0, \"TotalBsmtSF\": 1590.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1627, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 2334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 376162}, {\"Order\": 38, \"PID\": 528112020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 39, \"PID\": 528120060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1940, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395192}, {\"Order\": 40, \"PID\": 528120090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1544.0, \"TotalBsmtSF\": 1544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290941}, {\"Order\": 41, \"PID\": 528120100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 220000}, {\"Order\": 42, \"PID\": 528120120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 615.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 43, \"PID\": 528138020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1794.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1822, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259000}, {\"Order\": 44, \"PID\": 528138060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1515.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 45, \"PID\": 528150070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12919, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 760.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 2330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 611657}, {\"Order\": 46, \"PID\": 528175010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6371, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224000}, {\"Order\": 47, \"PID\": 528176010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1095.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1473.0, \"TotalBsmtSF\": 2846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 958.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 500000}, {\"Order\": 48, \"PID\": 528176070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 563, \"LowQualFinSF\": 0, \"GrLivArea\": 2250, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 49, \"PID\": 528180070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 412.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1296.0, \"TotalBsmtSF\": 1752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 50, \"PID\": 528181050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 7132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 51, \"PID\": 528188120, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 52, \"PID\": 528218150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 18494, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1324.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 53, \"PID\": 528228285, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 54, \"PID\": 528228440, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 55, \"PID\": 528231020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 58.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 56, \"PID\": 528240070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 1100, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216500}, {\"Order\": 57, \"PID\": 528240130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185088}, {\"Order\": 58, \"PID\": 528250100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 59, \"PID\": 528292020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9505, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 1151, \"LowQualFinSF\": 0, \"GrLivArea\": 2035, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 60, \"PID\": 528328100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 14774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1393.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2599, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 668, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 333168}, {\"Order\": 61, \"PID\": 528344070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 17433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1629.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1645, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 2475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 962.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 23, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 62, \"PID\": 528358010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 919.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 56, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260400}, {\"Order\": 63, \"PID\": 528363130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 1122, \"LowQualFinSF\": 0, \"GrLivArea\": 2622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 64, \"PID\": 528382020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1999, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 348.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1106, \"LowQualFinSF\": 0, \"GrLivArea\": 2270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 671.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 65, \"PID\": 528382030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 66, \"PID\": 528386040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 14720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 579.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1217.0, \"TotalBsmtSF\": 2033.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2053, \"2ndFlrSF\": 1185, \"LowQualFinSF\": 0, \"GrLivArea\": 3238, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 283, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 67, \"PID\": 528445060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8987, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221500}, {\"Order\": 68, \"PID\": 528456160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 92.0, \"LotArea\": 9215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204500}, {\"Order\": 69, \"PID\": 528458070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1547, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215200}, {\"Order\": 70, \"PID\": 528458110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 488.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1566, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 71, \"PID\": 528477080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 12552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 222.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 956, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 72, \"PID\": 528480090, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271500}, {\"Order\": 73, \"PID\": 531367050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 956.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233000}, {\"Order\": 74, \"PID\": 531369060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 75, \"PID\": 531380080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 76, \"PID\": 531451110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 543.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 119.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 77, \"PID\": 531451280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 635, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 78, \"PID\": 531452020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 79, \"PID\": 531452050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 353, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 80, \"PID\": 531452180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1744, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 238, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 81, \"PID\": 531453010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 82, \"PID\": 531453040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 83, \"PID\": 531477050, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67500}, {\"Order\": 84, \"PID\": 532351140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1318, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 85, \"PID\": 532354090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 899.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1155, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1155, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 86, \"PID\": 532376160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 416, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 87, \"PID\": 532377060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 31.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 88, \"PID\": 532377100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 220, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 89, \"PID\": 532378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6897, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 90, \"PID\": 532479070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 15410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 126.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 859.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 169000}, {\"Order\": 91, \"PID\": 533130020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10186, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 92, \"PID\": 533130130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 981.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1231.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2349, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 362500}, {\"Order\": 93, \"PID\": 533130160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1129.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 823, \"LowQualFinSF\": 0, \"GrLivArea\": 2225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 713.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 94, \"PID\": 533205060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 25.0, \"LotArea\": 4835, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 95, \"PID\": 533208090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 39.0, \"LotArea\": 3515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 96, \"PID\": 533210060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3215, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 97, \"PID\": 533212010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 98, \"PID\": 533212020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 99, \"PID\": 533212060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 376.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 100, \"PID\": 533213030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 101, \"PID\": 533221090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 102, \"PID\": 533221110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1159.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 466.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 103, \"PID\": 533223020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 696, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 104, \"PID\": 533223100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 244.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147110}, {\"Order\": 105, \"PID\": 533238045, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 57.0, \"LotArea\": 12853, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 1642.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 224, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267916}, {\"Order\": 106, \"PID\": 533244030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 7379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 107, \"PID\": 533253060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 4420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 108, \"PID\": 533253210, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1052.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 223, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 109, \"PID\": 533352170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13517, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 475.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 110, \"PID\": 534102025, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 659.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 111, \"PID\": 534129040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1323.0, \"TotalBsmtSF\": 1829.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1829, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 535.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218500}, {\"Order\": 112, \"PID\": 534151175, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1137.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243500}, {\"Order\": 113, \"PID\": 534152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 114, \"PID\": 534152070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 687.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 46.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 1891, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 115, \"PID\": 534152100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10421, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 394.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 734, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 66, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 116, \"PID\": 534176060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 982.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 1161.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1381, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1381, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 117, \"PID\": 534176230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 715, \"LowQualFinSF\": 0, \"GrLivArea\": 1645, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 118, \"PID\": 534202160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142250}, {\"Order\": 119, \"PID\": 534251320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 451.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 81.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1328.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 120, \"PID\": 534276360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128950}, {\"Order\": 121, \"PID\": 534401110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1209, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 122, \"PID\": 534401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 9680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1510, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 123, \"PID\": 534403360, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10600, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136300}, {\"Order\": 124, \"PID\": 534403410, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14112, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1014.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 227, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 125, \"PID\": 534425310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 156.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 126, \"PID\": 534427010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 13260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 127, \"PID\": 534430080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 49.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1029.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142125}, {\"Order\": 128, \"PID\": 534431050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 670.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1929, \"2ndFlrSF\": 532, \"LowQualFinSF\": 0, \"GrLivArea\": 2461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197600}, {\"Order\": 129, \"PID\": 534431070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 17360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1019, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 130, \"PID\": 534450180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 131, \"PID\": 534451150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1940, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 263, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76500}, {\"Order\": 132, \"PID\": 534475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 133, \"PID\": 534476260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 132.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 189, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 134, \"PID\": 534479320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 244.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 135, \"PID\": 535101020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 136, \"PID\": 535106190, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 361.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1169, \"LowQualFinSF\": 0, \"GrLivArea\": 2274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154300}, {\"Order\": 137, \"PID\": 535125010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 287.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 912.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1947.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2207, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 301, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 138, \"PID\": 535126040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 137.0, \"LotArea\": 16492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 713.0, \"BsmtUnfSF\": 557.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 139, \"PID\": 535152010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1604.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 140, \"PID\": 535152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 300, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 141, \"PID\": 535152130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 142, \"PID\": 535152150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 143, \"PID\": 535152250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 144, \"PID\": 535153070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1194.0, \"TotalBsmtSF\": 1194.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 145, \"PID\": 535154050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142000}, {\"Order\": 146, \"PID\": 535175070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 324.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 571.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 143, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 147, \"PID\": 535175180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10725, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 91.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1206, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108538}, {\"Order\": 148, \"PID\": 535179020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 149, \"PID\": 535180130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 832, \"2ndFlrSF\": 505, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 263.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 150, \"PID\": 535302080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 339.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 151, \"PID\": 535302200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 119.0, \"LotArea\": 10895, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 152, \"PID\": 535304060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 153, \"PID\": 535304180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 731.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109000}, {\"Order\": 154, \"PID\": 535325400, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 155, \"PID\": 535327140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 156, \"PID\": 535350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 362.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 157, \"PID\": 535350040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 5868, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 158, \"PID\": 535353190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 17503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97500}, {\"Order\": 159, \"PID\": 535377090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 160, \"PID\": 535401080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 72.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 258.0, \"BsmtUnfSF\": 733.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 161, \"PID\": 535425010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 1080, \"LowQualFinSF\": 0, \"GrLivArea\": 2978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 162, \"PID\": 535450210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 481.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 163, \"PID\": 535453070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 906.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 164, \"PID\": 535454070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 475, \"LowQualFinSF\": 0, \"GrLivArea\": 1385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 165, \"PID\": 535456110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 486.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134800}, {\"Order\": 166, \"PID\": 535457010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1116.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 385, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 167, \"PID\": 535457090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 7635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 350.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 168, \"PID\": 535476350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 263.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1395, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 657, \"OpenPorchSF\": 0, \"EnclosedPorch\": 113, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 169, \"PID\": 535477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 170, \"PID\": 902102100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 771.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80400}, {\"Order\": 171, \"PID\": 902104060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 172, \"PID\": 902106130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4485, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 579.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 51, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 173, \"PID\": 902106140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1028, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 130, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 174, \"PID\": 902110090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 5805, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1073.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1347, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 175, \"PID\": 902125080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1605, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107400}, {\"Order\": 176, \"PID\": 902125160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 4608, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 177, \"PID\": 902128170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 294.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 804, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 178, \"PID\": 902206040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 692.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 390, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 179, \"PID\": 902206130, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 827.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 180, \"PID\": 902206220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 606, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 181, \"PID\": 902206240, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 185, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 334, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 182, \"PID\": 902207130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1923, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 780.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 12789}, {\"Order\": 183, \"PID\": 902207140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1928, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105900}, {\"Order\": 184, \"PID\": 902305110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 228, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 185, \"PID\": 902327040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 966, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 186, \"PID\": 902329030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 187, \"PID\": 902401060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 18, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 188, \"PID\": 902402010, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 7407, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 923.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149700}, {\"Order\": 189, \"PID\": 902402130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 622, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 190, \"PID\": 902402250, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1885, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 777.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 191, \"PID\": 902403070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140750}, {\"Order\": 192, \"PID\": 903204040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1030, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 363.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 193, \"PID\": 903206120, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 194, \"PID\": 903225150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 765, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 765, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 195, \"PID\": 903226160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 452.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 12.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 134000}, {\"Order\": 196, \"PID\": 903227020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 197, \"PID\": 903227150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 955, \"2ndFlrSF\": 498, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 148, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 198, \"PID\": 903228150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 221, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 199, \"PID\": 903232190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 548, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 200, \"PID\": 903233120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 928, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138400}, {\"Order\": 201, \"PID\": 903234050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 164.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 202, \"PID\": 903425110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 10300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 11, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 203, \"PID\": 903426180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 888.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 1074, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 364, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 204, \"PID\": 903426200, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 205, \"PID\": 903430080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 3068, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 662, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 206, \"PID\": 903450110, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 110.0, \"LotArea\": 8472, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 207, \"PID\": 903454060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 372, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3500, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 208, \"PID\": 903476030, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 7630, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 209, \"PID\": 904100140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1032.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 1196, \"LowQualFinSF\": 0, \"GrLivArea\": 2403, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 0, \"EnclosedPorch\": 318, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 244400}, {\"Order\": 210, \"PID\": 904101110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 365.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 211, \"PID\": 904300150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 499, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Po\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 212, \"PID\": 904302260, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1026.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 180, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 213, \"PID\": 904350045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 214, \"PID\": 904351040, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 6449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1907, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 73.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93369}, {\"Order\": 215, \"PID\": 904352190, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 6048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114900}, {\"Order\": 216, \"PID\": 905101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 6342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1875, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94000}, {\"Order\": 217, \"PID\": 905101300, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1832, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 218, \"PID\": 905101310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1768.0, \"TotalBsmtSF\": 1768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 219, \"PID\": 905102060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 1039.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 220, \"PID\": 905103060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11341, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1302.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 221, \"PID\": 905104210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8521, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 842.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 222, \"PID\": 905105070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 668.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 223, \"PID\": 905105200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 47.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 474.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 224, \"PID\": 905106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 663, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 379, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 225, \"PID\": 905106170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137250}, {\"Order\": 226, \"PID\": 905107110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7424, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1373, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1373, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160250}, {\"Order\": 227, \"PID\": 905107250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 453.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 228, \"PID\": 905107320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 328.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1386, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 229, \"PID\": 905109130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 954, \"LowQualFinSF\": 0, \"GrLivArea\": 2260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 328000}, {\"Order\": 230, \"PID\": 905109170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1092.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1483, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1483, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 496, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 231, \"PID\": 905201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 756, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 232, \"PID\": 905202090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 233, \"PID\": 905325030, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23595, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 74.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 192, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 234, \"PID\": 905352140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 336, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 235, \"PID\": 905378040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 18600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 684.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 558, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 236, \"PID\": 905426060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 108.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 835, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 237, \"PID\": 905426200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11479, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 387.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 238, \"PID\": 905451320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 44, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 239, \"PID\": 905452110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 362, \"GrLivArea\": 1531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 209.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 240, \"PID\": 905452160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 954.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 1172.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1172, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 241, \"PID\": 905453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1176.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 242, \"PID\": 905453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 17485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1508, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Partial\", \"SalePrice\": 308030}, {\"Order\": 243, \"PID\": 905475510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1250.0, \"TotalBsmtSF\": 1250.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 244, \"PID\": 905478190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 245, \"PID\": 906201030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 977, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1732, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 246, \"PID\": 906201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 11980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 177.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1433.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1433.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 278, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 247, \"PID\": 906204230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 12361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 86.0, \"TotalBsmtSF\": 946.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1017.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 450, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 248, \"PID\": 906223090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 750.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 249, \"PID\": 906225210, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 250, \"PID\": 906378100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245350}, {\"Order\": 251, \"PID\": 906380190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 252, \"PID\": 906385010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 10402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 740.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198900}, {\"Order\": 253, \"PID\": 906385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1222.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1222, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 254, \"PID\": 906402200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12376, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1470.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 1523, \"LowQualFinSF\": 0, \"GrLivArea\": 3222, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 367, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 255, \"PID\": 906425045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 14235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 614, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 256, \"PID\": 906477110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 257, \"PID\": 907125090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 71, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 258, \"PID\": 907180050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 878.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 259, \"PID\": 907185060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 260, \"PID\": 907200280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 15240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 688.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 261, \"PID\": 907200290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161750}, {\"Order\": 262, \"PID\": 907200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 365, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128200}, {\"Order\": 263, \"PID\": 907203070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 264, \"PID\": 907250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 296.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 265, \"PID\": 907252120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 479.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1581.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 266, \"PID\": 907262050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 9548, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 223.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 458.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 613.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 267, \"PID\": 907280040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 331, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 268, \"PID\": 907290040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1649.0, \"TotalBsmtSF\": 1649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 269, \"PID\": 907290170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 270, \"PID\": 907290240, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 271, \"PID\": 907401090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 10635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 972.0, \"BsmtUnfSF\": 315.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 262, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 272, \"PID\": 907410080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 109.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 761.0, \"TotalBsmtSF\": 1473.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 273, \"PID\": 907414030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185500}, {\"Order\": 274, \"PID\": 908102060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 84900}, {\"Order\": 275, \"PID\": 908102110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 155891}, {\"Order\": 276, \"PID\": 908102130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 277, \"PID\": 908102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 278, \"PID\": 908102300, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 792, \"2ndFlrSF\": 328, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 64000}, {\"Order\": 279, \"PID\": 908103350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125200}, {\"Order\": 280, \"PID\": 908152080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 7819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 422.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 281, \"PID\": 908203100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 282, \"PID\": 908208020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 8546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1121.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 283, \"PID\": 908225320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 94.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1487, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 284, \"PID\": 908226130, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 285, \"PID\": 908275300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1526, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 286, \"PID\": 909100080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 4853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 974.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 287, \"PID\": 909100110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 841, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 288, \"PID\": 909101070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 289, \"PID\": 909176140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 242, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 290, \"PID\": 909176150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 166, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 291, \"PID\": 909177100, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 862, \"2ndFlrSF\": 1788, \"LowQualFinSF\": 0, \"GrLivArea\": 2650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 292, \"PID\": 909250030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 293, \"PID\": 909250060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 804.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 2447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 294, \"PID\": 909281080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 371.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 86, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 295, \"PID\": 909426080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 657.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1075, \"LowQualFinSF\": 0, \"GrLivArea\": 2177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 296, \"PID\": 909427230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 877.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 1152, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266500}, {\"Order\": 297, \"PID\": 909428280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 207, \"EnclosedPorch\": 162, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 298, \"PID\": 909452114, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 423.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203135}, {\"Order\": 299, \"PID\": 909455030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 300, \"PID\": 909455040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 76.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1115.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1191, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1191, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 301, \"PID\": 909475140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15602, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1801, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 289000}, {\"Order\": 302, \"PID\": 910202060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 61.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 358, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 303, \"PID\": 910203250, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 540, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 304, \"PID\": 910205120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 727, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 305, \"PID\": 911128180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 68400}, {\"Order\": 306, \"PID\": 911202100, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 859.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 859, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 102776}, {\"Order\": 307, \"PID\": 911204090, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 54, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 55993}, {\"Order\": 308, \"PID\": 911204100, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1896, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1896.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 265, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 50138}, {\"Order\": 309, \"PID\": 911370510, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246000}, {\"Order\": 310, \"PID\": 914467040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 615.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1916, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 741.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 311, \"PID\": 914475090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9620, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1243.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 375, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 80, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 312, \"PID\": 914476520, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 9196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 313, \"PID\": 914478045, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 473.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169900}, {\"Order\": 314, \"PID\": 914478110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1958.0, \"TotalBsmtSF\": 1958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 315, \"PID\": 916125360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 57200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 334.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 50, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 316, \"PID\": 916386010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 78.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1346, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 317, \"PID\": 916386020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1214.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179781}, {\"Order\": 318, \"PID\": 916386060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 319, \"PID\": 916386090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 774.0, \"TotalBsmtSF\": 774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 1194, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 269500}, {\"Order\": 320, \"PID\": 916455170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 1894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214900}, {\"Order\": 321, \"PID\": 916475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202900}, {\"Order\": 322, \"PID\": 921128020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 13214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2002.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2018, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2018, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378500}, {\"Order\": 323, \"PID\": 923201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 42.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 324, \"PID\": 923202105, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10114, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1430.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 325, \"PID\": 923204150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 326, \"PID\": 923205015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1344.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166500}, {\"Order\": 327, \"PID\": 923225300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83500}, {\"Order\": 328, \"PID\": 923225390, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 31.0, \"LotArea\": 2394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 945, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 329, \"PID\": 923225440, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 2592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 129.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 232.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 536, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 330, \"PID\": 923226250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 331, \"PID\": 923226320, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1491, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75500}, {\"Order\": 332, \"PID\": 923228270, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88250}, {\"Order\": 333, \"PID\": 923228370, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 334, \"PID\": 923230190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 469.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 335, \"PID\": 923251080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 26142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 336, \"PID\": 923276030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 207.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 337, \"PID\": 923276250, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1985, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1216.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 338, \"PID\": 923426070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 22, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 339, \"PID\": 924100050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 388.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 615, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 287, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 340, \"PID\": 924151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1341.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 284.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1679.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 64, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 341, \"PID\": 924152030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12961, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 342, \"PID\": 526302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 343, \"PID\": 526351100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 440.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 844.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 344, \"PID\": 526355080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 542.0, \"TotalBsmtSF\": 1952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 2704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 269, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 345, \"PID\": 527105070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 346, \"PID\": 527105130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 1275, \"LowQualFinSF\": 0, \"GrLivArea\": 2283, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 347, \"PID\": 527107130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1628, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 490, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 348, \"PID\": 527108070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 14892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1746, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377500}, {\"Order\": 349, \"PID\": 527110020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 22.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 350, \"PID\": 527127100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 28.0, \"LotArea\": 7296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 243.0, \"TotalBsmtSF\": 2208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2522, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 351, \"PID\": 527131030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 5664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1659, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 352, \"PID\": 527132090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 353, \"PID\": 527146010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 354, \"PID\": 527161040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 355, \"PID\": 527162110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 94, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 291, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 356, \"PID\": 527162120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 357, \"PID\": 527163040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 799.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 799, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 358, \"PID\": 527163070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 359, \"PID\": 527163130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181316}, {\"Order\": 360, \"PID\": 527164020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 7250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 361, \"PID\": 527164060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 362, \"PID\": 527164090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 702, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1481, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 363, \"PID\": 527165130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 364, \"PID\": 527166010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 694.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 1983, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 365, \"PID\": 527180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1424.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 508, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 366, \"PID\": 527182110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 187500}, {\"Order\": 367, \"PID\": 527214050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 17423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 748.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 2216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1166.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 501837}, {\"Order\": 368, \"PID\": 527254020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 464.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2046.0, \"TotalBsmtSF\": 2046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372500}, {\"Order\": 369, \"PID\": 527258020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 16158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 370, \"PID\": 527276160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1934, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 371, \"PID\": 527301320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 692.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 1200, \"LowQualFinSF\": 0, \"GrLivArea\": 2353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 372, \"PID\": 527302175, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 17043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1586, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 373, \"PID\": 527326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 82500}, {\"Order\": 374, \"PID\": 527326150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 375, \"PID\": 527352150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 154000}, {\"Order\": 376, \"PID\": 527353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 363.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 377, \"PID\": 527353060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 229.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1539, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2673, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 378, \"PID\": 527354100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 225.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 379, \"PID\": 527354200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 380, \"PID\": 527355150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1420.0, \"TotalBsmtSF\": 2524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 381, \"PID\": 527356040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157000}, {\"Order\": 382, \"PID\": 527359050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 383, \"PID\": 527359180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 448, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 384, \"PID\": 527364030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1016, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 581.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240900}, {\"Order\": 385, \"PID\": 527365030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 8004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 1103, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 263435}, {\"Order\": 386, \"PID\": 527366030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1058.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 387, \"PID\": 527368010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 225.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 471.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 839, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 388, \"PID\": 527375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1333.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 490, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 389, \"PID\": 527375180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 888.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 390, \"PID\": 527375210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 391, \"PID\": 527376100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 392, \"PID\": 527378140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 333.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 2119, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158000}, {\"Order\": 393, \"PID\": 527401160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 394, \"PID\": 527402220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1002, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 902.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 395, \"PID\": 527403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 439.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 472.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 396, \"PID\": 527404020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1180.0, \"TotalBsmtSF\": 1180.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 397, \"PID\": 527404030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 398, \"PID\": 527405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 726.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 399, \"PID\": 527405160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 239.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 400, \"PID\": 527405180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 401, \"PID\": 527425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97000}, {\"Order\": 402, \"PID\": 527425110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 403, \"PID\": 527450280, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 254.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 404, \"PID\": 527451110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 312.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 405, \"PID\": 527451320, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 406, \"PID\": 527451540, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 79.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 407, \"PID\": 527451640, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 510.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 408, \"PID\": 527451650, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 409, \"PID\": 527452060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 410, \"PID\": 527453050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 411, \"PID\": 527453060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 87, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 412, \"PID\": 527453140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 622.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 413, \"PID\": 527454050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 260, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 414, \"PID\": 527454130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2349, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 389.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 415, \"PID\": 527455050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 416, \"PID\": 527455060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 586, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 417, \"PID\": 527455080, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 279.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 418, \"PID\": 527455090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 345.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 419, \"PID\": 527455240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 420, \"PID\": 527455280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 421, \"PID\": 528102040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1172.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337500}, {\"Order\": 422, \"PID\": 528102140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 726.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1794, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 462000}, {\"Order\": 423, \"PID\": 528104070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 13518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 860.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1926.0, \"TotalBsmtSF\": 1926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 1174, \"LowQualFinSF\": 0, \"GrLivArea\": 3140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 485000}, {\"Order\": 424, \"PID\": 528106020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1767.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 3094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2402, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 555000}, {\"Order\": 425, \"PID\": 528106070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 404, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 426, \"PID\": 528108010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 640.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1566.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 890.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256300}, {\"Order\": 427, \"PID\": 528108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2042.0, \"TotalBsmtSF\": 2042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 253293}, {\"Order\": 428, \"PID\": 528108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1365, \"2ndFlrSF\": 1325, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 197, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 398800}, {\"Order\": 429, \"PID\": 528108070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 154.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 430, \"PID\": 528108130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 2020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 404000}, {\"Order\": 431, \"PID\": 528108140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 2006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 402861}, {\"Order\": 432, \"PID\": 528110010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 13478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1722.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 2296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 842.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 451950}, {\"Order\": 433, \"PID\": 528110020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 2630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2674, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2674, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 610000}, {\"Order\": 434, \"PID\": 528110090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 424.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1734.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 1088, \"LowQualFinSF\": 0, \"GrLivArea\": 2822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1020.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 582933}, {\"Order\": 435, \"PID\": 528112040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1736.0, \"TotalBsmtSF\": 1736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1736, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1736, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 436, \"PID\": 528116010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 99, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 296000}, {\"Order\": 437, \"PID\": 528118060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 23303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 273, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 409900}, {\"Order\": 438, \"PID\": 528120020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1709.0, \"TotalBsmtSF\": 1709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1717, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255500}, {\"Order\": 439, \"PID\": 528120030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1015.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 1739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 927.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 440, \"PID\": 528120160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 262.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274900}, {\"Order\": 441, \"PID\": 528120170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1037.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1531, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 700.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 442, \"PID\": 528138010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 13514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 285.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1142.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 1774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1808, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 443, \"PID\": 528142040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8834, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1170.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1462, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 444, \"PID\": 528142090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 11362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 862.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 185, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 445, \"PID\": 528142130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1124.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 479.0, \"BsmtUnfSF\": 1603.0, \"TotalBsmtSF\": 3206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 446, \"PID\": 528142150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12878, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 418.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 1760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1760, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 190, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 447, \"PID\": 528144020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1502.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233170}, {\"Order\": 448, \"PID\": 528166060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 922.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2336.0, \"TotalBsmtSF\": 2392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 386250}, {\"Order\": 449, \"PID\": 528166090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 724.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1972.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 2452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 886.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 445000}, {\"Order\": 450, \"PID\": 528168030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1295, \"LowQualFinSF\": 0, \"GrLivArea\": 2400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 451, \"PID\": 528172060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1598.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1606, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1606, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 452, \"PID\": 528174050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 6904, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 453, \"PID\": 528174060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 900.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 454, \"PID\": 528174070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 455, \"PID\": 528175050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 456, \"PID\": 528175060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 457, \"PID\": 528176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 730.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2146.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 2492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 949.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 552000}, {\"Order\": 458, \"PID\": 528178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 117.0, \"LotArea\": 15262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 470.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 643.0, \"TotalBsmtSF\": 2200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 685.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 382500}, {\"Order\": 459, \"PID\": 528180120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 308.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1084.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 460, \"PID\": 528180130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 461, \"PID\": 528186010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 1712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 183, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286500}, {\"Order\": 462, \"PID\": 528186180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 863.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 463, \"PID\": 528188020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 464, \"PID\": 528188060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2268, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 465, \"PID\": 528218090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 466, \"PID\": 528220040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 745.0, \"TotalBsmtSF\": 745.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 745, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167800}, {\"Order\": 467, \"PID\": 528221060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 12589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 468, \"PID\": 528221070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 469, \"PID\": 528228290, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1373.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 470, \"PID\": 528228295, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1569, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1569, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 471, \"PID\": 528228435, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1357.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 472, \"PID\": 528228450, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 473, \"PID\": 528228455, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 474, \"PID\": 528228460, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 11.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160200}, {\"Order\": 475, \"PID\": 528235010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 476, \"PID\": 528235090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1010.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1010, \"2ndFlrSF\": 1257, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 477, \"PID\": 528235200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 478, \"PID\": 528240030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 479, \"PID\": 528240060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 779, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184100}, {\"Order\": 480, \"PID\": 528240150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 481, \"PID\": 528250020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 482, \"PID\": 528250040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8174, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 483, \"PID\": 528253010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 484, \"PID\": 528275070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 1276, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 485, \"PID\": 528275160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 1126, \"LowQualFinSF\": 0, \"GrLivArea\": 2004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 486, \"PID\": 528280230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 487, \"PID\": 528290030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9734, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 113.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 488, \"PID\": 528290120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8123, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 489, \"PID\": 528290180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 8433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 683.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1514, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 490, \"PID\": 528290190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 491, \"PID\": 528292030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1177.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2312, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 492, \"PID\": 528292040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 841.0, \"TotalBsmtSF\": 841.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 493, \"PID\": 528292070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 772.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1038, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 494, \"PID\": 528294050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7848, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 495, \"PID\": 528315090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 673.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1163.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337000}, {\"Order\": 496, \"PID\": 528321010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 15138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 689.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 773.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1490, \"2ndFlrSF\": 1304, \"LowQualFinSF\": 0, \"GrLivArea\": 2794, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 403000}, {\"Order\": 497, \"PID\": 528327070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 1455.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1221, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 327000}, {\"Order\": 498, \"PID\": 528344040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 731.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2450, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1069.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 499, \"PID\": 528344100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 975.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 854.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1225.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 1336, \"LowQualFinSF\": 0, \"GrLivArea\": 2612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 336000}, {\"Order\": 500, \"PID\": 528354050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10208, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 921.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1264.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 1067, \"LowQualFinSF\": 0, \"GrLivArea\": 2344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 889.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 501, \"PID\": 528363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 634.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1526.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 2024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 815.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 502, \"PID\": 528365070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 987.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 1274, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 60, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 503, \"PID\": 528385050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 967, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 102, \"EnclosedPorch\": 209, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 504, \"PID\": 528387030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 372.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 623.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263550}, {\"Order\": 505, \"PID\": 528390100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 46589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 528.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 517, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 402000}, {\"Order\": 506, \"PID\": 528390210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 29959, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 507, \"PID\": 528427020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 244600}, {\"Order\": 508, \"PID\": 528431020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1696.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 972.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 509, \"PID\": 528431070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 294.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1614.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1658, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 510, \"PID\": 528435030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1573.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287090}, {\"Order\": 511, \"PID\": 528435050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 512, \"PID\": 528439060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 513, \"PID\": 528441020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 772.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 689.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 514, \"PID\": 528441090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2490, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 226, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 468000}, {\"Order\": 515, \"PID\": 528456180, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 920, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252678}, {\"Order\": 516, \"PID\": 528456220, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 517, \"PID\": 528456240, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7862, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 27.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208300}, {\"Order\": 518, \"PID\": 528458020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 90.0, \"LotArea\": 7993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 519, \"PID\": 528458040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229456}, {\"Order\": 520, \"PID\": 528458060, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1402.0, \"TotalBsmtSF\": 1402.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 205, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229800}, {\"Order\": 521, \"PID\": 528458140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 984.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 522, \"PID\": 528458160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 645.0, \"TotalBsmtSF\": 1766.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 195, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370878}, {\"Order\": 523, \"PID\": 528458180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1348.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1448, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1448, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238500}, {\"Order\": 524, \"PID\": 528477050, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 981, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 310000}, {\"Order\": 525, \"PID\": 528477070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 121.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 526, \"PID\": 528480040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1043.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 527, \"PID\": 528480130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 438, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241000}, {\"Order\": 528, \"PID\": 528480170, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264500}, {\"Order\": 529, \"PID\": 528482040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1662, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1662, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 530, \"PID\": 528482130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 531, \"PID\": 528488100, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1221.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 532, \"PID\": 528490040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 8736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 771.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 360.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1553.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234500}, {\"Order\": 533, \"PID\": 528490070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8127, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 841, \"LowQualFinSF\": 0, \"GrLivArea\": 1653, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 534, \"PID\": 531363010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 178, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 535, \"PID\": 531363030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1087.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 536, \"PID\": 531363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 537, \"PID\": 531369010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 871, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 538, \"PID\": 531369020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 774.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1512.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 845.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 539, \"PID\": 531371050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10083, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 540, \"PID\": 531375040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 541, \"PID\": 531375090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 542, \"PID\": 531375130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 543, \"PID\": 531376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1450, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224243}, {\"Order\": 544, \"PID\": 531379050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 11492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 1209, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 559.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 545, \"PID\": 531382070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10994, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 366.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 257000}, {\"Order\": 546, \"PID\": 531385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1434.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 547, \"PID\": 531450120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 364.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1730, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 548, \"PID\": 531452010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 626, \"2ndFlrSF\": 591, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 549, \"PID\": 531452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1332.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1332, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 550, \"PID\": 531452260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 786, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 551, \"PID\": 531453100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 141.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 465.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 552, \"PID\": 531475220, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 553, \"PID\": 531477020, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 721.0, \"TotalBsmtSF\": 721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 841, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 841, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 554, \"PID\": 531479020, \"MSSubClass\": 45, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 91, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 555, \"PID\": 532353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 884.0, \"BsmtUnfSF\": 28.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 556, \"PID\": 532353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 557, \"PID\": 532354160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 558, \"PID\": 532354230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9079, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 559, \"PID\": 532376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Family\", \"SalePrice\": 124100}, {\"Order\": 560, \"PID\": 532376110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 561, \"PID\": 532377130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131400}, {\"Order\": 562, \"PID\": 532378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 311.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 62383}, {\"Order\": 563, \"PID\": 532378180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 140.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 564, \"PID\": 532478020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15676, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1733.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 92.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 2014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 462, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 255, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 565, \"PID\": 533135020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11949, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1991, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 601.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 216.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 502, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 566, \"PID\": 533206020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 2880, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1376.0, \"TotalBsmtSF\": 1376.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1376, \"2ndFlrSF\": 1629, \"LowQualFinSF\": 0, \"GrLivArea\": 3005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 177, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280750}, {\"Order\": 567, \"PID\": 533210010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164500}, {\"Order\": 568, \"PID\": 533210020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173733}, {\"Order\": 569, \"PID\": 533213010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 3830, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1726.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 254, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 570, \"PID\": 533213020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4217, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 183.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 571, \"PID\": 533213040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 894.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1471, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 572, \"PID\": 533221040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 249.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 573, \"PID\": 533223030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 574, \"PID\": 533236050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1739, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 172500}, {\"Order\": 575, \"PID\": 533252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1252.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 136.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 501, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 225, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318750}, {\"Order\": 576, \"PID\": 533253070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 3782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211500}, {\"Order\": 577, \"PID\": 533254050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15417, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1619.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 20, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241600}, {\"Order\": 578, \"PID\": 533254110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1487, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180500}, {\"Order\": 579, \"PID\": 533352150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1281.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 580, \"PID\": 534125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 727.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 829, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 581, \"PID\": 534127130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 571.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1442.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 371, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 582, \"PID\": 534127170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9156, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185750}, {\"Order\": 583, \"PID\": 534128010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 859.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 32.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 204, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 350, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 584, \"PID\": 534128020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 782, \"LowQualFinSF\": 0, \"GrLivArea\": 2067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 585, \"PID\": 534128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 735, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 586, \"PID\": 534128190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1369, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256900}, {\"Order\": 587, \"PID\": 534129080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1724, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 588, \"PID\": 534129370, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 589, \"PID\": 534129380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 955.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113000}, {\"Order\": 590, \"PID\": 534151120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 283.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 2288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 591, \"PID\": 534152120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 592, \"PID\": 534175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1127.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 78, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213250}, {\"Order\": 593, \"PID\": 534177230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 594, \"PID\": 534200030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 595, \"PID\": 534202170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 596, \"PID\": 534226120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 466.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 597, \"PID\": 534250400, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 168500}, {\"Order\": 598, \"PID\": 534251030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 509.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 599, \"PID\": 534252240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 251.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 630.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 197, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 600, \"PID\": 534275060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 360, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 601, \"PID\": 534275100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 602, \"PID\": 534276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 603, \"PID\": 534277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 604, \"PID\": 534278070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 201.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177625}, {\"Order\": 605, \"PID\": 534278230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 606, \"PID\": 534400050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 345.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 1516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 152, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 607, \"PID\": 534400290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 217.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 512.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1313, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 121, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 608, \"PID\": 534402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1292.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1292, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145100}, {\"Order\": 609, \"PID\": 534402140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 230.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1154.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 610, \"PID\": 534402170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 549.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 611, \"PID\": 534403370, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 563.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 612, \"PID\": 534426110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 991.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 50.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 613, \"PID\": 534429150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 614, \"PID\": 534431130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 100.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 613.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 615, \"PID\": 534450150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 616, \"PID\": 534451110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 185.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 224, \"LowQualFinSF\": 0, \"GrLivArea\": 1203, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 617, \"PID\": 534475185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 1505.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1505, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 162, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 618, \"PID\": 534475250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 260, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 619, \"PID\": 534476150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 1416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 620, \"PID\": 534476320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 621, \"PID\": 534477110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 556, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 622, \"PID\": 534478230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 607.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 623, \"PID\": 535101120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 624, \"PID\": 535104120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10573, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 3.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 625, \"PID\": 535105100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 247.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1394.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1394, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 185, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 626, \"PID\": 535125070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 1562.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 342, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 627, \"PID\": 535125090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 314.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1186, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 628, \"PID\": 535126010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 576.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 2142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 252, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 629, \"PID\": 535126100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1392.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 630, \"PID\": 535150070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1281, \"2ndFlrSF\": 457, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 631, \"PID\": 535151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 313.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 632, \"PID\": 535152230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 661.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 633, \"PID\": 535154060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 203, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 634, \"PID\": 535154130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 635, \"PID\": 535175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 620.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 636, \"PID\": 535175050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1215.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 234, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 637, \"PID\": 535178040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 565.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1202, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1202, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 638, \"PID\": 535178120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 172.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 727.0, \"TotalBsmtSF\": 1382.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 639, \"PID\": 535179160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 155.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 750.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144000}, {\"Order\": 640, \"PID\": 535300120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 19296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 399.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 690.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 641, \"PID\": 535301170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 1297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1297, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1297, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 642, \"PID\": 535302120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 657.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1866.0, \"TotalBsmtSF\": 1866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 643, \"PID\": 535303110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 8128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 644, \"PID\": 535303150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10634, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1319, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1319, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 645, \"PID\": 535304100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 631.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 646, \"PID\": 535325290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1005.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 647, \"PID\": 535351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 178.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 648, \"PID\": 535352090, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 793, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 649, \"PID\": 535353040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1952, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1031.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1031, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 650, \"PID\": 535353060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102900}, {\"Order\": 651, \"PID\": 535353140, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1699, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 95000}, {\"Order\": 652, \"PID\": 535353240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 699.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 801, \"2ndFlrSF\": 726, \"LowQualFinSF\": 0, \"GrLivArea\": 1527, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 653, \"PID\": 535354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 654, \"PID\": 535354100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 655, \"PID\": 535375010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 656, \"PID\": 535375050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 704, \"LowQualFinSF\": 144, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 140, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 657, \"PID\": 535376060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 658, \"PID\": 535377150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 717, \"2ndFlrSF\": 322, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 111, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 659, \"PID\": 535378020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 9022, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1924, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 660, \"PID\": 535378120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10230, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 661, \"PID\": 535381040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 1064, \"GrLivArea\": 2377, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 432, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142900}, {\"Order\": 662, \"PID\": 535382100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 760, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 663, \"PID\": 535383060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 599, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 599, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 59000}, {\"Order\": 664, \"PID\": 535383070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 198, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 665, \"PID\": 535383110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 666, \"PID\": 535383120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 725, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78500}, {\"Order\": 667, \"PID\": 535402010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1248.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 907.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 668, \"PID\": 535402090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 996.0, \"TotalBsmtSF\": 1380.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1380, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 669, \"PID\": 535402270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 670, \"PID\": 535402330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2634, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 671, \"PID\": 535403190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1958, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 672, \"PID\": 535403210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 559.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1105, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 673, \"PID\": 535403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 674, \"PID\": 535425070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1270.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 675, \"PID\": 535426150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 676, \"PID\": 535450070, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 232, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 677, \"PID\": 535450160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 92900}, {\"Order\": 678, \"PID\": 535450200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 231, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 679, \"PID\": 535451170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 680, \"PID\": 535451250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 352.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 681, \"PID\": 535452090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1041.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 682, \"PID\": 535452100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 683, \"PID\": 535452140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 102.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 732, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118900}, {\"Order\": 684, \"PID\": 535453100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 433.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 95.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1183, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 685, \"PID\": 535453200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 686, \"PID\": 535454100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 832, \"2ndFlrSF\": 629, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 687, \"PID\": 535454160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 431, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 688, \"PID\": 535475010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 7570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1806, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144750}, {\"Order\": 689, \"PID\": 535476110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 124.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 690, \"PID\": 535476240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 7936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 826.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 691, \"PID\": 535477150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 692, \"PID\": 902101010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3950, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 693, \"PID\": 902102080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 682, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 694, \"PID\": 902103100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 4080, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 695, \"PID\": 902103120, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 972, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 696, \"PID\": 902103170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 5720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 455, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 66500}, {\"Order\": 697, \"PID\": 902105050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 496, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 698, \"PID\": 902105060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 699, \"PID\": 902106010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6406, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 269.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 868, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 700, \"PID\": 902106060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1892, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 994, \"LowQualFinSF\": 0, \"GrLivArea\": 2372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 287, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 701, \"PID\": 902109130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94550}, {\"Order\": 702, \"PID\": 902109140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7596, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1000, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 703, \"PID\": 902110080, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3378, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1946, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 651.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 682, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 704, \"PID\": 902134120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 801, \"2ndFlrSF\": 646, \"LowQualFinSF\": 0, \"GrLivArea\": 1447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 705, \"PID\": 902135020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 706, \"PID\": 902201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 707, \"PID\": 902202150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 811.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 811, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 708, \"PID\": 902204080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 709, \"PID\": 902205010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 25, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 45000}, {\"Order\": 710, \"PID\": 902205030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 37900}, {\"Order\": 711, \"PID\": 902206260, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1938, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 886, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91300}, {\"Order\": 712, \"PID\": 902207170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 713, \"PID\": 902300090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 4456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 113000}, {\"Order\": 714, \"PID\": 902301060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 677.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 715, \"PID\": 902301080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 716, \"PID\": 902325070, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1898, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 849.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 1063, \"LowQualFinSF\": 0, \"GrLivArea\": 2138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 717, \"PID\": 902326030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 181, \"OpenPorchSF\": 0, \"EnclosedPorch\": 386, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265979}, {\"Order\": 718, \"PID\": 902327070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 917.0, \"TotalBsmtSF\": 917.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 719, \"PID\": 902329080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1917, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 720, \"PID\": 902330040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 121.0, \"LotArea\": 17671, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1882, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 826, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 424.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 721, \"PID\": 902331010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 3300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 722, \"PID\": 902401130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1920, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 26.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 723, \"PID\": 902402150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 226, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 724, \"PID\": 902405100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 98.0, \"LotArea\": 8820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 561, \"LowQualFinSF\": 120, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 725, \"PID\": 902405120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 436, \"GrLivArea\": 1480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 207.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 119000}, {\"Order\": 726, \"PID\": 902406070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 238, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 727, \"PID\": 902477120, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 523, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 34900}, {\"Order\": 728, \"PID\": 902477130, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 72.0, \"LotArea\": 9392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 245.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 44000}, {\"Order\": 729, \"PID\": 903200080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 144.0, \"LotArea\": 21384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 15.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 730, \"PID\": 903201020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1022.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 731, \"PID\": 903201080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 732, \"PID\": 903202170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 244, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 733, \"PID\": 903205040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 192.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 40, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 734, \"PID\": 903226130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 735, \"PID\": 903226170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 390, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 736, \"PID\": 903227070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 737, \"PID\": 903227090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 825, \"2ndFlrSF\": 587, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 45, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 738, \"PID\": 903228070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 444.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 320, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 739, \"PID\": 903228120, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 740, \"PID\": 903230100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 741, \"PID\": 903231010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 927.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 742, \"PID\": 903231030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 989, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 54, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 743, \"PID\": 903231060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 744, \"PID\": 903231130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1931, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 745, \"PID\": 903232060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 995, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 15, \"EnclosedPorch\": 51, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 746, \"PID\": 903234220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 679.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 994, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 189, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 150, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 747, \"PID\": 903236040, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 134.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 1072.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 5.0, \"GarageArea\": 1184.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 748, \"PID\": 903400220, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11888, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 2134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 268, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214500}, {\"Order\": 749, \"PID\": 903425245, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 883, \"LowQualFinSF\": 0, \"GrLivArea\": 2019, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 509, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 750, \"PID\": 903427120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 751, \"PID\": 903429080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 2500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 752, \"PID\": 903429110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 753, \"PID\": 903430060, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 92.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 929, \"LowQualFinSF\": 371, \"GrLivArea\": 2229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 198, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 104000}, {\"Order\": 754, \"PID\": 903430070, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Sev\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 62500}, {\"Order\": 755, \"PID\": 903451090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 316.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 213, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 756, \"PID\": 903458170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 757, \"PID\": 903475100, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 758, \"PID\": 903476090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1902, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 169.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 978, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 759, \"PID\": 903481120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 760, \"PID\": 903481130, \"MSSubClass\": 85, \"MSZoning\": \"RM\", \"LotFrontage\": 86.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 749.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 63.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 70000}, {\"Order\": 761, \"PID\": 903484110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 262.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 754, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 288, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 762, \"PID\": 904100190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1946, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 704, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88750}, {\"Order\": 763, \"PID\": 904301060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 764, \"PID\": 904301070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 765, \"PID\": 904301100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 766, \"PID\": 904301375, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61000}, {\"Order\": 767, \"PID\": 904351200, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 54.0, \"LotArea\": 6629, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 551.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103600}, {\"Order\": 768, \"PID\": 904351240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 687, \"2ndFlrSF\": 425, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 226.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63000}, {\"Order\": 769, \"PID\": 905101260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12886, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 770, \"PID\": 905101490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 771, \"PID\": 905103040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 92.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 500.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1683, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 772, \"PID\": 905103070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 215, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113500}, {\"Order\": 773, \"PID\": 905105190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 774, \"PID\": 905107310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 775, \"PID\": 905108190, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7252, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 776, \"PID\": 905108220, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 860, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 777, \"PID\": 905200220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 170.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 778, \"PID\": 905200260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 611, \"LowQualFinSF\": 259, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 779, \"PID\": 905200350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15312, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 780, \"PID\": 905225090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 366.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2071, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2071, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 781, \"PID\": 905228050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63900}, {\"Order\": 782, \"PID\": 905229040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1104.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 783, \"PID\": 905325020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 25095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1473, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1473, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 60, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 143000}, {\"Order\": 784, \"PID\": 905377010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 284.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 785, \"PID\": 905377130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 786, \"PID\": 905401100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10708, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 768.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1867, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1867, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 476, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 787, \"PID\": 905402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139600}, {\"Order\": 788, \"PID\": 905402070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 789, \"PID\": 905450020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 790, \"PID\": 905451300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 340.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 791, \"PID\": 905451340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1276, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 60000}, {\"Order\": 792, \"PID\": 905452040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 747, \"LowQualFinSF\": 0, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154400}, {\"Order\": 793, \"PID\": 905452050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 344.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 794, \"PID\": 905475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1089.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1089, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 795, \"PID\": 905475500, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 290.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84000}, {\"Order\": 796, \"PID\": 905476230, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 393.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1049, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 266.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 797, \"PID\": 905478030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11409, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 798, \"PID\": 905480030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 799, \"PID\": 905480210, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 800, \"PID\": 906201021, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 286.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 801, \"PID\": 906201050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 19255, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 450.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 802, \"PID\": 906201130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1983, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 2132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316600}, {\"Order\": 803, \"PID\": 906203120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 177.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 2158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271900}, {\"Order\": 804, \"PID\": 906223060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 137.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 227.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 769, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 425.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 234, \"OpenPorchSF\": 72, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 805, \"PID\": 906223080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1879, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 100, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 806, \"PID\": 906223210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 807, \"PID\": 906226060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 26400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 2016, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 808, \"PID\": 906226070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118964}, {\"Order\": 809, \"PID\": 906226080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1086.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 153337}, {\"Order\": 810, \"PID\": 906226090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 1114, \"LowQualFinSF\": 0, \"GrLivArea\": 2228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 73, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 147983}, {\"Order\": 811, \"PID\": 906226100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 812, \"PID\": 906226110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 813, \"PID\": 906226120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 1120, \"LowQualFinSF\": 0, \"GrLivArea\": 2240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 142953}, {\"Order\": 814, \"PID\": 906226130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1094.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 148325}, {\"Order\": 815, \"PID\": 906226140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 113722}, {\"Order\": 816, \"PID\": 906230010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 817, \"PID\": 906230020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7939, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 818, \"PID\": 906230030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 819, \"PID\": 906340100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10933, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1021.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1555.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1138.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 323262}, {\"Order\": 820, \"PID\": 906340110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 417.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 297000}, {\"Order\": 821, \"PID\": 906340120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1622.0, \"TotalBsmtSF\": 1622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 860.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295493}, {\"Order\": 822, \"PID\": 906340130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 364.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 332000}, {\"Order\": 823, \"PID\": 906378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 904.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 824, \"PID\": 906380050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 825, \"PID\": 906380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11422, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1359.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 222, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272500}, {\"Order\": 826, \"PID\": 906380100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 827, \"PID\": 906380130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 828, \"PID\": 906380210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1282.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 829, \"PID\": 906380220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 10324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 382.0, \"TotalBsmtSF\": 1254.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221800}, {\"Order\": 830, \"PID\": 906392070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 82.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 831, \"PID\": 906392110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1474.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 832, \"PID\": 906392130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 704, \"2ndFlrSF\": 718, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 833, \"PID\": 906402060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 396, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 834, \"PID\": 906426210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 1449.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 815, \"LowQualFinSF\": 0, \"GrLivArea\": 1759, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 193, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233500}, {\"Order\": 835, \"PID\": 906475070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 28698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 764.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 966, \"LowQualFinSF\": 0, \"GrLivArea\": 2126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 836, \"PID\": 907126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 837, \"PID\": 907126050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9757, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 838, \"PID\": 907130100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 15426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 836, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 839, \"PID\": 907131090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 834, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 840, \"PID\": 907131190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14753, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 950.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1463, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1463, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 841, \"PID\": 907135040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 10859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1097.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 392, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 842, \"PID\": 907135170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 746.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 843, \"PID\": 907175100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 866.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 913, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 844, \"PID\": 907180130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1490.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 845, \"PID\": 907181100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9017, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 871.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 846, \"PID\": 907185050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 847, \"PID\": 907192030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8935, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 848, \"PID\": 907192090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 9808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1573, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 849, \"PID\": 907194010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1840, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 850, \"PID\": 907194110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 16285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1413.0, \"TotalBsmtSF\": 1413.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187100}, {\"Order\": 851, \"PID\": 907194160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10739, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 852, \"PID\": 907196060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11166, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 201000}, {\"Order\": 853, \"PID\": 907200230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 854, \"PID\": 907201220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16269, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 855, \"PID\": 907201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 6950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 710.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 856, \"PID\": 907202050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150500}, {\"Order\": 857, \"PID\": 907202080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 858, \"PID\": 907202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1072.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 859, \"PID\": 907227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 15523, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 860, \"PID\": 907227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 215, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 861, \"PID\": 907227110, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 862, \"PID\": 907227290, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8445, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 863, \"PID\": 907250070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 335.0, \"TotalBsmtSF\": 1569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 864, \"PID\": 907252060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1068.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254750}, {\"Order\": 865, \"PID\": 907252210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 866, \"PID\": 907252220, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 990.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 309.0, \"TotalBsmtSF\": 1299.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 573, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 261500}, {\"Order\": 867, \"PID\": 907253130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 2153, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 313000}, {\"Order\": 868, \"PID\": 907260030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 869, \"PID\": 907265010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 944.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 926, \"LowQualFinSF\": 0, \"GrLivArea\": 1870, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 870, \"PID\": 907275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 871, \"PID\": 907275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 814.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 872, \"PID\": 907275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 873, \"PID\": 907280170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1111.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1417, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1417, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 117, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 874, \"PID\": 907285020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 573.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 977, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 576, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 875, \"PID\": 907285050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 876, \"PID\": 907290070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1212.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 877, \"PID\": 907290090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1630.0, \"TotalBsmtSF\": 1630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 878, \"PID\": 907290180, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 879, \"PID\": 907290210, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 880, \"PID\": 907410130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1478.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 293200}, {\"Order\": 881, \"PID\": 907412020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 882, \"PID\": 907414020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1480.0, \"TotalBsmtSF\": 1500.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 883, \"PID\": 907414080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 193.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 884, \"PID\": 907420040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 885, \"PID\": 908102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 886, \"PID\": 908102270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1486.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 887, \"PID\": 908102290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 888, \"PID\": 908128060, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 495, \"2ndFlrSF\": 1427, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 177, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 889, \"PID\": 908151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 155.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 890, \"PID\": 908152035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 615.0, \"TotalBsmtSF\": 1014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 891, \"PID\": 908152100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 255.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 631.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 892, \"PID\": 908154040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 13286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 464.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 327, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 893, \"PID\": 908186080, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 894, \"PID\": 908201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1947, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 895, \"PID\": 908203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 332.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 243.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 896, \"PID\": 908225290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 900, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 897, \"PID\": 908225370, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 441, \"LowQualFinSF\": 0, \"GrLivArea\": 1529, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 898, \"PID\": 908229020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 899, \"PID\": 908250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 900, \"PID\": 908275040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1678.0, \"TotalBsmtSF\": 1678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1678, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1678, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 901, \"PID\": 908275110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 902, \"PID\": 908276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 903, \"PID\": 909101010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12354, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 800, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 904, \"PID\": 909101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 444, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 905, \"PID\": 909101140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10998, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 420.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 906, \"PID\": 909129090, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 907, \"PID\": 909129100, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1932, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 159434}, {\"Order\": 908, \"PID\": 909175080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 438, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 438, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 909, \"PID\": 909178160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 545, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 910, \"PID\": 909179020, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 15863, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 3, \"YearBuilt\": 1920, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 998, \"LowQualFinSF\": 397, \"GrLivArea\": 3082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 911, \"PID\": 909250080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 583.0, \"TotalBsmtSF\": 583.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 647, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 329, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 912, \"PID\": 909250220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 913, \"PID\": 909251050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 914, \"PID\": 909251170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137450}, {\"Order\": 915, \"PID\": 909252020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1936, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 575, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1135, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 916, \"PID\": 909253010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7558, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1913, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 917, \"PID\": 909253180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 877, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1477, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 918, \"PID\": 909254010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 919, \"PID\": 909257050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 10918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 920, \"PID\": 909275080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 921, \"PID\": 909276110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 753, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 213.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 922, \"PID\": 909276200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 332, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 923, \"PID\": 909277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1273, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 307.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 924, \"PID\": 909277100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13360, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 713.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 44, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 925, \"PID\": 909278020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7681, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 731.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 523, \"LowQualFinSF\": 0, \"GrLivArea\": 1343, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 186.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154900}, {\"Order\": 926, \"PID\": 909279010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 674.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 13, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 57, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 927, \"PID\": 909282130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 154.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 694.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144800}, {\"Order\": 928, \"PID\": 909425060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 929, \"PID\": 909425130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 65.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 875.0, \"BsmtUnfSF\": 621.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 930, \"PID\": 909426090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 507.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 295.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 931, \"PID\": 909427200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 158500}, {\"Order\": 932, \"PID\": 909428240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 91.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1906, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1906, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 201, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 933, \"PID\": 909451040, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 279, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 934, \"PID\": 909451100, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 935, \"PID\": 909451140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 561.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 936, \"PID\": 909451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 937, \"PID\": 909452050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13607, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 118.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208000}, {\"Order\": 938, \"PID\": 909475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17597, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1971, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 419.0, \"BsmtUnfSF\": 581.0, \"TotalBsmtSF\": 1803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2365, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 939, \"PID\": 909475300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1988, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 808.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 182, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 940, \"PID\": 910202070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 10690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 941, \"PID\": 910204050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 760.0, \"TotalBsmtSF\": 760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 928, \"LowQualFinSF\": 312, \"GrLivArea\": 2168, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 160, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 942, \"PID\": 910205020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 596, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 189.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 943, \"PID\": 911103050, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 105.0, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1915, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1013.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 513, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85000}, {\"Order\": 944, \"PID\": 911104060, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 72, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 945, \"PID\": 911370500, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230000}, {\"Order\": 946, \"PID\": 912251110, \"MSSubClass\": 30, \"MSZoning\": \"I (all)\", \"LotFrontage\": 109.0, \"LotArea\": 21780, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 119, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 57625}, {\"Order\": 947, \"PID\": 914465020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 250.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 948, \"PID\": 914465040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 2149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 239686}, {\"Order\": 949, \"PID\": 914465055, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1710.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 950, \"PID\": 914474070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 12209, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 1157, \"LowQualFinSF\": 0, \"GrLivArea\": 1961, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 951, \"PID\": 914475010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 926, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156450}, {\"Order\": 952, \"PID\": 914475030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 953, \"PID\": 914476020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 954, \"PID\": 914476380, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9947, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 955, \"PID\": 914476430, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 55.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1527.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 152000}, {\"Order\": 956, \"PID\": 916176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSeWa\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 541.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 118, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 233, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 957, \"PID\": 916176125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 215245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 820.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 958, \"PID\": 916380070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1022.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315500}, {\"Order\": 959, \"PID\": 916382010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224500}, {\"Order\": 960, \"PID\": 916382100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 13438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 2190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 780.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 961, \"PID\": 916382110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 406.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1115.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316500}, {\"Order\": 962, \"PID\": 916386140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 963, \"PID\": 916403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 387.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1412, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 964, \"PID\": 916403200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2237, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 965, \"PID\": 916403250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 14419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 624.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 1645.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 966, \"PID\": 916455070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 967, \"PID\": 916460110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 968, \"PID\": 916475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14601, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 584.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 578.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 969, \"PID\": 921128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1640.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 308, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 425000}, {\"Order\": 970, \"PID\": 923201100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 971, \"PID\": 923202060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1771, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 972, \"PID\": 923203110, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 247, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 973, \"PID\": 923203190, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 883.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 974, \"PID\": 923225360, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 975, \"PID\": 923225490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 9858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 33, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 976, \"PID\": 923226270, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 515.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 977, \"PID\": 923227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13383, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1404, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 978, \"PID\": 923228110, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 979, \"PID\": 923228150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 980, \"PID\": 923228230, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 981, \"PID\": 923230200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7689, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 76.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131900}, {\"Order\": 982, \"PID\": 923252075, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7706, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131250}, {\"Order\": 983, \"PID\": 923275040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1097.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 602.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 303, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 984, \"PID\": 923275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 985, \"PID\": 923276260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 718.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 883, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 883, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 698.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 986, \"PID\": 923400025, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 566, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 320, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 987, \"PID\": 923400110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10429, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 988, \"PID\": 924100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1567.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 989, \"PID\": 924100060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 496.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 368, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 990, \"PID\": 526351030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 411.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 601.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 190, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 991, \"PID\": 526353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1205.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237500}, {\"Order\": 992, \"PID\": 526354070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 2112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206900}, {\"Order\": 993, \"PID\": 527105050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 994, \"PID\": 527106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 995, \"PID\": 527106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 996, \"PID\": 527106150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 997, \"PID\": 527107010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 998, \"PID\": 527107090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 898.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177900}, {\"Order\": 999, \"PID\": 527107210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 21872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1446, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 406.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1000, \"PID\": 527127140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1593.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1593, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 1001, \"PID\": 527131110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 6264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247900}, {\"Order\": 1002, \"PID\": 527140090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1003, \"PID\": 527145090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1280.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1004, \"PID\": 527161010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 926.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1005, \"PID\": 527162180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 183000}, {\"Order\": 1006, \"PID\": 527163100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1007, \"PID\": 527164120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1895, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 1008, \"PID\": 527165010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1009, \"PID\": 527183030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1010, \"PID\": 527183060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 5950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1011, \"PID\": 527208010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 13543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 1012, \"PID\": 527212050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1122.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 1370, \"LowQualFinSF\": 0, \"GrLivArea\": 2504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1013, \"PID\": 527214030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 15401, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 547.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 387000}, {\"Order\": 1014, \"PID\": 527226020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 31220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 2, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1474, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 750, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1015, \"PID\": 527252080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1034.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 557.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 1016, \"PID\": 527276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 47280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1488.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 133000}, {\"Order\": 1017, \"PID\": 527301170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 20544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 791.0, \"TotalBsmtSF\": 791.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 2093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1018, \"PID\": 527301245, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 983.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 1675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1688, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 141, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1019, \"PID\": 527302050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 228.0, \"BsmtUnfSF\": 606.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1020, \"PID\": 527302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1021, \"PID\": 527302185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 18559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 186.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 2048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1022, \"PID\": 527302210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 449.0, \"BsmtUnfSF\": 469.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 1023, \"PID\": 527325070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 424.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 896.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 550, \"OpenPorchSF\": 282, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 1024, \"PID\": 527325240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 48.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 1211.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 174, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1025, \"PID\": 527326130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1026, \"PID\": 527354160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 2044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1027, \"PID\": 527357110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9743, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146900}, {\"Order\": 1028, \"PID\": 527357180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12511, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1420, \"2ndFlrSF\": 1420, \"LowQualFinSF\": 0, \"GrLivArea\": 2840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1314.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 208, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 292500}, {\"Order\": 1029, \"PID\": 527358120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 11361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1193.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1523, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1030, \"PID\": 527359030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1444.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1031, \"PID\": 527359070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1032, \"PID\": 527378020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1033, \"PID\": 527380240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1236.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 787.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 180, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 1034, \"PID\": 527401130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1035, \"PID\": 527402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 438.0, \"BsmtUnfSF\": 14.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 80, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1036, \"PID\": 527402130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 16, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111900}, {\"Order\": 1037, \"PID\": 527403360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 613.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1038, \"PID\": 527425035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111250}, {\"Order\": 1039, \"PID\": 527427110, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1040, \"PID\": 527450110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103400}, {\"Order\": 1041, \"PID\": 527450250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1042, \"PID\": 527450520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 411, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100500}, {\"Order\": 1043, \"PID\": 527451060, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 127.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1044, \"PID\": 527451290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85400}, {\"Order\": 1045, \"PID\": 527451400, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 604.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1046, \"PID\": 527451550, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111750}, {\"Order\": 1047, \"PID\": 527452150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 559.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1048, \"PID\": 527453160, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 286.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 275.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1049, \"PID\": 527454120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 1050, \"PID\": 527455270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1051, \"PID\": 528102030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12444, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 426.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 304, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394617}, {\"Order\": 1052, \"PID\": 528102110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 590, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 426000}, {\"Order\": 1053, \"PID\": 528104050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 816.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 442.0, \"TotalBsmtSF\": 2078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2084, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 385000}, {\"Order\": 1054, \"PID\": 528104080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 14948, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 1237, \"LowQualFinSF\": 0, \"GrLivArea\": 2713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 858.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 446261}, {\"Order\": 1055, \"PID\": 528108150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 317500}, {\"Order\": 1056, \"PID\": 528110080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 436.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372402}, {\"Order\": 1057, \"PID\": 528110110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1728.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 2418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 358, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 417500}, {\"Order\": 1058, \"PID\": 528114040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 14418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 1950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 383000}, {\"Order\": 1059, \"PID\": 528118030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 2748, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 390000}, {\"Order\": 1060, \"PID\": 528118090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12539, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 468.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 1158, \"LowQualFinSF\": 0, \"GrLivArea\": 2790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1150.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 460000}, {\"Order\": 1061, \"PID\": 528120130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12151, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2331, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1003.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 379000}, {\"Order\": 1062, \"PID\": 528142020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 908.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1063, \"PID\": 528142140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1162, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316000}, {\"Order\": 1064, \"PID\": 528164060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 680.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 2535.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2470, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2470, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 144, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 615000}, {\"Order\": 1065, \"PID\": 528166120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 664.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 1096, \"LowQualFinSF\": 0, \"GrLivArea\": 2668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 412500}, {\"Order\": 1066, \"PID\": 528170070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1067, \"PID\": 528172080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 454.0, \"TotalBsmtSF\": 1603.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1068, \"PID\": 528178070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 16900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1075.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1515, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2649, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 421250}, {\"Order\": 1069, \"PID\": 528178090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 16451, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 221.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1765.0, \"TotalBsmtSF\": 1765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1804, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1070, \"PID\": 528180110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1486.0, \"TotalBsmtSF\": 1858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336860}, {\"Order\": 1071, \"PID\": 528180140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 766.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 367294}, {\"Order\": 1072, \"PID\": 528181010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 135.0, \"LotArea\": 12304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1347.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1367, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1073, \"PID\": 528186030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 12677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1074, \"PID\": 528186080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 616.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1684, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1684, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 495, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266000}, {\"Order\": 1075, \"PID\": 528186130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 8232, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 714.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370967}, {\"Order\": 1076, \"PID\": 528186160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234250}, {\"Order\": 1077, \"PID\": 528186170, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1318.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1078, \"PID\": 528188090, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1079, \"PID\": 528188150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 1080, \"PID\": 528190010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1081, \"PID\": 528228345, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1073.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 1415.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1455, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1455, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1082, \"PID\": 528228405, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1087.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219990}, {\"Order\": 1083, \"PID\": 528228445, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1084, \"PID\": 528228465, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159895}, {\"Order\": 1085, \"PID\": 528228540, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1146.0, \"TotalBsmtSF\": 1146.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 428.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187687}, {\"Order\": 1086, \"PID\": 528235020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1515, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1087, \"PID\": 528235120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7415, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 759.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 839.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1088, \"PID\": 528235180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1166, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1089, \"PID\": 528240040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 8029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1090, \"PID\": 528240050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1091, \"PID\": 528250030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8396, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1139, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1092, \"PID\": 528253020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 217300}, {\"Order\": 1093, \"PID\": 528280130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1094, \"PID\": 528280180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 647.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226750}, {\"Order\": 1095, \"PID\": 528290010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 15384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1096, \"PID\": 528290090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1097, \"PID\": 528292060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12460, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1098, \"PID\": 528294060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 873, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1099, \"PID\": 528315060, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1173.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284500}, {\"Order\": 1100, \"PID\": 528315110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1470, \"2ndFlrSF\": 1160, \"LowQualFinSF\": 0, \"GrLivArea\": 2630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 696.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 1101, \"PID\": 528326030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 14260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 1053, \"LowQualFinSF\": 0, \"GrLivArea\": 2198, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1102, \"PID\": 528326110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1519.0, \"TotalBsmtSF\": 1519.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 687.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 1103, \"PID\": 528346050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 136.0, \"LotArea\": 11675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 495.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2006, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1104, \"PID\": 528354100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 1061, \"LowQualFinSF\": 0, \"GrLivArea\": 2125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 1105, \"PID\": 528363020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1242.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1250, \"LowQualFinSF\": 0, \"GrLivArea\": 2501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1106, \"PID\": 528363110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10437, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 2109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 236, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1107, \"PID\": 528365060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 651.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1311.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 1093, \"LowQualFinSF\": 0, \"GrLivArea\": 2418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 983.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 154, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 341000}, {\"Order\": 1108, \"PID\": 528365080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 852.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2197, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 783.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 385, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287500}, {\"Order\": 1109, \"PID\": 528387050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 448.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 904, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1110, \"PID\": 528390020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 1986.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1987, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301500}, {\"Order\": 1111, \"PID\": 528427010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11932, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 830.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235128}, {\"Order\": 1112, \"PID\": 528427070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14598, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 74.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 1039, \"LowQualFinSF\": 0, \"GrLivArea\": 1933, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1113, \"PID\": 528429050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1574, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 824.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 1114, \"PID\": 528429070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13253, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1115, \"PID\": 528429080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264132}, {\"Order\": 1116, \"PID\": 528431060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 468.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 33.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1563.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1563, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1563, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1117, \"PID\": 528431080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 12274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1417.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227680}, {\"Order\": 1118, \"PID\": 528431120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1341.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 851.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 1119, \"PID\": 528435020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 919, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 297900}, {\"Order\": 1120, \"PID\": 528439010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1460.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1460, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1460, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247000}, {\"Order\": 1121, \"PID\": 528458030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1363.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212700}, {\"Order\": 1122, \"PID\": 528458050, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1372.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250580}, {\"Order\": 1123, \"PID\": 528462040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 95.0, \"LotArea\": 11639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1428.0, \"TotalBsmtSF\": 1428.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 182000}, {\"Order\": 1124, \"PID\": 528477040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226700}, {\"Order\": 1125, \"PID\": 528478030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 768.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1053.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 939, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1126, \"PID\": 528478040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 932, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1127, \"PID\": 528480060, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1034.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 1028, \"LowQualFinSF\": 0, \"GrLivArea\": 2078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 339750}, {\"Order\": 1128, \"PID\": 528480160, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 843, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 562.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205950}, {\"Order\": 1129, \"PID\": 528482020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1660.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1130, \"PID\": 528488140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230348}, {\"Order\": 1131, \"PID\": 528490080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 64.0, \"LotArea\": 8791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 361.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 673.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1132, \"PID\": 531363060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1133, \"PID\": 531371070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 555.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 861, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1134, \"PID\": 531373060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 1135, \"PID\": 531375050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1136, \"PID\": 531375110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1137, \"PID\": 531375120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1138, \"PID\": 531376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1139, \"PID\": 531376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1162.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1162, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1140, \"PID\": 531382090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 362.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1141, \"PID\": 531382110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 886.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 794, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1142, \"PID\": 531382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 258.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1679, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1679, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 1143, \"PID\": 531384030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 14565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 537.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1144, \"PID\": 531385060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1677, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190500}, {\"Order\": 1145, \"PID\": 531450030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 439.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1146, \"PID\": 531450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1147, \"PID\": 531450170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1148, \"PID\": 531451020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 165.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1617, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1617, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1149, \"PID\": 531452140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 899.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1199, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1150, \"PID\": 532351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 53.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 799.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1151, \"PID\": 532353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12968, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1152, \"PID\": 532354150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 764.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1153, \"PID\": 532376170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 890.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 890, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 890, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1154, \"PID\": 532377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119916}, {\"Order\": 1155, \"PID\": 532378200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1156, \"PID\": 532477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 19508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 108, \"EnclosedPorch\": 165, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1157, \"PID\": 532479020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 811.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 92, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1158, \"PID\": 533125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 1319, \"LowQualFinSF\": 0, \"GrLivArea\": 2683, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 251, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1159, \"PID\": 533125140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1328.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1827, \"2ndFlrSF\": 959, \"LowQualFinSF\": 0, \"GrLivArea\": 2786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372500}, {\"Order\": 1160, \"PID\": 533206050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 59.0, \"LotArea\": 4282, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1391, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 1161, \"PID\": 533208080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4017, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171900}, {\"Order\": 1162, \"PID\": 533208140, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3435, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1211.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 1163, \"PID\": 533212050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1164, \"PID\": 533212140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1165, \"PID\": 533212150, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3604, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1166, \"PID\": 533213070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179400}, {\"Order\": 1167, \"PID\": 533213120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 194.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 792, \"LowQualFinSF\": 0, \"GrLivArea\": 1549, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172900}, {\"Order\": 1168, \"PID\": 533215020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1027.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 587.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1638, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1169, \"PID\": 533215030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4538, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 179.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1170, \"PID\": 533215040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 42.0, \"LotArea\": 4385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1171, \"PID\": 533215070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1557.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1172, \"PID\": 533215080, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 50.0, \"LotArea\": 5119, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1709, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 97, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"CWD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 328900}, {\"Order\": 1173, \"PID\": 533217050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 628, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1174, \"PID\": 533217060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 20, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1175, \"PID\": 533234020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 79.0, \"LotArea\": 10646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 1789, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 1176, \"PID\": 533236060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1177, \"PID\": 533236070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 147.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1607, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1178, \"PID\": 533236090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 36.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 128.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 842.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1469, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2393, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 94, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 1179, \"PID\": 533250050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 14963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245500}, {\"Order\": 1180, \"PID\": 533250110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 22.0, \"LotArea\": 11064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1230.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1239, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1239, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 1181, \"PID\": 533250160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 32.0, \"LotArea\": 10846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1719.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1719, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1719, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 1182, \"PID\": 533251120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1183, \"PID\": 533350090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1050.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 584.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1599, \"2ndFlrSF\": 1345, \"LowQualFinSF\": 0, \"GrLivArea\": 2944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 70, \"EnclosedPorch\": 16, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1184, \"PID\": 533350120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 16280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1044.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 382.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1426.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1185, \"PID\": 534104100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 469.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1186, \"PID\": 534126090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1304.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 98, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1187, \"PID\": 534127210, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1427, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1188, \"PID\": 534127230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1439.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1189, \"PID\": 534128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1190, \"PID\": 534129060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 62, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1191, \"PID\": 534175140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1625.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1192, \"PID\": 534177180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1522.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 1066, \"LowQualFinSF\": 0, \"GrLivArea\": 2614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 243, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1193, \"PID\": 534201240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1194, \"PID\": 534202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1195, \"PID\": 534204030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 456.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1196, \"PID\": 534225110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1728.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1197, \"PID\": 534225120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1497.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142600}, {\"Order\": 1198, \"PID\": 534250010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 9246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 564.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1199, \"PID\": 534250335, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1200, \"PID\": 534250370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 1540, \"LowQualFinSF\": 0, \"GrLivArea\": 2715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 299800}, {\"Order\": 1201, \"PID\": 534250410, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 933, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1202, \"PID\": 534251280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 800, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1203, \"PID\": 534252090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 867.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178400}, {\"Order\": 1204, \"PID\": 534252270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1205, \"PID\": 534276190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7785, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 267.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1206, \"PID\": 534277060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 619.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109008}, {\"Order\": 1207, \"PID\": 534277070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135750}, {\"Order\": 1208, \"PID\": 534400030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 20, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1209, \"PID\": 534400060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 407, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 1210, \"PID\": 534401130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1165, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 129, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174900}, {\"Order\": 1211, \"PID\": 534401190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 892.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 426, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1212, \"PID\": 534403050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 305.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1213, \"PID\": 534403080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 1219.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1265, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 96, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1214, \"PID\": 534403100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 336.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1215, \"PID\": 534403260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 164, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1216, \"PID\": 534426040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 806.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 1217, \"PID\": 534427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10721, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 243.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1252.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1218, \"PID\": 534428020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12493, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 306.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1219, \"PID\": 534428100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1118.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1220, \"PID\": 534451080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Floor\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72500}, {\"Order\": 1221, \"PID\": 534451170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52000}, {\"Order\": 1222, \"PID\": 534452060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 4, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1223, \"PID\": 534453140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 453, \"2ndFlrSF\": 453, \"LowQualFinSF\": 0, \"GrLivArea\": 906, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 1224, \"PID\": 534455030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1225, \"PID\": 534477080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 220, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 1226, \"PID\": 534477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 32.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 308.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1227, \"PID\": 534477270, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 377.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 178, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1228, \"PID\": 534479150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 505.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112900}, {\"Order\": 1229, \"PID\": 535103050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 273, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201800}, {\"Order\": 1230, \"PID\": 535104020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 491.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1231, \"PID\": 535105030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139950}, {\"Order\": 1232, \"PID\": 535105060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1962, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 237.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1319.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1233, \"PID\": 535105090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 9150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1234, \"PID\": 535126140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 529.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 230, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1235, \"PID\": 535150210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 151.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 1098.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1236, \"PID\": 535150280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 25.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 872.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1237, \"PID\": 535151160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1283, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1283, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1238, \"PID\": 535152200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8856, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 52.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1239, \"PID\": 535153140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1240, \"PID\": 535153150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1261.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1261, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1261, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1400, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1241, \"PID\": 535176100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 187.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1570, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1570, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 490, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166800}, {\"Order\": 1242, \"PID\": 535178060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 580.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1243, \"PID\": 535179060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 387.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 458.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 1244, \"PID\": 535180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 135.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 130, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1245, \"PID\": 535180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1104, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1246, \"PID\": 535301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1247, \"PID\": 535302130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 196.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1248, \"PID\": 535302140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1249, \"PID\": 535303030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 14250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 998.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1250, \"PID\": 535305030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 852.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 1251, \"PID\": 535305160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 773, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 1252, \"PID\": 535327230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1253, \"PID\": 535352080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 1254, \"PID\": 535354200, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1255, \"PID\": 535375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 66, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89900}, {\"Order\": 1256, \"PID\": 535375160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 7506, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1257, \"PID\": 535380050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10930, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1258, \"PID\": 535380110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 1259, \"PID\": 535380140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 182, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 1488.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1260, \"PID\": 535383100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 694, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 114, \"EnclosedPorch\": 210, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106250}, {\"Order\": 1261, \"PID\": 535402120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9247, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 539.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1262, \"PID\": 535403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1263, \"PID\": 535425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Othr\", \"MiscVal\": 6500, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 1264, \"PID\": 535426260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1253.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 213, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1265, \"PID\": 535426350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 276.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1081.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1081, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 401.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1266, \"PID\": 535427070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 27650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2069, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 1267, \"PID\": 535451010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 910, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 414.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1268, \"PID\": 535451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 94000}, {\"Order\": 1269, \"PID\": 535451230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98300}, {\"Order\": 1270, \"PID\": 535452120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1507, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1507, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1271, \"PID\": 535453020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 488.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1272, \"PID\": 535453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 319.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125900}, {\"Order\": 1273, \"PID\": 535453210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 532.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1269.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1274, \"PID\": 535454150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 453.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 501, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1275, \"PID\": 535455060, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1276, \"PID\": 535455080, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 1277, \"PID\": 535455090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 181.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1278, \"PID\": 535456050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 8513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1279, \"PID\": 535456070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1280, \"PID\": 535456100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1281, \"PID\": 535475020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 415.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1282, \"PID\": 535476370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 106.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 1283, \"PID\": 535477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136870}, {\"Order\": 1284, \"PID\": 902100020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 96.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143000}, {\"Order\": 1285, \"PID\": 902100030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 30.0, \"LotArea\": 5232, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 1286, \"PID\": 902102060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1904, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 78, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1287, \"PID\": 902103150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9184, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 375, \"LowQualFinSF\": 0, \"GrLivArea\": 1323, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122600}, {\"Order\": 1288, \"PID\": 902105010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 680, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 1289, \"PID\": 902105020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 547, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 480, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1150, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1290, \"PID\": 902105130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1291, \"PID\": 902107030, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1292, \"PID\": 902109080, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 828.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 828, \"2ndFlrSF\": 658, \"LowQualFinSF\": 108, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 109, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1293, \"PID\": 902109110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 2082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1294, \"PID\": 902109120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 561, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119164}, {\"Order\": 1295, \"PID\": 902109160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 7308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122250}, {\"Order\": 1296, \"PID\": 902128075, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 931.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1297, \"PID\": 902128150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 590.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 552, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1298, \"PID\": 902134100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6756, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 481.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 1299, \"PID\": 902136110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 5914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 396, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 165, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1300, \"PID\": 902201120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 169.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 115000}, {\"Order\": 1301, \"PID\": 902201140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 608.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1302, \"PID\": 902202090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 904.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 869.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1303, \"PID\": 902205070, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 407.0, \"TotalBsmtSF\": 407.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 407, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 407, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 46500}, {\"Order\": 1304, \"PID\": 902205090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 620.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1305, \"PID\": 902205140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 901, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107900}, {\"Order\": 1306, \"PID\": 902207120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 103.0, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 1, \"YearBuilt\": 1949, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 65000}, {\"Order\": 1307, \"PID\": 902207220, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 87.0, \"LotArea\": 18386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1880, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1470.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 1818, \"LowQualFinSF\": 0, \"GrLivArea\": 3493, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295000}, {\"Order\": 1308, \"PID\": 902300110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 797.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 830, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1627, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1309, \"PID\": 902300215, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 540, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 418, \"OpenPorchSF\": 0, \"EnclosedPorch\": 194, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1310, \"PID\": 902300260, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 730, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1311, \"PID\": 902301140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 34.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 513.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98000}, {\"Order\": 1312, \"PID\": 902301150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9143, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 709, \"2ndFlrSF\": 308, \"LowQualFinSF\": 0, \"GrLivArea\": 1017, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 139, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1313, \"PID\": 902304060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 973, \"LowQualFinSF\": 0, \"GrLivArea\": 2350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 219, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1314, \"PID\": 902305080, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2058, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 259, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1315, \"PID\": 902306120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1905, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129400}, {\"Order\": 1316, \"PID\": 902306130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1928, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1317, \"PID\": 902326060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1905, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 691, \"LowQualFinSF\": 0, \"GrLivArea\": 1912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1318, \"PID\": 902328040, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 291, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1319, \"PID\": 902330010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5250, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1872, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 205, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 1320, \"PID\": 902401010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 572, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1321, \"PID\": 902401120, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1893, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1521, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 880.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 502, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1322, \"PID\": 902402260, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 2, \"OverallCond\": 1, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 723, \"2ndFlrSF\": 363, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1323, \"PID\": 902405070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 299, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1324, \"PID\": 902406020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1325, \"PID\": 902406090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1050.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 1326, \"PID\": 902427045, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 12702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 1327, \"PID\": 902427150, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8516, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 869.0, \"TotalBsmtSF\": 869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115500}, {\"Order\": 1328, \"PID\": 903201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7111, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1329, \"PID\": 903204010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 1330, \"PID\": 903204095, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 156, \"GrLivArea\": 935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 1331, \"PID\": 903206070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 175.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 594, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1332, \"PID\": 903225050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1333, \"PID\": 903225140, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1334, \"PID\": 903225160, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 554, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106900}, {\"Order\": 1335, \"PID\": 903226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 658, \"LowQualFinSF\": 0, \"GrLivArea\": 1672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 1336, \"PID\": 903226150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 949.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1337, \"PID\": 903227080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 862.0, \"TotalBsmtSF\": 862.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 208.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1338, \"PID\": 903228040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 201.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1497, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1339, \"PID\": 903228060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1340, \"PID\": 903228090, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 992.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1013, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 101, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1341, \"PID\": 903230110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 565, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1342, \"PID\": 903230120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 99.0, \"LotArea\": 5940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": null, \"BsmtFinType2\": null, \"BsmtFinSF2\": null, \"BsmtUnfSF\": null, \"TotalBsmtSF\": null, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79000}, {\"Order\": 1343, \"PID\": 903231080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 365, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1344, \"PID\": 903232030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81300}, {\"Order\": 1345, \"PID\": 903232090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1078.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 1346, \"PID\": 903233080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 989.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1347, \"PID\": 903234090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 897.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 139, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 1348, \"PID\": 903234100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129900}, {\"Order\": 1349, \"PID\": 903235010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 611.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1350, \"PID\": 903235100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 87, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68500}, {\"Order\": 1351, \"PID\": 903236010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 213, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1352, \"PID\": 903400180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 13053, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 220, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1353, \"PID\": 903401020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1354, \"PID\": 903401030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1355, \"PID\": 903401050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 883.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1356, \"PID\": 903425420, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 606.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1357, \"PID\": 903426160, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1000, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1358, \"PID\": 903427090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5100, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1359, \"PID\": 903429010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 4347, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1360, \"PID\": 903452025, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6291, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93850}, {\"Order\": 1361, \"PID\": 903453050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10266, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 216, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 136000}, {\"Order\": 1362, \"PID\": 903454100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1272.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 0, \"LowQualFinSF\": 697, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1363, \"PID\": 903455030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 428, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 117, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1364, \"PID\": 903455140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1365, \"PID\": 903456130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 647.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 127000}, {\"Order\": 1366, \"PID\": 903458110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 371, \"LowQualFinSF\": 0, \"GrLivArea\": 1406, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1367, \"PID\": 903475020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 645.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1368, \"PID\": 903476110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5586, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 110, \"LowQualFinSF\": 0, \"GrLivArea\": 1198, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79900}, {\"Order\": 1369, \"PID\": 903481010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 451.0, \"TotalBsmtSF\": 451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 759, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Family\", \"SalePrice\": 85000}, {\"Order\": 1370, \"PID\": 903481100, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 808, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 204, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82375}, {\"Order\": 1371, \"PID\": 903484020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1906, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 1469, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1906.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 57, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1372, \"PID\": 904100020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 122, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 1373, \"PID\": 904100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 1374, \"PID\": 904100160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 21286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1271, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1375, \"PID\": 904101170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134432}, {\"Order\": 1376, \"PID\": 904351280, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10106, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 181.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 547, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1377, \"PID\": 905100020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 64, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 148000}, {\"Order\": 1378, \"PID\": 905102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 906.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1379, \"PID\": 905103030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 39.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1380, \"PID\": 905104080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109900}, {\"Order\": 1381, \"PID\": 905104110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1382, \"PID\": 905104180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 702.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1383, \"PID\": 905107280, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 311, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1384, \"PID\": 905107380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9981, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 221.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 852.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1385, \"PID\": 905108170, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 956.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1386, \"PID\": 905200090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1198.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 108959}, {\"Order\": 1387, \"PID\": 905200100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 95541}, {\"Order\": 1388, \"PID\": 905200160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 1006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1006, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 1389, \"PID\": 905200510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149350}, {\"Order\": 1390, \"PID\": 905201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 634.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 1391, \"PID\": 905201110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 102, \"OpenPorchSF\": 89, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1392, \"PID\": 905201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1064.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 354.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 511, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1393, \"PID\": 905202230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 429.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1080.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 409, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1394, \"PID\": 905225040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1021, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1395, \"PID\": 905226030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1396, \"PID\": 905226110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1397, \"PID\": 905227050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 486, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152400}, {\"Order\": 1398, \"PID\": 905300020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1399, \"PID\": 905351089, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1003.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1291.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1291, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1400, \"PID\": 905352030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 299.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 2022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 117, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1401, \"PID\": 905352070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 20270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1402, \"PID\": 905401045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 39104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Membran\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1063.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1403, \"PID\": 905401060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1663, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1404, \"PID\": 905402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 11512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1019.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1357, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1357, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 163, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1405, \"PID\": 905403060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 617, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1079, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 249.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125600}, {\"Order\": 1406, \"PID\": 905403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 287, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1407, \"PID\": 905425125, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 45600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 907.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1307, \"2ndFlrSF\": 1051, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1908.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1408, \"PID\": 905426030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"PreCast\", \"Exterior2nd\": \"PreCast\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1035.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1409, \"PID\": 905427050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1163.0, \"TotalBsmtSF\": 1163.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 511, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1410, \"PID\": 905427070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 2108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1411, \"PID\": 905451330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1509.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 576, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1412, \"PID\": 905452070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99600}, {\"Order\": 1413, \"PID\": 905452120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 621, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1414, \"PID\": 905476120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1415, \"PID\": 905477050, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 969.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 527, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 1416, \"PID\": 905479110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1417, \"PID\": 905480150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 572, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 8, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 1418, \"PID\": 905480240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 380.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1419, \"PID\": 906204150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1475.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1532, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2329, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262280}, {\"Order\": 1420, \"PID\": 906204280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9771, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 1721, \"LowQualFinSF\": 0, \"GrLivArea\": 2814, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1421, \"PID\": 906223110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 251.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1626, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1422, \"PID\": 906223140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 355.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 1099, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1423, \"PID\": 906223220, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 735, \"LowQualFinSF\": 0, \"GrLivArea\": 2037, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 1424, \"PID\": 906378190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 628.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177439}, {\"Order\": 1425, \"PID\": 906380030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1615.0, \"TotalBsmtSF\": 1615.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1615, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1615, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 1426, \"PID\": 906412010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 2271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2276, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1348.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 475000}, {\"Order\": 1427, \"PID\": 906412050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1751.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395039}, {\"Order\": 1428, \"PID\": 906420130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 531.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 187, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 1429, \"PID\": 906424010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 631.0, \"TotalBsmtSF\": 1401.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 811.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1430, \"PID\": 906475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1182.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1643, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1643, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 339, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1431, \"PID\": 906476030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12798, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 154.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 1072, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 403, \"OpenPorchSF\": 114, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1432, \"PID\": 907126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 722.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1433, \"PID\": 907135020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1099.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1099, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1099, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1434, \"PID\": 907135260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1435, \"PID\": 907175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226001}, {\"Order\": 1436, \"PID\": 907176010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 688.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 899, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215700}, {\"Order\": 1437, \"PID\": 907181120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 782, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1438, \"PID\": 907181140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 873.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 193000}, {\"Order\": 1439, \"PID\": 907187030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1440, \"PID\": 907187080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 9382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1441, \"PID\": 907192130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 1442, \"PID\": 907194020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 963.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 963, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 245, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 1443, \"PID\": 907196040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1823, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 4500, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1444, \"PID\": 907196050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 1445, \"PID\": 907200110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 491.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 938, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130250}, {\"Order\": 1446, \"PID\": 907201060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 328.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 1447, \"PID\": 907202010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1174, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 211, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1448, \"PID\": 907202160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1449, \"PID\": 907202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1076, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143195}, {\"Order\": 1450, \"PID\": 907202240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 88.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1558, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1451, \"PID\": 907203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 7990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1452, \"PID\": 907227050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1453, \"PID\": 907227300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 780, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 1454, \"PID\": 907250020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1777.0, \"TotalBsmtSF\": 1777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 159, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1455, \"PID\": 907251090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9473, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 903, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 1456, \"PID\": 907253060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 257.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1457, \"PID\": 907253110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 1458, \"PID\": 907254020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9066, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 106, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1459, \"PID\": 907254090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 1460, \"PID\": 907255020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 396.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287000}, {\"Order\": 1461, \"PID\": 907255030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1357.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1366, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1462, \"PID\": 907255060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1786, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 715.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1463, \"PID\": 907260010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 1141, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 1464, \"PID\": 907262030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 334.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 1465, \"PID\": 907262060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 10905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1129.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1129, \"2ndFlrSF\": 1198, \"LowQualFinSF\": 0, \"GrLivArea\": 2327, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1466, \"PID\": 907262070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 595.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1467, \"PID\": 907265100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1468, \"PID\": 907285080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 642.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 933, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1469, \"PID\": 907290150, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1470, \"PID\": 907290250, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1471, \"PID\": 907295020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 215.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1493, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1493, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208900}, {\"Order\": 1472, \"PID\": 907295100, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 83.0, \"LotArea\": 10126, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1593.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 1473, \"PID\": 907405020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 726.0, \"TotalBsmtSF\": 1536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1536, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1474, \"PID\": 907405140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 854, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208500}, {\"Order\": 1475, \"PID\": 907412040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1421.0, \"TotalBsmtSF\": 1445.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1476, \"PID\": 907412070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 946.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 139, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1477, \"PID\": 907412080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 770, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1478, \"PID\": 907412090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1234, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1479, \"PID\": 907418010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1508.0, \"TotalBsmtSF\": 1564.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218836}, {\"Order\": 1480, \"PID\": 907418040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1327.0, \"TotalBsmtSF\": 1351.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1481, \"PID\": 907420080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1482, \"PID\": 907425010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149300}, {\"Order\": 1483, \"PID\": 907425015, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1484, \"PID\": 907425030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1485, \"PID\": 907425035, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 1486, \"PID\": 908102030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1487, \"PID\": 908102040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 928, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145900}, {\"Order\": 1488, \"PID\": 908102140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 259, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 123000}, {\"Order\": 1489, \"PID\": 908102260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 830.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 736, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1490, \"PID\": 908103260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 12102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 222.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1033, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1033, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 165000}, {\"Order\": 1491, \"PID\": 908103280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1033.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1127, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1492, \"PID\": 908127120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1493, \"PID\": 908128050, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 38.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1181, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1181, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1494, \"PID\": 908128110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 92.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165400}, {\"Order\": 1495, \"PID\": 908151040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 120.0, \"BsmtUnfSF\": 541.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1496, \"PID\": 908152110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1497, \"PID\": 908152270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1132.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1498, \"PID\": 908154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 123.0, \"LotArea\": 47007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3820, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3820, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 372, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284700}, {\"Order\": 1499, \"PID\": 908154235, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 63887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"ClyTile\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 796.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 5644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 6110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 4692, \"2ndFlrSF\": 950, \"LowQualFinSF\": 0, \"GrLivArea\": 5642, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 1418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 292, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 480, \"PoolQC\": \"Gd\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 160000}, {\"Order\": 1500, \"PID\": 908186040, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 459.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1501, \"PID\": 908201100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1502, \"PID\": 908201110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1503, \"PID\": 908201120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1307.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1504, \"PID\": 908204160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 1505, \"PID\": 908225170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91900}, {\"Order\": 1506, \"PID\": 908226120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 585, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 120000}, {\"Order\": 1507, \"PID\": 908250040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 1508, \"PID\": 908250090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 134, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Gar2\", \"MiscVal\": 3000, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1509, \"PID\": 908275130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1510, \"PID\": 908275180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1511, \"PID\": 908275280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 521, \"LowQualFinSF\": 0, \"GrLivArea\": 1393, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 265, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 1512, \"PID\": 908276140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1513, \"PID\": 909100150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 343, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1514, \"PID\": 909100170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1515, \"PID\": 909101060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 41.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 823.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67000}, {\"Order\": 1516, \"PID\": 909101180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5687, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135900}, {\"Order\": 1517, \"PID\": 909131170, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 254, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1518, \"PID\": 909175050, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 720, \"LowQualFinSF\": 420, \"GrLivArea\": 2192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179500}, {\"Order\": 1519, \"PID\": 909175100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 423.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 758.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 304, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1520, \"PID\": 909177120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1521, \"PID\": 909201110, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 8525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1911, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 940.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1522, \"PID\": 909250040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 1611, \"LowQualFinSF\": 0, \"GrLivArea\": 2601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 183, \"OpenPorchSF\": 0, \"EnclosedPorch\": 301, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1523, \"PID\": 909250230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 679.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 161900}, {\"Order\": 1524, \"PID\": 909251080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8969, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 369.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1525, \"PID\": 909251090, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1423, \"2ndFlrSF\": 748, \"LowQualFinSF\": 384, \"GrLivArea\": 2555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1526, \"PID\": 909252110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1527, \"PID\": 909252220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15564, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1528, \"PID\": 909253190, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 1529, \"PID\": 909254050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7609, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 16, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 1530, \"PID\": 909256060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 473, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1531, \"PID\": 909275040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 599.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 217, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1532, \"PID\": 909275050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1533, \"PID\": 909276170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1934, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 389.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 849, \"2ndFlrSF\": 811, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188700}, {\"Order\": 1534, \"PID\": 909277040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 673, \"LowQualFinSF\": 0, \"GrLivArea\": 1938, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 1535, \"PID\": 909277070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 932, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1536, \"PID\": 909281030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 7801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 591.0, \"TotalBsmtSF\": 1091.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 344.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 221, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 1537, \"PID\": 909281110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 786.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 207, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 257076}, {\"Order\": 1538, \"PID\": 909282030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1935, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1968, \"2ndFlrSF\": 1479, \"LowQualFinSF\": 0, \"GrLivArea\": 3447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1014.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 381000}, {\"Order\": 1539, \"PID\": 909425010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 817, \"LowQualFinSF\": 0, \"GrLivArea\": 1954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 311500}, {\"Order\": 1540, \"PID\": 909425085, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 943, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263400}, {\"Order\": 1541, \"PID\": 909428170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 26073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1898.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1898, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 1542, \"PID\": 909428190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 568.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 924.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 1543, \"PID\": 909451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 366.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 213, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 1544, \"PID\": 909451150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 612.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1545, \"PID\": 910200080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 555.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 919, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1546, \"PID\": 910201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 330, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1547, \"PID\": 910202050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1548, \"PID\": 910202100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1549, \"PID\": 910203020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 71.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 125.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 778, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 924.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1550, \"PID\": 910203090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 780, \"2ndFlrSF\": 420, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1551, \"PID\": 910205010, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1552, \"PID\": 910206110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 1553, \"PID\": 910226040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1955, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1554, \"PID\": 910251050, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 80.0, \"LotArea\": 14584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Po\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 13100}, {\"Order\": 1555, \"PID\": 911102090, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 5280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1895, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1895.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 185.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 1556, \"PID\": 911102170, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 649, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1317, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 172, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 40000}, {\"Order\": 1557, \"PID\": 911102180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 52.0, \"LotArea\": 5150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 671, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80900}, {\"Order\": 1558, \"PID\": 911226010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 120.0, \"LotArea\": 18000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 560, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1559, \"PID\": 911226030, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 432, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 65000}, {\"Order\": 1560, \"PID\": 911370410, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 5587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392500}, {\"Order\": 1561, \"PID\": 911370490, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294464}, {\"Order\": 1562, \"PID\": 911370520, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1563, \"PID\": 911370540, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 1564, \"PID\": 914453045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 668.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2032, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1565, \"PID\": 914465060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 857.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1566, \"PID\": 914467050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 910.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 318, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1567, \"PID\": 914475020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 574.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 358.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 576, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1568, \"PID\": 914476010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 83, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 1569, \"PID\": 914476080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1570, \"PID\": 914476450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 428, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 1571, \"PID\": 916125425, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 164660, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 1499.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1619, \"2ndFlrSF\": 167, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 670, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228950}, {\"Order\": 1572, \"PID\": 916226030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 893.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1573, \"PID\": 916325080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15498, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1165.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 665.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 174, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 287000}, {\"Order\": 1574, \"PID\": 916380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 258.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1575, \"PID\": 916382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293077}, {\"Order\": 1576, \"PID\": 916384100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264966}, {\"Order\": 1577, \"PID\": 916386040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 712, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 1578, \"PID\": 916386080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": null, \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 1579, \"PID\": 916386180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 12018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 218689}, {\"Order\": 1580, \"PID\": 916402015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1495.0, \"TotalBsmtSF\": 1495.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1495, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1581, \"PID\": 916402115, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 12416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1398.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 208.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1582, \"PID\": 916402215, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 18265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1583, \"PID\": 916403230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 219.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 783.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1584, \"PID\": 916455120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11202, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1029.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 1432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232500}, {\"Order\": 1585, \"PID\": 916460060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7915, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1586, \"PID\": 916477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 2262, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 749.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1587, \"PID\": 921126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1011.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 873.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 276, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 298751}, {\"Order\": 1588, \"PID\": 921201060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1571.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 393.0, \"TotalBsmtSF\": 1964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 892.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1589, \"PID\": 923202005, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 97.0, \"LotArea\": 8940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 209200}, {\"Order\": 1590, \"PID\": 923202015, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 206300}, {\"Order\": 1591, \"PID\": 923202137, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9278, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1592, \"PID\": 923203140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 197.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 1189.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1189, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1189, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1593, \"PID\": 923204040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 171, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1594, \"PID\": 923225080, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 271.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1595, \"PID\": 923225150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1596, \"PID\": 923225200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 318.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1597, \"PID\": 923225310, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 501.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 526.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1598, \"PID\": 923225370, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 120, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94900}, {\"Order\": 1599, \"PID\": 923227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1160, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 257.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 1600, \"PID\": 923228080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1970, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1601, \"PID\": 923228420, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1602, \"PID\": 923250210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 988.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1603, \"PID\": 923252100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 6490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1604, \"PID\": 923275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 6951, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 362, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1605, \"PID\": 923277030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1982, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1606, \"PID\": 923277040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1982, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1607, \"PID\": 923277080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1608, \"PID\": 923400040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 983.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1300, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1609, \"PID\": 923426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 647.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 889, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1610, \"PID\": 924100020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 562.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 193.0, \"BsmtUnfSF\": 29.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1611, \"PID\": 1007100110, \"MSSubClass\": 70, \"MSZoning\": \"I (all)\", \"LotFrontage\": null, \"LotArea\": 56600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1612, \"PID\": 526352080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 838.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 749.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1587, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1587, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167300}, {\"Order\": 1613, \"PID\": 526352090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1277, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 526.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 1614, \"PID\": 526355170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 2223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2223, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2223, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 1615, \"PID\": 526355190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 15865, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 823.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 2217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 1616, \"PID\": 527105140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 225000}, {\"Order\": 1617, \"PID\": 527107040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 373.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1618, \"PID\": 527110080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 794, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1619, \"PID\": 527110120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 1620, \"PID\": 527110130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 1621, \"PID\": 527126030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 1622, \"PID\": 527158090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 770, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1623, \"PID\": 527161090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 947, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1624, \"PID\": 527162080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178750}, {\"Order\": 1625, \"PID\": 527162090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1626, \"PID\": 527162140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 957, \"2ndFlrSF\": 1342, \"LowQualFinSF\": 0, \"GrLivArea\": 2299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1627, \"PID\": 527163080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1168.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1628, \"PID\": 527165020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1629, \"PID\": 527165100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163900}, {\"Order\": 1630, \"PID\": 527165170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 903.0, \"TotalBsmtSF\": 903.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1631, \"PID\": 527175130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 18160, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 154204}, {\"Order\": 1632, \"PID\": 527182040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1633, \"PID\": 527182170, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1634, \"PID\": 527184020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 4740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1166.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 135, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1635, \"PID\": 527184110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 5118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 926.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1321, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1321, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 1636, \"PID\": 527210060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377426}, {\"Order\": 1637, \"PID\": 527212060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1377, \"LowQualFinSF\": 0, \"GrLivArea\": 2541, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 729.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 349265}, {\"Order\": 1638, \"PID\": 527216080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 51974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 710.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1101.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1559.0, \"TotalBsmtSF\": 2660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1110.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 591587}, {\"Order\": 1639, \"PID\": 527226040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 195.0, \"LotArea\": 41600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1047.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 53.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1640, \"PID\": 527252050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8035, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 797.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 164, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 1641, \"PID\": 527252070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8089, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 1642, \"PID\": 527256030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 945.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1558.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 2220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 441929}, {\"Order\": 1643, \"PID\": 527256040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 13870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 174, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 455000}, {\"Order\": 1644, \"PID\": 527301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 99, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182900}, {\"Order\": 1645, \"PID\": 527301280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1028.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1646, \"PID\": 527302020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 178000}, {\"Order\": 1647, \"PID\": 527302060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 167, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1648, \"PID\": 527302090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1328.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 1529.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1649, \"PID\": 527325090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 11339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 549.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 22.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1650, \"PID\": 527325110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11952, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1161, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 276, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1651, \"PID\": 527327050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12046, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 2030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1652, \"PID\": 527328020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 605.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1653, \"PID\": 527328050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1177, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1654, \"PID\": 527353080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 539.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 1655, \"PID\": 527354050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 253.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1259.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1353, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192350}, {\"Order\": 1656, \"PID\": 527356050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 263.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1657, \"PID\": 527357020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 13001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 249, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1658, \"PID\": 527358060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1659, \"PID\": 527359010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 175.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1660, \"PID\": 527359080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 1661, \"PID\": 527359160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 604.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 585.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 407, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1662, \"PID\": 527377110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 153.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1877, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 1663, \"PID\": 527402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 349.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 533, \"LowQualFinSF\": 0, \"GrLivArea\": 1109, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 35, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1664, \"PID\": 527402150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 35.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143250}, {\"Order\": 1665, \"PID\": 527402240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1972, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1666, \"PID\": 527403310, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1667, \"PID\": 527404050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 619.0, \"BsmtUnfSF\": 214.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1668, \"PID\": 527404100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 412.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1669, \"PID\": 527404140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8294, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1670, \"PID\": 527404150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 322.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1671, \"PID\": 527425025, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1672, \"PID\": 527425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1673, \"PID\": 527427090, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 139.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 767, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 367.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1674, \"PID\": 527427160, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 33.0, \"LotArea\": 4113, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1337.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1675, \"PID\": 527427200, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 10943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1676, \"PID\": 527450030, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 1677, \"PID\": 527450150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 356.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1678, \"PID\": 527450220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113700}, {\"Order\": 1679, \"PID\": 527451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2016, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1680, \"PID\": 527451170, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 376.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 1681, \"PID\": 527452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 958.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 205, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1682, \"PID\": 527453010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 556.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1683, \"PID\": 527455030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 6.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 1061.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 1684, \"PID\": 527455250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 725.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129250}, {\"Order\": 1685, \"PID\": 528102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12469, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1151.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1790.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356000}, {\"Order\": 1686, \"PID\": 528102090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 452.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1774.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 260, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 314813}, {\"Order\": 1687, \"PID\": 528102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1688, \"PID\": 528102120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 322400}, {\"Order\": 1689, \"PID\": 528102130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 328.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 730.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1690, \"PID\": 528104010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 2108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345474}, {\"Order\": 1691, \"PID\": 528106040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 315.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2121.0, \"TotalBsmtSF\": 2121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 415298}, {\"Order\": 1692, \"PID\": 528106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13641, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1304.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1934.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1943, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 2656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1040.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 492000}, {\"Order\": 1693, \"PID\": 528106060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1108.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 1402, \"LowQualFinSF\": 0, \"GrLivArea\": 2550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338931}, {\"Order\": 1694, \"PID\": 528106110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 400.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 450000}, {\"Order\": 1695, \"PID\": 528108160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 14154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1063.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1071, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 947.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 280000}, {\"Order\": 1696, \"PID\": 528110040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 2552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 479069}, {\"Order\": 1697, \"PID\": 528110070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 375.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1935.0, \"TotalBsmtSF\": 1935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1973, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1973, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395000}, {\"Order\": 1698, \"PID\": 528110100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 772.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2153.0, \"TotalBsmtSF\": 2153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 2643, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 694.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 380000}, {\"Order\": 1699, \"PID\": 528112150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1626.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1634, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1634, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1700, \"PID\": 528114050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14977, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 1976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 440000}, {\"Order\": 1701, \"PID\": 528118040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13654, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1704.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1722, \"2ndFlrSF\": 1036, \"LowQualFinSF\": 0, \"GrLivArea\": 2758, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 418000}, {\"Order\": 1702, \"PID\": 528118050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 17169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 970.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 2320.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1174.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 500067}, {\"Order\": 1703, \"PID\": 528120010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1582.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 570, \"LowQualFinSF\": 0, \"GrLivArea\": 2152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 368, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260116}, {\"Order\": 1704, \"PID\": 528120150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 317000}, {\"Order\": 1705, \"PID\": 528142050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9709, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319500}, {\"Order\": 1706, \"PID\": 528144050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325624}, {\"Order\": 1707, \"PID\": 528150040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 510.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1802.0, \"TotalBsmtSF\": 1802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1802, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372000}, {\"Order\": 1708, \"PID\": 528150110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 13069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 502.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1706.0, \"TotalBsmtSF\": 1706.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 1238, \"LowQualFinSF\": 0, \"GrLivArea\": 2956, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 916.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 342000}, {\"Order\": 1709, \"PID\": 528150120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 388.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 970.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 872.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 354000}, {\"Order\": 1710, \"PID\": 528166150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14277, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1317.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1711, \"PID\": 528168040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11999, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1712, \"PID\": 528172030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 669.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 895.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 895, \"2ndFlrSF\": 923, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281500}, {\"Order\": 1713, \"PID\": 528172050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1178.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245700}, {\"Order\": 1714, \"PID\": 528172070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9254, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1602.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232698}, {\"Order\": 1715, \"PID\": 528172075, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1298.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 876.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 1716, \"PID\": 528174010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194700}, {\"Order\": 1717, \"PID\": 528174020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3901, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204000}, {\"Order\": 1718, \"PID\": 528174030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 272.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1719, \"PID\": 528174040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 6289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1720, \"PID\": 528181060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1721, \"PID\": 528181070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1722, \"PID\": 528181080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 1723, \"PID\": 528186050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 7841, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 394.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 848.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 729.0, \"TotalBsmtSF\": 1577.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1577, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 1724, \"PID\": 528186090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 1725, \"PID\": 528186120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1869.0, \"TotalBsmtSF\": 1869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318061}, {\"Order\": 1726, \"PID\": 528186190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1300.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221370}, {\"Order\": 1727, \"PID\": 528188160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 235.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1728, \"PID\": 528218010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 15810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181755}, {\"Order\": 1729, \"PID\": 528218020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1730, \"PID\": 528218050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 783, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 178900}, {\"Order\": 1731, \"PID\": 528218100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 13204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 168165}, {\"Order\": 1732, \"PID\": 528221030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8857, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 757, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 171925}, {\"Order\": 1733, \"PID\": 528221040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9729, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 1048, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198444}, {\"Order\": 1734, \"PID\": 528221050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 918.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 1735, \"PID\": 528221090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179540}, {\"Order\": 1736, \"PID\": 528222030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 176485}, {\"Order\": 1737, \"PID\": 528222040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1340.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181134}, {\"Order\": 1738, \"PID\": 528222050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 796, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156932}, {\"Order\": 1739, \"PID\": 528222060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8229, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 22.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1740, \"PID\": 528222080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7713, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177594}, {\"Order\": 1741, \"PID\": 528222090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1246.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173500}, {\"Order\": 1742, \"PID\": 528228270, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172500}, {\"Order\": 1743, \"PID\": 528228275, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194201}, {\"Order\": 1744, \"PID\": 528228375, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3621, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1589, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1745, \"PID\": 528228555, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185485}, {\"Order\": 1746, \"PID\": 528231010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 182.0, \"LotArea\": 14572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 259000}, {\"Order\": 1747, \"PID\": 528231030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 16219, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1119, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1119, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1748, \"PID\": 528235000, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 175000}, {\"Order\": 1749, \"PID\": 528235160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11796, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1112, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1750, \"PID\": 528235170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1510.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 206580}, {\"Order\": 1751, \"PID\": 528240020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 1752, \"PID\": 528250010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1753, \"PID\": 528250070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 1754, \"PID\": 528275035, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1755, \"PID\": 528275110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 1131, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1756, \"PID\": 528280110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 694, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1757, \"PID\": 528280150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1758, \"PID\": 528290060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 1759, \"PID\": 528290170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1760, \"PID\": 528294010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9649, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1761, \"PID\": 528320050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 15623, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2411, \"2ndFlrSF\": 2065, \"LowQualFinSF\": 0, \"GrLivArea\": 4476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 813.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 555, \"PoolQC\": \"Ex\", \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 745000}, {\"Order\": 1762, \"PID\": 528322020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 515.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 2551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 384500}, {\"Order\": 1763, \"PID\": 528326060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 1288, \"LowQualFinSF\": 0, \"GrLivArea\": 2285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 1764, \"PID\": 528327060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 705.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1351.0, \"TotalBsmtSF\": 2633.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2633, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2633, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 804.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 466500}, {\"Order\": 1765, \"PID\": 528340030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10557, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 1407, \"LowQualFinSF\": 0, \"GrLivArea\": 3078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 806.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 1766, \"PID\": 528344020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1048.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 1171, \"LowQualFinSF\": 0, \"GrLivArea\": 2582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 322500}, {\"Order\": 1767, \"PID\": 528348030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 275.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1066.0, \"TotalBsmtSF\": 1066.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1277, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 1768, \"PID\": 528351010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 21535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1170.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 989.0, \"TotalBsmtSF\": 2444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2444, \"2ndFlrSF\": 1872, \"LowQualFinSF\": 0, \"GrLivArea\": 4316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 832.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 755000}, {\"Order\": 1769, \"PID\": 528354060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 862.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2013, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 455.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269790}, {\"Order\": 1770, \"PID\": 528354110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11787, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 594.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 1379.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 1015, \"LowQualFinSF\": 0, \"GrLivArea\": 2398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315750}, {\"Order\": 1771, \"PID\": 528358040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1203.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 290000}, {\"Order\": 1772, \"PID\": 528364110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1318.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 752.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1773, \"PID\": 528366050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1969.0, \"TotalBsmtSF\": 3200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 75, \"EnclosedPorch\": 291, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 430000}, {\"Order\": 1774, \"PID\": 528366070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 335.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2202, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 1775, \"PID\": 528376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 526.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1225.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1325.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2538, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 933.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 1776, \"PID\": 528427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1369.0, \"TotalBsmtSF\": 1369.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1369, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 203, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 213133}, {\"Order\": 1777, \"PID\": 528427100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1542, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260261}, {\"Order\": 1778, \"PID\": 528429090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 11670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1905.0, \"TotalBsmtSF\": 1905.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1905, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1905, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 1779, \"PID\": 528429110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282922}, {\"Order\": 1780, \"PID\": 528431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1534, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 215000}, {\"Order\": 1781, \"PID\": 528431040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 754.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 394.0, \"TotalBsmtSF\": 1966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1966, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1092.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 419005}, {\"Order\": 1782, \"PID\": 528431050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13501, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 63.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1623.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1783, \"PID\": 528431110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9986, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 428.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1795.0, \"TotalBsmtSF\": 1795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 1784, \"PID\": 528435010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1528, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235876}, {\"Order\": 1785, \"PID\": 528435040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1126.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 311872}, {\"Order\": 1786, \"PID\": 528435060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 954.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248328}, {\"Order\": 1787, \"PID\": 528435070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 825.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1788, \"PID\": 528439040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8847, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 1538.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1538, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1538, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1789, \"PID\": 528439050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 1790, \"PID\": 528439080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8251, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 1791, \"PID\": 528441080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 255, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 307000}, {\"Order\": 1792, \"PID\": 528445020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 982, \"2ndFlrSF\": 995, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 250000}, {\"Order\": 1793, \"PID\": 528445070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 528, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 859.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221300}, {\"Order\": 1794, \"PID\": 528456190, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1314.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1795, \"PID\": 528456230, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1335.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1335, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210400}, {\"Order\": 1796, \"PID\": 528458080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 255000}, {\"Order\": 1797, \"PID\": 528458090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 10411, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212109}, {\"Order\": 1798, \"PID\": 528458120, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1025.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 1799, \"PID\": 528458130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 64.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1120.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1184, \"2ndFlrSF\": 1426, \"LowQualFinSF\": 0, \"GrLivArea\": 2610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 364, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 303477}, {\"Order\": 1800, \"PID\": 528458150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1880, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310013}, {\"Order\": 1801, \"PID\": 528477020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 11096, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249700}, {\"Order\": 1802, \"PID\": 528480020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 874.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1761, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227875}, {\"Order\": 1803, \"PID\": 528480180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1574.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 256, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 261329}, {\"Order\": 1804, \"PID\": 528482010, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 11824, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1685.0, \"TotalBsmtSF\": 1685.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1685, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1685, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 1805, \"PID\": 528482030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 353.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2443, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 744.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 1806, \"PID\": 528482090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 102.0, \"LotArea\": 11143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 159, \"OpenPorchSF\": 214, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 1807, \"PID\": 531363020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 146000}, {\"Order\": 1808, \"PID\": 531363040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1809, \"PID\": 531375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1810, \"PID\": 531376060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1461.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1811, \"PID\": 531380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 1812, \"PID\": 531384070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11613, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191750}, {\"Order\": 1813, \"PID\": 531385070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1349.0, \"TotalBsmtSF\": 1349.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1349, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1349, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1814, \"PID\": 531385130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 39.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 402, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1815, \"PID\": 531451030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1145.0, \"TotalBsmtSF\": 1575.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1816, \"PID\": 531451150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1817, \"PID\": 531453140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1818, \"PID\": 531477040, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1819, \"PID\": 532353120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 351.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120750}, {\"Order\": 1820, \"PID\": 532354010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1821, \"PID\": 532354060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1822, \"PID\": 532354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 999.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1823, \"PID\": 532376040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 6970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1824, \"PID\": 532376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 13673, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143900}, {\"Order\": 1825, \"PID\": 532377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 7476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1826, \"PID\": 532377140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 57.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 827.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1827, \"PID\": 532378240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1828, \"PID\": 532476080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1232, \"LowQualFinSF\": 0, \"GrLivArea\": 2503, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1829, \"PID\": 532477040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 125.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1031.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 2167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1830, \"PID\": 532479050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 10751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1037, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1831, \"PID\": 532479120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16647, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1701, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 611.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1832, \"PID\": 532479140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 968.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 455, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 147000}, {\"Order\": 1833, \"PID\": 533120030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 482.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 1357, \"LowQualFinSF\": 0, \"GrLivArea\": 2810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 500, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 1834, \"PID\": 533130170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10678, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 337.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 983.0, \"TotalBsmtSF\": 1683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2129, \"2ndFlrSF\": 743, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1835, \"PID\": 533205110, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 45.0, \"LotArea\": 4379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 527.0, \"TotalBsmtSF\": 1378.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1836, \"PID\": 533206060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 3523, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1081.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1151, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1837, \"PID\": 533206070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 3784, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1511.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193800}, {\"Order\": 1838, \"PID\": 533208010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 47.0, \"LotArea\": 4230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1352.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1839, \"PID\": 533208020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3606, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 937.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 1840, \"PID\": 533208030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1550, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 207500}, {\"Order\": 1841, \"PID\": 533208040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4274, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1106.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1241.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1241, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1241, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199900}, {\"Order\": 1842, \"PID\": 533208070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4251, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164700}, {\"Order\": 1843, \"PID\": 533213130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 1844, \"PID\": 533213140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1129.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1845, \"PID\": 533221030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1846, \"PID\": 533221060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1847, \"PID\": 533221100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1848, \"PID\": 533223050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 5105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 551.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 551, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 1849, \"PID\": 533236040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1850, \"PID\": 533241030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 66.0, \"LotArea\": 7399, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 1851, \"PID\": 533242080, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 73.0, \"LotArea\": 7321, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1339.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1852, \"PID\": 533242090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 1853, \"PID\": 533244040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 106.0, \"LotArea\": 8413, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 1105.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 1854, \"PID\": 533250190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1037.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 217, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279700}, {\"Order\": 1855, \"PID\": 533251110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1856, \"PID\": 533251130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 1857, \"PID\": 533252130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1157.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 1858, \"PID\": 533253180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 176.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 89, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213750}, {\"Order\": 1859, \"PID\": 533254100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 761, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1860, \"PID\": 533254130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 978.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181500}, {\"Order\": 1861, \"PID\": 533350020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 17778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1632.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 829.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 2461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2497, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2497, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 373000}, {\"Order\": 1862, \"PID\": 533352075, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAe\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 211.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 1361.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 1259, \"LowQualFinSF\": 0, \"GrLivArea\": 2620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 24, \"EnclosedPorch\": 145, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 8300, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1863, \"PID\": 534104090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 1929, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 1864, \"PID\": 534125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143450}, {\"Order\": 1865, \"PID\": 534127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 1008, \"LowQualFinSF\": 0, \"GrLivArea\": 2411, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240050}, {\"Order\": 1866, \"PID\": 534127140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 973.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1867, \"PID\": 534127260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 385.0, \"TotalBsmtSF\": 1295.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 194, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 1868, \"PID\": 534128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 11358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1869, \"PID\": 534151090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1594, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1870, \"PID\": 534151180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1871, \"PID\": 534175010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAn\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136905}, {\"Order\": 1872, \"PID\": 534176140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 792.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1873, \"PID\": 534177210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 916.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1874, \"PID\": 534178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1875, \"PID\": 534201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 38.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1876, \"PID\": 534202030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 519.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1877, \"PID\": 534204120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1878, \"PID\": 534252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1879, \"PID\": 534252060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10624, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1880, \"PID\": 534252070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1881, \"PID\": 534252110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 978.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 1882, \"PID\": 534275170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1960, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 15500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1883, \"PID\": 534275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 66.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1065, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 1884, \"PID\": 534276070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 63.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 81.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1885, \"PID\": 534276160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 285, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1886, \"PID\": 534276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 206.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1887, \"PID\": 534276290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 1888, \"PID\": 534278150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 167.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1889, \"PID\": 534278170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1890, \"PID\": 534278190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117600}, {\"Order\": 1891, \"PID\": 534401120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1174.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1892, \"PID\": 534401200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1893, \"PID\": 534403040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 270.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 580.0, \"BsmtUnfSF\": 452.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 309.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 333, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1894, \"PID\": 534403290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 1309, \"LowQualFinSF\": 0, \"GrLivArea\": 2154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 1895, \"PID\": 534403420, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 543.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1130.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1374, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1896, \"PID\": 534425015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 1592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 201, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1897, \"PID\": 534425080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 219.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1429, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1429, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1898, \"PID\": 534427140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1327, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1327, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150750}, {\"Order\": 1899, \"PID\": 534429030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101800}, {\"Order\": 1900, \"PID\": 534430090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 932, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 306.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 214, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1901, \"PID\": 534431020, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 259.0, \"BsmtUnfSF\": 433.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 908, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 1902, \"PID\": 534450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 2, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 39300}, {\"Order\": 1903, \"PID\": 534450110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1904, \"PID\": 534451020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 442, \"2ndFlrSF\": 228, \"LowQualFinSF\": 0, \"GrLivArea\": 670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1905, \"PID\": 534453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 404.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 1906, \"PID\": 534475170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1907, \"PID\": 534476080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1908, \"PID\": 534478140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Roll\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 708.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 992, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1909, \"PID\": 534479120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1910, \"PID\": 534479140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 1911, \"PID\": 535101150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1912, \"PID\": 535102010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 87.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1913, \"PID\": 535105110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 291.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1914, \"PID\": 535106140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 1915, \"PID\": 535106180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11344, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 874, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1916, \"PID\": 535126180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 1021.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1465, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Sev\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129000}, {\"Order\": 1917, \"PID\": 535151020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 873.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 63.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 219, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1918, \"PID\": 535151100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 908.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 1919, \"PID\": 535151110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 109, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142100}, {\"Order\": 1920, \"PID\": 535152060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1921, \"PID\": 535154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 243.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 834.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 275, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 1922, \"PID\": 535155110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 1923, \"PID\": 535176070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1244, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1244, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1924, \"PID\": 535177020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 69.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1144.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1925, \"PID\": 535177110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 138.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1331.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174850}, {\"Order\": 1926, \"PID\": 535179120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1927, \"PID\": 535180030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 586.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1928, \"PID\": 535181030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1237.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1657, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1929, \"PID\": 535181140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1930, \"PID\": 535300040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 928.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1931, \"PID\": 535301060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1932, \"PID\": 535301160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8078, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128600}, {\"Order\": 1933, \"PID\": 535302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1934, \"PID\": 535304170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 85.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 955.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 293.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1935, \"PID\": 535305180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1936, \"PID\": 535325090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 691.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1937, \"PID\": 535325280, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1938, \"PID\": 535325320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 500, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1939, \"PID\": 535327160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1940, \"PID\": 535327200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 377.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 551.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1941, \"PID\": 535353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 368, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1942, \"PID\": 535353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 324, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1943, \"PID\": 535353160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 14190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 544, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1944, \"PID\": 535354050, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 893, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 893, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1945, \"PID\": 535354260, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 512, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1946, \"PID\": 535355020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 21281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 1778, \"LowQualFinSF\": 0, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 208, \"EnclosedPorch\": 290, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 301600}, {\"Order\": 1947, \"PID\": 535375130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 735.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 735, \"2ndFlrSF\": 299, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 1948, \"PID\": 535376010, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 882.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103200}, {\"Order\": 1949, \"PID\": 535378080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 66.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 1950, \"PID\": 535379060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1951, \"PID\": 535379110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1895, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1952, \"PID\": 535382150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 691.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 86000}, {\"Order\": 1953, \"PID\": 535402140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 364.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 242.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1954, \"PID\": 535402180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 1955, \"PID\": 535403030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 952.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1956, \"PID\": 535426130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1957, \"PID\": 535450190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122900}, {\"Order\": 1958, \"PID\": 535450220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119200}, {\"Order\": 1959, \"PID\": 535450310, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10496, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1960, \"PID\": 535451040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 246.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1961, \"PID\": 535451100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1238, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 171, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 1962, \"PID\": 535451110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 398.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 149.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1963, \"PID\": 535452060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 254.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1964, \"PID\": 535453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1965, \"PID\": 535453150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7315, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1170.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1170, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1966, \"PID\": 535453180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 1967, \"PID\": 535457020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1098.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 154.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1377.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1377, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 1968, \"PID\": 535457040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1969, \"PID\": 535457050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1970, \"PID\": 535476360, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 831, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1971, \"PID\": 535477130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 1972, \"PID\": 535477180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 442.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1973, \"PID\": 535478040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 90, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1974, \"PID\": 902100010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1975, \"PID\": 902105110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 664, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 132000}, {\"Order\": 1976, \"PID\": 902106070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 175, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1977, \"PID\": 902106120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 782.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 184.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1978, \"PID\": 902107050, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1979, \"PID\": 902110010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 3153, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 26, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 1980, \"PID\": 902125120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1885, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1047, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1047, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1981, \"PID\": 902128160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 279.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1982, \"PID\": 902201090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 494, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 26, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1983, \"PID\": 902201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 679, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1984, \"PID\": 902202070, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 435.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 89471}, {\"Order\": 1985, \"PID\": 902205020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 122.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 448.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 761, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1986, \"PID\": 902205130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 1987, \"PID\": 902206270, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1075.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 642, \"LowQualFinSF\": 0, \"GrLivArea\": 1798, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1988, \"PID\": 902207010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1945, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 1989, \"PID\": 902207150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 968.0, \"TotalBsmtSF\": 968.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1990, \"PID\": 902300020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10337, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 1991, \"PID\": 902300040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 9863, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 374.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1992, \"PID\": 902301030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 842, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1993, \"PID\": 902301130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1994, \"PID\": 902302150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 1995, \"PID\": 902303100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 667.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 659, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144100}, {\"Order\": 1996, \"PID\": 902304040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1880, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 1997, \"PID\": 902305010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 316.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 687.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 687, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 124500}, {\"Order\": 1998, \"PID\": 902330090, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1879, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 819.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2454, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1999, \"PID\": 902332030, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1046.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 1031, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 99, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 2000, \"PID\": 902401030, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 779.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2001, \"PID\": 902404010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1221.0, \"TotalBsmtSF\": 1559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1559, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1559, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 230, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2002, \"PID\": 902408080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 718.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2003, \"PID\": 902427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 9439, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2004, \"PID\": 902427140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2005, \"PID\": 902427180, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2006, \"PID\": 903201090, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 6854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 227.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 916, \"2ndFlrSF\": 144, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 150, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2007, \"PID\": 903204030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8674, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1435, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128250}, {\"Order\": 2008, \"PID\": 903205085, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 8731, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 645.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2009, \"PID\": 903206170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 915, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2010, \"PID\": 903225040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2011, \"PID\": 903227140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 217.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 2012, \"PID\": 903228080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 349, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2013, \"PID\": 903231050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2014, \"PID\": 903231090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 809.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2015, \"PID\": 903231180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 423, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2016, \"PID\": 903232100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 966.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2017, \"PID\": 903233030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 903, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2018, \"PID\": 903233050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1933.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2019, \"PID\": 903233140, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 854, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2020, \"PID\": 903233180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 959, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 2021, \"PID\": 903234160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2022, \"PID\": 903236130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 7755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1164, \"LowQualFinSF\": 0, \"GrLivArea\": 2264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2023, \"PID\": 903400040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2024, \"PID\": 903401070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2025, \"PID\": 903425270, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 356, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2026, \"PID\": 903425280, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153575}, {\"Order\": 2027, \"PID\": 903426010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1929, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2028, \"PID\": 903427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 546.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 714.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 15, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136000}, {\"Order\": 2029, \"PID\": 903430040, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 933, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 113000}, {\"Order\": 2030, \"PID\": 903430050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 969, \"2ndFlrSF\": 245, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 117000}, {\"Order\": 2031, \"PID\": 903450060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 2032, \"PID\": 903451110, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 7449, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 2033, \"PID\": 903453080, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1497, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2034, \"PID\": 903454010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 0, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2035, \"PID\": 903454090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2036, \"PID\": 903456110, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 398.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 1952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 285, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212300}, {\"Order\": 2037, \"PID\": 903457040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 1042, \"LowQualFinSF\": 0, \"GrLivArea\": 2180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2038, \"PID\": 903457130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 4330, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 477, \"LowQualFinSF\": 0, \"GrLivArea\": 1315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 99500}, {\"Order\": 2039, \"PID\": 903458020, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 581, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101000}, {\"Order\": 2040, \"PID\": 903458060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 197.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 999.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2041, \"PID\": 903475040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 12358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 528, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2042, \"PID\": 903475060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 964, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2043, \"PID\": 903476100, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 4388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2044, \"PID\": 903484080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 771.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 504, \"LowQualFinSF\": 114, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 14, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 84, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 50000}, {\"Order\": 2045, \"PID\": 904100100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1937, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 1005, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 521, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219000}, {\"Order\": 2046, \"PID\": 904101070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 138.0, \"LotArea\": 18030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 977.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 971, \"LowQualFinSF\": 479, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 2047, \"PID\": 904301110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 756, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 126000}, {\"Order\": 2048, \"PID\": 904302010, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 4484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2049, \"PID\": 905100060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2050, \"PID\": 905100080, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158450}, {\"Order\": 2051, \"PID\": 905101070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 14299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115400}, {\"Order\": 2052, \"PID\": 905101200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1029, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 261.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2053, \"PID\": 905102010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 722.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2054, \"PID\": 905103110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 761.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2055, \"PID\": 905104030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 627.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 913, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2056, \"PID\": 905104090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 7094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2057, \"PID\": 905104170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 948.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 108000}, {\"Order\": 2058, \"PID\": 905104240, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 20.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2059, \"PID\": 905105040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 8665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 897, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2060, \"PID\": 905105170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 323.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 529.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2061, \"PID\": 905105260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 955, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2062, \"PID\": 905106150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 8724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2063, \"PID\": 905107140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 2064, \"PID\": 905200010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2065, \"PID\": 905201080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 522.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 323.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2066, \"PID\": 905225020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 16779, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 1087, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 570, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2067, \"PID\": 905226050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1416, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2068, \"PID\": 905226080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165250}, {\"Order\": 2069, \"PID\": 905226130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 231.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2070, \"PID\": 905226170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 873.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"VWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2071, \"PID\": 905228020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 998, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 998, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 2072, \"PID\": 905301050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 115149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 739.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 380, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 2073, \"PID\": 905352010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 891.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2074, \"PID\": 905352180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2075, \"PID\": 905376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 109.0, \"TotalBsmtSF\": 409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1325, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 2076, \"PID\": 905377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 587.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2077, \"PID\": 905377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 17808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2078, \"PID\": 905401020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2079, \"PID\": 905426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 12615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 477.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243000}, {\"Order\": 2080, \"PID\": 905451390, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 491.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 638, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 332.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 2081, \"PID\": 905475270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2082, \"PID\": 905475520, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11515, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2083, \"PID\": 905476160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 7711, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2084, \"PID\": 905476170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 605, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 605, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 2085, \"PID\": 905476225, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 3869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 755.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1038.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1038, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2086, \"PID\": 905478140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2087, \"PID\": 905478220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1080.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 400, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2088, \"PID\": 905480090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 951.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 376, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 2089, \"PID\": 905480180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2090, \"PID\": 906200230, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 23920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1105.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 1012, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 444, \"PoolQC\": \"TA\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2091, \"PID\": 906201022, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 10357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 719.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 244, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2092, \"PID\": 906201023, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 1121, \"LowQualFinSF\": 0, \"GrLivArea\": 2243, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 44, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2093, \"PID\": 906201200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1474.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2730, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 2094, \"PID\": 906203140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 634.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 833.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 192, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2095, \"PID\": 906204140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 807.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 196, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2096, \"PID\": 906223040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 497.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 929, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2097, \"PID\": 906340080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 984.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 1414, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 383970}, {\"Order\": 2098, \"PID\": 906340090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1362, \"LowQualFinSF\": 0, \"GrLivArea\": 2828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 424870}, {\"Order\": 2099, \"PID\": 906378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 2100, \"PID\": 906378150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10481, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2140.0, \"TotalBsmtSF\": 2140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 360000}, {\"Order\": 2101, \"PID\": 906378170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10652, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1494.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 279500}, {\"Order\": 2102, \"PID\": 906380010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 11175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 200141}, {\"Order\": 2103, \"PID\": 906380040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 10235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246500}, {\"Order\": 2104, \"PID\": 906380070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1482.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 1092, \"LowQualFinSF\": 0, \"GrLivArea\": 2574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 276000}, {\"Order\": 2105, \"PID\": 906380120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 349.0, \"TotalBsmtSF\": 1274.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1274, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203000}, {\"Order\": 2106, \"PID\": 906380140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11103, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155835}, {\"Order\": 2107, \"PID\": 906380160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2108, \"PID\": 906380200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 195400}, {\"Order\": 2109, \"PID\": 906382020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1526.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1546, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1546, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2110, \"PID\": 906382060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1453.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 674.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212999}, {\"Order\": 2111, \"PID\": 906392080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1270.0, \"TotalBsmtSF\": 1270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1270, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2112, \"PID\": 906394020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 916, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 2113, \"PID\": 906394050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176432}, {\"Order\": 2114, \"PID\": 906402070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1157.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 882, \"LowQualFinSF\": 0, \"GrLivArea\": 2062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 154, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2115, \"PID\": 906403060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 321.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 927, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2116, \"PID\": 906426060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 159000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 2144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2117, \"PID\": 906426195, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53107, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 985.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 874, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 231, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2118, \"PID\": 906475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2087, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2119, \"PID\": 906475170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 155.0, \"LotArea\": 20064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 51.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 915.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 646, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2120, \"PID\": 907125040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 472.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 747.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2121, \"PID\": 907125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2122, \"PID\": 907130060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11249, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 544.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 2123, \"PID\": 907131060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 10021, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 635.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 646, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2124, \"PID\": 907131120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9531, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 914, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2125, \"PID\": 907135050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2126, \"PID\": 907135080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 16561, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 242.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147900}, {\"Order\": 2127, \"PID\": 907135180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123600}, {\"Order\": 2128, \"PID\": 907180040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 905, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204750}, {\"Order\": 2129, \"PID\": 907187040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 646.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 597.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235500}, {\"Order\": 2130, \"PID\": 907187060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12352, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 853, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1753, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2131, \"PID\": 907192020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 845.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190550}, {\"Order\": 2132, \"PID\": 907192040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8826, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2133, \"PID\": 907192120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 167.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1013.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2134, \"PID\": 907192150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2135, \"PID\": 907200130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 131000}, {\"Order\": 2136, \"PID\": 907200190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 502.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2137, \"PID\": 907200250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1009, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2138, \"PID\": 907200270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 2139, \"PID\": 907202100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 16300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 417.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2140, \"PID\": 907202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 432.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2141, \"PID\": 907203060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 2142, \"PID\": 907203110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 10356, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 969, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2143, \"PID\": 907227060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 671.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2144, \"PID\": 907227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2145, \"PID\": 907250050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 2000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305900}, {\"Order\": 2146, \"PID\": 907252020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1284.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 2169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2147, \"PID\": 907252190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11354, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1412.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1673, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1673, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2148, \"PID\": 907260040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1459.0, \"TotalBsmtSF\": 1459.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1459, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1459, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 2149, \"PID\": 907260050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 2150, \"PID\": 907262020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 214.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2151, \"PID\": 907270040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 16226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 1242, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 267000}, {\"Order\": 2152, \"PID\": 907275080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 519.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 683.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1592, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1592, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2153, \"PID\": 907275150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 1531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2439, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2154, \"PID\": 907280090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2155, \"PID\": 907280100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 2156, \"PID\": 907285040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 438.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1079.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2157, \"PID\": 907290140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 2158, \"PID\": 907295040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 17227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246900}, {\"Order\": 2159, \"PID\": 907401060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1081, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2160, \"PID\": 907405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2161, \"PID\": 907410020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179400}, {\"Order\": 2162, \"PID\": 907410050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 639.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 2163, \"PID\": 907414060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1422.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179600}, {\"Order\": 2164, \"PID\": 907414070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 709.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 2165, \"PID\": 907420050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1330, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167840}, {\"Order\": 2166, \"PID\": 907420060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 753, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168675}, {\"Order\": 2167, \"PID\": 907420110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2168, \"PID\": 908102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2169, \"PID\": 908102160, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 405, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 2170, \"PID\": 908103090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 132.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2171, \"PID\": 908127040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 10921, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 48.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94750}, {\"Order\": 2172, \"PID\": 908127060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 16287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 450, \"LowQualFinSF\": 0, \"GrLivArea\": 1351, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 43, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2173, \"PID\": 908127070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1179.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2174, \"PID\": 908127100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 11841, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2175, \"PID\": 908152060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2176, \"PID\": 908152070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 751.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2177, \"PID\": 908152180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9555, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1133, \"LowQualFinSF\": 0, \"GrLivArea\": 2233, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2178, \"PID\": 908152260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1125.0, \"TotalBsmtSF\": 1125.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155000}, {\"Order\": 2179, \"PID\": 908152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2180, \"PID\": 908152290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 123.0, \"TotalBsmtSF\": 734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 674, \"LowQualFinSF\": 0, \"GrLivArea\": 1408, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 2181, \"PID\": 908154195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 39290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 4010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 5095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 5095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 5095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 15, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1154.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 546, \"OpenPorchSF\": 484, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Elev\", \"MiscVal\": 17000, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 183850}, {\"Order\": 2182, \"PID\": 908154205, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 40094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 762.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 3138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3138, \"2ndFlrSF\": 1538, \"LowQualFinSF\": 0, \"GrLivArea\": 4676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 406, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 184750}, {\"Order\": 2183, \"PID\": 908186050, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 467.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2184, \"PID\": 908204090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 77.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 831.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2185, \"PID\": 908204180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2186, \"PID\": 908225240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 2187, \"PID\": 908225310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1195, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 118, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98500}, {\"Order\": 2188, \"PID\": 908226180, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 4270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 286, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2189, \"PID\": 908228010, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 278.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 740, \"2ndFlrSF\": 125, \"LowQualFinSF\": 0, \"GrLivArea\": 865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2190, \"PID\": 908250100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 2191, \"PID\": 908275090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2192, \"PID\": 908275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2193, \"PID\": 908275240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 79275}, {\"Order\": 2194, \"PID\": 908276230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2195, \"PID\": 909176080, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 10896, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1184.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 1440, \"LowQualFinSF\": 515, \"GrLivArea\": 3395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 8, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 14, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 200000}, {\"Order\": 2196, \"PID\": 909176170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2592, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 742, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1512, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 150000}, {\"Order\": 2197, \"PID\": 909250150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 53, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2198, \"PID\": 909250160, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10594, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 2199, \"PID\": 909251030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7223, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2200, \"PID\": 909251040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6821, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 113.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2201, \"PID\": 909252010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 787, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2202, \"PID\": 909252150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 4000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 567, \"2ndFlrSF\": 531, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 2203, \"PID\": 909252170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 6720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 585, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 2204, \"PID\": 909254090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7642, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 514, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189950}, {\"Order\": 2205, \"PID\": 909254100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 775, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2206, \"PID\": 909254130, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 364.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2207, \"PID\": 909254140, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1913, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 365.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90350}, {\"Order\": 2208, \"PID\": 909254150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 661.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 661, \"2ndFlrSF\": 589, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 242, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2209, \"PID\": 909256120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 920.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119750}, {\"Order\": 2210, \"PID\": 909275020, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 7136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 979, \"2ndFlrSF\": 979, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2211, \"PID\": 909275030, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 6270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 1001, \"LowQualFinSF\": 0, \"GrLivArea\": 2002, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2212, \"PID\": 909275110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1927, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 867, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 291, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2213, \"PID\": 909275160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 126.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 24, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 228, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2214, \"PID\": 909275310, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 22420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1128.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2215, \"PID\": 909276160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12168, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 537.0, \"TotalBsmtSF\": 965.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 3194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 359100}, {\"Order\": 2216, \"PID\": 909276210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 7810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1230, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2217, \"PID\": 909279080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 557.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 19, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2218, \"PID\": 909281020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 6221, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2219, \"PID\": 909281130, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1549, \"2ndFlrSF\": 1178, \"LowQualFinSF\": 0, \"GrLivArea\": 2727, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2220, \"PID\": 909282020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1945, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 150.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 2320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259500}, {\"Order\": 2221, \"PID\": 909425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 1477.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1839, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 2222, \"PID\": 909425270, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2223, \"PID\": 909428120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 35.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 869.0, \"BsmtUnfSF\": 905.0, \"TotalBsmtSF\": 1809.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2259, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2259, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 217000}, {\"Order\": 2224, \"PID\": 909428180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1020.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 584, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 2225, \"PID\": 909428340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21579, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2226, \"PID\": 909451130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 529, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 2227, \"PID\": 909452102, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2228, \"PID\": 909455060, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 577.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2229, \"PID\": 909475050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 652.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 434.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1262.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 2230, \"PID\": 909475070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 2035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2515, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2515, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 200624}, {\"Order\": 2231, \"PID\": 909475230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 18044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 279.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 64, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 228, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2232, \"PID\": 910200040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 997, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2233, \"PID\": 910200110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2234, \"PID\": 910201020, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 803, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2235, \"PID\": 910201050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 176, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129850}, {\"Order\": 2236, \"PID\": 910201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 772, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1123, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 2237, \"PID\": 910201180, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": null, \"GarageArea\": null, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 150909}, {\"Order\": 2238, \"PID\": 910202030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 46.0, \"LotArea\": 3672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 100.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75200}, {\"Order\": 2239, \"PID\": 910203290, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118400}, {\"Order\": 2240, \"PID\": 910204090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 961.0, \"TotalBsmtSF\": 961.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"Mix\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 67000}, {\"Order\": 2241, \"PID\": 910205130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 910, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2242, \"PID\": 910206010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 11067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 205, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68104}, {\"Order\": 2243, \"PID\": 911103060, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1895, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 957.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 957, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 133, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119600}, {\"Order\": 2244, \"PID\": 911128010, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 65.0, \"LotArea\": 6565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 106.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 444, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2245, \"PID\": 911128020, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 837.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1001, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 86, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 2246, \"PID\": 911370450, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2247, \"PID\": 911370460, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 481.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 235000}, {\"Order\": 2248, \"PID\": 914452090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1001.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2249, \"PID\": 914452120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2250, \"PID\": 914452190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2251, \"PID\": 914460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 856.0, \"TotalBsmtSF\": 1441.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2252, \"PID\": 914460110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 12864, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 17.0, \"TotalBsmtSF\": 1409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1409, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 2253, \"PID\": 914476330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2254, \"PID\": 914478020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 530.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 852.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2255, \"PID\": 914478100, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 924.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2256, \"PID\": 916226090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 4054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 949.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 2257, \"PID\": 916253320, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 9763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 239.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1102.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 2258, \"PID\": 916326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 16905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2259, \"PID\": 916326090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 19958, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 274, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2260, \"PID\": 916384050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 231713}, {\"Order\": 2261, \"PID\": 916384070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8298, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 963.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2207.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267300}, {\"Order\": 2262, \"PID\": 916384080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1476.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265900}, {\"Order\": 2263, \"PID\": 916384150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1571.0, \"TotalBsmtSF\": 1571.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1571, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239000}, {\"Order\": 2264, \"PID\": 916386170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 274.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1638.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248900}, {\"Order\": 2265, \"PID\": 916403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 215.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 1265.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2266, \"PID\": 916403290, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2267, \"PID\": 916455010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 742.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1756, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 2268, \"PID\": 916455050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6718, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2269, \"PID\": 916455110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 82.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2270, \"PID\": 916455150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 886.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 593.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282000}, {\"Order\": 2271, \"PID\": 916460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2272, \"PID\": 916475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 808.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 252, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2273, \"PID\": 916477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 1340, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279900}, {\"Order\": 2274, \"PID\": 917425190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 35133, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 995.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 263, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 263, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186700}, {\"Order\": 2275, \"PID\": 921126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 15306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1652.0, \"TotalBsmtSF\": 1732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 283463}, {\"Order\": 2276, \"PID\": 921128030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 2277, \"PID\": 921205070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1094.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 1349, \"LowQualFinSF\": 0, \"GrLivArea\": 2482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 281213}, {\"Order\": 2278, \"PID\": 923202134, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 914.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 2279, \"PID\": 923202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 200.0, \"LotArea\": 43500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1041.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 561, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2280, \"PID\": 923203010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 6710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 904.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2281, \"PID\": 923204050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 25286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132250}, {\"Order\": 2282, \"PID\": 923204140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 25000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2283, \"PID\": 923205025, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 149.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1622, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 439, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2284, \"PID\": 923225040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 840.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2285, \"PID\": 923225050, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 874.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 536, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2286, \"PID\": 923226300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2287, \"PID\": 923228200, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 27.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 97, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 2288, \"PID\": 923228220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93900}, {\"Order\": 2289, \"PID\": 923228250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 2290, \"PID\": 923228290, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 131.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 499.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2291, \"PID\": 923228390, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 75190}, {\"Order\": 2292, \"PID\": 923229010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146800}, {\"Order\": 2293, \"PID\": 923229040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9129, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2294, \"PID\": 923229100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1356, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 1424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2295, \"PID\": 923229140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 33983, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1112.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1676, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 690, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2296, \"PID\": 923230010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 185.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2297, \"PID\": 923230120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 2298, \"PID\": 923230180, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 149.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2299, \"PID\": 923251160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 27697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"CBlock\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 811.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1608, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2300, \"PID\": 923252080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7599, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2301, \"PID\": 923275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1090.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 88, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2302, \"PID\": 923275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2303, \"PID\": 923276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 596.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 330, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2304, \"PID\": 923400150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 212.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 974.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 974, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 974, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93500}, {\"Order\": 2305, \"PID\": 923425030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 887, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2306, \"PID\": 526302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11027, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1178.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1293, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1293, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2307, \"PID\": 526302040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 280, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2308, \"PID\": 526302120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1127.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 963.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2309, \"PID\": 526303060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 39384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 902.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 252000}, {\"Order\": 2310, \"PID\": 526354020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11727, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 434.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1851.0, \"TotalBsmtSF\": 1851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1851, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192100}, {\"Order\": 2311, \"PID\": 527105060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8238, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2312, \"PID\": 527106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 964.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 1243, \"LowQualFinSF\": 0, \"GrLivArea\": 2236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2313, \"PID\": 527107020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 781, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2314, \"PID\": 527107030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13031, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 592.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2315, \"PID\": 527107120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 821.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 821, \"2ndFlrSF\": 955, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 443.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2316, \"PID\": 527107240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 714.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 413.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 95, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2317, \"PID\": 527108010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 19378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 2462, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2318, \"PID\": 527108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 14859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 27.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1670.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 240000}, {\"Order\": 2319, \"PID\": 527108030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 13128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 990, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2320, \"PID\": 527108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 893.0, \"TotalBsmtSF\": 893.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 2321, \"PID\": 527108060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 13751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1640.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 2212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 773.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 309000}, {\"Order\": 2322, \"PID\": 527108090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 168.0, \"LotArea\": 23257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2021, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 274725}, {\"Order\": 2323, \"PID\": 527146135, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2062.0, \"TotalBsmtSF\": 2062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2079, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2324, \"PID\": 527158020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8076, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2325, \"PID\": 527163020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165600}, {\"Order\": 2326, \"PID\": 527166030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 2327, \"PID\": 527182020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 3701, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2328, \"PID\": 527190050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 5306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 215.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 441, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2329, \"PID\": 527190220, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 28, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2330, \"PID\": 527210030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 1384, \"LowQualFinSF\": 0, \"GrLivArea\": 2798, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 37, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 457347}, {\"Order\": 2331, \"PID\": 527210040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 18062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 662.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 1862, \"LowQualFinSF\": 0, \"GrLivArea\": 3390, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 545224}, {\"Order\": 2332, \"PID\": 527210050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 205.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 889.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1371, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 246, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356383}, {\"Order\": 2333, \"PID\": 527212030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 16056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1752.0, \"TotalBsmtSF\": 1992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1992, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 2868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 716.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 556581}, {\"Order\": 2334, \"PID\": 527212040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 1312, \"LowQualFinSF\": 0, \"GrLivArea\": 2576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 361919}, {\"Order\": 2335, \"PID\": 527214060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 16052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 734.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 2698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 535000}, {\"Order\": 2336, \"PID\": 527216010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 15922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 550.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 1405, \"LowQualFinSF\": 0, \"GrLivArea\": 2795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 401179}, {\"Order\": 2337, \"PID\": 527216050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1031.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1410.0, \"TotalBsmtSF\": 1410.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 1519, \"LowQualFinSF\": 0, \"GrLivArea\": 2945, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 37, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 438780}, {\"Order\": 2338, \"PID\": 527226010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1547, \"2ndFlrSF\": 720, \"LowQualFinSF\": 53, \"GrLivArea\": 2320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2339, \"PID\": 527250040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 34650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2340, \"PID\": 527252090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 523.0, \"TotalBsmtSF\": 1714.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1714, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 2341, \"PID\": 527254070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11302, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Other\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1422.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1826, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319000}, {\"Order\": 2342, \"PID\": 527256120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 18261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 123, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 470000}, {\"Order\": 2343, \"PID\": 527301010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 995.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2344, \"PID\": 527302080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1002.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 2183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2345, \"PID\": 527325160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 34.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 795.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 250, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2346, \"PID\": 527327080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2347, \"PID\": 527328010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2348, \"PID\": 527354040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 604.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 2349, \"PID\": 527355060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1857, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188900}, {\"Order\": 2350, \"PID\": 527355280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 1061.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 384, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2351, \"PID\": 527356020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1392, \"LowQualFinSF\": 0, \"GrLivArea\": 2784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 440, \"PoolArea\": 519, \"PoolQC\": \"Fa\", \"Fence\": \"MnPrv\", \"MiscFeature\": \"TenC\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2352, \"PID\": 527356060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 811, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 208, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2353, \"PID\": 527358090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 42.0, \"TotalBsmtSF\": 1047.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1083, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1083, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 444, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2354, \"PID\": 527365010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1358, \"LowQualFinSF\": 0, \"GrLivArea\": 2318, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 246, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294323}, {\"Order\": 2355, \"PID\": 527375160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 127.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1109, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 485.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 2356, \"PID\": 527376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2357, \"PID\": 527376110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 2358, \"PID\": 527377030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 377.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1309, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1309, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 648, \"PoolQC\": \"Fa\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2359, \"PID\": 527378010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2360, \"PID\": 527402210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 75.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 791.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 138800}, {\"Order\": 2361, \"PID\": 527402380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9353, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 116050}, {\"Order\": 2362, \"PID\": 527403120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 614.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 2363, \"PID\": 527404180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 2364, \"PID\": 527427210, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 951.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1487.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2365, \"PID\": 527450010, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 514.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 2366, \"PID\": 527450080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2367, \"PID\": 527450210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 408.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83000}, {\"Order\": 2368, \"PID\": 527450460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 494, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2369, \"PID\": 527451200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 91500}, {\"Order\": 2370, \"PID\": 527451380, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2371, \"PID\": 527451450, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 465, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2372, \"PID\": 527451460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 382.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2373, \"PID\": 527451520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 297.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94500}, {\"Order\": 2374, \"PID\": 527452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 156.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146300}, {\"Order\": 2375, \"PID\": 527452290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 373.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1387, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2376, \"PID\": 527452310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 175, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2377, \"PID\": 527453070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2378, \"PID\": 527455100, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2379, \"PID\": 528102010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 66.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1447.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 770.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2380, \"PID\": 528102080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 16387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1738, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 2589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 412083}, {\"Order\": 2381, \"PID\": 528106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 111.0, \"LotArea\": 16259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 370.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1249.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1249, \"2ndFlrSF\": 1347, \"LowQualFinSF\": 0, \"GrLivArea\": 2596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 342643}, {\"Order\": 2382, \"PID\": 528106120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 16163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1618.0, \"TotalBsmtSF\": 1618.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1618, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1618, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 2383, \"PID\": 528110050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 690.0, \"TotalBsmtSF\": 2076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2076, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 229, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 465000}, {\"Order\": 2384, \"PID\": 528112010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 12228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1721.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293000}, {\"Order\": 2385, \"PID\": 528114010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 14780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1085.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 354, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2386, \"PID\": 528116030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 16033, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1261.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 519, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 326000}, {\"Order\": 2387, \"PID\": 528118010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 14215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1218, \"LowQualFinSF\": 0, \"GrLivArea\": 2376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 853.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325300}, {\"Order\": 2388, \"PID\": 528118020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 309000}, {\"Order\": 2389, \"PID\": 528118110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13975, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 300000}, {\"Order\": 2390, \"PID\": 528120110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1030.0, \"TotalBsmtSF\": 1030.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 1060, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 2391, \"PID\": 528120140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 385.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 466, \"LowQualFinSF\": 0, \"GrLivArea\": 2091, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338500}, {\"Order\": 2392, \"PID\": 528138030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345000}, {\"Order\": 2393, \"PID\": 528142010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 12867, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1209.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 344133}, {\"Order\": 2394, \"PID\": 528142060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 10672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 1335, \"LowQualFinSF\": 0, \"GrLivArea\": 2389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 298236}, {\"Order\": 2395, \"PID\": 528142070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 814, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 329900}, {\"Order\": 2396, \"PID\": 528142110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 1896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 708.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 2397, \"PID\": 528144030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11065, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 788.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 1085.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 753.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281000}, {\"Order\": 2398, \"PID\": 528150080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372397}, {\"Order\": 2399, \"PID\": 528150090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 131.0, \"LotArea\": 14828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 1780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378000}, {\"Order\": 2400, \"PID\": 528164040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 562.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 374000}, {\"Order\": 2401, \"PID\": 528170040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 20431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 870.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1848, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 2728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 437154}, {\"Order\": 2402, \"PID\": 528172020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 512.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 179, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2403, \"PID\": 528172150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 488, \"LowQualFinSF\": 0, \"GrLivArea\": 1914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2404, \"PID\": 528174080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 705.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185850}, {\"Order\": 2405, \"PID\": 528180080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 5911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282500}, {\"Order\": 2406, \"PID\": 528181030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6955, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202500}, {\"Order\": 2407, \"PID\": 528181040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 6792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202665}, {\"Order\": 2408, \"PID\": 528186100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 518.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 899.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 332200}, {\"Order\": 2409, \"PID\": 528186110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 572.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1251.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310090}, {\"Order\": 2410, \"PID\": 528188040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171750}, {\"Order\": 2411, \"PID\": 528218030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 23, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169990}, {\"Order\": 2412, \"PID\": 528218060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 170440}, {\"Order\": 2413, \"PID\": 528218080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169985}, {\"Order\": 2414, \"PID\": 528218130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 17104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 426.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179665}, {\"Order\": 2415, \"PID\": 528218140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 14054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 1863, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 219210}, {\"Order\": 2416, \"PID\": 528221010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 11660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1326.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 174190}, {\"Order\": 2417, \"PID\": 528221100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172785}, {\"Order\": 2418, \"PID\": 528222010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11631, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1052.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 1321, \"LowQualFinSF\": 0, \"GrLivArea\": 2373, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 258000}, {\"Order\": 2419, \"PID\": 528222020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185101}, {\"Order\": 2420, \"PID\": 528228280, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3087, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 767.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210250}, {\"Order\": 2421, \"PID\": 528228325, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1374.0, \"TotalBsmtSF\": 1374.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 2422, \"PID\": 528228340, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1273.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2423, \"PID\": 528228360, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1038.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246990}, {\"Order\": 2424, \"PID\": 528228415, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1375.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178740}, {\"Order\": 2425, \"PID\": 528228430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2426, \"PID\": 528228545, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167240}, {\"Order\": 2427, \"PID\": 528228550, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1126.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156820}, {\"Order\": 2428, \"PID\": 528228565, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213490}, {\"Order\": 2429, \"PID\": 528228575, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1154.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 1520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264561}, {\"Order\": 2430, \"PID\": 528228580, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246578}, {\"Order\": 2431, \"PID\": 528231050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 21930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192140}, {\"Order\": 2432, \"PID\": 528235050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7861, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183200}, {\"Order\": 2433, \"PID\": 528235130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2434, \"PID\": 528235190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1598, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201490}, {\"Order\": 2435, \"PID\": 528240080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1406.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1454, \"2ndFlrSF\": 482, \"LowQualFinSF\": 0, \"GrLivArea\": 1936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 2436, \"PID\": 528250060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2437, \"PID\": 528275060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8121, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 711, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172400}, {\"Order\": 2438, \"PID\": 528275080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2439, \"PID\": 528280100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 930, \"LowQualFinSF\": 0, \"GrLivArea\": 1886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 89, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199900}, {\"Order\": 2440, \"PID\": 528290140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 959.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 2441, \"PID\": 528292080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287602}, {\"Order\": 2442, \"PID\": 528294070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 1286, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2443, \"PID\": 528315030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1074.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1407, \"2ndFlrSF\": 985, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 348000}, {\"Order\": 2444, \"PID\": 528315070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 31, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 2445, \"PID\": 528315080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 322.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 655.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1205, \"2ndFlrSF\": 1029, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2446, \"PID\": 528320060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 35760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1831, \"2ndFlrSF\": 1796, \"LowQualFinSF\": 0, \"GrLivArea\": 3627, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 807.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 361, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 625000}, {\"Order\": 2447, \"PID\": 528327010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9233, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 877.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 358.0, \"TotalBsmtSF\": 1540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1540, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2855, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 247, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 405000}, {\"Order\": 2448, \"PID\": 528344060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 530.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 374, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2449, \"PID\": 528348010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 258000}, {\"Order\": 2450, \"PID\": 528358030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 397.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 1368, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 169, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 2451, \"PID\": 528360050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 17242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 738.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1393.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1733.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1933, \"2ndFlrSF\": 1567, \"LowQualFinSF\": 0, \"GrLivArea\": 3500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 959.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 870, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 584500}, {\"Order\": 2452, \"PID\": 528363070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 501.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1305, \"2ndFlrSF\": 1189, \"LowQualFinSF\": 0, \"GrLivArea\": 2494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 803.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 321000}, {\"Order\": 2453, \"PID\": 528365090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 391.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1203, \"2ndFlrSF\": 1323, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 309, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 2454, \"PID\": 528366040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1039.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 1234, \"LowQualFinSF\": 0, \"GrLivArea\": 2799, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 432, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2455, \"PID\": 528429060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 760.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252000}, {\"Order\": 2456, \"PID\": 528429100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1562.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336820}, {\"Order\": 2457, \"PID\": 528429120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 20896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1721.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 2077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1134.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 267, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 423000}, {\"Order\": 2458, \"PID\": 528429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290000}, {\"Order\": 2459, \"PID\": 528439030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1616.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 2460, \"PID\": 528445010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1504.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199000}, {\"Order\": 2461, \"PID\": 528456200, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1254.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 584.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198600}, {\"Order\": 2462, \"PID\": 528477010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 13162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 2036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 405749}, {\"Order\": 2463, \"PID\": 528477030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 11216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 232600}, {\"Order\": 2464, \"PID\": 528480070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1053.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 266000}, {\"Order\": 2465, \"PID\": 528480100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186500}, {\"Order\": 2466, \"PID\": 528480110, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200825}, {\"Order\": 2467, \"PID\": 528480150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 798, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 197000}, {\"Order\": 2468, \"PID\": 528488110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 905.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185000}, {\"Order\": 2469, \"PID\": 528488120, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2470, \"PID\": 528488130, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1293.0, \"TotalBsmtSF\": 1293.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187750}, {\"Order\": 2471, \"PID\": 531363080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1118.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 4, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2472, \"PID\": 531367010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 118.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1400.0, \"TotalBsmtSF\": 1400.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1400, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186800}, {\"Order\": 2473, \"PID\": 531375060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1131.0, \"TotalBsmtSF\": 1131.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 132000}, {\"Order\": 2474, \"PID\": 531375070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2475, \"PID\": 531375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 158000}, {\"Order\": 2476, \"PID\": 531376030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 891.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 891, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 2477, \"PID\": 531376050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1585, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 449.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 2478, \"PID\": 531379030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1837, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 688.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2479, \"PID\": 531450040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 761.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2480, \"PID\": 531451290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1731, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3000, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 248500}, {\"Order\": 2481, \"PID\": 531452080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1398, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2482, \"PID\": 531452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 278.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 1217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2483, \"PID\": 531452210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 362.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 636, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2484, \"PID\": 531478010, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 8900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107000}, {\"Order\": 2485, \"PID\": 531479030, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2486, \"PID\": 532351060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2487, \"PID\": 532351090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1332.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2488, \"PID\": 532351150, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1286, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2489, \"PID\": 532353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2490, \"PID\": 532353180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 8471, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 46.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 506.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2491, \"PID\": 532376080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2492, \"PID\": 532376180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2493, \"PID\": 532376250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2494, \"PID\": 532378050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120875}, {\"Order\": 2495, \"PID\": 532378070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 375.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 935, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2496, \"PID\": 532378130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2497, \"PID\": 532378160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 465.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 447.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2498, \"PID\": 532378220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8789, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129200}, {\"Order\": 2499, \"PID\": 532476050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 497.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1748.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2151, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 4, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 641, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 800, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2500, \"PID\": 533110130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 16059, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2417, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2501, \"PID\": 533125120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 692.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1118.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 208, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 2502, \"PID\": 533127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 310000}, {\"Order\": 2503, \"PID\": 533128030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13346, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 1129, \"LowQualFinSF\": 0, \"GrLivArea\": 2295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 2504, \"PID\": 533128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"ImStucc\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 757.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262000}, {\"Order\": 2505, \"PID\": 533206040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3628, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176400}, {\"Order\": 2506, \"PID\": 533208050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3316, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1247.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1247, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1247, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2507, \"PID\": 533212100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2508, \"PID\": 533212110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147400}, {\"Order\": 2509, \"PID\": 533212120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2510, \"PID\": 533212130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 144152}, {\"Order\": 2511, \"PID\": 533221080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 2512, \"PID\": 533223010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 241.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183900}, {\"Order\": 2513, \"PID\": 533223080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 673, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 153, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2514, \"PID\": 533223110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2515, \"PID\": 533241010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 114.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 382, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2516, \"PID\": 533242030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 2517, \"PID\": 533250130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 9549, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1057.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2518, \"PID\": 533252020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2519, \"PID\": 533253030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1009.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 44.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2520, \"PID\": 533253050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 3640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2521, \"PID\": 533253090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3874, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 807.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 419.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2522, \"PID\": 533253160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 526.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2523, \"PID\": 533350050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 50271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 1842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1842, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 857, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 385000}, {\"Order\": 2524, \"PID\": 534125210, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 13110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2525, \"PID\": 534126060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 10192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2526, \"PID\": 534127190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 1203.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2156, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2156, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 290, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 2527, \"PID\": 534127270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 404.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 708.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 708, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 119, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2528, \"PID\": 534128210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 435.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 222, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2529, \"PID\": 534129230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165150}, {\"Order\": 2530, \"PID\": 534175100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 264, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164500}, {\"Order\": 2531, \"PID\": 534176250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1164.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2532, \"PID\": 534201130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2533, \"PID\": 534201230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2534, \"PID\": 534201250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1770, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 270, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 455, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2535, \"PID\": 534201260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 94, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157500}, {\"Order\": 2536, \"PID\": 534201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 2537, \"PID\": 534201300, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2538, \"PID\": 534202020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124400}, {\"Order\": 2539, \"PID\": 534202180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 402.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 568.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2540, \"PID\": 534226060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 661.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2541, \"PID\": 534250300, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1993, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2542, \"PID\": 534275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 319, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2543, \"PID\": 534276010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2544, \"PID\": 534276230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1098.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 145000}, {\"Order\": 2545, \"PID\": 534400120, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 34.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 25, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 460, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185900}, {\"Order\": 2546, \"PID\": 534403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2547, \"PID\": 534403400, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 748.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2548, \"PID\": 534403440, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2549, \"PID\": 534427090, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2550, \"PID\": 534428060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 8973, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 28.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2551, \"PID\": 534429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 2552, \"PID\": 534430050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129800}, {\"Order\": 2553, \"PID\": 534430110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2554, \"PID\": 534431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1043, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1043, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2555, \"PID\": 534451050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 4712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 456, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 63, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 121600}, {\"Order\": 2556, \"PID\": 534451120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 5900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2557, \"PID\": 534451130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 5825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79900}, {\"Order\": 2558, \"PID\": 534453150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 7438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 316, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2559, \"PID\": 534455080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2560, \"PID\": 534475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1404.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 324, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 146500}, {\"Order\": 2561, \"PID\": 534476100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2562, \"PID\": 534477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 756.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1380.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 2136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 2563, \"PID\": 534479130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 165.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 958, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2564, \"PID\": 534479240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2565, \"PID\": 534479300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2566, \"PID\": 535101110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2567, \"PID\": 535103070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 939.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 307.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2568, \"PID\": 535105160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98600}, {\"Order\": 2569, \"PID\": 535125060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 2157, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2570, \"PID\": 535150240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 118000}, {\"Order\": 2571, \"PID\": 535150300, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 25419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 4, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 184.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 1360, \"LowQualFinSF\": 392, \"GrLivArea\": 3112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 552, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 512, \"PoolQC\": \"Ex\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 235000}, {\"Order\": 2572, \"PID\": 535151080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 9723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 332.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2573, \"PID\": 535151130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 303.0, \"TotalBsmtSF\": 1106.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2574, \"PID\": 535152070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 86, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2575, \"PID\": 535152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2576, \"PID\": 535176050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 175.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145250}, {\"Order\": 2577, \"PID\": 535177100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9610, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 2578, \"PID\": 535178100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 281.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 191, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2579, \"PID\": 535179050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 14850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 895.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 122, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2580, \"PID\": 535180020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 914.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 353.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 2581, \"PID\": 535180070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 64.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134450}, {\"Order\": 2582, \"PID\": 535301010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 943.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135960}, {\"Order\": 2583, \"PID\": 535301150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8092, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 156000}, {\"Order\": 2584, \"PID\": 535303050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1367.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2585, \"PID\": 535304020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2586, \"PID\": 535305120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 522.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2587, \"PID\": 535325130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 301.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2588, \"PID\": 535325340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 488.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 517.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2589, \"PID\": 535325350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 912.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2590, \"PID\": 535325450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2591, \"PID\": 535325460, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 21299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 929.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 791.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2592, \"PID\": 535327210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 521.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 75, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 323, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2593, \"PID\": 535353180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 22136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1153.0, \"TotalBsmtSF\": 2171.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1248, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1008.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 631, \"OpenPorchSF\": 48, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2594, \"PID\": 535354130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 900, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2595, \"PID\": 535355100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 865, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2596, \"PID\": 535375040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 713, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 161, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99800}, {\"Order\": 2597, \"PID\": 535376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 418.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2598, \"PID\": 535376100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1073.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108480}, {\"Order\": 2599, \"PID\": 535377070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 715, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 75, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68000}, {\"Order\": 2600, \"PID\": 535377100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 448, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 2601, \"PID\": 535379100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1130, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 229, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2602, \"PID\": 535380010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 821, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155500}, {\"Order\": 2603, \"PID\": 535380130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10818, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 981, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2604, \"PID\": 535381060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 105000}, {\"Order\": 2605, \"PID\": 535382020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 2414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2606, \"PID\": 535382130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1936, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 370, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 436, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2607, \"PID\": 535401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 445.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 2608, \"PID\": 535402070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1047.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159950}, {\"Order\": 2609, \"PID\": 535402100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 379.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1083.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 345, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2610, \"PID\": 535402220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 128, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2611, \"PID\": 535402230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 701.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1135.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1207, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 2612, \"PID\": 535403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 600.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2613, \"PID\": 535403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 8910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 655.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2614, \"PID\": 535403200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 207.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 2615, \"PID\": 535404080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 7100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2616, \"PID\": 535425040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1773, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 2617, \"PID\": 535425050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2618, \"PID\": 535425080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 802.0, \"TotalBsmtSF\": 1438.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1900, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 520, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 2619, \"PID\": 535426195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 16321, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1277.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 258, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2620, \"PID\": 535450100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 597.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 2621, \"PID\": 535450180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 2622, \"PID\": 535451190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 2623, \"PID\": 535451210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2624, \"PID\": 535453160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133700}, {\"Order\": 2625, \"PID\": 535454030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81400}, {\"Order\": 2626, \"PID\": 535454050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 2627, \"PID\": 535454060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2628, \"PID\": 535456010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1556.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1556, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2629, \"PID\": 535456020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 179.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 506.0, \"BsmtUnfSF\": 465.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2630, \"PID\": 535457070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 162, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2631, \"PID\": 535477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2632, \"PID\": 535478010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 10205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2633, \"PID\": 535478070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 809.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 236.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2634, \"PID\": 535478090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2635, \"PID\": 535478110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 953.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 1025.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2636, \"PID\": 902100110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 9856, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 1007, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 167, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2637, \"PID\": 902100130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9906, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 518, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 107000}, {\"Order\": 2638, \"PID\": 902101050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2639, \"PID\": 902103090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 863.0, \"TotalBsmtSF\": 1147.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1147, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2640, \"PID\": 902104020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 476, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2641, \"PID\": 902106040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2642, \"PID\": 902106090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6451, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 208.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 2643, \"PID\": 902108060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 66.0, \"LotArea\": 3960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 502.0, \"TotalBsmtSF\": 502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 502, \"2ndFlrSF\": 502, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2644, \"PID\": 902109010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 813, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 813, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2645, \"PID\": 902110120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7745, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 867, \"LowQualFinSF\": 0, \"GrLivArea\": 1951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 6, \"EnclosedPorch\": 28, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2646, \"PID\": 902110130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7741, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 143.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 2647, \"PID\": 902111010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5633, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 81, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2648, \"PID\": 902125020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1880, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 661, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 293, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 2649, \"PID\": 902128020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2650, \"PID\": 902128100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 648.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 734, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2651, \"PID\": 902134060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 7614, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1905, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 714, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 104, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96900}, {\"Order\": 2652, \"PID\": 902204060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2653, \"PID\": 902204120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 296, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2654, \"PID\": 902206020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2655, \"PID\": 902206090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 297, \"LowQualFinSF\": 0, \"GrLivArea\": 1182, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 378.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2656, \"PID\": 902207080, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 5820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 906.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1163, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126175}, {\"Order\": 2657, \"PID\": 902207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 48.0, \"LotArea\": 5747, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 2658, \"PID\": 902301120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 908, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2659, \"PID\": 902305090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 2, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 679, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2660, \"PID\": 902325050, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 2661, \"PID\": 902325100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2104, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2662, \"PID\": 902325160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 889, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2663, \"PID\": 902328100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 815.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 815, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 330, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2664, \"PID\": 902329070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 684, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114504}, {\"Order\": 2665, \"PID\": 902329090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 998, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 0, \"EnclosedPorch\": 221, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2666, \"PID\": 902400090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 84.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1200.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 125000}, {\"Order\": 2667, \"PID\": 902400110, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 22950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1892, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1107.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 1518, \"LowQualFinSF\": 572, \"GrLivArea\": 3608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 260, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 410, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 475000}, {\"Order\": 2668, \"PID\": 902401090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 5976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 624, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 256, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2669, \"PID\": 902406030, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 4500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2670, \"PID\": 902456015, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 63.0, \"LotArea\": 4761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 2671, \"PID\": 903200050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7446, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 2672, \"PID\": 903202120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 605, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140200}, {\"Order\": 2673, \"PID\": 903206160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1017, \"2ndFlrSF\": 810, \"LowQualFinSF\": 0, \"GrLivArea\": 1827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1943.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 27, \"OpenPorchSF\": 36, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2674, \"PID\": 903225090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2675, \"PID\": 903229040, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 325, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 271, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2676, \"PID\": 903231070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 2677, \"PID\": 903231190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2678, \"PID\": 903231220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 347.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 434, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 258.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 75000}, {\"Order\": 2679, \"PID\": 903231240, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1015, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1015, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 620, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 88000}, {\"Order\": 2680, \"PID\": 903232170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80500}, {\"Order\": 2681, \"PID\": 903233100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1042.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 149000}, {\"Order\": 2682, \"PID\": 903233220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 583, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2683, \"PID\": 903234030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 2684, \"PID\": 903235020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 129, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2685, \"PID\": 903236200, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 993.0, \"TotalBsmtSF\": 993.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2686, \"PID\": 903400030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 11672, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 2687, \"PID\": 903425190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 33120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2688, \"PID\": 903425340, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9873, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 288, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2689, \"PID\": 903430090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 634, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 255.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 394, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2690, \"PID\": 903430130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 153.0, \"LotArea\": 4118, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 693.0, \"TotalBsmtSF\": 693.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 693, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 693, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52500}, {\"Order\": 2691, \"PID\": 903451050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 834, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 2692, \"PID\": 903452090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 665, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 2693, \"PID\": 903454020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 819, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 819, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 72000}, {\"Order\": 2694, \"PID\": 903454080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 198.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2695, \"PID\": 903455090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 803.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 803, \"2ndFlrSF\": 557, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2696, \"PID\": 903456060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1007.0, \"TotalBsmtSF\": 1007.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 2697, \"PID\": 903456090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 234, \"GrLivArea\": 754, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 53, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2698, \"PID\": 903458010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2699, \"PID\": 904100030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 477.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 341, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2700, \"PID\": 904100090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 11136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1921.0, \"TotalBsmtSF\": 1921.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1921, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1921, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2701, \"PID\": 904100170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 225, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2702, \"PID\": 904101040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 6930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 294, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 2703, \"PID\": 904301410, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2704, \"PID\": 904302020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 830.0, \"TotalBsmtSF\": 830.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2705, \"PID\": 904302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 373.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2706, \"PID\": 905100030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 459.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2707, \"PID\": 905101330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 2708, \"PID\": 905101450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154500}, {\"Order\": 2709, \"PID\": 905103130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153600}, {\"Order\": 2710, \"PID\": 905103140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 97.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 328.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 68, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 164500}, {\"Order\": 2711, \"PID\": 905103180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 934, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 934, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 77, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2712, \"PID\": 905105010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1059, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1059, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2713, \"PID\": 905106210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11553, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1159, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 466, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2714, \"PID\": 905107070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 463.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 2715, \"PID\": 905107220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 982.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1458, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2716, \"PID\": 905107240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2717, \"PID\": 905107300, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 794.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 2718, \"PID\": 905108090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9662, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1967.0, \"TotalBsmtSF\": 1967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2719, \"PID\": 905108120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1466.0, \"TotalBsmtSF\": 1949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2720, \"PID\": 905200280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 441.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 2721, \"PID\": 905200290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 682.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2722, \"PID\": 905200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 17920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1085.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 418, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 312, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 2723, \"PID\": 905200380, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2724, \"PID\": 905200490, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1965, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2725, \"PID\": 905201090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 304, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2726, \"PID\": 905202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 826.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 1865.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1830, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 115, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 2727, \"PID\": 905202210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 13050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 850.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2728, \"PID\": 905225080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 15593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 701.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1304, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 667.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2729, \"PID\": 905300010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2730, \"PID\": 905300080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 241, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2731, \"PID\": 905351045, \"MSSubClass\": 150, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 1700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 33.0, \"TotalBsmtSF\": 430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 680, \"LowQualFinSF\": 140, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148400}, {\"Order\": 2732, \"PID\": 905351150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 445.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 190000}, {\"Order\": 2733, \"PID\": 905402110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2734, \"PID\": 905403050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 6488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 799, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 128000}, {\"Order\": 2735, \"PID\": 905426100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 103, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2736, \"PID\": 905426150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 626, \"LowQualFinSF\": 0, \"GrLivArea\": 2201, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 586, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 738, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 274970}, {\"Order\": 2737, \"PID\": 905427010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 19950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2738, \"PID\": 905427030, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 19800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1411.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 1836, \"LowQualFinSF\": 0, \"GrLivArea\": 3672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 684, \"OpenPorchSF\": 80, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2739, \"PID\": 905427140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11679, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1164.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 453, \"OpenPorchSF\": 253, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2740, \"PID\": 905451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 348, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2741, \"PID\": 905451410, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10519, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1057.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2742, \"PID\": 905452140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 325.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136900}, {\"Order\": 2743, \"PID\": 905452150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 532.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 541, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2744, \"PID\": 905475150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 6420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 2745, \"PID\": 905477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 2746, \"PID\": 905480160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 454, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91500}, {\"Order\": 2747, \"PID\": 906202040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 40.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2748, \"PID\": 906204180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1246, \"LowQualFinSF\": 0, \"GrLivArea\": 2559, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 245, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 209000}, {\"Order\": 2749, \"PID\": 906223180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9554, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1911, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2750, \"PID\": 906225180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 261.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1083.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 2751, \"PID\": 906380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 133.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1308.0, \"TotalBsmtSF\": 1308.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 848.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229800}, {\"Order\": 2752, \"PID\": 906380150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 393.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 183600}, {\"Order\": 2753, \"PID\": 906380170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7406, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 515.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 2754, \"PID\": 906380180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193879}, {\"Order\": 2755, \"PID\": 906382030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221500}, {\"Order\": 2756, \"PID\": 906382040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204900}, {\"Order\": 2757, \"PID\": 906382050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 571, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239799}, {\"Order\": 2758, \"PID\": 906392090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13377, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 260.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233555}, {\"Order\": 2759, \"PID\": 906392100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2760, \"PID\": 906392120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1122.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 1570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1590, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294900}, {\"Order\": 2761, \"PID\": 906394010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1809, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 209700}, {\"Order\": 2762, \"PID\": 906394040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1558.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2763, \"PID\": 906394060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 532.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2764, \"PID\": 906420020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 119.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 927, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1915, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 2765, \"PID\": 906426090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 36500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 812.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 198, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2766, \"PID\": 906475050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Metal\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 130, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2767, \"PID\": 906475200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 70761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 1533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1533, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2768, \"PID\": 906476140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 853.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 535.0, \"TotalBsmtSF\": 1388.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1388, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 2769, \"PID\": 907125020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2770, \"PID\": 907125080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2771, \"PID\": 907130110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 795, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 413, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2772, \"PID\": 907131070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 579.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 2773, \"PID\": 907135230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 13568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 274.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2774, \"PID\": 907175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2775, \"PID\": 907175060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2776, \"PID\": 907180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2777, \"PID\": 907181090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9272, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1749, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2778, \"PID\": 907187010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 13426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 57.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 107, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2779, \"PID\": 907192010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2780, \"PID\": 907194130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 2781, \"PID\": 907196020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1541.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 468, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 2782, \"PID\": 907200170, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 428.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2783, \"PID\": 907201160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 62.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 317.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2784, \"PID\": 907201230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2785, \"PID\": 907202140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 971.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 971, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2786, \"PID\": 907203010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 9560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2787, \"PID\": 907203040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 149900}, {\"Order\": 2788, \"PID\": 907227090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2789, \"PID\": 907230240, \"MSSubClass\": 160, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 3612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Landmrk\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2790, \"PID\": 907251100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 1989, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2791, \"PID\": 907252050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 199.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 826.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2792, \"PID\": 907254050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 9468, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2793, \"PID\": 907255010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2794, \"PID\": 907255050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1787, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1787, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2795, \"PID\": 907262080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8726, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 1909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2796, \"PID\": 907265030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 668.0, \"TotalBsmtSF\": 1654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1654, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2797, \"PID\": 907270050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10566, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 1124, \"LowQualFinSF\": 0, \"GrLivArea\": 2214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 646.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268500}, {\"Order\": 2798, \"PID\": 907275030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210900}, {\"Order\": 2799, \"PID\": 907285010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 258.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1070, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 2800, \"PID\": 907285100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 1045, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 2801, \"PID\": 907290020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 989, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274300}, {\"Order\": 2802, \"PID\": 907290080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216837}, {\"Order\": 2803, \"PID\": 907290160, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2804, \"PID\": 907290230, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155900}, {\"Order\": 2805, \"PID\": 907290260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1079.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 685.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233230}, {\"Order\": 2806, \"PID\": 907401050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2807, \"PID\": 907401080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2808, \"PID\": 907405030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2809, \"PID\": 907410040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8581, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203160}, {\"Order\": 2810, \"PID\": 907410100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 827, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195800}, {\"Order\": 2811, \"PID\": 907410110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212900}, {\"Order\": 2812, \"PID\": 907412010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2813, \"PID\": 907414040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198000}, {\"Order\": 2814, \"PID\": 907418020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 750, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173900}, {\"Order\": 2815, \"PID\": 907420070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 163990}, {\"Order\": 2816, \"PID\": 907420090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164990}, {\"Order\": 2817, \"PID\": 908102020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 337.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 420, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 2818, \"PID\": 908102320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 17755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2819, \"PID\": 908102330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2820, \"PID\": 908103310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 7840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 355.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2821, \"PID\": 908103320, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2822, \"PID\": 908127050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 16133, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2823, \"PID\": 908128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2824, \"PID\": 908130020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 475.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 297.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117250}, {\"Order\": 2825, \"PID\": 908178050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1150.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1150, \"LowQualFinSF\": 0, \"GrLivArea\": 2314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2826, \"PID\": 908186060, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2827, \"PID\": 908186070, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 140000}, {\"Order\": 2828, \"PID\": 908186090, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 142500}, {\"Order\": 2829, \"PID\": 908188110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2830, \"PID\": 908188120, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2831, \"PID\": 908188130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2832, \"PID\": 908188140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2833, \"PID\": 908188150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 3363, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 976.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2834, \"PID\": 908225180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6956, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 312, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 265.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97900}, {\"Order\": 2835, \"PID\": 908227010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 846, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 92000}, {\"Order\": 2836, \"PID\": 908227030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1669, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 107000}, {\"Order\": 2837, \"PID\": 908227040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 658.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 658, \"2ndFlrSF\": 526, \"LowQualFinSF\": 0, \"GrLivArea\": 1184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 81000}, {\"Order\": 2838, \"PID\": 908228040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 2839, \"PID\": 908275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 167.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2840, \"PID\": 908275290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 16012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 691.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 609.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2841, \"PID\": 909101050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 207, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2842, \"PID\": 909101080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 450, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 2843, \"PID\": 909101190, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 795.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 795, \"LowQualFinSF\": 481, \"GrLivArea\": 2230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2844, \"PID\": 909101330, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8088, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1922, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 35000}, {\"Order\": 2845, \"PID\": 909103020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 218, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2846, \"PID\": 909131125, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 7082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 980, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2847, \"PID\": 909175030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1192, \"2ndFlrSF\": 403, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2848, \"PID\": 909176180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 128.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 493, \"LowQualFinSF\": 0, \"GrLivArea\": 1551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2849, \"PID\": 909201180, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 58.0, \"LotArea\": 6430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 816, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128000}, {\"Order\": 2850, \"PID\": 909250070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 424.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 743, \"2ndFlrSF\": 736, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 530, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2851, \"PID\": 909250120, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 892, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138887}, {\"Order\": 2852, \"PID\": 909250200, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 4899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 2853, \"PID\": 909250210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 514, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2854, \"PID\": 909253080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9399, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 818, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1919.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2855, \"PID\": 909254070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 901, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200100}, {\"Order\": 2856, \"PID\": 909256010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10164, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2857, \"PID\": 909256020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2858, \"PID\": 909275230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 272, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2859, \"PID\": 909275250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 940, \"2ndFlrSF\": 610, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 429, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2860, \"PID\": 909276010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 725, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2861, \"PID\": 909276070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 113, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2862, \"PID\": 909279040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 67, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2863, \"PID\": 909280030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2864, \"PID\": 909280070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 8170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 526.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 549, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 2865, \"PID\": 909281010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1175, \"LowQualFinSF\": 0, \"GrLivArea\": 2345, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2866, \"PID\": 909282060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 104, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 2867, \"PID\": 909282110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 14210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 697, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 365.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2868, \"PID\": 909425120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 296.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 547.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1811, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 230000}, {\"Order\": 2869, \"PID\": 909425180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 459.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1283.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2870, \"PID\": 909426060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 405.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2871, \"PID\": 909428110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 375.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2872, \"PID\": 909475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 734.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 2873, \"PID\": 910200020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 102000}, {\"Order\": 2874, \"PID\": 910200060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 132, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145400}, {\"Order\": 2875, \"PID\": 910203100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 61.0, \"LotArea\": 8534, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72000}, {\"Order\": 2876, \"PID\": 910203230, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 272.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 2877, \"PID\": 910207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8765, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 327.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 106500}, {\"Order\": 2878, \"PID\": 910226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 327.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2879, \"PID\": 911175360, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 439, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 47, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2880, \"PID\": 911175410, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 69.0, \"LotArea\": 12366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 23, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 51689}, {\"Order\": 2881, \"PID\": 911175430, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 35311}, {\"Order\": 2882, \"PID\": 911175440, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2883, \"PID\": 911225110, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 360, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 2884, \"PID\": 911370430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5748, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1778, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2885, \"PID\": 911370530, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2886, \"PID\": 913350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 23580, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242500}, {\"Order\": 2887, \"PID\": 914452060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1664.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2888, \"PID\": 914474020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9116, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 2889, \"PID\": 914476050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2890, \"PID\": 914476130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 11080, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 257.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2891, \"PID\": 914476500, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1907.0, \"TotalBsmtSF\": 1907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1959, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 766.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 171000}, {\"Order\": 2892, \"PID\": 916225130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 26178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 293.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1210.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 1281, \"LowQualFinSF\": 0, \"GrLivArea\": 2519, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 2893, \"PID\": 916252170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2894, \"PID\": 916325040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 50102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 909.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1650, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 250764}, {\"Order\": 2895, \"PID\": 916326010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 653.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1686.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 574, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2896, \"PID\": 916402125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 13811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2897, \"PID\": 916403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1309.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2898, \"PID\": 916403130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2514, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 693.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2899, \"PID\": 916460070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1136.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 129.0, \"TotalBsmtSF\": 1381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2900, \"PID\": 916475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 630.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 2901, \"PID\": 916477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13618, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2902, \"PID\": 921205030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11443, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2028, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 326, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 369900}, {\"Order\": 2903, \"PID\": 921205050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 382.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 225, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 359900}, {\"Order\": 2904, \"PID\": 923125030, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 125.0, \"LotArea\": 31250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81500}, {\"Order\": 2905, \"PID\": 923202025, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1243.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 45.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2906, \"PID\": 923203090, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 897.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 125, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2907, \"PID\": 923203100, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 443.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 405.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 199, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2908, \"PID\": 923205120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 17217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84500}, {\"Order\": 2909, \"PID\": 923225190, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2910, \"PID\": 923225240, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 173.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 757.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2911, \"PID\": 923225260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 3964, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 837.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 1230, \"LowQualFinSF\": 0, \"GrLivArea\": 2521, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 728, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151400}, {\"Order\": 2912, \"PID\": 923225510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 2913, \"PID\": 923226150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1503.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2914, \"PID\": 923226180, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 2915, \"PID\": 923226290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79400}, {\"Order\": 2916, \"PID\": 923227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2917, \"PID\": 923228130, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 92000}, {\"Order\": 2918, \"PID\": 923228180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 87550}, {\"Order\": 2919, \"PID\": 923228210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 2920, \"PID\": 923228260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90500}, {\"Order\": 2921, \"PID\": 923228310, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1894, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 71000}, {\"Order\": 2922, \"PID\": 923229110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 12640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 396.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150900}, {\"Order\": 2923, \"PID\": 923230040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9297, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 188000}, {\"Order\": 2924, \"PID\": 923250060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2925, \"PID\": 923251180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 20000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 131000}, {\"Order\": 2926, \"PID\": 923275080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 7937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1003.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1003, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1003, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2927, \"PID\": 923276100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 324.0, \"BsmtUnfSF\": 239.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2928, \"PID\": 923400125, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2929, \"PID\": 924100070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1071.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 123.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1389, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2930, \"PID\": 924151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 1004, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "# Configure the options common to all layers\n",
        "brush = alt.selection_interval()\n",
        "base = alt.Chart(train).add_params(brush)\n",
        "\n",
        "# Configure the points\n",
        "points = base.mark_point().encode(\n",
        "    x=alt.X('GrLivArea', title=''),\n",
        "    y=alt.Y('SalePrice', title=''),\n",
        "    color=alt.condition(brush, 'KitchenQual', alt.value('grey'))\n",
        ")\n",
        "\n",
        "# Configure the ticks\n",
        "tick_axis = alt.Axis(labels=False, domain=False, ticks=False)\n",
        "\n",
        "x_ticks = base.mark_tick().encode(\n",
        "    alt.X('GrLivArea', axis=tick_axis),\n",
        "    alt.Y('KitchenQual', title='', axis=tick_axis),\n",
        "    color=alt.condition(brush, 'KitchenQual', alt.value('lightgrey'))\n",
        ")\n",
        "\n",
        "y_ticks = base.mark_tick().encode(\n",
        "    alt.X('KitchenQual', title='', axis=tick_axis),\n",
        "    alt.Y('SalePrice', axis=tick_axis),\n",
        "    color=alt.condition(brush, 'KitchenQual', alt.value('lightgrey'))\n",
        ")\n",
        "\n",
        "# Build the chart\n",
        "(\n",
        "    y_ticks | (points & x_ticks)\n",
        ").configure_axis(\n",
        "    grid=False\n",
        ")"
      ],
      "id": "cell-19"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Multifeature Scatter Plot\n",
        "\n",
        "Let’s create a scatter plot with **multiple feature encodings**.\n",
        "\n",
        "With `.interactive()` you can zoom in. You can also **click on legend**\n",
        "to select specific `KitchenQual` values."
      ],
      "id": "8b776e09-d7a0-4610-86a6-e01f870b3e2b"
    },
    {
      "cell_type": "code",
      "execution_count": 22,
      "metadata": {
        "cell_id": "3f8369493838487684f8f9f83624a869",
        "deepnote_cell_type": "code",
        "deepnote_to_be_reexecuted": true,
        "execution_millis": 1142,
        "execution_start": 1685107006269,
        "papermill": {
          "duration": 0.729867,
          "end_time": "2023-01-11T23:38:34.303645",
          "exception": false,
          "start_time": "2023-01-11T23:38:33.573778",
          "status": "completed"
        },
        "source_hash": "89e5a420",
        "tags": []
      },
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-d3fc6472d57e466b86118898d7c4d002.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-d3fc6472d57e466b86118898d7c4d002.vega-embed details,\n",
              "  #altair-viz-d3fc6472d57e466b86118898d7c4d002.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-d3fc6472d57e466b86118898d7c4d002\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-d3fc6472d57e466b86118898d7c4d002\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-d3fc6472d57e466b86118898d7c4d002\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"axis\": {\"grid\": false}}, \"data\": {\"name\": \"data-bd4440f2bd659840503c9701cdb81363\"}, \"mark\": {\"type\": \"circle\"}, \"encoding\": {\"color\": {\"field\": \"KitchenQual\", \"type\": \"nominal\"}, \"opacity\": {\"condition\": {\"param\": \"param_9\", \"value\": 1}, \"value\": 0.2}, \"size\": {\"bin\": {\"maxbins\": 10}, \"field\": \"SalePrice\", \"title\": \"SalePrice\", \"type\": \"quantitative\"}, \"tooltip\": [{\"field\": \"GrLivArea\", \"type\": \"quantitative\"}, {\"field\": \"SalePrice\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"GrLivArea\", \"scale\": {\"zero\": false}, \"type\": \"quantitative\"}, \"y\": {\"field\": \"GarageArea\", \"scale\": {\"padding\": 1, \"zero\": false}, \"type\": \"quantitative\"}}, \"height\": 500, \"params\": [{\"name\": \"param_9\", \"select\": {\"type\": \"point\", \"fields\": [\"KitchenQual\"]}, \"bind\": \"legend\"}, {\"name\": \"param_10\", \"select\": {\"type\": \"interval\", \"encodings\": [\"x\", \"y\"]}, \"bind\": \"scales\"}], \"width\": 500, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-bd4440f2bd659840503c9701cdb81363\": [{\"Order\": 1, \"PID\": 526301100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 141.0, \"LotArea\": 31770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2, \"PID\": 526350040, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 80.0, \"LotArea\": 11622, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 3, \"PID\": 526351010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 393, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 12500, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 4, \"PID\": 526353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1045.0, \"TotalBsmtSF\": 2110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 5, \"PID\": 527105010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189900}, {\"Order\": 6, \"PID\": 527105030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 7, \"PID\": 527127150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 8, \"PID\": 527145080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 263.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191500}, {\"Order\": 9, \"PID\": 527146030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1180.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 10, \"PID\": 527162130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 776, \"LowQualFinSF\": 0, \"GrLivArea\": 1804, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 11, \"PID\": 527163010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 763, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1655, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 157, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 12, \"PID\": 527165230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1992, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 935.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 233.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 13, \"PID\": 527166040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180400}, {\"Order\": 14, \"PID\": 527180040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 15, \"PID\": 527182190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 1120.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 16, \"PID\": 527216070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 53504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 603.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1690, \"2ndFlrSF\": 1589, \"LowQualFinSF\": 0, \"GrLivArea\": 3279, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 841.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 503, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 538000}, {\"Order\": 17, \"PID\": 527225035, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 152.0, \"LotArea\": 12134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1988, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 427.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 325, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 18, \"PID\": 527258010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 2, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 1856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394432}, {\"Order\": 19, \"PID\": 527276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 19138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 20, \"PID\": 527302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 163.0, \"BsmtUnfSF\": 589.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 21, \"PID\": 527358140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 22, \"PID\": 527358200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 81.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 885.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1173, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 170000}, {\"Order\": 23, \"PID\": 527368020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 814, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 24, \"PID\": 527402200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11241, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 25, \"PID\": 527402250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12537, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 26, \"PID\": 527403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 27, \"PID\": 527404120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 78.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 28, \"PID\": 527425090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 29, \"PID\": 527427230, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 5858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1051.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 30, \"PID\": 527451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 327.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 31, \"PID\": 527451330, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 32, \"PID\": 527451410, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 381.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 88000}, {\"Order\": 33, \"PID\": 527452190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 709.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 34, \"PID\": 527453130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 514.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 35, \"PID\": 527453150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 836.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 36, \"PID\": 527454200, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 37, \"PID\": 528108120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1590.0, \"TotalBsmtSF\": 1590.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1627, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 2334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 376162}, {\"Order\": 38, \"PID\": 528112020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 39, \"PID\": 528120060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1940, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395192}, {\"Order\": 40, \"PID\": 528120090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1544.0, \"TotalBsmtSF\": 1544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290941}, {\"Order\": 41, \"PID\": 528120100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 220000}, {\"Order\": 42, \"PID\": 528120120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 615.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 43, \"PID\": 528138020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1794.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1822, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259000}, {\"Order\": 44, \"PID\": 528138060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1515.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 45, \"PID\": 528150070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12919, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 760.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 2330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 611657}, {\"Order\": 46, \"PID\": 528175010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6371, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224000}, {\"Order\": 47, \"PID\": 528176010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1095.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1473.0, \"TotalBsmtSF\": 2846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 958.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 500000}, {\"Order\": 48, \"PID\": 528176070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 563, \"LowQualFinSF\": 0, \"GrLivArea\": 2250, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 49, \"PID\": 528180070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 412.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1296.0, \"TotalBsmtSF\": 1752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 50, \"PID\": 528181050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 7132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 51, \"PID\": 528188120, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 52, \"PID\": 528218150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 18494, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1324.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 53, \"PID\": 528228285, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 54, \"PID\": 528228440, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 55, \"PID\": 528231020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 58.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 56, \"PID\": 528240070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 1100, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216500}, {\"Order\": 57, \"PID\": 528240130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185088}, {\"Order\": 58, \"PID\": 528250100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 59, \"PID\": 528292020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9505, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 1151, \"LowQualFinSF\": 0, \"GrLivArea\": 2035, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 60, \"PID\": 528328100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 14774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1393.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2599, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 668, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 333168}, {\"Order\": 61, \"PID\": 528344070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 17433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1629.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1645, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 2475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 962.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 23, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 62, \"PID\": 528358010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 919.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 56, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260400}, {\"Order\": 63, \"PID\": 528363130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 1122, \"LowQualFinSF\": 0, \"GrLivArea\": 2622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 64, \"PID\": 528382020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1999, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 348.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1106, \"LowQualFinSF\": 0, \"GrLivArea\": 2270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 671.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 65, \"PID\": 528382030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 66, \"PID\": 528386040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 14720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 579.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1217.0, \"TotalBsmtSF\": 2033.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2053, \"2ndFlrSF\": 1185, \"LowQualFinSF\": 0, \"GrLivArea\": 3238, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 283, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 67, \"PID\": 528445060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8987, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221500}, {\"Order\": 68, \"PID\": 528456160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 92.0, \"LotArea\": 9215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204500}, {\"Order\": 69, \"PID\": 528458070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1547, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215200}, {\"Order\": 70, \"PID\": 528458110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 488.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1566, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 71, \"PID\": 528477080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 12552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 222.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 956, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 72, \"PID\": 528480090, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271500}, {\"Order\": 73, \"PID\": 531367050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 956.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233000}, {\"Order\": 74, \"PID\": 531369060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 75, \"PID\": 531380080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 76, \"PID\": 531451110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 543.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 119.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 77, \"PID\": 531451280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 635, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 78, \"PID\": 531452020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 79, \"PID\": 531452050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 353, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 80, \"PID\": 531452180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1744, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 238, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 81, \"PID\": 531453010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 82, \"PID\": 531453040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 83, \"PID\": 531477050, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67500}, {\"Order\": 84, \"PID\": 532351140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1318, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 85, \"PID\": 532354090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 899.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1155, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1155, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 86, \"PID\": 532376160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 416, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 87, \"PID\": 532377060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 31.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 88, \"PID\": 532377100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 220, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 89, \"PID\": 532378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6897, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 90, \"PID\": 532479070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 15410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 126.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 859.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 169000}, {\"Order\": 91, \"PID\": 533130020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10186, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 92, \"PID\": 533130130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 981.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1231.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2349, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 362500}, {\"Order\": 93, \"PID\": 533130160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1129.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 823, \"LowQualFinSF\": 0, \"GrLivArea\": 2225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 713.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 94, \"PID\": 533205060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 25.0, \"LotArea\": 4835, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 95, \"PID\": 533208090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 39.0, \"LotArea\": 3515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 96, \"PID\": 533210060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3215, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 97, \"PID\": 533212010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 98, \"PID\": 533212020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 99, \"PID\": 533212060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 376.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 100, \"PID\": 533213030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 101, \"PID\": 533221090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 102, \"PID\": 533221110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1159.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 466.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 103, \"PID\": 533223020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 696, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 104, \"PID\": 533223100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 244.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147110}, {\"Order\": 105, \"PID\": 533238045, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 57.0, \"LotArea\": 12853, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 1642.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 224, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267916}, {\"Order\": 106, \"PID\": 533244030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 7379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 107, \"PID\": 533253060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 4420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 108, \"PID\": 533253210, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1052.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 223, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 109, \"PID\": 533352170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13517, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 475.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 110, \"PID\": 534102025, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 659.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 111, \"PID\": 534129040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1323.0, \"TotalBsmtSF\": 1829.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1829, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 535.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218500}, {\"Order\": 112, \"PID\": 534151175, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1137.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243500}, {\"Order\": 113, \"PID\": 534152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 114, \"PID\": 534152070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 687.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 46.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 1891, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 115, \"PID\": 534152100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10421, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 394.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 734, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 66, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 116, \"PID\": 534176060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 982.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 1161.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1381, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1381, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 117, \"PID\": 534176230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 715, \"LowQualFinSF\": 0, \"GrLivArea\": 1645, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 118, \"PID\": 534202160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142250}, {\"Order\": 119, \"PID\": 534251320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 451.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 81.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1328.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 120, \"PID\": 534276360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128950}, {\"Order\": 121, \"PID\": 534401110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1209, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 122, \"PID\": 534401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 9680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1510, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 123, \"PID\": 534403360, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10600, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136300}, {\"Order\": 124, \"PID\": 534403410, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14112, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1014.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 227, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 125, \"PID\": 534425310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 156.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 126, \"PID\": 534427010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 13260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 127, \"PID\": 534430080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 49.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1029.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142125}, {\"Order\": 128, \"PID\": 534431050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 670.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1929, \"2ndFlrSF\": 532, \"LowQualFinSF\": 0, \"GrLivArea\": 2461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197600}, {\"Order\": 129, \"PID\": 534431070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 17360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1019, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 130, \"PID\": 534450180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 131, \"PID\": 534451150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1940, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 263, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76500}, {\"Order\": 132, \"PID\": 534475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 133, \"PID\": 534476260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 132.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 189, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 134, \"PID\": 534479320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 244.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 135, \"PID\": 535101020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 136, \"PID\": 535106190, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 361.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1169, \"LowQualFinSF\": 0, \"GrLivArea\": 2274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154300}, {\"Order\": 137, \"PID\": 535125010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 287.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 912.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1947.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2207, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 301, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 138, \"PID\": 535126040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 137.0, \"LotArea\": 16492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 713.0, \"BsmtUnfSF\": 557.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 139, \"PID\": 535152010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1604.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 140, \"PID\": 535152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 300, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 141, \"PID\": 535152130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 142, \"PID\": 535152150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 143, \"PID\": 535152250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 144, \"PID\": 535153070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1194.0, \"TotalBsmtSF\": 1194.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 145, \"PID\": 535154050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142000}, {\"Order\": 146, \"PID\": 535175070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 324.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 571.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 143, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 147, \"PID\": 535175180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10725, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 91.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1206, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108538}, {\"Order\": 148, \"PID\": 535179020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 149, \"PID\": 535180130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 832, \"2ndFlrSF\": 505, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 263.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 150, \"PID\": 535302080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 339.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 151, \"PID\": 535302200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 119.0, \"LotArea\": 10895, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 152, \"PID\": 535304060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 153, \"PID\": 535304180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 731.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109000}, {\"Order\": 154, \"PID\": 535325400, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 155, \"PID\": 535327140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 156, \"PID\": 535350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 362.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 157, \"PID\": 535350040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 5868, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 158, \"PID\": 535353190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 17503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97500}, {\"Order\": 159, \"PID\": 535377090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 160, \"PID\": 535401080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 72.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 258.0, \"BsmtUnfSF\": 733.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 161, \"PID\": 535425010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 1080, \"LowQualFinSF\": 0, \"GrLivArea\": 2978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 162, \"PID\": 535450210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 481.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 163, \"PID\": 535453070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 906.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 164, \"PID\": 535454070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 475, \"LowQualFinSF\": 0, \"GrLivArea\": 1385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 165, \"PID\": 535456110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 486.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134800}, {\"Order\": 166, \"PID\": 535457010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1116.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 385, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 167, \"PID\": 535457090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 7635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 350.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 168, \"PID\": 535476350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 263.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1395, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 657, \"OpenPorchSF\": 0, \"EnclosedPorch\": 113, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 169, \"PID\": 535477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 170, \"PID\": 902102100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 771.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80400}, {\"Order\": 171, \"PID\": 902104060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 172, \"PID\": 902106130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4485, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 579.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 51, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 173, \"PID\": 902106140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1028, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 130, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 174, \"PID\": 902110090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 5805, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1073.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1347, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 175, \"PID\": 902125080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1605, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107400}, {\"Order\": 176, \"PID\": 902125160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 4608, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 177, \"PID\": 902128170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 294.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 804, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 178, \"PID\": 902206040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 692.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 390, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 179, \"PID\": 902206130, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 827.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 180, \"PID\": 902206220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 606, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 181, \"PID\": 902206240, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 185, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 334, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 182, \"PID\": 902207130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1923, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 780.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 12789}, {\"Order\": 183, \"PID\": 902207140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1928, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105900}, {\"Order\": 184, \"PID\": 902305110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 228, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 185, \"PID\": 902327040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 966, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 186, \"PID\": 902329030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 187, \"PID\": 902401060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 18, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 188, \"PID\": 902402010, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 7407, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 923.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149700}, {\"Order\": 189, \"PID\": 902402130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 622, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 190, \"PID\": 902402250, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1885, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 777.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 191, \"PID\": 902403070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140750}, {\"Order\": 192, \"PID\": 903204040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1030, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 363.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 193, \"PID\": 903206120, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 194, \"PID\": 903225150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 765, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 765, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 195, \"PID\": 903226160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 452.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 12.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 134000}, {\"Order\": 196, \"PID\": 903227020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 197, \"PID\": 903227150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 955, \"2ndFlrSF\": 498, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 148, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 198, \"PID\": 903228150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 221, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 199, \"PID\": 903232190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 548, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 200, \"PID\": 903233120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 928, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138400}, {\"Order\": 201, \"PID\": 903234050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 164.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 202, \"PID\": 903425110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 10300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 11, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 203, \"PID\": 903426180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 888.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 1074, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 364, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 204, \"PID\": 903426200, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 205, \"PID\": 903430080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 3068, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 662, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 206, \"PID\": 903450110, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 110.0, \"LotArea\": 8472, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 207, \"PID\": 903454060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 372, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3500, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 208, \"PID\": 903476030, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 7630, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 209, \"PID\": 904100140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1032.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 1196, \"LowQualFinSF\": 0, \"GrLivArea\": 2403, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 0, \"EnclosedPorch\": 318, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 244400}, {\"Order\": 210, \"PID\": 904101110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 365.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 211, \"PID\": 904300150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 499, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Po\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 212, \"PID\": 904302260, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1026.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 180, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 213, \"PID\": 904350045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 214, \"PID\": 904351040, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 6449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1907, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 73.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93369}, {\"Order\": 215, \"PID\": 904352190, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 6048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114900}, {\"Order\": 216, \"PID\": 905101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 6342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1875, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94000}, {\"Order\": 217, \"PID\": 905101300, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1832, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 218, \"PID\": 905101310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1768.0, \"TotalBsmtSF\": 1768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 219, \"PID\": 905102060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 1039.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 220, \"PID\": 905103060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11341, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1302.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 221, \"PID\": 905104210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8521, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 842.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 222, \"PID\": 905105070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 668.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 223, \"PID\": 905105200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 47.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 474.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 224, \"PID\": 905106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 663, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 379, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 225, \"PID\": 905106170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137250}, {\"Order\": 226, \"PID\": 905107110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7424, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1373, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1373, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160250}, {\"Order\": 227, \"PID\": 905107250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 453.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 228, \"PID\": 905107320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 328.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1386, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 229, \"PID\": 905109130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 954, \"LowQualFinSF\": 0, \"GrLivArea\": 2260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 328000}, {\"Order\": 230, \"PID\": 905109170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1092.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1483, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1483, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 496, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 231, \"PID\": 905201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 756, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 232, \"PID\": 905202090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 233, \"PID\": 905325030, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23595, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 74.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 192, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 234, \"PID\": 905352140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 336, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 235, \"PID\": 905378040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 18600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 684.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 558, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 236, \"PID\": 905426060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 108.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 835, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 237, \"PID\": 905426200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11479, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 387.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 238, \"PID\": 905451320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 44, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 239, \"PID\": 905452110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 362, \"GrLivArea\": 1531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 209.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 240, \"PID\": 905452160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 954.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 1172.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1172, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 241, \"PID\": 905453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1176.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 242, \"PID\": 905453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 17485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1508, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Partial\", \"SalePrice\": 308030}, {\"Order\": 243, \"PID\": 905475510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1250.0, \"TotalBsmtSF\": 1250.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 244, \"PID\": 905478190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 245, \"PID\": 906201030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 977, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1732, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 246, \"PID\": 906201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 11980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 177.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1433.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1433.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 278, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 247, \"PID\": 906204230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 12361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 86.0, \"TotalBsmtSF\": 946.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1017.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 450, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 248, \"PID\": 906223090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 750.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 249, \"PID\": 906225210, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 250, \"PID\": 906378100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245350}, {\"Order\": 251, \"PID\": 906380190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 252, \"PID\": 906385010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 10402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 740.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198900}, {\"Order\": 253, \"PID\": 906385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1222.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1222, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 254, \"PID\": 906402200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12376, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1470.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 1523, \"LowQualFinSF\": 0, \"GrLivArea\": 3222, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 367, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 255, \"PID\": 906425045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 14235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 614, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 256, \"PID\": 906477110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 257, \"PID\": 907125090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 71, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 258, \"PID\": 907180050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 878.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 259, \"PID\": 907185060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 260, \"PID\": 907200280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 15240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 688.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 261, \"PID\": 907200290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161750}, {\"Order\": 262, \"PID\": 907200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 365, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128200}, {\"Order\": 263, \"PID\": 907203070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 264, \"PID\": 907250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 296.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 265, \"PID\": 907252120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 479.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1581.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 266, \"PID\": 907262050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 9548, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 223.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 458.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 613.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 267, \"PID\": 907280040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 331, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 268, \"PID\": 907290040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1649.0, \"TotalBsmtSF\": 1649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 269, \"PID\": 907290170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 270, \"PID\": 907290240, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 271, \"PID\": 907401090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 10635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 972.0, \"BsmtUnfSF\": 315.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 262, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 272, \"PID\": 907410080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 109.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 761.0, \"TotalBsmtSF\": 1473.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 273, \"PID\": 907414030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185500}, {\"Order\": 274, \"PID\": 908102060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 84900}, {\"Order\": 275, \"PID\": 908102110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 155891}, {\"Order\": 276, \"PID\": 908102130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 277, \"PID\": 908102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 278, \"PID\": 908102300, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 792, \"2ndFlrSF\": 328, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 64000}, {\"Order\": 279, \"PID\": 908103350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125200}, {\"Order\": 280, \"PID\": 908152080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 7819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 422.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 281, \"PID\": 908203100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 282, \"PID\": 908208020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 8546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1121.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 283, \"PID\": 908225320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 94.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1487, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 284, \"PID\": 908226130, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 285, \"PID\": 908275300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1526, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 286, \"PID\": 909100080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 4853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 974.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 287, \"PID\": 909100110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 841, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 288, \"PID\": 909101070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 289, \"PID\": 909176140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 242, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 290, \"PID\": 909176150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 166, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 291, \"PID\": 909177100, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 862, \"2ndFlrSF\": 1788, \"LowQualFinSF\": 0, \"GrLivArea\": 2650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 292, \"PID\": 909250030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 293, \"PID\": 909250060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 804.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 2447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 294, \"PID\": 909281080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 371.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 86, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 295, \"PID\": 909426080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 657.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1075, \"LowQualFinSF\": 0, \"GrLivArea\": 2177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 296, \"PID\": 909427230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 877.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 1152, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266500}, {\"Order\": 297, \"PID\": 909428280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 207, \"EnclosedPorch\": 162, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 298, \"PID\": 909452114, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 423.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203135}, {\"Order\": 299, \"PID\": 909455030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 300, \"PID\": 909455040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 76.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1115.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1191, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1191, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 301, \"PID\": 909475140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15602, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1801, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 289000}, {\"Order\": 302, \"PID\": 910202060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 61.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 358, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 303, \"PID\": 910203250, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 540, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 304, \"PID\": 910205120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 727, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 305, \"PID\": 911128180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 68400}, {\"Order\": 306, \"PID\": 911202100, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 859.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 859, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 102776}, {\"Order\": 307, \"PID\": 911204090, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 54, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 55993}, {\"Order\": 308, \"PID\": 911204100, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1896, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1896.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 265, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 50138}, {\"Order\": 309, \"PID\": 911370510, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246000}, {\"Order\": 310, \"PID\": 914467040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 615.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1916, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 741.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 311, \"PID\": 914475090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9620, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1243.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 375, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 80, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 312, \"PID\": 914476520, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 9196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 313, \"PID\": 914478045, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 473.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169900}, {\"Order\": 314, \"PID\": 914478110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1958.0, \"TotalBsmtSF\": 1958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 315, \"PID\": 916125360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 57200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 334.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 50, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 316, \"PID\": 916386010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 78.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1346, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 317, \"PID\": 916386020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1214.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179781}, {\"Order\": 318, \"PID\": 916386060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 319, \"PID\": 916386090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 774.0, \"TotalBsmtSF\": 774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 1194, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 269500}, {\"Order\": 320, \"PID\": 916455170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 1894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214900}, {\"Order\": 321, \"PID\": 916475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202900}, {\"Order\": 322, \"PID\": 921128020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 13214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2002.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2018, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2018, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378500}, {\"Order\": 323, \"PID\": 923201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 42.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 324, \"PID\": 923202105, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10114, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1430.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 325, \"PID\": 923204150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 326, \"PID\": 923205015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1344.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166500}, {\"Order\": 327, \"PID\": 923225300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83500}, {\"Order\": 328, \"PID\": 923225390, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 31.0, \"LotArea\": 2394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 945, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 329, \"PID\": 923225440, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 2592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 129.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 232.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 536, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 330, \"PID\": 923226250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 331, \"PID\": 923226320, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1491, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75500}, {\"Order\": 332, \"PID\": 923228270, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88250}, {\"Order\": 333, \"PID\": 923228370, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 334, \"PID\": 923230190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 469.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 335, \"PID\": 923251080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 26142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 336, \"PID\": 923276030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 207.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 337, \"PID\": 923276250, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1985, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1216.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 338, \"PID\": 923426070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 22, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 339, \"PID\": 924100050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 388.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 615, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 287, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 340, \"PID\": 924151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1341.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 284.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1679.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 64, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 341, \"PID\": 924152030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12961, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 342, \"PID\": 526302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 343, \"PID\": 526351100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 440.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 844.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 344, \"PID\": 526355080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 542.0, \"TotalBsmtSF\": 1952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 2704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 269, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 345, \"PID\": 527105070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 346, \"PID\": 527105130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 1275, \"LowQualFinSF\": 0, \"GrLivArea\": 2283, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 347, \"PID\": 527107130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1628, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 490, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 348, \"PID\": 527108070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 14892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1746, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377500}, {\"Order\": 349, \"PID\": 527110020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 22.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 350, \"PID\": 527127100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 28.0, \"LotArea\": 7296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 243.0, \"TotalBsmtSF\": 2208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2522, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 351, \"PID\": 527131030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 5664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1659, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 352, \"PID\": 527132090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 353, \"PID\": 527146010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 354, \"PID\": 527161040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 355, \"PID\": 527162110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 94, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 291, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 356, \"PID\": 527162120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 357, \"PID\": 527163040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 799.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 799, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 358, \"PID\": 527163070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 359, \"PID\": 527163130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181316}, {\"Order\": 360, \"PID\": 527164020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 7250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 361, \"PID\": 527164060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 362, \"PID\": 527164090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 702, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1481, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 363, \"PID\": 527165130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 364, \"PID\": 527166010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 694.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 1983, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 365, \"PID\": 527180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1424.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 508, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 366, \"PID\": 527182110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 187500}, {\"Order\": 367, \"PID\": 527214050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 17423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 748.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 2216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1166.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 501837}, {\"Order\": 368, \"PID\": 527254020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 464.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2046.0, \"TotalBsmtSF\": 2046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372500}, {\"Order\": 369, \"PID\": 527258020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 16158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 370, \"PID\": 527276160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1934, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 371, \"PID\": 527301320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 692.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 1200, \"LowQualFinSF\": 0, \"GrLivArea\": 2353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 372, \"PID\": 527302175, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 17043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1586, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 373, \"PID\": 527326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 82500}, {\"Order\": 374, \"PID\": 527326150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 375, \"PID\": 527352150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 154000}, {\"Order\": 376, \"PID\": 527353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 363.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 377, \"PID\": 527353060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 229.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1539, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2673, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 378, \"PID\": 527354100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 225.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 379, \"PID\": 527354200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 380, \"PID\": 527355150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1420.0, \"TotalBsmtSF\": 2524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 381, \"PID\": 527356040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157000}, {\"Order\": 382, \"PID\": 527359050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 383, \"PID\": 527359180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 448, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 384, \"PID\": 527364030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1016, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 581.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240900}, {\"Order\": 385, \"PID\": 527365030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 8004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 1103, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 263435}, {\"Order\": 386, \"PID\": 527366030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1058.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 387, \"PID\": 527368010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 225.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 471.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 839, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 388, \"PID\": 527375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1333.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 490, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 389, \"PID\": 527375180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 888.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 390, \"PID\": 527375210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 391, \"PID\": 527376100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 392, \"PID\": 527378140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 333.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 2119, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158000}, {\"Order\": 393, \"PID\": 527401160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 394, \"PID\": 527402220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1002, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 902.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 395, \"PID\": 527403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 439.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 472.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 396, \"PID\": 527404020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1180.0, \"TotalBsmtSF\": 1180.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 397, \"PID\": 527404030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 398, \"PID\": 527405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 726.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 399, \"PID\": 527405160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 239.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 400, \"PID\": 527405180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 401, \"PID\": 527425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97000}, {\"Order\": 402, \"PID\": 527425110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 403, \"PID\": 527450280, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 254.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 404, \"PID\": 527451110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 312.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 405, \"PID\": 527451320, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 406, \"PID\": 527451540, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 79.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 407, \"PID\": 527451640, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 510.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 408, \"PID\": 527451650, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 409, \"PID\": 527452060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 410, \"PID\": 527453050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 411, \"PID\": 527453060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 87, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 412, \"PID\": 527453140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 622.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 413, \"PID\": 527454050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 260, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 414, \"PID\": 527454130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2349, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 389.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 415, \"PID\": 527455050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 416, \"PID\": 527455060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 586, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 417, \"PID\": 527455080, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 279.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 418, \"PID\": 527455090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 345.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 419, \"PID\": 527455240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 420, \"PID\": 527455280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 421, \"PID\": 528102040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1172.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337500}, {\"Order\": 422, \"PID\": 528102140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 726.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1794, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 462000}, {\"Order\": 423, \"PID\": 528104070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 13518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 860.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1926.0, \"TotalBsmtSF\": 1926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 1174, \"LowQualFinSF\": 0, \"GrLivArea\": 3140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 485000}, {\"Order\": 424, \"PID\": 528106020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1767.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 3094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2402, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 555000}, {\"Order\": 425, \"PID\": 528106070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 404, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 426, \"PID\": 528108010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 640.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1566.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 890.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256300}, {\"Order\": 427, \"PID\": 528108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2042.0, \"TotalBsmtSF\": 2042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 253293}, {\"Order\": 428, \"PID\": 528108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1365, \"2ndFlrSF\": 1325, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 197, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 398800}, {\"Order\": 429, \"PID\": 528108070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 154.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 430, \"PID\": 528108130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 2020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 404000}, {\"Order\": 431, \"PID\": 528108140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 2006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 402861}, {\"Order\": 432, \"PID\": 528110010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 13478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1722.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 2296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 842.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 451950}, {\"Order\": 433, \"PID\": 528110020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 2630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2674, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2674, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 610000}, {\"Order\": 434, \"PID\": 528110090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 424.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1734.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 1088, \"LowQualFinSF\": 0, \"GrLivArea\": 2822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1020.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 582933}, {\"Order\": 435, \"PID\": 528112040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1736.0, \"TotalBsmtSF\": 1736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1736, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1736, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 436, \"PID\": 528116010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 99, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 296000}, {\"Order\": 437, \"PID\": 528118060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 23303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 273, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 409900}, {\"Order\": 438, \"PID\": 528120020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1709.0, \"TotalBsmtSF\": 1709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1717, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255500}, {\"Order\": 439, \"PID\": 528120030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1015.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 1739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 927.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 440, \"PID\": 528120160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 262.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274900}, {\"Order\": 441, \"PID\": 528120170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1037.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1531, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 700.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 442, \"PID\": 528138010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 13514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 285.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1142.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 1774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1808, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 443, \"PID\": 528142040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8834, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1170.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1462, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 444, \"PID\": 528142090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 11362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 862.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 185, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 445, \"PID\": 528142130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1124.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 479.0, \"BsmtUnfSF\": 1603.0, \"TotalBsmtSF\": 3206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 446, \"PID\": 528142150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12878, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 418.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 1760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1760, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 190, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 447, \"PID\": 528144020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1502.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233170}, {\"Order\": 448, \"PID\": 528166060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 922.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2336.0, \"TotalBsmtSF\": 2392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 386250}, {\"Order\": 449, \"PID\": 528166090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 724.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1972.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 2452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 886.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 445000}, {\"Order\": 450, \"PID\": 528168030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1295, \"LowQualFinSF\": 0, \"GrLivArea\": 2400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 451, \"PID\": 528172060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1598.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1606, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1606, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 452, \"PID\": 528174050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 6904, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 453, \"PID\": 528174060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 900.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 454, \"PID\": 528174070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 455, \"PID\": 528175050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 456, \"PID\": 528175060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 457, \"PID\": 528176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 730.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2146.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 2492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 949.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 552000}, {\"Order\": 458, \"PID\": 528178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 117.0, \"LotArea\": 15262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 470.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 643.0, \"TotalBsmtSF\": 2200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 685.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 382500}, {\"Order\": 459, \"PID\": 528180120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 308.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1084.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 460, \"PID\": 528180130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 461, \"PID\": 528186010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 1712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 183, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286500}, {\"Order\": 462, \"PID\": 528186180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 863.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 463, \"PID\": 528188020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 464, \"PID\": 528188060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2268, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 465, \"PID\": 528218090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 466, \"PID\": 528220040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 745.0, \"TotalBsmtSF\": 745.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 745, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167800}, {\"Order\": 467, \"PID\": 528221060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 12589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 468, \"PID\": 528221070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 469, \"PID\": 528228290, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1373.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 470, \"PID\": 528228295, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1569, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1569, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 471, \"PID\": 528228435, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1357.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 472, \"PID\": 528228450, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 473, \"PID\": 528228455, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 474, \"PID\": 528228460, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 11.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160200}, {\"Order\": 475, \"PID\": 528235010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 476, \"PID\": 528235090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1010.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1010, \"2ndFlrSF\": 1257, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 477, \"PID\": 528235200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 478, \"PID\": 528240030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 479, \"PID\": 528240060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 779, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184100}, {\"Order\": 480, \"PID\": 528240150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 481, \"PID\": 528250020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 482, \"PID\": 528250040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8174, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 483, \"PID\": 528253010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 484, \"PID\": 528275070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 1276, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 485, \"PID\": 528275160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 1126, \"LowQualFinSF\": 0, \"GrLivArea\": 2004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 486, \"PID\": 528280230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 487, \"PID\": 528290030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9734, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 113.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 488, \"PID\": 528290120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8123, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 489, \"PID\": 528290180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 8433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 683.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1514, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 490, \"PID\": 528290190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 491, \"PID\": 528292030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1177.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2312, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 492, \"PID\": 528292040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 841.0, \"TotalBsmtSF\": 841.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 493, \"PID\": 528292070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 772.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1038, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 494, \"PID\": 528294050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7848, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 495, \"PID\": 528315090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 673.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1163.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337000}, {\"Order\": 496, \"PID\": 528321010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 15138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 689.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 773.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1490, \"2ndFlrSF\": 1304, \"LowQualFinSF\": 0, \"GrLivArea\": 2794, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 403000}, {\"Order\": 497, \"PID\": 528327070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 1455.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1221, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 327000}, {\"Order\": 498, \"PID\": 528344040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 731.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2450, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1069.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 499, \"PID\": 528344100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 975.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 854.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1225.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 1336, \"LowQualFinSF\": 0, \"GrLivArea\": 2612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 336000}, {\"Order\": 500, \"PID\": 528354050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10208, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 921.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1264.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 1067, \"LowQualFinSF\": 0, \"GrLivArea\": 2344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 889.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 501, \"PID\": 528363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 634.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1526.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 2024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 815.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 502, \"PID\": 528365070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 987.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 1274, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 60, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 503, \"PID\": 528385050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 967, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 102, \"EnclosedPorch\": 209, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 504, \"PID\": 528387030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 372.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 623.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263550}, {\"Order\": 505, \"PID\": 528390100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 46589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 528.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 517, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 402000}, {\"Order\": 506, \"PID\": 528390210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 29959, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 507, \"PID\": 528427020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 244600}, {\"Order\": 508, \"PID\": 528431020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1696.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 972.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 509, \"PID\": 528431070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 294.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1614.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1658, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 510, \"PID\": 528435030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1573.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287090}, {\"Order\": 511, \"PID\": 528435050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 512, \"PID\": 528439060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 513, \"PID\": 528441020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 772.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 689.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 514, \"PID\": 528441090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2490, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 226, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 468000}, {\"Order\": 515, \"PID\": 528456180, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 920, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252678}, {\"Order\": 516, \"PID\": 528456220, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 517, \"PID\": 528456240, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7862, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 27.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208300}, {\"Order\": 518, \"PID\": 528458020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 90.0, \"LotArea\": 7993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 519, \"PID\": 528458040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229456}, {\"Order\": 520, \"PID\": 528458060, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1402.0, \"TotalBsmtSF\": 1402.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 205, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229800}, {\"Order\": 521, \"PID\": 528458140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 984.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 522, \"PID\": 528458160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 645.0, \"TotalBsmtSF\": 1766.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 195, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370878}, {\"Order\": 523, \"PID\": 528458180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1348.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1448, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1448, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238500}, {\"Order\": 524, \"PID\": 528477050, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 981, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 310000}, {\"Order\": 525, \"PID\": 528477070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 121.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 526, \"PID\": 528480040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1043.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 527, \"PID\": 528480130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 438, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241000}, {\"Order\": 528, \"PID\": 528480170, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264500}, {\"Order\": 529, \"PID\": 528482040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1662, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1662, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 530, \"PID\": 528482130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 531, \"PID\": 528488100, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1221.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 532, \"PID\": 528490040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 8736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 771.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 360.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1553.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234500}, {\"Order\": 533, \"PID\": 528490070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8127, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 841, \"LowQualFinSF\": 0, \"GrLivArea\": 1653, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 534, \"PID\": 531363010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 178, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 535, \"PID\": 531363030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1087.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 536, \"PID\": 531363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 537, \"PID\": 531369010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 871, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 538, \"PID\": 531369020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 774.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1512.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 845.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 539, \"PID\": 531371050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10083, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 540, \"PID\": 531375040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 541, \"PID\": 531375090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 542, \"PID\": 531375130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 543, \"PID\": 531376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1450, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224243}, {\"Order\": 544, \"PID\": 531379050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 11492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 1209, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 559.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 545, \"PID\": 531382070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10994, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 366.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 257000}, {\"Order\": 546, \"PID\": 531385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1434.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 547, \"PID\": 531450120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 364.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1730, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 548, \"PID\": 531452010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 626, \"2ndFlrSF\": 591, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 549, \"PID\": 531452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1332.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1332, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 550, \"PID\": 531452260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 786, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 551, \"PID\": 531453100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 141.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 465.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 552, \"PID\": 531475220, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 553, \"PID\": 531477020, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 721.0, \"TotalBsmtSF\": 721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 841, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 841, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 554, \"PID\": 531479020, \"MSSubClass\": 45, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 91, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 555, \"PID\": 532353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 884.0, \"BsmtUnfSF\": 28.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 556, \"PID\": 532353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 557, \"PID\": 532354160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 558, \"PID\": 532354230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9079, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 559, \"PID\": 532376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Family\", \"SalePrice\": 124100}, {\"Order\": 560, \"PID\": 532376110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 561, \"PID\": 532377130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131400}, {\"Order\": 562, \"PID\": 532378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 311.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 62383}, {\"Order\": 563, \"PID\": 532378180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 140.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 564, \"PID\": 532478020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15676, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1733.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 92.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 2014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 462, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 255, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 565, \"PID\": 533135020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11949, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1991, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 601.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 216.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 502, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 566, \"PID\": 533206020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 2880, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1376.0, \"TotalBsmtSF\": 1376.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1376, \"2ndFlrSF\": 1629, \"LowQualFinSF\": 0, \"GrLivArea\": 3005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 177, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280750}, {\"Order\": 567, \"PID\": 533210010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164500}, {\"Order\": 568, \"PID\": 533210020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173733}, {\"Order\": 569, \"PID\": 533213010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 3830, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1726.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 254, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 570, \"PID\": 533213020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4217, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 183.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 571, \"PID\": 533213040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 894.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1471, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 572, \"PID\": 533221040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 249.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 573, \"PID\": 533223030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 574, \"PID\": 533236050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1739, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 172500}, {\"Order\": 575, \"PID\": 533252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1252.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 136.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 501, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 225, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318750}, {\"Order\": 576, \"PID\": 533253070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 3782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211500}, {\"Order\": 577, \"PID\": 533254050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15417, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1619.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 20, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241600}, {\"Order\": 578, \"PID\": 533254110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1487, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180500}, {\"Order\": 579, \"PID\": 533352150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1281.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 580, \"PID\": 534125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 727.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 829, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 581, \"PID\": 534127130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 571.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1442.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 371, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 582, \"PID\": 534127170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9156, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185750}, {\"Order\": 583, \"PID\": 534128010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 859.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 32.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 204, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 350, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 584, \"PID\": 534128020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 782, \"LowQualFinSF\": 0, \"GrLivArea\": 2067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 585, \"PID\": 534128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 735, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 586, \"PID\": 534128190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1369, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256900}, {\"Order\": 587, \"PID\": 534129080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1724, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 588, \"PID\": 534129370, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 589, \"PID\": 534129380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 955.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113000}, {\"Order\": 590, \"PID\": 534151120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 283.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 2288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 591, \"PID\": 534152120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 592, \"PID\": 534175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1127.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 78, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213250}, {\"Order\": 593, \"PID\": 534177230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 594, \"PID\": 534200030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 595, \"PID\": 534202170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 596, \"PID\": 534226120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 466.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 597, \"PID\": 534250400, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 168500}, {\"Order\": 598, \"PID\": 534251030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 509.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 599, \"PID\": 534252240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 251.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 630.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 197, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 600, \"PID\": 534275060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 360, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 601, \"PID\": 534275100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 602, \"PID\": 534276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 603, \"PID\": 534277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 604, \"PID\": 534278070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 201.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177625}, {\"Order\": 605, \"PID\": 534278230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 606, \"PID\": 534400050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 345.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 1516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 152, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 607, \"PID\": 534400290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 217.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 512.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1313, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 121, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 608, \"PID\": 534402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1292.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1292, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145100}, {\"Order\": 609, \"PID\": 534402140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 230.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1154.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 610, \"PID\": 534402170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 549.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 611, \"PID\": 534403370, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 563.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 612, \"PID\": 534426110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 991.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 50.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 613, \"PID\": 534429150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 614, \"PID\": 534431130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 100.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 613.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 615, \"PID\": 534450150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 616, \"PID\": 534451110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 185.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 224, \"LowQualFinSF\": 0, \"GrLivArea\": 1203, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 617, \"PID\": 534475185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 1505.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1505, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 162, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 618, \"PID\": 534475250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 260, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 619, \"PID\": 534476150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 1416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 620, \"PID\": 534476320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 621, \"PID\": 534477110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 556, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 622, \"PID\": 534478230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 607.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 623, \"PID\": 535101120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 624, \"PID\": 535104120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10573, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 3.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 625, \"PID\": 535105100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 247.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1394.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1394, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 185, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 626, \"PID\": 535125070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 1562.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 342, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 627, \"PID\": 535125090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 314.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1186, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 628, \"PID\": 535126010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 576.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 2142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 252, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 629, \"PID\": 535126100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1392.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 630, \"PID\": 535150070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1281, \"2ndFlrSF\": 457, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 631, \"PID\": 535151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 313.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 632, \"PID\": 535152230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 661.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 633, \"PID\": 535154060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 203, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 634, \"PID\": 535154130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 635, \"PID\": 535175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 620.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 636, \"PID\": 535175050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1215.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 234, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 637, \"PID\": 535178040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 565.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1202, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1202, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 638, \"PID\": 535178120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 172.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 727.0, \"TotalBsmtSF\": 1382.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 639, \"PID\": 535179160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 155.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 750.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144000}, {\"Order\": 640, \"PID\": 535300120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 19296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 399.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 690.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 641, \"PID\": 535301170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 1297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1297, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1297, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 642, \"PID\": 535302120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 657.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1866.0, \"TotalBsmtSF\": 1866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 643, \"PID\": 535303110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 8128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 644, \"PID\": 535303150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10634, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1319, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1319, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 645, \"PID\": 535304100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 631.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 646, \"PID\": 535325290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1005.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 647, \"PID\": 535351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 178.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 648, \"PID\": 535352090, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 793, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 649, \"PID\": 535353040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1952, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1031.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1031, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 650, \"PID\": 535353060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102900}, {\"Order\": 651, \"PID\": 535353140, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1699, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 95000}, {\"Order\": 652, \"PID\": 535353240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 699.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 801, \"2ndFlrSF\": 726, \"LowQualFinSF\": 0, \"GrLivArea\": 1527, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 653, \"PID\": 535354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 654, \"PID\": 535354100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 655, \"PID\": 535375010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 656, \"PID\": 535375050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 704, \"LowQualFinSF\": 144, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 140, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 657, \"PID\": 535376060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 658, \"PID\": 535377150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 717, \"2ndFlrSF\": 322, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 111, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 659, \"PID\": 535378020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 9022, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1924, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 660, \"PID\": 535378120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10230, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 661, \"PID\": 535381040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 1064, \"GrLivArea\": 2377, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 432, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142900}, {\"Order\": 662, \"PID\": 535382100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 760, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 663, \"PID\": 535383060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 599, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 599, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 59000}, {\"Order\": 664, \"PID\": 535383070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 198, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 665, \"PID\": 535383110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 666, \"PID\": 535383120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 725, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78500}, {\"Order\": 667, \"PID\": 535402010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1248.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 907.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 668, \"PID\": 535402090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 996.0, \"TotalBsmtSF\": 1380.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1380, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 669, \"PID\": 535402270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 670, \"PID\": 535402330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2634, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 671, \"PID\": 535403190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1958, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 672, \"PID\": 535403210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 559.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1105, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 673, \"PID\": 535403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 674, \"PID\": 535425070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1270.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 675, \"PID\": 535426150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 676, \"PID\": 535450070, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 232, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 677, \"PID\": 535450160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 92900}, {\"Order\": 678, \"PID\": 535450200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 231, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 679, \"PID\": 535451170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 680, \"PID\": 535451250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 352.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 681, \"PID\": 535452090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1041.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 682, \"PID\": 535452100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 683, \"PID\": 535452140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 102.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 732, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118900}, {\"Order\": 684, \"PID\": 535453100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 433.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 95.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1183, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 685, \"PID\": 535453200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 686, \"PID\": 535454100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 832, \"2ndFlrSF\": 629, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 687, \"PID\": 535454160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 431, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 688, \"PID\": 535475010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 7570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1806, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144750}, {\"Order\": 689, \"PID\": 535476110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 124.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 690, \"PID\": 535476240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 7936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 826.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 691, \"PID\": 535477150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 692, \"PID\": 902101010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3950, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 693, \"PID\": 902102080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 682, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 694, \"PID\": 902103100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 4080, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 695, \"PID\": 902103120, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 972, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 696, \"PID\": 902103170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 5720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 455, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 66500}, {\"Order\": 697, \"PID\": 902105050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 496, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 698, \"PID\": 902105060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 699, \"PID\": 902106010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6406, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 269.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 868, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 700, \"PID\": 902106060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1892, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 994, \"LowQualFinSF\": 0, \"GrLivArea\": 2372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 287, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 701, \"PID\": 902109130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94550}, {\"Order\": 702, \"PID\": 902109140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7596, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1000, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 703, \"PID\": 902110080, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3378, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1946, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 651.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 682, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 704, \"PID\": 902134120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 801, \"2ndFlrSF\": 646, \"LowQualFinSF\": 0, \"GrLivArea\": 1447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 705, \"PID\": 902135020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 706, \"PID\": 902201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 707, \"PID\": 902202150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 811.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 811, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 708, \"PID\": 902204080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 709, \"PID\": 902205010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 25, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 45000}, {\"Order\": 710, \"PID\": 902205030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 37900}, {\"Order\": 711, \"PID\": 902206260, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1938, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 886, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91300}, {\"Order\": 712, \"PID\": 902207170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 713, \"PID\": 902300090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 4456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 113000}, {\"Order\": 714, \"PID\": 902301060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 677.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 715, \"PID\": 902301080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 716, \"PID\": 902325070, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1898, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 849.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 1063, \"LowQualFinSF\": 0, \"GrLivArea\": 2138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 717, \"PID\": 902326030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 181, \"OpenPorchSF\": 0, \"EnclosedPorch\": 386, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265979}, {\"Order\": 718, \"PID\": 902327070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 917.0, \"TotalBsmtSF\": 917.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 719, \"PID\": 902329080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1917, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 720, \"PID\": 902330040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 121.0, \"LotArea\": 17671, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1882, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 826, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 424.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 721, \"PID\": 902331010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 3300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 722, \"PID\": 902401130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1920, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 26.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 723, \"PID\": 902402150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 226, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 724, \"PID\": 902405100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 98.0, \"LotArea\": 8820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 561, \"LowQualFinSF\": 120, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 725, \"PID\": 902405120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 436, \"GrLivArea\": 1480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 207.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 119000}, {\"Order\": 726, \"PID\": 902406070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 238, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 727, \"PID\": 902477120, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 523, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 34900}, {\"Order\": 728, \"PID\": 902477130, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 72.0, \"LotArea\": 9392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 245.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 44000}, {\"Order\": 729, \"PID\": 903200080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 144.0, \"LotArea\": 21384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 15.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 730, \"PID\": 903201020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1022.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 731, \"PID\": 903201080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 732, \"PID\": 903202170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 244, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 733, \"PID\": 903205040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 192.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 40, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 734, \"PID\": 903226130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 735, \"PID\": 903226170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 390, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 736, \"PID\": 903227070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 737, \"PID\": 903227090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 825, \"2ndFlrSF\": 587, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 45, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 738, \"PID\": 903228070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 444.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 320, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 739, \"PID\": 903228120, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 740, \"PID\": 903230100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 741, \"PID\": 903231010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 927.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 742, \"PID\": 903231030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 989, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 54, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 743, \"PID\": 903231060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 744, \"PID\": 903231130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1931, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 745, \"PID\": 903232060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 995, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 15, \"EnclosedPorch\": 51, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 746, \"PID\": 903234220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 679.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 994, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 189, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 150, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 747, \"PID\": 903236040, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 134.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 1072.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 5.0, \"GarageArea\": 1184.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 748, \"PID\": 903400220, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11888, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 2134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 268, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214500}, {\"Order\": 749, \"PID\": 903425245, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 883, \"LowQualFinSF\": 0, \"GrLivArea\": 2019, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 509, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 750, \"PID\": 903427120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 751, \"PID\": 903429080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 2500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 752, \"PID\": 903429110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 753, \"PID\": 903430060, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 92.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 929, \"LowQualFinSF\": 371, \"GrLivArea\": 2229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 198, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 104000}, {\"Order\": 754, \"PID\": 903430070, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Sev\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 62500}, {\"Order\": 755, \"PID\": 903451090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 316.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 213, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 756, \"PID\": 903458170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 757, \"PID\": 903475100, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 758, \"PID\": 903476090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1902, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 169.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 978, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 759, \"PID\": 903481120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 760, \"PID\": 903481130, \"MSSubClass\": 85, \"MSZoning\": \"RM\", \"LotFrontage\": 86.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 749.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 63.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 70000}, {\"Order\": 761, \"PID\": 903484110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 262.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 754, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 288, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 762, \"PID\": 904100190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1946, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 704, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88750}, {\"Order\": 763, \"PID\": 904301060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 764, \"PID\": 904301070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 765, \"PID\": 904301100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 766, \"PID\": 904301375, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61000}, {\"Order\": 767, \"PID\": 904351200, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 54.0, \"LotArea\": 6629, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 551.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103600}, {\"Order\": 768, \"PID\": 904351240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 687, \"2ndFlrSF\": 425, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 226.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63000}, {\"Order\": 769, \"PID\": 905101260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12886, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 770, \"PID\": 905101490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 771, \"PID\": 905103040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 92.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 500.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1683, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 772, \"PID\": 905103070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 215, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113500}, {\"Order\": 773, \"PID\": 905105190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 774, \"PID\": 905107310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 775, \"PID\": 905108190, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7252, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 776, \"PID\": 905108220, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 860, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 777, \"PID\": 905200220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 170.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 778, \"PID\": 905200260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 611, \"LowQualFinSF\": 259, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 779, \"PID\": 905200350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15312, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 780, \"PID\": 905225090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 366.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2071, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2071, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 781, \"PID\": 905228050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63900}, {\"Order\": 782, \"PID\": 905229040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1104.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 783, \"PID\": 905325020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 25095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1473, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1473, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 60, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 143000}, {\"Order\": 784, \"PID\": 905377010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 284.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 785, \"PID\": 905377130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 786, \"PID\": 905401100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10708, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 768.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1867, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1867, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 476, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 787, \"PID\": 905402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139600}, {\"Order\": 788, \"PID\": 905402070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 789, \"PID\": 905450020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 790, \"PID\": 905451300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 340.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 791, \"PID\": 905451340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1276, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 60000}, {\"Order\": 792, \"PID\": 905452040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 747, \"LowQualFinSF\": 0, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154400}, {\"Order\": 793, \"PID\": 905452050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 344.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 794, \"PID\": 905475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1089.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1089, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 795, \"PID\": 905475500, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 290.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84000}, {\"Order\": 796, \"PID\": 905476230, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 393.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1049, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 266.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 797, \"PID\": 905478030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11409, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 798, \"PID\": 905480030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 799, \"PID\": 905480210, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 800, \"PID\": 906201021, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 286.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 801, \"PID\": 906201050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 19255, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 450.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 802, \"PID\": 906201130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1983, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 2132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316600}, {\"Order\": 803, \"PID\": 906203120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 177.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 2158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271900}, {\"Order\": 804, \"PID\": 906223060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 137.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 227.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 769, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 425.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 234, \"OpenPorchSF\": 72, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 805, \"PID\": 906223080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1879, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 100, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 806, \"PID\": 906223210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 807, \"PID\": 906226060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 26400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 2016, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 808, \"PID\": 906226070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118964}, {\"Order\": 809, \"PID\": 906226080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1086.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 153337}, {\"Order\": 810, \"PID\": 906226090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 1114, \"LowQualFinSF\": 0, \"GrLivArea\": 2228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 73, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 147983}, {\"Order\": 811, \"PID\": 906226100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 812, \"PID\": 906226110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 813, \"PID\": 906226120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 1120, \"LowQualFinSF\": 0, \"GrLivArea\": 2240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 142953}, {\"Order\": 814, \"PID\": 906226130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1094.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 148325}, {\"Order\": 815, \"PID\": 906226140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 113722}, {\"Order\": 816, \"PID\": 906230010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 817, \"PID\": 906230020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7939, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 818, \"PID\": 906230030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 819, \"PID\": 906340100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10933, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1021.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1555.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1138.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 323262}, {\"Order\": 820, \"PID\": 906340110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 417.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 297000}, {\"Order\": 821, \"PID\": 906340120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1622.0, \"TotalBsmtSF\": 1622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 860.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295493}, {\"Order\": 822, \"PID\": 906340130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 364.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 332000}, {\"Order\": 823, \"PID\": 906378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 904.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 824, \"PID\": 906380050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 825, \"PID\": 906380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11422, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1359.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 222, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272500}, {\"Order\": 826, \"PID\": 906380100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 827, \"PID\": 906380130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 828, \"PID\": 906380210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1282.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 829, \"PID\": 906380220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 10324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 382.0, \"TotalBsmtSF\": 1254.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221800}, {\"Order\": 830, \"PID\": 906392070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 82.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 831, \"PID\": 906392110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1474.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 832, \"PID\": 906392130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 704, \"2ndFlrSF\": 718, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 833, \"PID\": 906402060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 396, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 834, \"PID\": 906426210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 1449.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 815, \"LowQualFinSF\": 0, \"GrLivArea\": 1759, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 193, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233500}, {\"Order\": 835, \"PID\": 906475070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 28698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 764.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 966, \"LowQualFinSF\": 0, \"GrLivArea\": 2126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 836, \"PID\": 907126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 837, \"PID\": 907126050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9757, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 838, \"PID\": 907130100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 15426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 836, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 839, \"PID\": 907131090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 834, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 840, \"PID\": 907131190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14753, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 950.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1463, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1463, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 841, \"PID\": 907135040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 10859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1097.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 392, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 842, \"PID\": 907135170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 746.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 843, \"PID\": 907175100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 866.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 913, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 844, \"PID\": 907180130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1490.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 845, \"PID\": 907181100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9017, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 871.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 846, \"PID\": 907185050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 847, \"PID\": 907192030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8935, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 848, \"PID\": 907192090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 9808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1573, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 849, \"PID\": 907194010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1840, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 850, \"PID\": 907194110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 16285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1413.0, \"TotalBsmtSF\": 1413.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187100}, {\"Order\": 851, \"PID\": 907194160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10739, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 852, \"PID\": 907196060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11166, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 201000}, {\"Order\": 853, \"PID\": 907200230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 854, \"PID\": 907201220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16269, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 855, \"PID\": 907201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 6950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 710.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 856, \"PID\": 907202050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150500}, {\"Order\": 857, \"PID\": 907202080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 858, \"PID\": 907202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1072.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 859, \"PID\": 907227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 15523, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 860, \"PID\": 907227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 215, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 861, \"PID\": 907227110, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 862, \"PID\": 907227290, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8445, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 863, \"PID\": 907250070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 335.0, \"TotalBsmtSF\": 1569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 864, \"PID\": 907252060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1068.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254750}, {\"Order\": 865, \"PID\": 907252210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 866, \"PID\": 907252220, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 990.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 309.0, \"TotalBsmtSF\": 1299.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 573, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 261500}, {\"Order\": 867, \"PID\": 907253130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 2153, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 313000}, {\"Order\": 868, \"PID\": 907260030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 869, \"PID\": 907265010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 944.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 926, \"LowQualFinSF\": 0, \"GrLivArea\": 1870, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 870, \"PID\": 907275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 871, \"PID\": 907275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 814.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 872, \"PID\": 907275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 873, \"PID\": 907280170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1111.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1417, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1417, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 117, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 874, \"PID\": 907285020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 573.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 977, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 576, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 875, \"PID\": 907285050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 876, \"PID\": 907290070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1212.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 877, \"PID\": 907290090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1630.0, \"TotalBsmtSF\": 1630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 878, \"PID\": 907290180, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 879, \"PID\": 907290210, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 880, \"PID\": 907410130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1478.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 293200}, {\"Order\": 881, \"PID\": 907412020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 882, \"PID\": 907414020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1480.0, \"TotalBsmtSF\": 1500.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 883, \"PID\": 907414080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 193.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 884, \"PID\": 907420040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 885, \"PID\": 908102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 886, \"PID\": 908102270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1486.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 887, \"PID\": 908102290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 888, \"PID\": 908128060, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 495, \"2ndFlrSF\": 1427, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 177, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 889, \"PID\": 908151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 155.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 890, \"PID\": 908152035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 615.0, \"TotalBsmtSF\": 1014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 891, \"PID\": 908152100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 255.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 631.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 892, \"PID\": 908154040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 13286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 464.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 327, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 893, \"PID\": 908186080, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 894, \"PID\": 908201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1947, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 895, \"PID\": 908203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 332.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 243.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 896, \"PID\": 908225290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 900, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 897, \"PID\": 908225370, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 441, \"LowQualFinSF\": 0, \"GrLivArea\": 1529, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 898, \"PID\": 908229020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 899, \"PID\": 908250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 900, \"PID\": 908275040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1678.0, \"TotalBsmtSF\": 1678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1678, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1678, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 901, \"PID\": 908275110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 902, \"PID\": 908276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 903, \"PID\": 909101010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12354, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 800, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 904, \"PID\": 909101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 444, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 905, \"PID\": 909101140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10998, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 420.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 906, \"PID\": 909129090, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 907, \"PID\": 909129100, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1932, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 159434}, {\"Order\": 908, \"PID\": 909175080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 438, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 438, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 909, \"PID\": 909178160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 545, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 910, \"PID\": 909179020, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 15863, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 3, \"YearBuilt\": 1920, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 998, \"LowQualFinSF\": 397, \"GrLivArea\": 3082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 911, \"PID\": 909250080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 583.0, \"TotalBsmtSF\": 583.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 647, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 329, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 912, \"PID\": 909250220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 913, \"PID\": 909251050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 914, \"PID\": 909251170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137450}, {\"Order\": 915, \"PID\": 909252020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1936, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 575, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1135, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 916, \"PID\": 909253010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7558, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1913, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 917, \"PID\": 909253180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 877, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1477, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 918, \"PID\": 909254010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 919, \"PID\": 909257050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 10918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 920, \"PID\": 909275080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 921, \"PID\": 909276110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 753, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 213.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 922, \"PID\": 909276200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 332, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 923, \"PID\": 909277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1273, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 307.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 924, \"PID\": 909277100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13360, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 713.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 44, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 925, \"PID\": 909278020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7681, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 731.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 523, \"LowQualFinSF\": 0, \"GrLivArea\": 1343, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 186.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154900}, {\"Order\": 926, \"PID\": 909279010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 674.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 13, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 57, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 927, \"PID\": 909282130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 154.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 694.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144800}, {\"Order\": 928, \"PID\": 909425060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 929, \"PID\": 909425130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 65.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 875.0, \"BsmtUnfSF\": 621.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 930, \"PID\": 909426090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 507.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 295.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 931, \"PID\": 909427200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 158500}, {\"Order\": 932, \"PID\": 909428240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 91.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1906, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1906, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 201, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 933, \"PID\": 909451040, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 279, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 934, \"PID\": 909451100, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 935, \"PID\": 909451140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 561.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 936, \"PID\": 909451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 937, \"PID\": 909452050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13607, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 118.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208000}, {\"Order\": 938, \"PID\": 909475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17597, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1971, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 419.0, \"BsmtUnfSF\": 581.0, \"TotalBsmtSF\": 1803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2365, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 939, \"PID\": 909475300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1988, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 808.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 182, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 940, \"PID\": 910202070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 10690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 941, \"PID\": 910204050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 760.0, \"TotalBsmtSF\": 760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 928, \"LowQualFinSF\": 312, \"GrLivArea\": 2168, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 160, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 942, \"PID\": 910205020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 596, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 189.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 943, \"PID\": 911103050, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 105.0, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1915, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1013.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 513, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85000}, {\"Order\": 944, \"PID\": 911104060, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 72, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 945, \"PID\": 911370500, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230000}, {\"Order\": 946, \"PID\": 912251110, \"MSSubClass\": 30, \"MSZoning\": \"I (all)\", \"LotFrontage\": 109.0, \"LotArea\": 21780, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 119, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 57625}, {\"Order\": 947, \"PID\": 914465020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 250.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 948, \"PID\": 914465040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 2149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 239686}, {\"Order\": 949, \"PID\": 914465055, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1710.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 950, \"PID\": 914474070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 12209, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 1157, \"LowQualFinSF\": 0, \"GrLivArea\": 1961, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 951, \"PID\": 914475010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 926, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156450}, {\"Order\": 952, \"PID\": 914475030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 953, \"PID\": 914476020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 954, \"PID\": 914476380, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9947, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 955, \"PID\": 914476430, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 55.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1527.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 152000}, {\"Order\": 956, \"PID\": 916176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSeWa\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 541.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 118, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 233, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 957, \"PID\": 916176125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 215245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 820.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 958, \"PID\": 916380070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1022.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315500}, {\"Order\": 959, \"PID\": 916382010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224500}, {\"Order\": 960, \"PID\": 916382100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 13438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 2190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 780.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 961, \"PID\": 916382110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 406.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1115.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316500}, {\"Order\": 962, \"PID\": 916386140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 963, \"PID\": 916403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 387.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1412, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 964, \"PID\": 916403200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2237, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 965, \"PID\": 916403250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 14419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 624.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 1645.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 966, \"PID\": 916455070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 967, \"PID\": 916460110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 968, \"PID\": 916475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14601, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 584.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 578.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 969, \"PID\": 921128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1640.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 308, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 425000}, {\"Order\": 970, \"PID\": 923201100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 971, \"PID\": 923202060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1771, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 972, \"PID\": 923203110, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 247, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 973, \"PID\": 923203190, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 883.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 974, \"PID\": 923225360, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 975, \"PID\": 923225490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 9858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 33, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 976, \"PID\": 923226270, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 515.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 977, \"PID\": 923227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13383, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1404, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 978, \"PID\": 923228110, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 979, \"PID\": 923228150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 980, \"PID\": 923228230, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 981, \"PID\": 923230200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7689, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 76.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131900}, {\"Order\": 982, \"PID\": 923252075, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7706, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131250}, {\"Order\": 983, \"PID\": 923275040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1097.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 602.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 303, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 984, \"PID\": 923275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 985, \"PID\": 923276260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 718.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 883, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 883, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 698.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 986, \"PID\": 923400025, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 566, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 320, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 987, \"PID\": 923400110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10429, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 988, \"PID\": 924100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1567.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 989, \"PID\": 924100060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 496.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 368, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 990, \"PID\": 526351030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 411.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 601.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 190, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 991, \"PID\": 526353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1205.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237500}, {\"Order\": 992, \"PID\": 526354070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 2112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206900}, {\"Order\": 993, \"PID\": 527105050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 994, \"PID\": 527106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 995, \"PID\": 527106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 996, \"PID\": 527106150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 997, \"PID\": 527107010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 998, \"PID\": 527107090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 898.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177900}, {\"Order\": 999, \"PID\": 527107210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 21872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1446, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 406.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1000, \"PID\": 527127140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1593.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1593, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 1001, \"PID\": 527131110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 6264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247900}, {\"Order\": 1002, \"PID\": 527140090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1003, \"PID\": 527145090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1280.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1004, \"PID\": 527161010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 926.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1005, \"PID\": 527162180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 183000}, {\"Order\": 1006, \"PID\": 527163100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1007, \"PID\": 527164120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1895, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 1008, \"PID\": 527165010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1009, \"PID\": 527183030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1010, \"PID\": 527183060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 5950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1011, \"PID\": 527208010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 13543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 1012, \"PID\": 527212050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1122.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 1370, \"LowQualFinSF\": 0, \"GrLivArea\": 2504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1013, \"PID\": 527214030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 15401, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 547.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 387000}, {\"Order\": 1014, \"PID\": 527226020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 31220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 2, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1474, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 750, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1015, \"PID\": 527252080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1034.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 557.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 1016, \"PID\": 527276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 47280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1488.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 133000}, {\"Order\": 1017, \"PID\": 527301170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 20544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 791.0, \"TotalBsmtSF\": 791.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 2093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1018, \"PID\": 527301245, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 983.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 1675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1688, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 141, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1019, \"PID\": 527302050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 228.0, \"BsmtUnfSF\": 606.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1020, \"PID\": 527302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1021, \"PID\": 527302185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 18559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 186.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 2048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1022, \"PID\": 527302210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 449.0, \"BsmtUnfSF\": 469.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 1023, \"PID\": 527325070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 424.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 896.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 550, \"OpenPorchSF\": 282, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 1024, \"PID\": 527325240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 48.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 1211.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 174, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1025, \"PID\": 527326130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1026, \"PID\": 527354160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 2044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1027, \"PID\": 527357110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9743, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146900}, {\"Order\": 1028, \"PID\": 527357180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12511, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1420, \"2ndFlrSF\": 1420, \"LowQualFinSF\": 0, \"GrLivArea\": 2840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1314.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 208, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 292500}, {\"Order\": 1029, \"PID\": 527358120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 11361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1193.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1523, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1030, \"PID\": 527359030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1444.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1031, \"PID\": 527359070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1032, \"PID\": 527378020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1033, \"PID\": 527380240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1236.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 787.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 180, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 1034, \"PID\": 527401130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1035, \"PID\": 527402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 438.0, \"BsmtUnfSF\": 14.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 80, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1036, \"PID\": 527402130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 16, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111900}, {\"Order\": 1037, \"PID\": 527403360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 613.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1038, \"PID\": 527425035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111250}, {\"Order\": 1039, \"PID\": 527427110, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1040, \"PID\": 527450110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103400}, {\"Order\": 1041, \"PID\": 527450250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1042, \"PID\": 527450520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 411, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100500}, {\"Order\": 1043, \"PID\": 527451060, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 127.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1044, \"PID\": 527451290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85400}, {\"Order\": 1045, \"PID\": 527451400, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 604.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1046, \"PID\": 527451550, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111750}, {\"Order\": 1047, \"PID\": 527452150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 559.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1048, \"PID\": 527453160, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 286.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 275.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1049, \"PID\": 527454120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 1050, \"PID\": 527455270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1051, \"PID\": 528102030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12444, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 426.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 304, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394617}, {\"Order\": 1052, \"PID\": 528102110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 590, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 426000}, {\"Order\": 1053, \"PID\": 528104050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 816.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 442.0, \"TotalBsmtSF\": 2078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2084, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 385000}, {\"Order\": 1054, \"PID\": 528104080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 14948, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 1237, \"LowQualFinSF\": 0, \"GrLivArea\": 2713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 858.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 446261}, {\"Order\": 1055, \"PID\": 528108150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 317500}, {\"Order\": 1056, \"PID\": 528110080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 436.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372402}, {\"Order\": 1057, \"PID\": 528110110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1728.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 2418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 358, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 417500}, {\"Order\": 1058, \"PID\": 528114040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 14418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 1950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 383000}, {\"Order\": 1059, \"PID\": 528118030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 2748, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 390000}, {\"Order\": 1060, \"PID\": 528118090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12539, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 468.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 1158, \"LowQualFinSF\": 0, \"GrLivArea\": 2790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1150.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 460000}, {\"Order\": 1061, \"PID\": 528120130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12151, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2331, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1003.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 379000}, {\"Order\": 1062, \"PID\": 528142020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 908.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1063, \"PID\": 528142140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1162, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316000}, {\"Order\": 1064, \"PID\": 528164060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 680.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 2535.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2470, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2470, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 144, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 615000}, {\"Order\": 1065, \"PID\": 528166120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 664.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 1096, \"LowQualFinSF\": 0, \"GrLivArea\": 2668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 412500}, {\"Order\": 1066, \"PID\": 528170070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1067, \"PID\": 528172080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 454.0, \"TotalBsmtSF\": 1603.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1068, \"PID\": 528178070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 16900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1075.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1515, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2649, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 421250}, {\"Order\": 1069, \"PID\": 528178090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 16451, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 221.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1765.0, \"TotalBsmtSF\": 1765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1804, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1070, \"PID\": 528180110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1486.0, \"TotalBsmtSF\": 1858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336860}, {\"Order\": 1071, \"PID\": 528180140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 766.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 367294}, {\"Order\": 1072, \"PID\": 528181010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 135.0, \"LotArea\": 12304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1347.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1367, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1073, \"PID\": 528186030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 12677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1074, \"PID\": 528186080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 616.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1684, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1684, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 495, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266000}, {\"Order\": 1075, \"PID\": 528186130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 8232, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 714.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370967}, {\"Order\": 1076, \"PID\": 528186160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234250}, {\"Order\": 1077, \"PID\": 528186170, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1318.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1078, \"PID\": 528188090, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1079, \"PID\": 528188150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 1080, \"PID\": 528190010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1081, \"PID\": 528228345, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1073.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 1415.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1455, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1455, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1082, \"PID\": 528228405, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1087.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219990}, {\"Order\": 1083, \"PID\": 528228445, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1084, \"PID\": 528228465, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159895}, {\"Order\": 1085, \"PID\": 528228540, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1146.0, \"TotalBsmtSF\": 1146.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 428.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187687}, {\"Order\": 1086, \"PID\": 528235020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1515, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1087, \"PID\": 528235120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7415, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 759.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 839.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1088, \"PID\": 528235180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1166, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1089, \"PID\": 528240040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 8029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1090, \"PID\": 528240050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1091, \"PID\": 528250030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8396, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1139, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1092, \"PID\": 528253020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 217300}, {\"Order\": 1093, \"PID\": 528280130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1094, \"PID\": 528280180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 647.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226750}, {\"Order\": 1095, \"PID\": 528290010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 15384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1096, \"PID\": 528290090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1097, \"PID\": 528292060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12460, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1098, \"PID\": 528294060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 873, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1099, \"PID\": 528315060, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1173.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284500}, {\"Order\": 1100, \"PID\": 528315110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1470, \"2ndFlrSF\": 1160, \"LowQualFinSF\": 0, \"GrLivArea\": 2630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 696.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 1101, \"PID\": 528326030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 14260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 1053, \"LowQualFinSF\": 0, \"GrLivArea\": 2198, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1102, \"PID\": 528326110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1519.0, \"TotalBsmtSF\": 1519.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 687.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 1103, \"PID\": 528346050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 136.0, \"LotArea\": 11675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 495.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2006, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1104, \"PID\": 528354100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 1061, \"LowQualFinSF\": 0, \"GrLivArea\": 2125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 1105, \"PID\": 528363020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1242.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1250, \"LowQualFinSF\": 0, \"GrLivArea\": 2501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1106, \"PID\": 528363110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10437, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 2109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 236, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1107, \"PID\": 528365060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 651.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1311.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 1093, \"LowQualFinSF\": 0, \"GrLivArea\": 2418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 983.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 154, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 341000}, {\"Order\": 1108, \"PID\": 528365080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 852.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2197, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 783.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 385, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287500}, {\"Order\": 1109, \"PID\": 528387050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 448.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 904, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1110, \"PID\": 528390020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 1986.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1987, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301500}, {\"Order\": 1111, \"PID\": 528427010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11932, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 830.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235128}, {\"Order\": 1112, \"PID\": 528427070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14598, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 74.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 1039, \"LowQualFinSF\": 0, \"GrLivArea\": 1933, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1113, \"PID\": 528429050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1574, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 824.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 1114, \"PID\": 528429070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13253, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1115, \"PID\": 528429080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264132}, {\"Order\": 1116, \"PID\": 528431060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 468.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 33.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1563.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1563, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1563, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1117, \"PID\": 528431080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 12274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1417.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227680}, {\"Order\": 1118, \"PID\": 528431120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1341.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 851.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 1119, \"PID\": 528435020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 919, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 297900}, {\"Order\": 1120, \"PID\": 528439010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1460.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1460, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1460, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247000}, {\"Order\": 1121, \"PID\": 528458030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1363.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212700}, {\"Order\": 1122, \"PID\": 528458050, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1372.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250580}, {\"Order\": 1123, \"PID\": 528462040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 95.0, \"LotArea\": 11639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1428.0, \"TotalBsmtSF\": 1428.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 182000}, {\"Order\": 1124, \"PID\": 528477040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226700}, {\"Order\": 1125, \"PID\": 528478030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 768.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1053.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 939, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1126, \"PID\": 528478040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 932, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1127, \"PID\": 528480060, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1034.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 1028, \"LowQualFinSF\": 0, \"GrLivArea\": 2078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 339750}, {\"Order\": 1128, \"PID\": 528480160, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 843, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 562.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205950}, {\"Order\": 1129, \"PID\": 528482020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1660.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1130, \"PID\": 528488140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230348}, {\"Order\": 1131, \"PID\": 528490080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 64.0, \"LotArea\": 8791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 361.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 673.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1132, \"PID\": 531363060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1133, \"PID\": 531371070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 555.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 861, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1134, \"PID\": 531373060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 1135, \"PID\": 531375050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1136, \"PID\": 531375110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1137, \"PID\": 531375120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1138, \"PID\": 531376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1139, \"PID\": 531376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1162.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1162, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1140, \"PID\": 531382090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 362.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1141, \"PID\": 531382110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 886.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 794, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1142, \"PID\": 531382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 258.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1679, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1679, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 1143, \"PID\": 531384030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 14565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 537.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1144, \"PID\": 531385060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1677, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190500}, {\"Order\": 1145, \"PID\": 531450030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 439.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1146, \"PID\": 531450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1147, \"PID\": 531450170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1148, \"PID\": 531451020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 165.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1617, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1617, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1149, \"PID\": 531452140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 899.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1199, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1150, \"PID\": 532351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 53.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 799.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1151, \"PID\": 532353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12968, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1152, \"PID\": 532354150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 764.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1153, \"PID\": 532376170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 890.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 890, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 890, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1154, \"PID\": 532377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119916}, {\"Order\": 1155, \"PID\": 532378200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1156, \"PID\": 532477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 19508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 108, \"EnclosedPorch\": 165, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1157, \"PID\": 532479020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 811.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 92, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1158, \"PID\": 533125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 1319, \"LowQualFinSF\": 0, \"GrLivArea\": 2683, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 251, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1159, \"PID\": 533125140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1328.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1827, \"2ndFlrSF\": 959, \"LowQualFinSF\": 0, \"GrLivArea\": 2786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372500}, {\"Order\": 1160, \"PID\": 533206050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 59.0, \"LotArea\": 4282, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1391, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 1161, \"PID\": 533208080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4017, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171900}, {\"Order\": 1162, \"PID\": 533208140, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3435, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1211.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 1163, \"PID\": 533212050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1164, \"PID\": 533212140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1165, \"PID\": 533212150, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3604, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1166, \"PID\": 533213070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179400}, {\"Order\": 1167, \"PID\": 533213120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 194.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 792, \"LowQualFinSF\": 0, \"GrLivArea\": 1549, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172900}, {\"Order\": 1168, \"PID\": 533215020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1027.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 587.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1638, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1169, \"PID\": 533215030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4538, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 179.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1170, \"PID\": 533215040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 42.0, \"LotArea\": 4385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1171, \"PID\": 533215070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1557.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1172, \"PID\": 533215080, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 50.0, \"LotArea\": 5119, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1709, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 97, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"CWD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 328900}, {\"Order\": 1173, \"PID\": 533217050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 628, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1174, \"PID\": 533217060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 20, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1175, \"PID\": 533234020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 79.0, \"LotArea\": 10646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 1789, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 1176, \"PID\": 533236060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1177, \"PID\": 533236070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 147.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1607, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1178, \"PID\": 533236090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 36.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 128.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 842.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1469, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2393, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 94, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 1179, \"PID\": 533250050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 14963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245500}, {\"Order\": 1180, \"PID\": 533250110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 22.0, \"LotArea\": 11064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1230.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1239, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1239, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 1181, \"PID\": 533250160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 32.0, \"LotArea\": 10846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1719.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1719, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1719, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 1182, \"PID\": 533251120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1183, \"PID\": 533350090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1050.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 584.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1599, \"2ndFlrSF\": 1345, \"LowQualFinSF\": 0, \"GrLivArea\": 2944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 70, \"EnclosedPorch\": 16, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1184, \"PID\": 533350120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 16280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1044.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 382.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1426.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1185, \"PID\": 534104100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 469.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1186, \"PID\": 534126090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1304.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 98, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1187, \"PID\": 534127210, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1427, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1188, \"PID\": 534127230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1439.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1189, \"PID\": 534128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1190, \"PID\": 534129060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 62, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1191, \"PID\": 534175140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1625.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1192, \"PID\": 534177180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1522.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 1066, \"LowQualFinSF\": 0, \"GrLivArea\": 2614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 243, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1193, \"PID\": 534201240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1194, \"PID\": 534202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1195, \"PID\": 534204030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 456.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1196, \"PID\": 534225110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1728.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1197, \"PID\": 534225120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1497.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142600}, {\"Order\": 1198, \"PID\": 534250010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 9246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 564.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1199, \"PID\": 534250335, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1200, \"PID\": 534250370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 1540, \"LowQualFinSF\": 0, \"GrLivArea\": 2715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 299800}, {\"Order\": 1201, \"PID\": 534250410, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 933, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1202, \"PID\": 534251280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 800, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1203, \"PID\": 534252090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 867.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178400}, {\"Order\": 1204, \"PID\": 534252270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1205, \"PID\": 534276190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7785, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 267.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1206, \"PID\": 534277060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 619.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109008}, {\"Order\": 1207, \"PID\": 534277070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135750}, {\"Order\": 1208, \"PID\": 534400030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 20, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1209, \"PID\": 534400060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 407, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 1210, \"PID\": 534401130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1165, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 129, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174900}, {\"Order\": 1211, \"PID\": 534401190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 892.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 426, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1212, \"PID\": 534403050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 305.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1213, \"PID\": 534403080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 1219.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1265, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 96, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1214, \"PID\": 534403100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 336.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1215, \"PID\": 534403260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 164, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1216, \"PID\": 534426040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 806.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 1217, \"PID\": 534427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10721, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 243.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1252.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1218, \"PID\": 534428020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12493, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 306.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1219, \"PID\": 534428100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1118.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1220, \"PID\": 534451080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Floor\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72500}, {\"Order\": 1221, \"PID\": 534451170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52000}, {\"Order\": 1222, \"PID\": 534452060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 4, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1223, \"PID\": 534453140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 453, \"2ndFlrSF\": 453, \"LowQualFinSF\": 0, \"GrLivArea\": 906, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 1224, \"PID\": 534455030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1225, \"PID\": 534477080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 220, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 1226, \"PID\": 534477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 32.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 308.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1227, \"PID\": 534477270, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 377.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 178, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1228, \"PID\": 534479150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 505.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112900}, {\"Order\": 1229, \"PID\": 535103050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 273, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201800}, {\"Order\": 1230, \"PID\": 535104020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 491.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1231, \"PID\": 535105030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139950}, {\"Order\": 1232, \"PID\": 535105060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1962, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 237.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1319.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1233, \"PID\": 535105090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 9150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1234, \"PID\": 535126140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 529.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 230, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1235, \"PID\": 535150210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 151.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 1098.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1236, \"PID\": 535150280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 25.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 872.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1237, \"PID\": 535151160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1283, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1283, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1238, \"PID\": 535152200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8856, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 52.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1239, \"PID\": 535153140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1240, \"PID\": 535153150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1261.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1261, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1261, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1400, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1241, \"PID\": 535176100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 187.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1570, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1570, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 490, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166800}, {\"Order\": 1242, \"PID\": 535178060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 580.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1243, \"PID\": 535179060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 387.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 458.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 1244, \"PID\": 535180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 135.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 130, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1245, \"PID\": 535180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1104, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1246, \"PID\": 535301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1247, \"PID\": 535302130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 196.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1248, \"PID\": 535302140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1249, \"PID\": 535303030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 14250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 998.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1250, \"PID\": 535305030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 852.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 1251, \"PID\": 535305160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 773, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 1252, \"PID\": 535327230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1253, \"PID\": 535352080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 1254, \"PID\": 535354200, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1255, \"PID\": 535375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 66, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89900}, {\"Order\": 1256, \"PID\": 535375160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 7506, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1257, \"PID\": 535380050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10930, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1258, \"PID\": 535380110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 1259, \"PID\": 535380140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 182, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 1488.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1260, \"PID\": 535383100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 694, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 114, \"EnclosedPorch\": 210, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106250}, {\"Order\": 1261, \"PID\": 535402120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9247, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 539.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1262, \"PID\": 535403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1263, \"PID\": 535425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Othr\", \"MiscVal\": 6500, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 1264, \"PID\": 535426260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1253.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 213, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1265, \"PID\": 535426350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 276.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1081.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1081, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 401.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1266, \"PID\": 535427070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 27650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2069, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 1267, \"PID\": 535451010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 910, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 414.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1268, \"PID\": 535451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 94000}, {\"Order\": 1269, \"PID\": 535451230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98300}, {\"Order\": 1270, \"PID\": 535452120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1507, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1507, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1271, \"PID\": 535453020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 488.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1272, \"PID\": 535453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 319.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125900}, {\"Order\": 1273, \"PID\": 535453210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 532.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1269.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1274, \"PID\": 535454150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 453.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 501, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1275, \"PID\": 535455060, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1276, \"PID\": 535455080, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 1277, \"PID\": 535455090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 181.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1278, \"PID\": 535456050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 8513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1279, \"PID\": 535456070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1280, \"PID\": 535456100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1281, \"PID\": 535475020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 415.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1282, \"PID\": 535476370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 106.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 1283, \"PID\": 535477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136870}, {\"Order\": 1284, \"PID\": 902100020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 96.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143000}, {\"Order\": 1285, \"PID\": 902100030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 30.0, \"LotArea\": 5232, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 1286, \"PID\": 902102060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1904, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 78, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1287, \"PID\": 902103150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9184, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 375, \"LowQualFinSF\": 0, \"GrLivArea\": 1323, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122600}, {\"Order\": 1288, \"PID\": 902105010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 680, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 1289, \"PID\": 902105020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 547, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 480, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1150, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1290, \"PID\": 902105130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1291, \"PID\": 902107030, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1292, \"PID\": 902109080, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 828.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 828, \"2ndFlrSF\": 658, \"LowQualFinSF\": 108, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 109, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1293, \"PID\": 902109110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 2082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1294, \"PID\": 902109120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 561, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119164}, {\"Order\": 1295, \"PID\": 902109160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 7308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122250}, {\"Order\": 1296, \"PID\": 902128075, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 931.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1297, \"PID\": 902128150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 590.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 552, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1298, \"PID\": 902134100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6756, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 481.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 1299, \"PID\": 902136110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 5914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 396, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 165, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1300, \"PID\": 902201120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 169.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 115000}, {\"Order\": 1301, \"PID\": 902201140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 608.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1302, \"PID\": 902202090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 904.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 869.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1303, \"PID\": 902205070, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 407.0, \"TotalBsmtSF\": 407.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 407, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 407, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 46500}, {\"Order\": 1304, \"PID\": 902205090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 620.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1305, \"PID\": 902205140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 901, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107900}, {\"Order\": 1306, \"PID\": 902207120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 103.0, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 1, \"YearBuilt\": 1949, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 65000}, {\"Order\": 1307, \"PID\": 902207220, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 87.0, \"LotArea\": 18386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1880, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1470.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 1818, \"LowQualFinSF\": 0, \"GrLivArea\": 3493, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295000}, {\"Order\": 1308, \"PID\": 902300110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 797.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 830, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1627, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1309, \"PID\": 902300215, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 540, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 418, \"OpenPorchSF\": 0, \"EnclosedPorch\": 194, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1310, \"PID\": 902300260, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 730, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1311, \"PID\": 902301140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 34.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 513.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98000}, {\"Order\": 1312, \"PID\": 902301150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9143, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 709, \"2ndFlrSF\": 308, \"LowQualFinSF\": 0, \"GrLivArea\": 1017, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 139, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1313, \"PID\": 902304060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 973, \"LowQualFinSF\": 0, \"GrLivArea\": 2350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 219, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1314, \"PID\": 902305080, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2058, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 259, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1315, \"PID\": 902306120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1905, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129400}, {\"Order\": 1316, \"PID\": 902306130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1928, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1317, \"PID\": 902326060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1905, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 691, \"LowQualFinSF\": 0, \"GrLivArea\": 1912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1318, \"PID\": 902328040, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 291, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1319, \"PID\": 902330010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5250, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1872, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 205, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 1320, \"PID\": 902401010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 572, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1321, \"PID\": 902401120, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1893, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1521, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 880.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 502, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1322, \"PID\": 902402260, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 2, \"OverallCond\": 1, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 723, \"2ndFlrSF\": 363, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1323, \"PID\": 902405070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 299, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1324, \"PID\": 902406020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1325, \"PID\": 902406090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1050.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 1326, \"PID\": 902427045, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 12702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 1327, \"PID\": 902427150, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8516, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 869.0, \"TotalBsmtSF\": 869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115500}, {\"Order\": 1328, \"PID\": 903201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7111, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1329, \"PID\": 903204010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 1330, \"PID\": 903204095, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 156, \"GrLivArea\": 935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 1331, \"PID\": 903206070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 175.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 594, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1332, \"PID\": 903225050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1333, \"PID\": 903225140, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1334, \"PID\": 903225160, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 554, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106900}, {\"Order\": 1335, \"PID\": 903226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 658, \"LowQualFinSF\": 0, \"GrLivArea\": 1672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 1336, \"PID\": 903226150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 949.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1337, \"PID\": 903227080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 862.0, \"TotalBsmtSF\": 862.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 208.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1338, \"PID\": 903228040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 201.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1497, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1339, \"PID\": 903228060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1340, \"PID\": 903228090, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 992.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1013, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 101, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1341, \"PID\": 903230110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 565, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1342, \"PID\": 903230120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 99.0, \"LotArea\": 5940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": null, \"BsmtFinType2\": null, \"BsmtFinSF2\": null, \"BsmtUnfSF\": null, \"TotalBsmtSF\": null, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79000}, {\"Order\": 1343, \"PID\": 903231080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 365, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1344, \"PID\": 903232030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81300}, {\"Order\": 1345, \"PID\": 903232090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1078.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 1346, \"PID\": 903233080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 989.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1347, \"PID\": 903234090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 897.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 139, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 1348, \"PID\": 903234100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129900}, {\"Order\": 1349, \"PID\": 903235010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 611.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1350, \"PID\": 903235100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 87, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68500}, {\"Order\": 1351, \"PID\": 903236010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 213, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1352, \"PID\": 903400180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 13053, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 220, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1353, \"PID\": 903401020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1354, \"PID\": 903401030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1355, \"PID\": 903401050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 883.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1356, \"PID\": 903425420, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 606.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1357, \"PID\": 903426160, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1000, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1358, \"PID\": 903427090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5100, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1359, \"PID\": 903429010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 4347, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1360, \"PID\": 903452025, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6291, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93850}, {\"Order\": 1361, \"PID\": 903453050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10266, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 216, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 136000}, {\"Order\": 1362, \"PID\": 903454100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1272.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 0, \"LowQualFinSF\": 697, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1363, \"PID\": 903455030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 428, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 117, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1364, \"PID\": 903455140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1365, \"PID\": 903456130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 647.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 127000}, {\"Order\": 1366, \"PID\": 903458110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 371, \"LowQualFinSF\": 0, \"GrLivArea\": 1406, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1367, \"PID\": 903475020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 645.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1368, \"PID\": 903476110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5586, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 110, \"LowQualFinSF\": 0, \"GrLivArea\": 1198, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79900}, {\"Order\": 1369, \"PID\": 903481010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 451.0, \"TotalBsmtSF\": 451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 759, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Family\", \"SalePrice\": 85000}, {\"Order\": 1370, \"PID\": 903481100, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 808, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 204, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82375}, {\"Order\": 1371, \"PID\": 903484020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1906, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 1469, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1906.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 57, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1372, \"PID\": 904100020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 122, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 1373, \"PID\": 904100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 1374, \"PID\": 904100160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 21286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1271, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1375, \"PID\": 904101170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134432}, {\"Order\": 1376, \"PID\": 904351280, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10106, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 181.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 547, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1377, \"PID\": 905100020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 64, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 148000}, {\"Order\": 1378, \"PID\": 905102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 906.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1379, \"PID\": 905103030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 39.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1380, \"PID\": 905104080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109900}, {\"Order\": 1381, \"PID\": 905104110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1382, \"PID\": 905104180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 702.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1383, \"PID\": 905107280, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 311, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1384, \"PID\": 905107380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9981, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 221.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 852.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1385, \"PID\": 905108170, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 956.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1386, \"PID\": 905200090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1198.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 108959}, {\"Order\": 1387, \"PID\": 905200100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 95541}, {\"Order\": 1388, \"PID\": 905200160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 1006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1006, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 1389, \"PID\": 905200510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149350}, {\"Order\": 1390, \"PID\": 905201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 634.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 1391, \"PID\": 905201110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 102, \"OpenPorchSF\": 89, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1392, \"PID\": 905201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1064.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 354.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 511, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1393, \"PID\": 905202230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 429.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1080.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 409, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1394, \"PID\": 905225040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1021, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1395, \"PID\": 905226030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1396, \"PID\": 905226110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1397, \"PID\": 905227050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 486, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152400}, {\"Order\": 1398, \"PID\": 905300020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1399, \"PID\": 905351089, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1003.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1291.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1291, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1400, \"PID\": 905352030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 299.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 2022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 117, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1401, \"PID\": 905352070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 20270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1402, \"PID\": 905401045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 39104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Membran\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1063.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1403, \"PID\": 905401060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1663, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1404, \"PID\": 905402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 11512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1019.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1357, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1357, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 163, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1405, \"PID\": 905403060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 617, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1079, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 249.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125600}, {\"Order\": 1406, \"PID\": 905403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 287, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1407, \"PID\": 905425125, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 45600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 907.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1307, \"2ndFlrSF\": 1051, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1908.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1408, \"PID\": 905426030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"PreCast\", \"Exterior2nd\": \"PreCast\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1035.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1409, \"PID\": 905427050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1163.0, \"TotalBsmtSF\": 1163.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 511, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1410, \"PID\": 905427070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 2108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1411, \"PID\": 905451330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1509.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 576, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1412, \"PID\": 905452070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99600}, {\"Order\": 1413, \"PID\": 905452120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 621, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1414, \"PID\": 905476120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1415, \"PID\": 905477050, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 969.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 527, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 1416, \"PID\": 905479110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1417, \"PID\": 905480150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 572, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 8, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 1418, \"PID\": 905480240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 380.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1419, \"PID\": 906204150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1475.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1532, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2329, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262280}, {\"Order\": 1420, \"PID\": 906204280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9771, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 1721, \"LowQualFinSF\": 0, \"GrLivArea\": 2814, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1421, \"PID\": 906223110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 251.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1626, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1422, \"PID\": 906223140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 355.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 1099, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1423, \"PID\": 906223220, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 735, \"LowQualFinSF\": 0, \"GrLivArea\": 2037, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 1424, \"PID\": 906378190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 628.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177439}, {\"Order\": 1425, \"PID\": 906380030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1615.0, \"TotalBsmtSF\": 1615.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1615, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1615, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 1426, \"PID\": 906412010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 2271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2276, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1348.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 475000}, {\"Order\": 1427, \"PID\": 906412050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1751.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395039}, {\"Order\": 1428, \"PID\": 906420130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 531.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 187, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 1429, \"PID\": 906424010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 631.0, \"TotalBsmtSF\": 1401.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 811.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1430, \"PID\": 906475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1182.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1643, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1643, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 339, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1431, \"PID\": 906476030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12798, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 154.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 1072, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 403, \"OpenPorchSF\": 114, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1432, \"PID\": 907126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 722.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1433, \"PID\": 907135020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1099.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1099, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1099, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1434, \"PID\": 907135260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1435, \"PID\": 907175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226001}, {\"Order\": 1436, \"PID\": 907176010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 688.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 899, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215700}, {\"Order\": 1437, \"PID\": 907181120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 782, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1438, \"PID\": 907181140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 873.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 193000}, {\"Order\": 1439, \"PID\": 907187030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1440, \"PID\": 907187080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 9382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1441, \"PID\": 907192130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 1442, \"PID\": 907194020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 963.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 963, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 245, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 1443, \"PID\": 907196040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1823, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 4500, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1444, \"PID\": 907196050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 1445, \"PID\": 907200110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 491.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 938, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130250}, {\"Order\": 1446, \"PID\": 907201060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 328.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 1447, \"PID\": 907202010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1174, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 211, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1448, \"PID\": 907202160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1449, \"PID\": 907202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1076, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143195}, {\"Order\": 1450, \"PID\": 907202240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 88.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1558, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1451, \"PID\": 907203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 7990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1452, \"PID\": 907227050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1453, \"PID\": 907227300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 780, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 1454, \"PID\": 907250020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1777.0, \"TotalBsmtSF\": 1777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 159, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1455, \"PID\": 907251090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9473, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 903, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 1456, \"PID\": 907253060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 257.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1457, \"PID\": 907253110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 1458, \"PID\": 907254020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9066, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 106, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1459, \"PID\": 907254090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 1460, \"PID\": 907255020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 396.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287000}, {\"Order\": 1461, \"PID\": 907255030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1357.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1366, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1462, \"PID\": 907255060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1786, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 715.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1463, \"PID\": 907260010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 1141, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 1464, \"PID\": 907262030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 334.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 1465, \"PID\": 907262060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 10905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1129.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1129, \"2ndFlrSF\": 1198, \"LowQualFinSF\": 0, \"GrLivArea\": 2327, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1466, \"PID\": 907262070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 595.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1467, \"PID\": 907265100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1468, \"PID\": 907285080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 642.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 933, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1469, \"PID\": 907290150, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1470, \"PID\": 907290250, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1471, \"PID\": 907295020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 215.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1493, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1493, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208900}, {\"Order\": 1472, \"PID\": 907295100, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 83.0, \"LotArea\": 10126, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1593.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 1473, \"PID\": 907405020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 726.0, \"TotalBsmtSF\": 1536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1536, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1474, \"PID\": 907405140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 854, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208500}, {\"Order\": 1475, \"PID\": 907412040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1421.0, \"TotalBsmtSF\": 1445.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1476, \"PID\": 907412070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 946.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 139, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1477, \"PID\": 907412080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 770, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1478, \"PID\": 907412090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1234, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1479, \"PID\": 907418010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1508.0, \"TotalBsmtSF\": 1564.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218836}, {\"Order\": 1480, \"PID\": 907418040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1327.0, \"TotalBsmtSF\": 1351.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1481, \"PID\": 907420080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1482, \"PID\": 907425010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149300}, {\"Order\": 1483, \"PID\": 907425015, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1484, \"PID\": 907425030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1485, \"PID\": 907425035, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 1486, \"PID\": 908102030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1487, \"PID\": 908102040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 928, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145900}, {\"Order\": 1488, \"PID\": 908102140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 259, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 123000}, {\"Order\": 1489, \"PID\": 908102260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 830.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 736, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1490, \"PID\": 908103260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 12102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 222.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1033, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1033, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 165000}, {\"Order\": 1491, \"PID\": 908103280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1033.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1127, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1492, \"PID\": 908127120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1493, \"PID\": 908128050, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 38.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1181, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1181, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1494, \"PID\": 908128110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 92.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165400}, {\"Order\": 1495, \"PID\": 908151040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 120.0, \"BsmtUnfSF\": 541.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1496, \"PID\": 908152110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1497, \"PID\": 908152270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1132.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1498, \"PID\": 908154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 123.0, \"LotArea\": 47007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3820, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3820, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 372, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284700}, {\"Order\": 1499, \"PID\": 908154235, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 63887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"ClyTile\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 796.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 5644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 6110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 4692, \"2ndFlrSF\": 950, \"LowQualFinSF\": 0, \"GrLivArea\": 5642, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 1418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 292, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 480, \"PoolQC\": \"Gd\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 160000}, {\"Order\": 1500, \"PID\": 908186040, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 459.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1501, \"PID\": 908201100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1502, \"PID\": 908201110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1503, \"PID\": 908201120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1307.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1504, \"PID\": 908204160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 1505, \"PID\": 908225170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91900}, {\"Order\": 1506, \"PID\": 908226120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 585, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 120000}, {\"Order\": 1507, \"PID\": 908250040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 1508, \"PID\": 908250090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 134, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Gar2\", \"MiscVal\": 3000, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1509, \"PID\": 908275130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1510, \"PID\": 908275180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1511, \"PID\": 908275280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 521, \"LowQualFinSF\": 0, \"GrLivArea\": 1393, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 265, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 1512, \"PID\": 908276140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1513, \"PID\": 909100150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 343, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1514, \"PID\": 909100170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1515, \"PID\": 909101060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 41.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 823.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67000}, {\"Order\": 1516, \"PID\": 909101180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5687, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135900}, {\"Order\": 1517, \"PID\": 909131170, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 254, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1518, \"PID\": 909175050, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 720, \"LowQualFinSF\": 420, \"GrLivArea\": 2192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179500}, {\"Order\": 1519, \"PID\": 909175100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 423.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 758.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 304, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1520, \"PID\": 909177120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1521, \"PID\": 909201110, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 8525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1911, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 940.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1522, \"PID\": 909250040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 1611, \"LowQualFinSF\": 0, \"GrLivArea\": 2601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 183, \"OpenPorchSF\": 0, \"EnclosedPorch\": 301, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1523, \"PID\": 909250230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 679.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 161900}, {\"Order\": 1524, \"PID\": 909251080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8969, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 369.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1525, \"PID\": 909251090, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1423, \"2ndFlrSF\": 748, \"LowQualFinSF\": 384, \"GrLivArea\": 2555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1526, \"PID\": 909252110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1527, \"PID\": 909252220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15564, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1528, \"PID\": 909253190, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 1529, \"PID\": 909254050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7609, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 16, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 1530, \"PID\": 909256060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 473, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1531, \"PID\": 909275040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 599.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 217, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1532, \"PID\": 909275050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1533, \"PID\": 909276170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1934, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 389.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 849, \"2ndFlrSF\": 811, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188700}, {\"Order\": 1534, \"PID\": 909277040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 673, \"LowQualFinSF\": 0, \"GrLivArea\": 1938, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 1535, \"PID\": 909277070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 932, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1536, \"PID\": 909281030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 7801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 591.0, \"TotalBsmtSF\": 1091.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 344.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 221, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 1537, \"PID\": 909281110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 786.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 207, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 257076}, {\"Order\": 1538, \"PID\": 909282030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1935, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1968, \"2ndFlrSF\": 1479, \"LowQualFinSF\": 0, \"GrLivArea\": 3447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1014.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 381000}, {\"Order\": 1539, \"PID\": 909425010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 817, \"LowQualFinSF\": 0, \"GrLivArea\": 1954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 311500}, {\"Order\": 1540, \"PID\": 909425085, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 943, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263400}, {\"Order\": 1541, \"PID\": 909428170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 26073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1898.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1898, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 1542, \"PID\": 909428190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 568.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 924.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 1543, \"PID\": 909451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 366.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 213, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 1544, \"PID\": 909451150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 612.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1545, \"PID\": 910200080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 555.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 919, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1546, \"PID\": 910201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 330, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1547, \"PID\": 910202050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1548, \"PID\": 910202100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1549, \"PID\": 910203020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 71.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 125.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 778, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 924.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1550, \"PID\": 910203090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 780, \"2ndFlrSF\": 420, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1551, \"PID\": 910205010, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1552, \"PID\": 910206110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 1553, \"PID\": 910226040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1955, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1554, \"PID\": 910251050, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 80.0, \"LotArea\": 14584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Po\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 13100}, {\"Order\": 1555, \"PID\": 911102090, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 5280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1895, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1895.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 185.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 1556, \"PID\": 911102170, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 649, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1317, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 172, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 40000}, {\"Order\": 1557, \"PID\": 911102180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 52.0, \"LotArea\": 5150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 671, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80900}, {\"Order\": 1558, \"PID\": 911226010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 120.0, \"LotArea\": 18000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 560, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1559, \"PID\": 911226030, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 432, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 65000}, {\"Order\": 1560, \"PID\": 911370410, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 5587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392500}, {\"Order\": 1561, \"PID\": 911370490, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294464}, {\"Order\": 1562, \"PID\": 911370520, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1563, \"PID\": 911370540, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 1564, \"PID\": 914453045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 668.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2032, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1565, \"PID\": 914465060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 857.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1566, \"PID\": 914467050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 910.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 318, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1567, \"PID\": 914475020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 574.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 358.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 576, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1568, \"PID\": 914476010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 83, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 1569, \"PID\": 914476080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1570, \"PID\": 914476450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 428, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 1571, \"PID\": 916125425, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 164660, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 1499.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1619, \"2ndFlrSF\": 167, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 670, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228950}, {\"Order\": 1572, \"PID\": 916226030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 893.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1573, \"PID\": 916325080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15498, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1165.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 665.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 174, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 287000}, {\"Order\": 1574, \"PID\": 916380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 258.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1575, \"PID\": 916382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293077}, {\"Order\": 1576, \"PID\": 916384100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264966}, {\"Order\": 1577, \"PID\": 916386040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 712, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 1578, \"PID\": 916386080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": null, \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 1579, \"PID\": 916386180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 12018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 218689}, {\"Order\": 1580, \"PID\": 916402015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1495.0, \"TotalBsmtSF\": 1495.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1495, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1581, \"PID\": 916402115, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 12416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1398.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 208.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1582, \"PID\": 916402215, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 18265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1583, \"PID\": 916403230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 219.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 783.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1584, \"PID\": 916455120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11202, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1029.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 1432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232500}, {\"Order\": 1585, \"PID\": 916460060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7915, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1586, \"PID\": 916477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 2262, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 749.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1587, \"PID\": 921126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1011.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 873.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 276, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 298751}, {\"Order\": 1588, \"PID\": 921201060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1571.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 393.0, \"TotalBsmtSF\": 1964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 892.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1589, \"PID\": 923202005, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 97.0, \"LotArea\": 8940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 209200}, {\"Order\": 1590, \"PID\": 923202015, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 206300}, {\"Order\": 1591, \"PID\": 923202137, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9278, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1592, \"PID\": 923203140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 197.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 1189.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1189, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1189, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1593, \"PID\": 923204040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 171, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1594, \"PID\": 923225080, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 271.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1595, \"PID\": 923225150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1596, \"PID\": 923225200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 318.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1597, \"PID\": 923225310, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 501.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 526.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1598, \"PID\": 923225370, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 120, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94900}, {\"Order\": 1599, \"PID\": 923227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1160, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 257.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 1600, \"PID\": 923228080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1970, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1601, \"PID\": 923228420, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1602, \"PID\": 923250210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 988.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1603, \"PID\": 923252100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 6490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1604, \"PID\": 923275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 6951, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 362, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1605, \"PID\": 923277030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1982, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1606, \"PID\": 923277040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1982, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1607, \"PID\": 923277080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1608, \"PID\": 923400040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 983.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1300, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1609, \"PID\": 923426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 647.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 889, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1610, \"PID\": 924100020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 562.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 193.0, \"BsmtUnfSF\": 29.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1611, \"PID\": 1007100110, \"MSSubClass\": 70, \"MSZoning\": \"I (all)\", \"LotFrontage\": null, \"LotArea\": 56600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1612, \"PID\": 526352080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 838.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 749.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1587, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1587, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167300}, {\"Order\": 1613, \"PID\": 526352090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1277, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 526.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 1614, \"PID\": 526355170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 2223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2223, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2223, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 1615, \"PID\": 526355190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 15865, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 823.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 2217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 1616, \"PID\": 527105140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 225000}, {\"Order\": 1617, \"PID\": 527107040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 373.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1618, \"PID\": 527110080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 794, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1619, \"PID\": 527110120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 1620, \"PID\": 527110130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 1621, \"PID\": 527126030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 1622, \"PID\": 527158090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 770, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1623, \"PID\": 527161090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 947, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1624, \"PID\": 527162080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178750}, {\"Order\": 1625, \"PID\": 527162090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1626, \"PID\": 527162140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 957, \"2ndFlrSF\": 1342, \"LowQualFinSF\": 0, \"GrLivArea\": 2299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1627, \"PID\": 527163080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1168.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1628, \"PID\": 527165020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1629, \"PID\": 527165100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163900}, {\"Order\": 1630, \"PID\": 527165170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 903.0, \"TotalBsmtSF\": 903.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1631, \"PID\": 527175130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 18160, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 154204}, {\"Order\": 1632, \"PID\": 527182040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1633, \"PID\": 527182170, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1634, \"PID\": 527184020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 4740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1166.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 135, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1635, \"PID\": 527184110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 5118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 926.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1321, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1321, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 1636, \"PID\": 527210060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377426}, {\"Order\": 1637, \"PID\": 527212060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1377, \"LowQualFinSF\": 0, \"GrLivArea\": 2541, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 729.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 349265}, {\"Order\": 1638, \"PID\": 527216080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 51974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 710.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1101.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1559.0, \"TotalBsmtSF\": 2660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1110.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 591587}, {\"Order\": 1639, \"PID\": 527226040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 195.0, \"LotArea\": 41600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1047.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 53.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1640, \"PID\": 527252050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8035, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 797.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 164, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 1641, \"PID\": 527252070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8089, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 1642, \"PID\": 527256030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 945.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1558.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 2220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 441929}, {\"Order\": 1643, \"PID\": 527256040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 13870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 174, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 455000}, {\"Order\": 1644, \"PID\": 527301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 99, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182900}, {\"Order\": 1645, \"PID\": 527301280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1028.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1646, \"PID\": 527302020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 178000}, {\"Order\": 1647, \"PID\": 527302060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 167, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1648, \"PID\": 527302090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1328.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 1529.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1649, \"PID\": 527325090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 11339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 549.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 22.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1650, \"PID\": 527325110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11952, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1161, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 276, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1651, \"PID\": 527327050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12046, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 2030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1652, \"PID\": 527328020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 605.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1653, \"PID\": 527328050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1177, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1654, \"PID\": 527353080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 539.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 1655, \"PID\": 527354050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 253.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1259.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1353, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192350}, {\"Order\": 1656, \"PID\": 527356050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 263.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1657, \"PID\": 527357020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 13001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 249, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1658, \"PID\": 527358060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1659, \"PID\": 527359010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 175.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1660, \"PID\": 527359080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 1661, \"PID\": 527359160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 604.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 585.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 407, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1662, \"PID\": 527377110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 153.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1877, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 1663, \"PID\": 527402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 349.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 533, \"LowQualFinSF\": 0, \"GrLivArea\": 1109, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 35, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1664, \"PID\": 527402150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 35.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143250}, {\"Order\": 1665, \"PID\": 527402240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1972, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1666, \"PID\": 527403310, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1667, \"PID\": 527404050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 619.0, \"BsmtUnfSF\": 214.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1668, \"PID\": 527404100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 412.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1669, \"PID\": 527404140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8294, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1670, \"PID\": 527404150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 322.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1671, \"PID\": 527425025, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1672, \"PID\": 527425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1673, \"PID\": 527427090, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 139.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 767, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 367.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1674, \"PID\": 527427160, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 33.0, \"LotArea\": 4113, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1337.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1675, \"PID\": 527427200, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 10943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1676, \"PID\": 527450030, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 1677, \"PID\": 527450150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 356.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1678, \"PID\": 527450220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113700}, {\"Order\": 1679, \"PID\": 527451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2016, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1680, \"PID\": 527451170, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 376.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 1681, \"PID\": 527452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 958.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 205, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1682, \"PID\": 527453010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 556.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1683, \"PID\": 527455030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 6.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 1061.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 1684, \"PID\": 527455250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 725.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129250}, {\"Order\": 1685, \"PID\": 528102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12469, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1151.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1790.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356000}, {\"Order\": 1686, \"PID\": 528102090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 452.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1774.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 260, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 314813}, {\"Order\": 1687, \"PID\": 528102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1688, \"PID\": 528102120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 322400}, {\"Order\": 1689, \"PID\": 528102130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 328.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 730.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1690, \"PID\": 528104010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 2108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345474}, {\"Order\": 1691, \"PID\": 528106040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 315.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2121.0, \"TotalBsmtSF\": 2121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 415298}, {\"Order\": 1692, \"PID\": 528106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13641, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1304.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1934.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1943, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 2656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1040.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 492000}, {\"Order\": 1693, \"PID\": 528106060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1108.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 1402, \"LowQualFinSF\": 0, \"GrLivArea\": 2550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338931}, {\"Order\": 1694, \"PID\": 528106110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 400.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 450000}, {\"Order\": 1695, \"PID\": 528108160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 14154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1063.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1071, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 947.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 280000}, {\"Order\": 1696, \"PID\": 528110040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 2552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 479069}, {\"Order\": 1697, \"PID\": 528110070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 375.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1935.0, \"TotalBsmtSF\": 1935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1973, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1973, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395000}, {\"Order\": 1698, \"PID\": 528110100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 772.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2153.0, \"TotalBsmtSF\": 2153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 2643, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 694.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 380000}, {\"Order\": 1699, \"PID\": 528112150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1626.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1634, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1634, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1700, \"PID\": 528114050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14977, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 1976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 440000}, {\"Order\": 1701, \"PID\": 528118040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13654, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1704.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1722, \"2ndFlrSF\": 1036, \"LowQualFinSF\": 0, \"GrLivArea\": 2758, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 418000}, {\"Order\": 1702, \"PID\": 528118050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 17169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 970.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 2320.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1174.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 500067}, {\"Order\": 1703, \"PID\": 528120010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1582.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 570, \"LowQualFinSF\": 0, \"GrLivArea\": 2152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 368, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260116}, {\"Order\": 1704, \"PID\": 528120150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 317000}, {\"Order\": 1705, \"PID\": 528142050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9709, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319500}, {\"Order\": 1706, \"PID\": 528144050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325624}, {\"Order\": 1707, \"PID\": 528150040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 510.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1802.0, \"TotalBsmtSF\": 1802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1802, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372000}, {\"Order\": 1708, \"PID\": 528150110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 13069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 502.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1706.0, \"TotalBsmtSF\": 1706.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 1238, \"LowQualFinSF\": 0, \"GrLivArea\": 2956, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 916.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 342000}, {\"Order\": 1709, \"PID\": 528150120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 388.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 970.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 872.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 354000}, {\"Order\": 1710, \"PID\": 528166150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14277, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1317.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1711, \"PID\": 528168040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11999, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1712, \"PID\": 528172030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 669.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 895.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 895, \"2ndFlrSF\": 923, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281500}, {\"Order\": 1713, \"PID\": 528172050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1178.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245700}, {\"Order\": 1714, \"PID\": 528172070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9254, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1602.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232698}, {\"Order\": 1715, \"PID\": 528172075, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1298.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 876.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 1716, \"PID\": 528174010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194700}, {\"Order\": 1717, \"PID\": 528174020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3901, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204000}, {\"Order\": 1718, \"PID\": 528174030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 272.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1719, \"PID\": 528174040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 6289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1720, \"PID\": 528181060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1721, \"PID\": 528181070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1722, \"PID\": 528181080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 1723, \"PID\": 528186050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 7841, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 394.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 848.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 729.0, \"TotalBsmtSF\": 1577.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1577, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 1724, \"PID\": 528186090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 1725, \"PID\": 528186120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1869.0, \"TotalBsmtSF\": 1869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318061}, {\"Order\": 1726, \"PID\": 528186190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1300.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221370}, {\"Order\": 1727, \"PID\": 528188160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 235.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1728, \"PID\": 528218010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 15810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181755}, {\"Order\": 1729, \"PID\": 528218020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1730, \"PID\": 528218050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 783, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 178900}, {\"Order\": 1731, \"PID\": 528218100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 13204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 168165}, {\"Order\": 1732, \"PID\": 528221030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8857, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 757, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 171925}, {\"Order\": 1733, \"PID\": 528221040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9729, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 1048, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198444}, {\"Order\": 1734, \"PID\": 528221050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 918.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 1735, \"PID\": 528221090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179540}, {\"Order\": 1736, \"PID\": 528222030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 176485}, {\"Order\": 1737, \"PID\": 528222040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1340.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181134}, {\"Order\": 1738, \"PID\": 528222050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 796, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156932}, {\"Order\": 1739, \"PID\": 528222060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8229, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 22.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1740, \"PID\": 528222080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7713, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177594}, {\"Order\": 1741, \"PID\": 528222090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1246.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173500}, {\"Order\": 1742, \"PID\": 528228270, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172500}, {\"Order\": 1743, \"PID\": 528228275, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194201}, {\"Order\": 1744, \"PID\": 528228375, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3621, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1589, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1745, \"PID\": 528228555, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185485}, {\"Order\": 1746, \"PID\": 528231010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 182.0, \"LotArea\": 14572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 259000}, {\"Order\": 1747, \"PID\": 528231030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 16219, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1119, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1119, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1748, \"PID\": 528235000, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 175000}, {\"Order\": 1749, \"PID\": 528235160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11796, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1112, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1750, \"PID\": 528235170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1510.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 206580}, {\"Order\": 1751, \"PID\": 528240020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 1752, \"PID\": 528250010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1753, \"PID\": 528250070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 1754, \"PID\": 528275035, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1755, \"PID\": 528275110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 1131, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1756, \"PID\": 528280110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 694, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1757, \"PID\": 528280150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1758, \"PID\": 528290060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 1759, \"PID\": 528290170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1760, \"PID\": 528294010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9649, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1761, \"PID\": 528320050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 15623, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2411, \"2ndFlrSF\": 2065, \"LowQualFinSF\": 0, \"GrLivArea\": 4476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 813.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 555, \"PoolQC\": \"Ex\", \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 745000}, {\"Order\": 1762, \"PID\": 528322020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 515.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 2551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 384500}, {\"Order\": 1763, \"PID\": 528326060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 1288, \"LowQualFinSF\": 0, \"GrLivArea\": 2285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 1764, \"PID\": 528327060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 705.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1351.0, \"TotalBsmtSF\": 2633.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2633, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2633, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 804.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 466500}, {\"Order\": 1765, \"PID\": 528340030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10557, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 1407, \"LowQualFinSF\": 0, \"GrLivArea\": 3078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 806.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 1766, \"PID\": 528344020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1048.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 1171, \"LowQualFinSF\": 0, \"GrLivArea\": 2582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 322500}, {\"Order\": 1767, \"PID\": 528348030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 275.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1066.0, \"TotalBsmtSF\": 1066.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1277, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 1768, \"PID\": 528351010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 21535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1170.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 989.0, \"TotalBsmtSF\": 2444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2444, \"2ndFlrSF\": 1872, \"LowQualFinSF\": 0, \"GrLivArea\": 4316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 832.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 755000}, {\"Order\": 1769, \"PID\": 528354060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 862.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2013, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 455.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269790}, {\"Order\": 1770, \"PID\": 528354110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11787, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 594.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 1379.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 1015, \"LowQualFinSF\": 0, \"GrLivArea\": 2398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315750}, {\"Order\": 1771, \"PID\": 528358040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1203.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 290000}, {\"Order\": 1772, \"PID\": 528364110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1318.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 752.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1773, \"PID\": 528366050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1969.0, \"TotalBsmtSF\": 3200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 75, \"EnclosedPorch\": 291, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 430000}, {\"Order\": 1774, \"PID\": 528366070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 335.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2202, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 1775, \"PID\": 528376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 526.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1225.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1325.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2538, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 933.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 1776, \"PID\": 528427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1369.0, \"TotalBsmtSF\": 1369.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1369, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 203, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 213133}, {\"Order\": 1777, \"PID\": 528427100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1542, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260261}, {\"Order\": 1778, \"PID\": 528429090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 11670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1905.0, \"TotalBsmtSF\": 1905.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1905, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1905, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 1779, \"PID\": 528429110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282922}, {\"Order\": 1780, \"PID\": 528431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1534, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 215000}, {\"Order\": 1781, \"PID\": 528431040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 754.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 394.0, \"TotalBsmtSF\": 1966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1966, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1092.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 419005}, {\"Order\": 1782, \"PID\": 528431050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13501, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 63.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1623.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1783, \"PID\": 528431110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9986, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 428.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1795.0, \"TotalBsmtSF\": 1795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 1784, \"PID\": 528435010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1528, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235876}, {\"Order\": 1785, \"PID\": 528435040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1126.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 311872}, {\"Order\": 1786, \"PID\": 528435060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 954.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248328}, {\"Order\": 1787, \"PID\": 528435070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 825.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1788, \"PID\": 528439040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8847, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 1538.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1538, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1538, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1789, \"PID\": 528439050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 1790, \"PID\": 528439080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8251, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 1791, \"PID\": 528441080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 255, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 307000}, {\"Order\": 1792, \"PID\": 528445020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 982, \"2ndFlrSF\": 995, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 250000}, {\"Order\": 1793, \"PID\": 528445070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 528, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 859.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221300}, {\"Order\": 1794, \"PID\": 528456190, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1314.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1795, \"PID\": 528456230, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1335.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1335, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210400}, {\"Order\": 1796, \"PID\": 528458080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 255000}, {\"Order\": 1797, \"PID\": 528458090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 10411, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212109}, {\"Order\": 1798, \"PID\": 528458120, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1025.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 1799, \"PID\": 528458130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 64.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1120.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1184, \"2ndFlrSF\": 1426, \"LowQualFinSF\": 0, \"GrLivArea\": 2610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 364, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 303477}, {\"Order\": 1800, \"PID\": 528458150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1880, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310013}, {\"Order\": 1801, \"PID\": 528477020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 11096, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249700}, {\"Order\": 1802, \"PID\": 528480020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 874.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1761, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227875}, {\"Order\": 1803, \"PID\": 528480180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1574.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 256, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 261329}, {\"Order\": 1804, \"PID\": 528482010, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 11824, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1685.0, \"TotalBsmtSF\": 1685.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1685, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1685, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 1805, \"PID\": 528482030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 353.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2443, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 744.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 1806, \"PID\": 528482090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 102.0, \"LotArea\": 11143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 159, \"OpenPorchSF\": 214, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 1807, \"PID\": 531363020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 146000}, {\"Order\": 1808, \"PID\": 531363040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1809, \"PID\": 531375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1810, \"PID\": 531376060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1461.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1811, \"PID\": 531380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 1812, \"PID\": 531384070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11613, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191750}, {\"Order\": 1813, \"PID\": 531385070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1349.0, \"TotalBsmtSF\": 1349.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1349, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1349, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1814, \"PID\": 531385130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 39.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 402, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1815, \"PID\": 531451030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1145.0, \"TotalBsmtSF\": 1575.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1816, \"PID\": 531451150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1817, \"PID\": 531453140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1818, \"PID\": 531477040, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1819, \"PID\": 532353120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 351.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120750}, {\"Order\": 1820, \"PID\": 532354010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1821, \"PID\": 532354060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1822, \"PID\": 532354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 999.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1823, \"PID\": 532376040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 6970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1824, \"PID\": 532376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 13673, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143900}, {\"Order\": 1825, \"PID\": 532377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 7476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1826, \"PID\": 532377140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 57.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 827.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1827, \"PID\": 532378240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1828, \"PID\": 532476080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1232, \"LowQualFinSF\": 0, \"GrLivArea\": 2503, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1829, \"PID\": 532477040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 125.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1031.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 2167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1830, \"PID\": 532479050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 10751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1037, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1831, \"PID\": 532479120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16647, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1701, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 611.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1832, \"PID\": 532479140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 968.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 455, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 147000}, {\"Order\": 1833, \"PID\": 533120030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 482.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 1357, \"LowQualFinSF\": 0, \"GrLivArea\": 2810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 500, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 1834, \"PID\": 533130170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10678, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 337.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 983.0, \"TotalBsmtSF\": 1683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2129, \"2ndFlrSF\": 743, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1835, \"PID\": 533205110, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 45.0, \"LotArea\": 4379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 527.0, \"TotalBsmtSF\": 1378.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1836, \"PID\": 533206060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 3523, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1081.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1151, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1837, \"PID\": 533206070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 3784, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1511.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193800}, {\"Order\": 1838, \"PID\": 533208010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 47.0, \"LotArea\": 4230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1352.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1839, \"PID\": 533208020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3606, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 937.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 1840, \"PID\": 533208030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1550, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 207500}, {\"Order\": 1841, \"PID\": 533208040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4274, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1106.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1241.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1241, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1241, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199900}, {\"Order\": 1842, \"PID\": 533208070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4251, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164700}, {\"Order\": 1843, \"PID\": 533213130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 1844, \"PID\": 533213140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1129.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1845, \"PID\": 533221030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1846, \"PID\": 533221060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1847, \"PID\": 533221100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1848, \"PID\": 533223050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 5105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 551.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 551, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 1849, \"PID\": 533236040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1850, \"PID\": 533241030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 66.0, \"LotArea\": 7399, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 1851, \"PID\": 533242080, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 73.0, \"LotArea\": 7321, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1339.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1852, \"PID\": 533242090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 1853, \"PID\": 533244040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 106.0, \"LotArea\": 8413, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 1105.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 1854, \"PID\": 533250190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1037.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 217, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279700}, {\"Order\": 1855, \"PID\": 533251110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1856, \"PID\": 533251130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 1857, \"PID\": 533252130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1157.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 1858, \"PID\": 533253180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 176.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 89, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213750}, {\"Order\": 1859, \"PID\": 533254100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 761, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1860, \"PID\": 533254130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 978.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181500}, {\"Order\": 1861, \"PID\": 533350020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 17778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1632.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 829.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 2461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2497, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2497, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 373000}, {\"Order\": 1862, \"PID\": 533352075, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAe\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 211.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 1361.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 1259, \"LowQualFinSF\": 0, \"GrLivArea\": 2620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 24, \"EnclosedPorch\": 145, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 8300, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1863, \"PID\": 534104090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 1929, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 1864, \"PID\": 534125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143450}, {\"Order\": 1865, \"PID\": 534127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 1008, \"LowQualFinSF\": 0, \"GrLivArea\": 2411, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240050}, {\"Order\": 1866, \"PID\": 534127140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 973.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1867, \"PID\": 534127260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 385.0, \"TotalBsmtSF\": 1295.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 194, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 1868, \"PID\": 534128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 11358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1869, \"PID\": 534151090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1594, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1870, \"PID\": 534151180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1871, \"PID\": 534175010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAn\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136905}, {\"Order\": 1872, \"PID\": 534176140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 792.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1873, \"PID\": 534177210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 916.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1874, \"PID\": 534178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1875, \"PID\": 534201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 38.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1876, \"PID\": 534202030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 519.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1877, \"PID\": 534204120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1878, \"PID\": 534252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1879, \"PID\": 534252060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10624, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1880, \"PID\": 534252070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1881, \"PID\": 534252110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 978.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 1882, \"PID\": 534275170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1960, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 15500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1883, \"PID\": 534275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 66.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1065, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 1884, \"PID\": 534276070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 63.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 81.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1885, \"PID\": 534276160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 285, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1886, \"PID\": 534276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 206.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1887, \"PID\": 534276290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 1888, \"PID\": 534278150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 167.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1889, \"PID\": 534278170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1890, \"PID\": 534278190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117600}, {\"Order\": 1891, \"PID\": 534401120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1174.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1892, \"PID\": 534401200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1893, \"PID\": 534403040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 270.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 580.0, \"BsmtUnfSF\": 452.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 309.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 333, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1894, \"PID\": 534403290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 1309, \"LowQualFinSF\": 0, \"GrLivArea\": 2154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 1895, \"PID\": 534403420, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 543.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1130.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1374, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1896, \"PID\": 534425015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 1592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 201, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1897, \"PID\": 534425080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 219.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1429, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1429, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1898, \"PID\": 534427140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1327, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1327, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150750}, {\"Order\": 1899, \"PID\": 534429030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101800}, {\"Order\": 1900, \"PID\": 534430090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 932, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 306.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 214, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1901, \"PID\": 534431020, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 259.0, \"BsmtUnfSF\": 433.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 908, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 1902, \"PID\": 534450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 2, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 39300}, {\"Order\": 1903, \"PID\": 534450110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1904, \"PID\": 534451020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 442, \"2ndFlrSF\": 228, \"LowQualFinSF\": 0, \"GrLivArea\": 670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1905, \"PID\": 534453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 404.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 1906, \"PID\": 534475170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1907, \"PID\": 534476080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1908, \"PID\": 534478140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Roll\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 708.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 992, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1909, \"PID\": 534479120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1910, \"PID\": 534479140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 1911, \"PID\": 535101150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1912, \"PID\": 535102010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 87.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1913, \"PID\": 535105110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 291.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1914, \"PID\": 535106140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 1915, \"PID\": 535106180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11344, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 874, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1916, \"PID\": 535126180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 1021.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1465, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Sev\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129000}, {\"Order\": 1917, \"PID\": 535151020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 873.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 63.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 219, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1918, \"PID\": 535151100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 908.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 1919, \"PID\": 535151110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 109, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142100}, {\"Order\": 1920, \"PID\": 535152060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1921, \"PID\": 535154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 243.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 834.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 275, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 1922, \"PID\": 535155110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 1923, \"PID\": 535176070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1244, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1244, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1924, \"PID\": 535177020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 69.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1144.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1925, \"PID\": 535177110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 138.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1331.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174850}, {\"Order\": 1926, \"PID\": 535179120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1927, \"PID\": 535180030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 586.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1928, \"PID\": 535181030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1237.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1657, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1929, \"PID\": 535181140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1930, \"PID\": 535300040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 928.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1931, \"PID\": 535301060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1932, \"PID\": 535301160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8078, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128600}, {\"Order\": 1933, \"PID\": 535302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1934, \"PID\": 535304170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 85.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 955.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 293.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1935, \"PID\": 535305180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1936, \"PID\": 535325090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 691.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1937, \"PID\": 535325280, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1938, \"PID\": 535325320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 500, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1939, \"PID\": 535327160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1940, \"PID\": 535327200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 377.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 551.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1941, \"PID\": 535353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 368, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1942, \"PID\": 535353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 324, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1943, \"PID\": 535353160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 14190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 544, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1944, \"PID\": 535354050, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 893, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 893, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1945, \"PID\": 535354260, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 512, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1946, \"PID\": 535355020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 21281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 1778, \"LowQualFinSF\": 0, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 208, \"EnclosedPorch\": 290, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 301600}, {\"Order\": 1947, \"PID\": 535375130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 735.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 735, \"2ndFlrSF\": 299, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 1948, \"PID\": 535376010, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 882.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103200}, {\"Order\": 1949, \"PID\": 535378080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 66.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 1950, \"PID\": 535379060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1951, \"PID\": 535379110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1895, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1952, \"PID\": 535382150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 691.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 86000}, {\"Order\": 1953, \"PID\": 535402140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 364.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 242.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1954, \"PID\": 535402180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 1955, \"PID\": 535403030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 952.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1956, \"PID\": 535426130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1957, \"PID\": 535450190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122900}, {\"Order\": 1958, \"PID\": 535450220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119200}, {\"Order\": 1959, \"PID\": 535450310, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10496, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1960, \"PID\": 535451040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 246.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1961, \"PID\": 535451100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1238, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 171, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 1962, \"PID\": 535451110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 398.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 149.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1963, \"PID\": 535452060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 254.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1964, \"PID\": 535453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1965, \"PID\": 535453150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7315, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1170.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1170, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1966, \"PID\": 535453180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 1967, \"PID\": 535457020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1098.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 154.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1377.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1377, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 1968, \"PID\": 535457040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1969, \"PID\": 535457050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1970, \"PID\": 535476360, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 831, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1971, \"PID\": 535477130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 1972, \"PID\": 535477180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 442.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1973, \"PID\": 535478040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 90, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1974, \"PID\": 902100010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1975, \"PID\": 902105110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 664, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 132000}, {\"Order\": 1976, \"PID\": 902106070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 175, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1977, \"PID\": 902106120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 782.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 184.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1978, \"PID\": 902107050, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1979, \"PID\": 902110010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 3153, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 26, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 1980, \"PID\": 902125120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1885, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1047, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1047, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1981, \"PID\": 902128160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 279.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1982, \"PID\": 902201090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 494, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 26, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1983, \"PID\": 902201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 679, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1984, \"PID\": 902202070, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 435.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 89471}, {\"Order\": 1985, \"PID\": 902205020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 122.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 448.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 761, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1986, \"PID\": 902205130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 1987, \"PID\": 902206270, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1075.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 642, \"LowQualFinSF\": 0, \"GrLivArea\": 1798, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1988, \"PID\": 902207010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1945, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 1989, \"PID\": 902207150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 968.0, \"TotalBsmtSF\": 968.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1990, \"PID\": 902300020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10337, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 1991, \"PID\": 902300040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 9863, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 374.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1992, \"PID\": 902301030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 842, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1993, \"PID\": 902301130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1994, \"PID\": 902302150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 1995, \"PID\": 902303100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 667.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 659, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144100}, {\"Order\": 1996, \"PID\": 902304040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1880, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 1997, \"PID\": 902305010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 316.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 687.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 687, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 124500}, {\"Order\": 1998, \"PID\": 902330090, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1879, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 819.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2454, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1999, \"PID\": 902332030, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1046.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 1031, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 99, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 2000, \"PID\": 902401030, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 779.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2001, \"PID\": 902404010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1221.0, \"TotalBsmtSF\": 1559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1559, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1559, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 230, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2002, \"PID\": 902408080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 718.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2003, \"PID\": 902427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 9439, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2004, \"PID\": 902427140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2005, \"PID\": 902427180, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2006, \"PID\": 903201090, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 6854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 227.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 916, \"2ndFlrSF\": 144, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 150, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2007, \"PID\": 903204030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8674, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1435, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128250}, {\"Order\": 2008, \"PID\": 903205085, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 8731, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 645.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2009, \"PID\": 903206170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 915, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2010, \"PID\": 903225040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2011, \"PID\": 903227140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 217.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 2012, \"PID\": 903228080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 349, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2013, \"PID\": 903231050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2014, \"PID\": 903231090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 809.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2015, \"PID\": 903231180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 423, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2016, \"PID\": 903232100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 966.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2017, \"PID\": 903233030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 903, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2018, \"PID\": 903233050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1933.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2019, \"PID\": 903233140, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 854, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2020, \"PID\": 903233180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 959, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 2021, \"PID\": 903234160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2022, \"PID\": 903236130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 7755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1164, \"LowQualFinSF\": 0, \"GrLivArea\": 2264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2023, \"PID\": 903400040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2024, \"PID\": 903401070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2025, \"PID\": 903425270, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 356, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2026, \"PID\": 903425280, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153575}, {\"Order\": 2027, \"PID\": 903426010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1929, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2028, \"PID\": 903427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 546.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 714.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 15, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136000}, {\"Order\": 2029, \"PID\": 903430040, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 933, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 113000}, {\"Order\": 2030, \"PID\": 903430050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 969, \"2ndFlrSF\": 245, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 117000}, {\"Order\": 2031, \"PID\": 903450060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 2032, \"PID\": 903451110, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 7449, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 2033, \"PID\": 903453080, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1497, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2034, \"PID\": 903454010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 0, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2035, \"PID\": 903454090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2036, \"PID\": 903456110, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 398.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 1952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 285, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212300}, {\"Order\": 2037, \"PID\": 903457040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 1042, \"LowQualFinSF\": 0, \"GrLivArea\": 2180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2038, \"PID\": 903457130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 4330, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 477, \"LowQualFinSF\": 0, \"GrLivArea\": 1315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 99500}, {\"Order\": 2039, \"PID\": 903458020, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 581, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101000}, {\"Order\": 2040, \"PID\": 903458060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 197.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 999.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2041, \"PID\": 903475040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 12358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 528, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2042, \"PID\": 903475060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 964, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2043, \"PID\": 903476100, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 4388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2044, \"PID\": 903484080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 771.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 504, \"LowQualFinSF\": 114, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 14, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 84, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 50000}, {\"Order\": 2045, \"PID\": 904100100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1937, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 1005, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 521, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219000}, {\"Order\": 2046, \"PID\": 904101070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 138.0, \"LotArea\": 18030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 977.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 971, \"LowQualFinSF\": 479, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 2047, \"PID\": 904301110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 756, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 126000}, {\"Order\": 2048, \"PID\": 904302010, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 4484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2049, \"PID\": 905100060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2050, \"PID\": 905100080, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158450}, {\"Order\": 2051, \"PID\": 905101070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 14299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115400}, {\"Order\": 2052, \"PID\": 905101200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1029, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 261.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2053, \"PID\": 905102010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 722.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2054, \"PID\": 905103110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 761.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2055, \"PID\": 905104030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 627.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 913, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2056, \"PID\": 905104090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 7094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2057, \"PID\": 905104170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 948.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 108000}, {\"Order\": 2058, \"PID\": 905104240, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 20.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2059, \"PID\": 905105040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 8665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 897, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2060, \"PID\": 905105170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 323.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 529.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2061, \"PID\": 905105260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 955, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2062, \"PID\": 905106150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 8724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2063, \"PID\": 905107140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 2064, \"PID\": 905200010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2065, \"PID\": 905201080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 522.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 323.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2066, \"PID\": 905225020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 16779, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 1087, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 570, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2067, \"PID\": 905226050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1416, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2068, \"PID\": 905226080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165250}, {\"Order\": 2069, \"PID\": 905226130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 231.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2070, \"PID\": 905226170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 873.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"VWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2071, \"PID\": 905228020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 998, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 998, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 2072, \"PID\": 905301050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 115149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 739.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 380, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 2073, \"PID\": 905352010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 891.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2074, \"PID\": 905352180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2075, \"PID\": 905376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 109.0, \"TotalBsmtSF\": 409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1325, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 2076, \"PID\": 905377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 587.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2077, \"PID\": 905377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 17808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2078, \"PID\": 905401020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2079, \"PID\": 905426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 12615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 477.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243000}, {\"Order\": 2080, \"PID\": 905451390, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 491.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 638, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 332.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 2081, \"PID\": 905475270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2082, \"PID\": 905475520, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11515, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2083, \"PID\": 905476160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 7711, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2084, \"PID\": 905476170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 605, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 605, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 2085, \"PID\": 905476225, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 3869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 755.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1038.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1038, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2086, \"PID\": 905478140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2087, \"PID\": 905478220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1080.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 400, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2088, \"PID\": 905480090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 951.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 376, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 2089, \"PID\": 905480180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2090, \"PID\": 906200230, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 23920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1105.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 1012, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 444, \"PoolQC\": \"TA\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2091, \"PID\": 906201022, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 10357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 719.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 244, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2092, \"PID\": 906201023, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 1121, \"LowQualFinSF\": 0, \"GrLivArea\": 2243, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 44, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2093, \"PID\": 906201200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1474.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2730, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 2094, \"PID\": 906203140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 634.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 833.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 192, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2095, \"PID\": 906204140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 807.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 196, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2096, \"PID\": 906223040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 497.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 929, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2097, \"PID\": 906340080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 984.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 1414, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 383970}, {\"Order\": 2098, \"PID\": 906340090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1362, \"LowQualFinSF\": 0, \"GrLivArea\": 2828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 424870}, {\"Order\": 2099, \"PID\": 906378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 2100, \"PID\": 906378150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10481, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2140.0, \"TotalBsmtSF\": 2140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 360000}, {\"Order\": 2101, \"PID\": 906378170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10652, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1494.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 279500}, {\"Order\": 2102, \"PID\": 906380010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 11175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 200141}, {\"Order\": 2103, \"PID\": 906380040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 10235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246500}, {\"Order\": 2104, \"PID\": 906380070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1482.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 1092, \"LowQualFinSF\": 0, \"GrLivArea\": 2574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 276000}, {\"Order\": 2105, \"PID\": 906380120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 349.0, \"TotalBsmtSF\": 1274.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1274, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203000}, {\"Order\": 2106, \"PID\": 906380140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11103, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155835}, {\"Order\": 2107, \"PID\": 906380160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2108, \"PID\": 906380200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 195400}, {\"Order\": 2109, \"PID\": 906382020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1526.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1546, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1546, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2110, \"PID\": 906382060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1453.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 674.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212999}, {\"Order\": 2111, \"PID\": 906392080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1270.0, \"TotalBsmtSF\": 1270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1270, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2112, \"PID\": 906394020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 916, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 2113, \"PID\": 906394050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176432}, {\"Order\": 2114, \"PID\": 906402070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1157.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 882, \"LowQualFinSF\": 0, \"GrLivArea\": 2062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 154, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2115, \"PID\": 906403060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 321.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 927, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2116, \"PID\": 906426060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 159000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 2144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2117, \"PID\": 906426195, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53107, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 985.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 874, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 231, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2118, \"PID\": 906475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2087, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2119, \"PID\": 906475170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 155.0, \"LotArea\": 20064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 51.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 915.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 646, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2120, \"PID\": 907125040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 472.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 747.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2121, \"PID\": 907125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2122, \"PID\": 907130060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11249, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 544.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 2123, \"PID\": 907131060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 10021, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 635.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 646, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2124, \"PID\": 907131120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9531, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 914, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2125, \"PID\": 907135050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2126, \"PID\": 907135080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 16561, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 242.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147900}, {\"Order\": 2127, \"PID\": 907135180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123600}, {\"Order\": 2128, \"PID\": 907180040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 905, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204750}, {\"Order\": 2129, \"PID\": 907187040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 646.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 597.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235500}, {\"Order\": 2130, \"PID\": 907187060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12352, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 853, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1753, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2131, \"PID\": 907192020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 845.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190550}, {\"Order\": 2132, \"PID\": 907192040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8826, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2133, \"PID\": 907192120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 167.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1013.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2134, \"PID\": 907192150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2135, \"PID\": 907200130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 131000}, {\"Order\": 2136, \"PID\": 907200190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 502.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2137, \"PID\": 907200250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1009, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2138, \"PID\": 907200270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 2139, \"PID\": 907202100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 16300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 417.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2140, \"PID\": 907202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 432.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2141, \"PID\": 907203060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 2142, \"PID\": 907203110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 10356, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 969, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2143, \"PID\": 907227060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 671.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2144, \"PID\": 907227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2145, \"PID\": 907250050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 2000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305900}, {\"Order\": 2146, \"PID\": 907252020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1284.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 2169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2147, \"PID\": 907252190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11354, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1412.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1673, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1673, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2148, \"PID\": 907260040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1459.0, \"TotalBsmtSF\": 1459.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1459, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1459, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 2149, \"PID\": 907260050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 2150, \"PID\": 907262020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 214.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2151, \"PID\": 907270040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 16226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 1242, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 267000}, {\"Order\": 2152, \"PID\": 907275080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 519.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 683.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1592, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1592, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2153, \"PID\": 907275150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 1531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2439, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2154, \"PID\": 907280090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2155, \"PID\": 907280100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 2156, \"PID\": 907285040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 438.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1079.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2157, \"PID\": 907290140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 2158, \"PID\": 907295040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 17227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246900}, {\"Order\": 2159, \"PID\": 907401060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1081, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2160, \"PID\": 907405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2161, \"PID\": 907410020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179400}, {\"Order\": 2162, \"PID\": 907410050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 639.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 2163, \"PID\": 907414060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1422.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179600}, {\"Order\": 2164, \"PID\": 907414070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 709.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 2165, \"PID\": 907420050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1330, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167840}, {\"Order\": 2166, \"PID\": 907420060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 753, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168675}, {\"Order\": 2167, \"PID\": 907420110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2168, \"PID\": 908102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2169, \"PID\": 908102160, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 405, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 2170, \"PID\": 908103090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 132.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2171, \"PID\": 908127040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 10921, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 48.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94750}, {\"Order\": 2172, \"PID\": 908127060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 16287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 450, \"LowQualFinSF\": 0, \"GrLivArea\": 1351, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 43, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2173, \"PID\": 908127070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1179.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2174, \"PID\": 908127100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 11841, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2175, \"PID\": 908152060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2176, \"PID\": 908152070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 751.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2177, \"PID\": 908152180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9555, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1133, \"LowQualFinSF\": 0, \"GrLivArea\": 2233, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2178, \"PID\": 908152260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1125.0, \"TotalBsmtSF\": 1125.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155000}, {\"Order\": 2179, \"PID\": 908152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2180, \"PID\": 908152290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 123.0, \"TotalBsmtSF\": 734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 674, \"LowQualFinSF\": 0, \"GrLivArea\": 1408, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 2181, \"PID\": 908154195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 39290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 4010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 5095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 5095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 5095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 15, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1154.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 546, \"OpenPorchSF\": 484, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Elev\", \"MiscVal\": 17000, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 183850}, {\"Order\": 2182, \"PID\": 908154205, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 40094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 762.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 3138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3138, \"2ndFlrSF\": 1538, \"LowQualFinSF\": 0, \"GrLivArea\": 4676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 406, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 184750}, {\"Order\": 2183, \"PID\": 908186050, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 467.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2184, \"PID\": 908204090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 77.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 831.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2185, \"PID\": 908204180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2186, \"PID\": 908225240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 2187, \"PID\": 908225310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1195, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 118, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98500}, {\"Order\": 2188, \"PID\": 908226180, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 4270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 286, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2189, \"PID\": 908228010, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 278.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 740, \"2ndFlrSF\": 125, \"LowQualFinSF\": 0, \"GrLivArea\": 865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2190, \"PID\": 908250100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 2191, \"PID\": 908275090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2192, \"PID\": 908275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2193, \"PID\": 908275240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 79275}, {\"Order\": 2194, \"PID\": 908276230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2195, \"PID\": 909176080, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 10896, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1184.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 1440, \"LowQualFinSF\": 515, \"GrLivArea\": 3395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 8, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 14, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 200000}, {\"Order\": 2196, \"PID\": 909176170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2592, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 742, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1512, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 150000}, {\"Order\": 2197, \"PID\": 909250150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 53, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2198, \"PID\": 909250160, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10594, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 2199, \"PID\": 909251030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7223, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2200, \"PID\": 909251040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6821, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 113.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2201, \"PID\": 909252010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 787, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2202, \"PID\": 909252150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 4000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 567, \"2ndFlrSF\": 531, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 2203, \"PID\": 909252170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 6720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 585, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 2204, \"PID\": 909254090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7642, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 514, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189950}, {\"Order\": 2205, \"PID\": 909254100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 775, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2206, \"PID\": 909254130, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 364.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2207, \"PID\": 909254140, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1913, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 365.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90350}, {\"Order\": 2208, \"PID\": 909254150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 661.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 661, \"2ndFlrSF\": 589, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 242, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2209, \"PID\": 909256120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 920.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119750}, {\"Order\": 2210, \"PID\": 909275020, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 7136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 979, \"2ndFlrSF\": 979, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2211, \"PID\": 909275030, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 6270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 1001, \"LowQualFinSF\": 0, \"GrLivArea\": 2002, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2212, \"PID\": 909275110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1927, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 867, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 291, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2213, \"PID\": 909275160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 126.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 24, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 228, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2214, \"PID\": 909275310, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 22420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1128.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2215, \"PID\": 909276160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12168, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 537.0, \"TotalBsmtSF\": 965.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 3194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 359100}, {\"Order\": 2216, \"PID\": 909276210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 7810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1230, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2217, \"PID\": 909279080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 557.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 19, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2218, \"PID\": 909281020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 6221, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2219, \"PID\": 909281130, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1549, \"2ndFlrSF\": 1178, \"LowQualFinSF\": 0, \"GrLivArea\": 2727, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2220, \"PID\": 909282020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1945, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 150.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 2320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259500}, {\"Order\": 2221, \"PID\": 909425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 1477.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1839, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 2222, \"PID\": 909425270, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2223, \"PID\": 909428120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 35.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 869.0, \"BsmtUnfSF\": 905.0, \"TotalBsmtSF\": 1809.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2259, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2259, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 217000}, {\"Order\": 2224, \"PID\": 909428180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1020.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 584, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 2225, \"PID\": 909428340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21579, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2226, \"PID\": 909451130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 529, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 2227, \"PID\": 909452102, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2228, \"PID\": 909455060, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 577.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2229, \"PID\": 909475050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 652.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 434.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1262.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 2230, \"PID\": 909475070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 2035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2515, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2515, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 200624}, {\"Order\": 2231, \"PID\": 909475230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 18044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 279.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 64, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 228, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2232, \"PID\": 910200040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 997, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2233, \"PID\": 910200110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2234, \"PID\": 910201020, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 803, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2235, \"PID\": 910201050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 176, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129850}, {\"Order\": 2236, \"PID\": 910201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 772, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1123, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 2237, \"PID\": 910201180, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": null, \"GarageArea\": null, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 150909}, {\"Order\": 2238, \"PID\": 910202030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 46.0, \"LotArea\": 3672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 100.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75200}, {\"Order\": 2239, \"PID\": 910203290, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118400}, {\"Order\": 2240, \"PID\": 910204090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 961.0, \"TotalBsmtSF\": 961.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"Mix\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 67000}, {\"Order\": 2241, \"PID\": 910205130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 910, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2242, \"PID\": 910206010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 11067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 205, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68104}, {\"Order\": 2243, \"PID\": 911103060, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1895, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 957.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 957, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 133, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119600}, {\"Order\": 2244, \"PID\": 911128010, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 65.0, \"LotArea\": 6565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 106.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 444, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2245, \"PID\": 911128020, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 837.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1001, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 86, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 2246, \"PID\": 911370450, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2247, \"PID\": 911370460, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 481.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 235000}, {\"Order\": 2248, \"PID\": 914452090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1001.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2249, \"PID\": 914452120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2250, \"PID\": 914452190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2251, \"PID\": 914460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 856.0, \"TotalBsmtSF\": 1441.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2252, \"PID\": 914460110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 12864, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 17.0, \"TotalBsmtSF\": 1409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1409, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 2253, \"PID\": 914476330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2254, \"PID\": 914478020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 530.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 852.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2255, \"PID\": 914478100, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 924.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2256, \"PID\": 916226090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 4054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 949.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 2257, \"PID\": 916253320, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 9763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 239.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1102.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 2258, \"PID\": 916326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 16905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2259, \"PID\": 916326090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 19958, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 274, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2260, \"PID\": 916384050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 231713}, {\"Order\": 2261, \"PID\": 916384070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8298, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 963.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2207.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267300}, {\"Order\": 2262, \"PID\": 916384080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1476.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265900}, {\"Order\": 2263, \"PID\": 916384150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1571.0, \"TotalBsmtSF\": 1571.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1571, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239000}, {\"Order\": 2264, \"PID\": 916386170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 274.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1638.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248900}, {\"Order\": 2265, \"PID\": 916403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 215.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 1265.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2266, \"PID\": 916403290, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2267, \"PID\": 916455010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 742.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1756, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 2268, \"PID\": 916455050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6718, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2269, \"PID\": 916455110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 82.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2270, \"PID\": 916455150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 886.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 593.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282000}, {\"Order\": 2271, \"PID\": 916460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2272, \"PID\": 916475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 808.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 252, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2273, \"PID\": 916477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 1340, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279900}, {\"Order\": 2274, \"PID\": 917425190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 35133, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 995.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 263, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 263, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186700}, {\"Order\": 2275, \"PID\": 921126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 15306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1652.0, \"TotalBsmtSF\": 1732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 283463}, {\"Order\": 2276, \"PID\": 921128030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 2277, \"PID\": 921205070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1094.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 1349, \"LowQualFinSF\": 0, \"GrLivArea\": 2482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 281213}, {\"Order\": 2278, \"PID\": 923202134, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 914.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 2279, \"PID\": 923202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 200.0, \"LotArea\": 43500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1041.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 561, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2280, \"PID\": 923203010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 6710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 904.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2281, \"PID\": 923204050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 25286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132250}, {\"Order\": 2282, \"PID\": 923204140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 25000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2283, \"PID\": 923205025, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 149.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1622, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 439, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2284, \"PID\": 923225040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 840.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2285, \"PID\": 923225050, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 874.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 536, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2286, \"PID\": 923226300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2287, \"PID\": 923228200, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 27.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 97, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 2288, \"PID\": 923228220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93900}, {\"Order\": 2289, \"PID\": 923228250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 2290, \"PID\": 923228290, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 131.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 499.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2291, \"PID\": 923228390, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 75190}, {\"Order\": 2292, \"PID\": 923229010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146800}, {\"Order\": 2293, \"PID\": 923229040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9129, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2294, \"PID\": 923229100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1356, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 1424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2295, \"PID\": 923229140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 33983, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1112.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1676, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 690, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2296, \"PID\": 923230010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 185.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2297, \"PID\": 923230120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 2298, \"PID\": 923230180, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 149.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2299, \"PID\": 923251160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 27697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"CBlock\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 811.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1608, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2300, \"PID\": 923252080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7599, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2301, \"PID\": 923275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1090.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 88, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2302, \"PID\": 923275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2303, \"PID\": 923276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 596.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 330, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2304, \"PID\": 923400150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 212.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 974.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 974, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 974, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93500}, {\"Order\": 2305, \"PID\": 923425030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 887, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2306, \"PID\": 526302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11027, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1178.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1293, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1293, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2307, \"PID\": 526302040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 280, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2308, \"PID\": 526302120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1127.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 963.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2309, \"PID\": 526303060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 39384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 902.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 252000}, {\"Order\": 2310, \"PID\": 526354020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11727, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 434.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1851.0, \"TotalBsmtSF\": 1851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1851, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192100}, {\"Order\": 2311, \"PID\": 527105060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8238, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2312, \"PID\": 527106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 964.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 1243, \"LowQualFinSF\": 0, \"GrLivArea\": 2236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2313, \"PID\": 527107020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 781, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2314, \"PID\": 527107030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13031, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 592.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2315, \"PID\": 527107120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 821.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 821, \"2ndFlrSF\": 955, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 443.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2316, \"PID\": 527107240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 714.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 413.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 95, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2317, \"PID\": 527108010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 19378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 2462, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2318, \"PID\": 527108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 14859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 27.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1670.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 240000}, {\"Order\": 2319, \"PID\": 527108030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 13128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 990, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2320, \"PID\": 527108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 893.0, \"TotalBsmtSF\": 893.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 2321, \"PID\": 527108060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 13751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1640.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 2212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 773.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 309000}, {\"Order\": 2322, \"PID\": 527108090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 168.0, \"LotArea\": 23257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2021, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 274725}, {\"Order\": 2323, \"PID\": 527146135, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2062.0, \"TotalBsmtSF\": 2062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2079, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2324, \"PID\": 527158020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8076, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2325, \"PID\": 527163020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165600}, {\"Order\": 2326, \"PID\": 527166030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 2327, \"PID\": 527182020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 3701, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2328, \"PID\": 527190050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 5306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 215.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 441, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2329, \"PID\": 527190220, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 28, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2330, \"PID\": 527210030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 1384, \"LowQualFinSF\": 0, \"GrLivArea\": 2798, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 37, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 457347}, {\"Order\": 2331, \"PID\": 527210040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 18062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 662.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 1862, \"LowQualFinSF\": 0, \"GrLivArea\": 3390, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 545224}, {\"Order\": 2332, \"PID\": 527210050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 205.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 889.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1371, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 246, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356383}, {\"Order\": 2333, \"PID\": 527212030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 16056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1752.0, \"TotalBsmtSF\": 1992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1992, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 2868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 716.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 556581}, {\"Order\": 2334, \"PID\": 527212040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 1312, \"LowQualFinSF\": 0, \"GrLivArea\": 2576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 361919}, {\"Order\": 2335, \"PID\": 527214060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 16052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 734.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 2698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 535000}, {\"Order\": 2336, \"PID\": 527216010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 15922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 550.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 1405, \"LowQualFinSF\": 0, \"GrLivArea\": 2795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 401179}, {\"Order\": 2337, \"PID\": 527216050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1031.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1410.0, \"TotalBsmtSF\": 1410.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 1519, \"LowQualFinSF\": 0, \"GrLivArea\": 2945, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 37, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 438780}, {\"Order\": 2338, \"PID\": 527226010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1547, \"2ndFlrSF\": 720, \"LowQualFinSF\": 53, \"GrLivArea\": 2320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2339, \"PID\": 527250040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 34650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2340, \"PID\": 527252090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 523.0, \"TotalBsmtSF\": 1714.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1714, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 2341, \"PID\": 527254070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11302, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Other\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1422.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1826, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319000}, {\"Order\": 2342, \"PID\": 527256120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 18261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 123, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 470000}, {\"Order\": 2343, \"PID\": 527301010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 995.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2344, \"PID\": 527302080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1002.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 2183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2345, \"PID\": 527325160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 34.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 795.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 250, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2346, \"PID\": 527327080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2347, \"PID\": 527328010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2348, \"PID\": 527354040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 604.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 2349, \"PID\": 527355060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1857, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188900}, {\"Order\": 2350, \"PID\": 527355280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 1061.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 384, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2351, \"PID\": 527356020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1392, \"LowQualFinSF\": 0, \"GrLivArea\": 2784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 440, \"PoolArea\": 519, \"PoolQC\": \"Fa\", \"Fence\": \"MnPrv\", \"MiscFeature\": \"TenC\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2352, \"PID\": 527356060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 811, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 208, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2353, \"PID\": 527358090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 42.0, \"TotalBsmtSF\": 1047.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1083, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1083, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 444, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2354, \"PID\": 527365010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1358, \"LowQualFinSF\": 0, \"GrLivArea\": 2318, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 246, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294323}, {\"Order\": 2355, \"PID\": 527375160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 127.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1109, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 485.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 2356, \"PID\": 527376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2357, \"PID\": 527376110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 2358, \"PID\": 527377030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 377.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1309, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1309, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 648, \"PoolQC\": \"Fa\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2359, \"PID\": 527378010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2360, \"PID\": 527402210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 75.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 791.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 138800}, {\"Order\": 2361, \"PID\": 527402380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9353, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 116050}, {\"Order\": 2362, \"PID\": 527403120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 614.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 2363, \"PID\": 527404180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 2364, \"PID\": 527427210, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 951.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1487.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2365, \"PID\": 527450010, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 514.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 2366, \"PID\": 527450080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2367, \"PID\": 527450210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 408.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83000}, {\"Order\": 2368, \"PID\": 527450460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 494, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2369, \"PID\": 527451200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 91500}, {\"Order\": 2370, \"PID\": 527451380, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2371, \"PID\": 527451450, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 465, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2372, \"PID\": 527451460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 382.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2373, \"PID\": 527451520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 297.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94500}, {\"Order\": 2374, \"PID\": 527452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 156.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146300}, {\"Order\": 2375, \"PID\": 527452290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 373.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1387, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2376, \"PID\": 527452310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 175, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2377, \"PID\": 527453070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2378, \"PID\": 527455100, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2379, \"PID\": 528102010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 66.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1447.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 770.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2380, \"PID\": 528102080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 16387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1738, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 2589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 412083}, {\"Order\": 2381, \"PID\": 528106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 111.0, \"LotArea\": 16259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 370.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1249.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1249, \"2ndFlrSF\": 1347, \"LowQualFinSF\": 0, \"GrLivArea\": 2596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 342643}, {\"Order\": 2382, \"PID\": 528106120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 16163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1618.0, \"TotalBsmtSF\": 1618.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1618, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1618, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 2383, \"PID\": 528110050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 690.0, \"TotalBsmtSF\": 2076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2076, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 229, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 465000}, {\"Order\": 2384, \"PID\": 528112010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 12228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1721.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293000}, {\"Order\": 2385, \"PID\": 528114010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 14780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1085.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 354, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2386, \"PID\": 528116030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 16033, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1261.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 519, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 326000}, {\"Order\": 2387, \"PID\": 528118010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 14215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1218, \"LowQualFinSF\": 0, \"GrLivArea\": 2376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 853.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325300}, {\"Order\": 2388, \"PID\": 528118020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 309000}, {\"Order\": 2389, \"PID\": 528118110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13975, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 300000}, {\"Order\": 2390, \"PID\": 528120110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1030.0, \"TotalBsmtSF\": 1030.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 1060, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 2391, \"PID\": 528120140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 385.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 466, \"LowQualFinSF\": 0, \"GrLivArea\": 2091, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338500}, {\"Order\": 2392, \"PID\": 528138030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345000}, {\"Order\": 2393, \"PID\": 528142010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 12867, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1209.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 344133}, {\"Order\": 2394, \"PID\": 528142060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 10672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 1335, \"LowQualFinSF\": 0, \"GrLivArea\": 2389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 298236}, {\"Order\": 2395, \"PID\": 528142070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 814, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 329900}, {\"Order\": 2396, \"PID\": 528142110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 1896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 708.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 2397, \"PID\": 528144030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11065, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 788.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 1085.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 753.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281000}, {\"Order\": 2398, \"PID\": 528150080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372397}, {\"Order\": 2399, \"PID\": 528150090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 131.0, \"LotArea\": 14828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 1780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378000}, {\"Order\": 2400, \"PID\": 528164040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 562.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 374000}, {\"Order\": 2401, \"PID\": 528170040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 20431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 870.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1848, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 2728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 437154}, {\"Order\": 2402, \"PID\": 528172020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 512.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 179, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2403, \"PID\": 528172150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 488, \"LowQualFinSF\": 0, \"GrLivArea\": 1914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2404, \"PID\": 528174080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 705.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185850}, {\"Order\": 2405, \"PID\": 528180080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 5911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282500}, {\"Order\": 2406, \"PID\": 528181030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6955, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202500}, {\"Order\": 2407, \"PID\": 528181040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 6792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202665}, {\"Order\": 2408, \"PID\": 528186100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 518.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 899.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 332200}, {\"Order\": 2409, \"PID\": 528186110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 572.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1251.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310090}, {\"Order\": 2410, \"PID\": 528188040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171750}, {\"Order\": 2411, \"PID\": 528218030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 23, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169990}, {\"Order\": 2412, \"PID\": 528218060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 170440}, {\"Order\": 2413, \"PID\": 528218080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169985}, {\"Order\": 2414, \"PID\": 528218130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 17104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 426.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179665}, {\"Order\": 2415, \"PID\": 528218140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 14054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 1863, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 219210}, {\"Order\": 2416, \"PID\": 528221010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 11660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1326.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 174190}, {\"Order\": 2417, \"PID\": 528221100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172785}, {\"Order\": 2418, \"PID\": 528222010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11631, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1052.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 1321, \"LowQualFinSF\": 0, \"GrLivArea\": 2373, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 258000}, {\"Order\": 2419, \"PID\": 528222020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185101}, {\"Order\": 2420, \"PID\": 528228280, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3087, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 767.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210250}, {\"Order\": 2421, \"PID\": 528228325, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1374.0, \"TotalBsmtSF\": 1374.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 2422, \"PID\": 528228340, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1273.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2423, \"PID\": 528228360, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1038.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246990}, {\"Order\": 2424, \"PID\": 528228415, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1375.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178740}, {\"Order\": 2425, \"PID\": 528228430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2426, \"PID\": 528228545, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167240}, {\"Order\": 2427, \"PID\": 528228550, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1126.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156820}, {\"Order\": 2428, \"PID\": 528228565, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213490}, {\"Order\": 2429, \"PID\": 528228575, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1154.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 1520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264561}, {\"Order\": 2430, \"PID\": 528228580, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246578}, {\"Order\": 2431, \"PID\": 528231050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 21930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192140}, {\"Order\": 2432, \"PID\": 528235050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7861, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183200}, {\"Order\": 2433, \"PID\": 528235130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2434, \"PID\": 528235190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1598, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201490}, {\"Order\": 2435, \"PID\": 528240080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1406.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1454, \"2ndFlrSF\": 482, \"LowQualFinSF\": 0, \"GrLivArea\": 1936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 2436, \"PID\": 528250060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2437, \"PID\": 528275060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8121, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 711, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172400}, {\"Order\": 2438, \"PID\": 528275080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2439, \"PID\": 528280100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 930, \"LowQualFinSF\": 0, \"GrLivArea\": 1886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 89, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199900}, {\"Order\": 2440, \"PID\": 528290140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 959.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 2441, \"PID\": 528292080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287602}, {\"Order\": 2442, \"PID\": 528294070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 1286, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2443, \"PID\": 528315030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1074.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1407, \"2ndFlrSF\": 985, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 348000}, {\"Order\": 2444, \"PID\": 528315070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 31, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 2445, \"PID\": 528315080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 322.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 655.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1205, \"2ndFlrSF\": 1029, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2446, \"PID\": 528320060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 35760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1831, \"2ndFlrSF\": 1796, \"LowQualFinSF\": 0, \"GrLivArea\": 3627, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 807.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 361, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 625000}, {\"Order\": 2447, \"PID\": 528327010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9233, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 877.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 358.0, \"TotalBsmtSF\": 1540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1540, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2855, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 247, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 405000}, {\"Order\": 2448, \"PID\": 528344060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 530.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 374, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2449, \"PID\": 528348010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 258000}, {\"Order\": 2450, \"PID\": 528358030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 397.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 1368, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 169, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 2451, \"PID\": 528360050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 17242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 738.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1393.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1733.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1933, \"2ndFlrSF\": 1567, \"LowQualFinSF\": 0, \"GrLivArea\": 3500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 959.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 870, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 584500}, {\"Order\": 2452, \"PID\": 528363070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 501.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1305, \"2ndFlrSF\": 1189, \"LowQualFinSF\": 0, \"GrLivArea\": 2494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 803.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 321000}, {\"Order\": 2453, \"PID\": 528365090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 391.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1203, \"2ndFlrSF\": 1323, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 309, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 2454, \"PID\": 528366040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1039.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 1234, \"LowQualFinSF\": 0, \"GrLivArea\": 2799, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 432, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2455, \"PID\": 528429060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 760.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252000}, {\"Order\": 2456, \"PID\": 528429100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1562.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336820}, {\"Order\": 2457, \"PID\": 528429120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 20896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1721.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 2077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1134.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 267, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 423000}, {\"Order\": 2458, \"PID\": 528429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290000}, {\"Order\": 2459, \"PID\": 528439030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1616.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 2460, \"PID\": 528445010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1504.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199000}, {\"Order\": 2461, \"PID\": 528456200, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1254.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 584.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198600}, {\"Order\": 2462, \"PID\": 528477010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 13162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 2036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 405749}, {\"Order\": 2463, \"PID\": 528477030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 11216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 232600}, {\"Order\": 2464, \"PID\": 528480070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1053.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 266000}, {\"Order\": 2465, \"PID\": 528480100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186500}, {\"Order\": 2466, \"PID\": 528480110, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200825}, {\"Order\": 2467, \"PID\": 528480150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 798, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 197000}, {\"Order\": 2468, \"PID\": 528488110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 905.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185000}, {\"Order\": 2469, \"PID\": 528488120, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2470, \"PID\": 528488130, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1293.0, \"TotalBsmtSF\": 1293.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187750}, {\"Order\": 2471, \"PID\": 531363080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1118.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 4, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2472, \"PID\": 531367010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 118.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1400.0, \"TotalBsmtSF\": 1400.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1400, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186800}, {\"Order\": 2473, \"PID\": 531375060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1131.0, \"TotalBsmtSF\": 1131.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 132000}, {\"Order\": 2474, \"PID\": 531375070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2475, \"PID\": 531375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 158000}, {\"Order\": 2476, \"PID\": 531376030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 891.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 891, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 2477, \"PID\": 531376050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1585, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 449.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 2478, \"PID\": 531379030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1837, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 688.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2479, \"PID\": 531450040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 761.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2480, \"PID\": 531451290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1731, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3000, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 248500}, {\"Order\": 2481, \"PID\": 531452080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1398, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2482, \"PID\": 531452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 278.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 1217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2483, \"PID\": 531452210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 362.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 636, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2484, \"PID\": 531478010, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 8900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107000}, {\"Order\": 2485, \"PID\": 531479030, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2486, \"PID\": 532351060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2487, \"PID\": 532351090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1332.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2488, \"PID\": 532351150, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1286, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2489, \"PID\": 532353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2490, \"PID\": 532353180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 8471, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 46.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 506.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2491, \"PID\": 532376080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2492, \"PID\": 532376180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2493, \"PID\": 532376250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2494, \"PID\": 532378050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120875}, {\"Order\": 2495, \"PID\": 532378070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 375.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 935, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2496, \"PID\": 532378130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2497, \"PID\": 532378160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 465.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 447.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2498, \"PID\": 532378220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8789, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129200}, {\"Order\": 2499, \"PID\": 532476050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 497.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1748.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2151, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 4, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 641, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 800, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2500, \"PID\": 533110130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 16059, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2417, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2501, \"PID\": 533125120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 692.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1118.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 208, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 2502, \"PID\": 533127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 310000}, {\"Order\": 2503, \"PID\": 533128030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13346, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 1129, \"LowQualFinSF\": 0, \"GrLivArea\": 2295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 2504, \"PID\": 533128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"ImStucc\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 757.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262000}, {\"Order\": 2505, \"PID\": 533206040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3628, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176400}, {\"Order\": 2506, \"PID\": 533208050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3316, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1247.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1247, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1247, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2507, \"PID\": 533212100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2508, \"PID\": 533212110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147400}, {\"Order\": 2509, \"PID\": 533212120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2510, \"PID\": 533212130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 144152}, {\"Order\": 2511, \"PID\": 533221080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 2512, \"PID\": 533223010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 241.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183900}, {\"Order\": 2513, \"PID\": 533223080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 673, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 153, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2514, \"PID\": 533223110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2515, \"PID\": 533241010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 114.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 382, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2516, \"PID\": 533242030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 2517, \"PID\": 533250130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 9549, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1057.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2518, \"PID\": 533252020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2519, \"PID\": 533253030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1009.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 44.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2520, \"PID\": 533253050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 3640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2521, \"PID\": 533253090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3874, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 807.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 419.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2522, \"PID\": 533253160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 526.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2523, \"PID\": 533350050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 50271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 1842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1842, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 857, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 385000}, {\"Order\": 2524, \"PID\": 534125210, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 13110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2525, \"PID\": 534126060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 10192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2526, \"PID\": 534127190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 1203.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2156, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2156, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 290, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 2527, \"PID\": 534127270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 404.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 708.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 708, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 119, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2528, \"PID\": 534128210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 435.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 222, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2529, \"PID\": 534129230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165150}, {\"Order\": 2530, \"PID\": 534175100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 264, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164500}, {\"Order\": 2531, \"PID\": 534176250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1164.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2532, \"PID\": 534201130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2533, \"PID\": 534201230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2534, \"PID\": 534201250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1770, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 270, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 455, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2535, \"PID\": 534201260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 94, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157500}, {\"Order\": 2536, \"PID\": 534201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 2537, \"PID\": 534201300, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2538, \"PID\": 534202020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124400}, {\"Order\": 2539, \"PID\": 534202180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 402.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 568.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2540, \"PID\": 534226060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 661.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2541, \"PID\": 534250300, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1993, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2542, \"PID\": 534275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 319, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2543, \"PID\": 534276010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2544, \"PID\": 534276230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1098.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 145000}, {\"Order\": 2545, \"PID\": 534400120, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 34.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 25, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 460, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185900}, {\"Order\": 2546, \"PID\": 534403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2547, \"PID\": 534403400, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 748.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2548, \"PID\": 534403440, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2549, \"PID\": 534427090, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2550, \"PID\": 534428060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 8973, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 28.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2551, \"PID\": 534429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 2552, \"PID\": 534430050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129800}, {\"Order\": 2553, \"PID\": 534430110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2554, \"PID\": 534431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1043, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1043, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2555, \"PID\": 534451050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 4712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 456, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 63, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 121600}, {\"Order\": 2556, \"PID\": 534451120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 5900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2557, \"PID\": 534451130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 5825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79900}, {\"Order\": 2558, \"PID\": 534453150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 7438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 316, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2559, \"PID\": 534455080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2560, \"PID\": 534475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1404.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 324, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 146500}, {\"Order\": 2561, \"PID\": 534476100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2562, \"PID\": 534477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 756.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1380.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 2136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 2563, \"PID\": 534479130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 165.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 958, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2564, \"PID\": 534479240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2565, \"PID\": 534479300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2566, \"PID\": 535101110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2567, \"PID\": 535103070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 939.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 307.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2568, \"PID\": 535105160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98600}, {\"Order\": 2569, \"PID\": 535125060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 2157, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2570, \"PID\": 535150240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 118000}, {\"Order\": 2571, \"PID\": 535150300, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 25419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 4, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 184.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 1360, \"LowQualFinSF\": 392, \"GrLivArea\": 3112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 552, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 512, \"PoolQC\": \"Ex\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 235000}, {\"Order\": 2572, \"PID\": 535151080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 9723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 332.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2573, \"PID\": 535151130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 303.0, \"TotalBsmtSF\": 1106.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2574, \"PID\": 535152070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 86, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2575, \"PID\": 535152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2576, \"PID\": 535176050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 175.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145250}, {\"Order\": 2577, \"PID\": 535177100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9610, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 2578, \"PID\": 535178100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 281.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 191, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2579, \"PID\": 535179050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 14850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 895.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 122, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2580, \"PID\": 535180020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 914.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 353.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 2581, \"PID\": 535180070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 64.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134450}, {\"Order\": 2582, \"PID\": 535301010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 943.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135960}, {\"Order\": 2583, \"PID\": 535301150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8092, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 156000}, {\"Order\": 2584, \"PID\": 535303050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1367.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2585, \"PID\": 535304020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2586, \"PID\": 535305120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 522.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2587, \"PID\": 535325130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 301.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2588, \"PID\": 535325340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 488.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 517.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2589, \"PID\": 535325350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 912.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2590, \"PID\": 535325450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2591, \"PID\": 535325460, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 21299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 929.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 791.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2592, \"PID\": 535327210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 521.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 75, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 323, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2593, \"PID\": 535353180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 22136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1153.0, \"TotalBsmtSF\": 2171.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1248, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1008.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 631, \"OpenPorchSF\": 48, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2594, \"PID\": 535354130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 900, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2595, \"PID\": 535355100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 865, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2596, \"PID\": 535375040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 713, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 161, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99800}, {\"Order\": 2597, \"PID\": 535376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 418.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2598, \"PID\": 535376100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1073.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108480}, {\"Order\": 2599, \"PID\": 535377070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 715, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 75, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68000}, {\"Order\": 2600, \"PID\": 535377100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 448, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 2601, \"PID\": 535379100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1130, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 229, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2602, \"PID\": 535380010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 821, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155500}, {\"Order\": 2603, \"PID\": 535380130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10818, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 981, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2604, \"PID\": 535381060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 105000}, {\"Order\": 2605, \"PID\": 535382020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 2414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2606, \"PID\": 535382130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1936, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 370, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 436, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2607, \"PID\": 535401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 445.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 2608, \"PID\": 535402070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1047.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159950}, {\"Order\": 2609, \"PID\": 535402100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 379.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1083.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 345, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2610, \"PID\": 535402220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 128, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2611, \"PID\": 535402230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 701.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1135.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1207, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 2612, \"PID\": 535403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 600.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2613, \"PID\": 535403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 8910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 655.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2614, \"PID\": 535403200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 207.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 2615, \"PID\": 535404080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 7100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2616, \"PID\": 535425040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1773, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 2617, \"PID\": 535425050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2618, \"PID\": 535425080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 802.0, \"TotalBsmtSF\": 1438.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1900, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 520, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 2619, \"PID\": 535426195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 16321, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1277.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 258, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2620, \"PID\": 535450100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 597.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 2621, \"PID\": 535450180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 2622, \"PID\": 535451190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 2623, \"PID\": 535451210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2624, \"PID\": 535453160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133700}, {\"Order\": 2625, \"PID\": 535454030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81400}, {\"Order\": 2626, \"PID\": 535454050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 2627, \"PID\": 535454060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2628, \"PID\": 535456010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1556.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1556, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2629, \"PID\": 535456020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 179.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 506.0, \"BsmtUnfSF\": 465.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2630, \"PID\": 535457070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 162, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2631, \"PID\": 535477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2632, \"PID\": 535478010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 10205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2633, \"PID\": 535478070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 809.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 236.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2634, \"PID\": 535478090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2635, \"PID\": 535478110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 953.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 1025.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2636, \"PID\": 902100110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 9856, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 1007, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 167, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2637, \"PID\": 902100130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9906, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 518, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 107000}, {\"Order\": 2638, \"PID\": 902101050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2639, \"PID\": 902103090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 863.0, \"TotalBsmtSF\": 1147.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1147, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2640, \"PID\": 902104020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 476, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2641, \"PID\": 902106040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2642, \"PID\": 902106090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6451, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 208.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 2643, \"PID\": 902108060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 66.0, \"LotArea\": 3960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 502.0, \"TotalBsmtSF\": 502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 502, \"2ndFlrSF\": 502, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2644, \"PID\": 902109010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 813, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 813, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2645, \"PID\": 902110120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7745, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 867, \"LowQualFinSF\": 0, \"GrLivArea\": 1951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 6, \"EnclosedPorch\": 28, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2646, \"PID\": 902110130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7741, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 143.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 2647, \"PID\": 902111010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5633, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 81, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2648, \"PID\": 902125020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1880, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 661, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 293, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 2649, \"PID\": 902128020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2650, \"PID\": 902128100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 648.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 734, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2651, \"PID\": 902134060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 7614, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1905, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 714, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 104, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96900}, {\"Order\": 2652, \"PID\": 902204060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2653, \"PID\": 902204120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 296, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2654, \"PID\": 902206020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2655, \"PID\": 902206090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 297, \"LowQualFinSF\": 0, \"GrLivArea\": 1182, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 378.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2656, \"PID\": 902207080, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 5820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 906.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1163, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126175}, {\"Order\": 2657, \"PID\": 902207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 48.0, \"LotArea\": 5747, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 2658, \"PID\": 902301120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 908, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2659, \"PID\": 902305090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 2, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 679, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2660, \"PID\": 902325050, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 2661, \"PID\": 902325100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2104, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2662, \"PID\": 902325160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 889, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2663, \"PID\": 902328100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 815.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 815, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 330, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2664, \"PID\": 902329070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 684, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114504}, {\"Order\": 2665, \"PID\": 902329090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 998, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 0, \"EnclosedPorch\": 221, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2666, \"PID\": 902400090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 84.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1200.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 125000}, {\"Order\": 2667, \"PID\": 902400110, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 22950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1892, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1107.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 1518, \"LowQualFinSF\": 572, \"GrLivArea\": 3608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 260, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 410, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 475000}, {\"Order\": 2668, \"PID\": 902401090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 5976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 624, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 256, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2669, \"PID\": 902406030, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 4500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2670, \"PID\": 902456015, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 63.0, \"LotArea\": 4761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 2671, \"PID\": 903200050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7446, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 2672, \"PID\": 903202120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 605, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140200}, {\"Order\": 2673, \"PID\": 903206160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1017, \"2ndFlrSF\": 810, \"LowQualFinSF\": 0, \"GrLivArea\": 1827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1943.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 27, \"OpenPorchSF\": 36, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2674, \"PID\": 903225090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2675, \"PID\": 903229040, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 325, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 271, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2676, \"PID\": 903231070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 2677, \"PID\": 903231190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2678, \"PID\": 903231220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 347.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 434, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 258.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 75000}, {\"Order\": 2679, \"PID\": 903231240, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1015, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1015, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 620, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 88000}, {\"Order\": 2680, \"PID\": 903232170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80500}, {\"Order\": 2681, \"PID\": 903233100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1042.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 149000}, {\"Order\": 2682, \"PID\": 903233220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 583, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2683, \"PID\": 903234030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 2684, \"PID\": 903235020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 129, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2685, \"PID\": 903236200, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 993.0, \"TotalBsmtSF\": 993.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2686, \"PID\": 903400030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 11672, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 2687, \"PID\": 903425190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 33120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2688, \"PID\": 903425340, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9873, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 288, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2689, \"PID\": 903430090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 634, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 255.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 394, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2690, \"PID\": 903430130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 153.0, \"LotArea\": 4118, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 693.0, \"TotalBsmtSF\": 693.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 693, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 693, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52500}, {\"Order\": 2691, \"PID\": 903451050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 834, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 2692, \"PID\": 903452090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 665, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 2693, \"PID\": 903454020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 819, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 819, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 72000}, {\"Order\": 2694, \"PID\": 903454080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 198.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2695, \"PID\": 903455090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 803.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 803, \"2ndFlrSF\": 557, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2696, \"PID\": 903456060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1007.0, \"TotalBsmtSF\": 1007.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 2697, \"PID\": 903456090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 234, \"GrLivArea\": 754, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 53, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2698, \"PID\": 903458010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2699, \"PID\": 904100030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 477.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 341, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2700, \"PID\": 904100090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 11136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1921.0, \"TotalBsmtSF\": 1921.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1921, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1921, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2701, \"PID\": 904100170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 225, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2702, \"PID\": 904101040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 6930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 294, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 2703, \"PID\": 904301410, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2704, \"PID\": 904302020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 830.0, \"TotalBsmtSF\": 830.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2705, \"PID\": 904302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 373.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2706, \"PID\": 905100030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 459.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2707, \"PID\": 905101330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 2708, \"PID\": 905101450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154500}, {\"Order\": 2709, \"PID\": 905103130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153600}, {\"Order\": 2710, \"PID\": 905103140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 97.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 328.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 68, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 164500}, {\"Order\": 2711, \"PID\": 905103180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 934, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 934, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 77, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2712, \"PID\": 905105010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1059, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1059, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2713, \"PID\": 905106210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11553, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1159, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 466, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2714, \"PID\": 905107070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 463.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 2715, \"PID\": 905107220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 982.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1458, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2716, \"PID\": 905107240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2717, \"PID\": 905107300, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 794.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 2718, \"PID\": 905108090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9662, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1967.0, \"TotalBsmtSF\": 1967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2719, \"PID\": 905108120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1466.0, \"TotalBsmtSF\": 1949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2720, \"PID\": 905200280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 441.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 2721, \"PID\": 905200290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 682.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2722, \"PID\": 905200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 17920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1085.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 418, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 312, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 2723, \"PID\": 905200380, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2724, \"PID\": 905200490, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1965, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2725, \"PID\": 905201090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 304, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2726, \"PID\": 905202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 826.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 1865.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1830, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 115, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 2727, \"PID\": 905202210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 13050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 850.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2728, \"PID\": 905225080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 15593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 701.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1304, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 667.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2729, \"PID\": 905300010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2730, \"PID\": 905300080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 241, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2731, \"PID\": 905351045, \"MSSubClass\": 150, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 1700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 33.0, \"TotalBsmtSF\": 430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 680, \"LowQualFinSF\": 140, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148400}, {\"Order\": 2732, \"PID\": 905351150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 445.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 190000}, {\"Order\": 2733, \"PID\": 905402110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2734, \"PID\": 905403050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 6488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 799, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 128000}, {\"Order\": 2735, \"PID\": 905426100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 103, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2736, \"PID\": 905426150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 626, \"LowQualFinSF\": 0, \"GrLivArea\": 2201, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 586, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 738, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 274970}, {\"Order\": 2737, \"PID\": 905427010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 19950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2738, \"PID\": 905427030, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 19800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1411.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 1836, \"LowQualFinSF\": 0, \"GrLivArea\": 3672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 684, \"OpenPorchSF\": 80, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2739, \"PID\": 905427140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11679, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1164.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 453, \"OpenPorchSF\": 253, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2740, \"PID\": 905451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 348, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2741, \"PID\": 905451410, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10519, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1057.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2742, \"PID\": 905452140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 325.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136900}, {\"Order\": 2743, \"PID\": 905452150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 532.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 541, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2744, \"PID\": 905475150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 6420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 2745, \"PID\": 905477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 2746, \"PID\": 905480160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 454, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91500}, {\"Order\": 2747, \"PID\": 906202040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 40.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2748, \"PID\": 906204180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1246, \"LowQualFinSF\": 0, \"GrLivArea\": 2559, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 245, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 209000}, {\"Order\": 2749, \"PID\": 906223180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9554, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1911, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2750, \"PID\": 906225180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 261.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1083.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 2751, \"PID\": 906380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 133.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1308.0, \"TotalBsmtSF\": 1308.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 848.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229800}, {\"Order\": 2752, \"PID\": 906380150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 393.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 183600}, {\"Order\": 2753, \"PID\": 906380170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7406, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 515.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 2754, \"PID\": 906380180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193879}, {\"Order\": 2755, \"PID\": 906382030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221500}, {\"Order\": 2756, \"PID\": 906382040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204900}, {\"Order\": 2757, \"PID\": 906382050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 571, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239799}, {\"Order\": 2758, \"PID\": 906392090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13377, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 260.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233555}, {\"Order\": 2759, \"PID\": 906392100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2760, \"PID\": 906392120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1122.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 1570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1590, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294900}, {\"Order\": 2761, \"PID\": 906394010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1809, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 209700}, {\"Order\": 2762, \"PID\": 906394040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1558.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2763, \"PID\": 906394060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 532.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2764, \"PID\": 906420020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 119.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 927, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1915, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 2765, \"PID\": 906426090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 36500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 812.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 198, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2766, \"PID\": 906475050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Metal\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 130, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2767, \"PID\": 906475200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 70761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 1533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1533, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2768, \"PID\": 906476140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 853.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 535.0, \"TotalBsmtSF\": 1388.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1388, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 2769, \"PID\": 907125020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2770, \"PID\": 907125080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2771, \"PID\": 907130110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 795, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 413, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2772, \"PID\": 907131070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 579.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 2773, \"PID\": 907135230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 13568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 274.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2774, \"PID\": 907175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2775, \"PID\": 907175060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2776, \"PID\": 907180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2777, \"PID\": 907181090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9272, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1749, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2778, \"PID\": 907187010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 13426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 57.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 107, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2779, \"PID\": 907192010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2780, \"PID\": 907194130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 2781, \"PID\": 907196020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1541.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 468, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 2782, \"PID\": 907200170, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 428.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2783, \"PID\": 907201160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 62.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 317.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2784, \"PID\": 907201230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2785, \"PID\": 907202140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 971.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 971, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2786, \"PID\": 907203010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 9560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2787, \"PID\": 907203040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 149900}, {\"Order\": 2788, \"PID\": 907227090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2789, \"PID\": 907230240, \"MSSubClass\": 160, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 3612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Landmrk\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2790, \"PID\": 907251100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 1989, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2791, \"PID\": 907252050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 199.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 826.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2792, \"PID\": 907254050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 9468, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2793, \"PID\": 907255010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2794, \"PID\": 907255050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1787, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1787, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2795, \"PID\": 907262080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8726, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 1909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2796, \"PID\": 907265030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 668.0, \"TotalBsmtSF\": 1654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1654, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2797, \"PID\": 907270050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10566, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 1124, \"LowQualFinSF\": 0, \"GrLivArea\": 2214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 646.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268500}, {\"Order\": 2798, \"PID\": 907275030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210900}, {\"Order\": 2799, \"PID\": 907285010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 258.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1070, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 2800, \"PID\": 907285100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 1045, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 2801, \"PID\": 907290020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 989, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274300}, {\"Order\": 2802, \"PID\": 907290080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216837}, {\"Order\": 2803, \"PID\": 907290160, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2804, \"PID\": 907290230, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155900}, {\"Order\": 2805, \"PID\": 907290260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1079.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 685.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233230}, {\"Order\": 2806, \"PID\": 907401050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2807, \"PID\": 907401080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2808, \"PID\": 907405030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2809, \"PID\": 907410040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8581, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203160}, {\"Order\": 2810, \"PID\": 907410100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 827, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195800}, {\"Order\": 2811, \"PID\": 907410110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212900}, {\"Order\": 2812, \"PID\": 907412010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2813, \"PID\": 907414040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198000}, {\"Order\": 2814, \"PID\": 907418020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 750, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173900}, {\"Order\": 2815, \"PID\": 907420070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 163990}, {\"Order\": 2816, \"PID\": 907420090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164990}, {\"Order\": 2817, \"PID\": 908102020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 337.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 420, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 2818, \"PID\": 908102320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 17755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2819, \"PID\": 908102330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2820, \"PID\": 908103310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 7840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 355.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2821, \"PID\": 908103320, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2822, \"PID\": 908127050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 16133, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2823, \"PID\": 908128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2824, \"PID\": 908130020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 475.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 297.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117250}, {\"Order\": 2825, \"PID\": 908178050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1150.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1150, \"LowQualFinSF\": 0, \"GrLivArea\": 2314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2826, \"PID\": 908186060, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2827, \"PID\": 908186070, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 140000}, {\"Order\": 2828, \"PID\": 908186090, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 142500}, {\"Order\": 2829, \"PID\": 908188110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2830, \"PID\": 908188120, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2831, \"PID\": 908188130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2832, \"PID\": 908188140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2833, \"PID\": 908188150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 3363, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 976.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2834, \"PID\": 908225180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6956, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 312, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 265.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97900}, {\"Order\": 2835, \"PID\": 908227010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 846, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 92000}, {\"Order\": 2836, \"PID\": 908227030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1669, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 107000}, {\"Order\": 2837, \"PID\": 908227040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 658.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 658, \"2ndFlrSF\": 526, \"LowQualFinSF\": 0, \"GrLivArea\": 1184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 81000}, {\"Order\": 2838, \"PID\": 908228040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 2839, \"PID\": 908275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 167.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2840, \"PID\": 908275290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 16012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 691.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 609.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2841, \"PID\": 909101050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 207, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2842, \"PID\": 909101080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 450, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 2843, \"PID\": 909101190, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 795.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 795, \"LowQualFinSF\": 481, \"GrLivArea\": 2230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2844, \"PID\": 909101330, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8088, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1922, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 35000}, {\"Order\": 2845, \"PID\": 909103020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 218, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2846, \"PID\": 909131125, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 7082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 980, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2847, \"PID\": 909175030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1192, \"2ndFlrSF\": 403, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2848, \"PID\": 909176180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 128.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 493, \"LowQualFinSF\": 0, \"GrLivArea\": 1551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2849, \"PID\": 909201180, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 58.0, \"LotArea\": 6430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 816, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128000}, {\"Order\": 2850, \"PID\": 909250070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 424.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 743, \"2ndFlrSF\": 736, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 530, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2851, \"PID\": 909250120, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 892, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138887}, {\"Order\": 2852, \"PID\": 909250200, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 4899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 2853, \"PID\": 909250210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 514, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2854, \"PID\": 909253080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9399, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 818, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1919.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2855, \"PID\": 909254070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 901, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200100}, {\"Order\": 2856, \"PID\": 909256010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10164, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2857, \"PID\": 909256020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2858, \"PID\": 909275230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 272, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2859, \"PID\": 909275250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 940, \"2ndFlrSF\": 610, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 429, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2860, \"PID\": 909276010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 725, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2861, \"PID\": 909276070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 113, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2862, \"PID\": 909279040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 67, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2863, \"PID\": 909280030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2864, \"PID\": 909280070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 8170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 526.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 549, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 2865, \"PID\": 909281010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1175, \"LowQualFinSF\": 0, \"GrLivArea\": 2345, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2866, \"PID\": 909282060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 104, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 2867, \"PID\": 909282110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 14210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 697, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 365.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2868, \"PID\": 909425120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 296.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 547.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1811, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 230000}, {\"Order\": 2869, \"PID\": 909425180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 459.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1283.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2870, \"PID\": 909426060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 405.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2871, \"PID\": 909428110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 375.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2872, \"PID\": 909475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 734.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 2873, \"PID\": 910200020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 102000}, {\"Order\": 2874, \"PID\": 910200060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 132, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145400}, {\"Order\": 2875, \"PID\": 910203100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 61.0, \"LotArea\": 8534, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72000}, {\"Order\": 2876, \"PID\": 910203230, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 272.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 2877, \"PID\": 910207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8765, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 327.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 106500}, {\"Order\": 2878, \"PID\": 910226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 327.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2879, \"PID\": 911175360, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 439, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 47, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2880, \"PID\": 911175410, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 69.0, \"LotArea\": 12366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 23, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 51689}, {\"Order\": 2881, \"PID\": 911175430, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 35311}, {\"Order\": 2882, \"PID\": 911175440, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2883, \"PID\": 911225110, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 360, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 2884, \"PID\": 911370430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5748, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1778, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2885, \"PID\": 911370530, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2886, \"PID\": 913350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 23580, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242500}, {\"Order\": 2887, \"PID\": 914452060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1664.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2888, \"PID\": 914474020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9116, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 2889, \"PID\": 914476050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2890, \"PID\": 914476130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 11080, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 257.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2891, \"PID\": 914476500, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1907.0, \"TotalBsmtSF\": 1907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1959, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 766.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 171000}, {\"Order\": 2892, \"PID\": 916225130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 26178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 293.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1210.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 1281, \"LowQualFinSF\": 0, \"GrLivArea\": 2519, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 2893, \"PID\": 916252170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2894, \"PID\": 916325040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 50102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 909.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1650, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 250764}, {\"Order\": 2895, \"PID\": 916326010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 653.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1686.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 574, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2896, \"PID\": 916402125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 13811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2897, \"PID\": 916403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1309.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2898, \"PID\": 916403130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2514, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 693.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2899, \"PID\": 916460070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1136.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 129.0, \"TotalBsmtSF\": 1381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2900, \"PID\": 916475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 630.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 2901, \"PID\": 916477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13618, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2902, \"PID\": 921205030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11443, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2028, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 326, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 369900}, {\"Order\": 2903, \"PID\": 921205050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 382.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 225, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 359900}, {\"Order\": 2904, \"PID\": 923125030, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 125.0, \"LotArea\": 31250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81500}, {\"Order\": 2905, \"PID\": 923202025, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1243.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 45.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2906, \"PID\": 923203090, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 897.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 125, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2907, \"PID\": 923203100, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 443.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 405.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 199, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2908, \"PID\": 923205120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 17217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84500}, {\"Order\": 2909, \"PID\": 923225190, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2910, \"PID\": 923225240, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 173.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 757.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2911, \"PID\": 923225260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 3964, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 837.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 1230, \"LowQualFinSF\": 0, \"GrLivArea\": 2521, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 728, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151400}, {\"Order\": 2912, \"PID\": 923225510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 2913, \"PID\": 923226150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1503.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2914, \"PID\": 923226180, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 2915, \"PID\": 923226290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79400}, {\"Order\": 2916, \"PID\": 923227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2917, \"PID\": 923228130, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 92000}, {\"Order\": 2918, \"PID\": 923228180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 87550}, {\"Order\": 2919, \"PID\": 923228210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 2920, \"PID\": 923228260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90500}, {\"Order\": 2921, \"PID\": 923228310, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1894, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 71000}, {\"Order\": 2922, \"PID\": 923229110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 12640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 396.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150900}, {\"Order\": 2923, \"PID\": 923230040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9297, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 188000}, {\"Order\": 2924, \"PID\": 923250060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2925, \"PID\": 923251180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 20000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 131000}, {\"Order\": 2926, \"PID\": 923275080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 7937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1003.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1003, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1003, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2927, \"PID\": 923276100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 324.0, \"BsmtUnfSF\": 239.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2928, \"PID\": 923400125, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2929, \"PID\": 924100070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1071.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 123.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1389, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2930, \"PID\": 924151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 1004, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "selection = alt.selection_point(fields=['KitchenQual'], bind='legend')\n",
        "\n",
        "alt.Chart(train).mark_circle().encode(\n",
        "    alt.X('GrLivArea', scale=alt.Scale(zero=False)),\n",
        "    alt.Y('GarageArea', scale=alt.Scale(zero=False, padding=1)),\n",
        "    color='KitchenQual',\n",
        "    size=alt.Size('SalePrice', bin=alt.Bin(maxbins=10), title='SalePrice'),\n",
        "    opacity=alt.condition(selection, alt.value(1), alt.value(0.2)),\n",
        "    tooltip=['GrLivArea', 'SalePrice']\n",
        ").properties(\n",
        "    width=500,\n",
        "    height=500\n",
        ").add_params(\n",
        "    selection\n",
        ").configure_axis(\n",
        "    grid=False\n",
        ").interactive()"
      ],
      "id": "cell-21"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Scatter Matrix\n",
        "\n",
        "Scatter matrix are one of the most common graph you’ll see on Kaggle. It\n",
        "consists of several **pair-wise scatter plots** of variables presented\n",
        "in a **matrix format**, useful to visualize **multiple relationships**\n",
        "between a pair of variables.\n",
        "\n",
        "In Altair this can be achieved using a RepeatChart, let’s see how!"
      ],
      "id": "1180e005-2d2b-4726-aab6-5c2f98ff672a"
    },
    {
      "cell_type": "code",
      "execution_count": 23,
      "metadata": {
        "cell_id": "c41abc74f1f7409497e79e79ad353194",
        "deepnote_cell_type": "code",
        "deepnote_to_be_reexecuted": false,
        "execution_millis": 1237,
        "execution_start": 1685107271924,
        "papermill": {
          "duration": 0.751793,
          "end_time": "2023-01-11T23:38:35.982231",
          "exception": false,
          "start_time": "2023-01-11T23:38:35.230438",
          "status": "completed"
        },
        "source_hash": "6db498ba",
        "tags": []
      },
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-1be40bfe15e34110944bffba5c59f280.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-1be40bfe15e34110944bffba5c59f280.vega-embed details,\n",
              "  #altair-viz-1be40bfe15e34110944bffba5c59f280.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-1be40bfe15e34110944bffba5c59f280\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-1be40bfe15e34110944bffba5c59f280\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-1be40bfe15e34110944bffba5c59f280\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}, \"axis\": {\"grid\": false}}, \"repeat\": {\"column\": [\"TotalBsmtSF\", \"GarageArea\", \"GrLivArea\"], \"row\": [\"GrLivArea\", \"GarageArea\", \"TotalBsmtSF\"]}, \"spec\": {\"data\": {\"name\": \"data-bd4440f2bd659840503c9701cdb81363\"}, \"mark\": {\"type\": \"circle\"}, \"encoding\": {\"color\": {\"field\": \"KitchenQual\", \"type\": \"nominal\"}, \"x\": {\"field\": {\"repeat\": \"column\"}, \"type\": \"quantitative\"}, \"y\": {\"field\": {\"repeat\": \"row\"}, \"type\": \"quantitative\"}}, \"height\": 300, \"width\": 300}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-bd4440f2bd659840503c9701cdb81363\": [{\"Order\": 1, \"PID\": 526301100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 141.0, \"LotArea\": 31770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2, \"PID\": 526350040, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 80.0, \"LotArea\": 11622, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 3, \"PID\": 526351010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 393, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 12500, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 4, \"PID\": 526353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1045.0, \"TotalBsmtSF\": 2110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 5, \"PID\": 527105010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189900}, {\"Order\": 6, \"PID\": 527105030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 7, \"PID\": 527127150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 8, \"PID\": 527145080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 263.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191500}, {\"Order\": 9, \"PID\": 527146030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1180.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 10, \"PID\": 527162130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 776, \"LowQualFinSF\": 0, \"GrLivArea\": 1804, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 11, \"PID\": 527163010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 763, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1655, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 157, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 12, \"PID\": 527165230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1992, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 935.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 233.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 13, \"PID\": 527166040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180400}, {\"Order\": 14, \"PID\": 527180040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 15, \"PID\": 527182190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 1120.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 16, \"PID\": 527216070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 53504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 603.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1690, \"2ndFlrSF\": 1589, \"LowQualFinSF\": 0, \"GrLivArea\": 3279, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 841.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 503, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 538000}, {\"Order\": 17, \"PID\": 527225035, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 152.0, \"LotArea\": 12134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1988, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 427.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 325, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 18, \"PID\": 527258010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 2, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 1856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394432}, {\"Order\": 19, \"PID\": 527276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 19138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 20, \"PID\": 527302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 163.0, \"BsmtUnfSF\": 589.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 21, \"PID\": 527358140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 22, \"PID\": 527358200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 81.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 885.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1173, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 170000}, {\"Order\": 23, \"PID\": 527368020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 814, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 24, \"PID\": 527402200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11241, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 25, \"PID\": 527402250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12537, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 26, \"PID\": 527403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 27, \"PID\": 527404120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 78.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 28, \"PID\": 527425090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 29, \"PID\": 527427230, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 5858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1051.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 30, \"PID\": 527451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 327.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 31, \"PID\": 527451330, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 32, \"PID\": 527451410, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 381.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 88000}, {\"Order\": 33, \"PID\": 527452190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 709.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 34, \"PID\": 527453130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 514.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 35, \"PID\": 527453150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 836.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 36, \"PID\": 527454200, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 37, \"PID\": 528108120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1590.0, \"TotalBsmtSF\": 1590.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1627, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 2334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 376162}, {\"Order\": 38, \"PID\": 528112020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 39, \"PID\": 528120060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1940, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395192}, {\"Order\": 40, \"PID\": 528120090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1544.0, \"TotalBsmtSF\": 1544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290941}, {\"Order\": 41, \"PID\": 528120100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 220000}, {\"Order\": 42, \"PID\": 528120120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 615.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 43, \"PID\": 528138020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1794.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1822, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259000}, {\"Order\": 44, \"PID\": 528138060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1515.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 45, \"PID\": 528150070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12919, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 760.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 2330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 611657}, {\"Order\": 46, \"PID\": 528175010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6371, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224000}, {\"Order\": 47, \"PID\": 528176010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1095.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1473.0, \"TotalBsmtSF\": 2846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 958.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 500000}, {\"Order\": 48, \"PID\": 528176070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 563, \"LowQualFinSF\": 0, \"GrLivArea\": 2250, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 49, \"PID\": 528180070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 412.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1296.0, \"TotalBsmtSF\": 1752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 50, \"PID\": 528181050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 7132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 51, \"PID\": 528188120, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 52, \"PID\": 528218150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 18494, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1324.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 53, \"PID\": 528228285, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 54, \"PID\": 528228440, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 55, \"PID\": 528231020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 58.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 56, \"PID\": 528240070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 1100, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216500}, {\"Order\": 57, \"PID\": 528240130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185088}, {\"Order\": 58, \"PID\": 528250100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 59, \"PID\": 528292020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9505, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 1151, \"LowQualFinSF\": 0, \"GrLivArea\": 2035, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 60, \"PID\": 528328100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 14774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1393.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2599, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 668, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 333168}, {\"Order\": 61, \"PID\": 528344070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 17433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1629.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1645, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 2475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 962.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 23, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 62, \"PID\": 528358010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 919.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 56, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260400}, {\"Order\": 63, \"PID\": 528363130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 1122, \"LowQualFinSF\": 0, \"GrLivArea\": 2622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 64, \"PID\": 528382020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1999, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 348.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1106, \"LowQualFinSF\": 0, \"GrLivArea\": 2270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 671.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 65, \"PID\": 528382030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 66, \"PID\": 528386040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 14720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 579.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1217.0, \"TotalBsmtSF\": 2033.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2053, \"2ndFlrSF\": 1185, \"LowQualFinSF\": 0, \"GrLivArea\": 3238, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 283, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 67, \"PID\": 528445060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8987, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221500}, {\"Order\": 68, \"PID\": 528456160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 92.0, \"LotArea\": 9215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204500}, {\"Order\": 69, \"PID\": 528458070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1547, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215200}, {\"Order\": 70, \"PID\": 528458110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 488.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1566, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 71, \"PID\": 528477080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 12552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 222.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 956, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 72, \"PID\": 528480090, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271500}, {\"Order\": 73, \"PID\": 531367050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 956.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233000}, {\"Order\": 74, \"PID\": 531369060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 75, \"PID\": 531380080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 76, \"PID\": 531451110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 543.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 119.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 77, \"PID\": 531451280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 635, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 78, \"PID\": 531452020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 79, \"PID\": 531452050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 353, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 80, \"PID\": 531452180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1744, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 238, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 81, \"PID\": 531453010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 82, \"PID\": 531453040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 83, \"PID\": 531477050, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67500}, {\"Order\": 84, \"PID\": 532351140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1318, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 85, \"PID\": 532354090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 899.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1155, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1155, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 86, \"PID\": 532376160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 416, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 87, \"PID\": 532377060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 31.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 88, \"PID\": 532377100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 220, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 89, \"PID\": 532378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6897, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 90, \"PID\": 532479070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 15410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 126.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 859.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 169000}, {\"Order\": 91, \"PID\": 533130020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10186, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 92, \"PID\": 533130130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 981.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1231.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2349, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 362500}, {\"Order\": 93, \"PID\": 533130160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1129.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 823, \"LowQualFinSF\": 0, \"GrLivArea\": 2225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 713.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 94, \"PID\": 533205060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 25.0, \"LotArea\": 4835, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 95, \"PID\": 533208090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 39.0, \"LotArea\": 3515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 96, \"PID\": 533210060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3215, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 97, \"PID\": 533212010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 98, \"PID\": 533212020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 99, \"PID\": 533212060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 376.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 100, \"PID\": 533213030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 101, \"PID\": 533221090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 102, \"PID\": 533221110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1159.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 466.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 103, \"PID\": 533223020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 696, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 104, \"PID\": 533223100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 244.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147110}, {\"Order\": 105, \"PID\": 533238045, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 57.0, \"LotArea\": 12853, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 1642.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 224, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267916}, {\"Order\": 106, \"PID\": 533244030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 7379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 107, \"PID\": 533253060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 4420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 108, \"PID\": 533253210, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1052.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 223, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 109, \"PID\": 533352170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13517, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 475.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 110, \"PID\": 534102025, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 659.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 111, \"PID\": 534129040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1323.0, \"TotalBsmtSF\": 1829.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1829, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 535.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218500}, {\"Order\": 112, \"PID\": 534151175, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1137.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243500}, {\"Order\": 113, \"PID\": 534152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 114, \"PID\": 534152070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 687.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 46.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 1891, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 115, \"PID\": 534152100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10421, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 394.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 734, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 66, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 116, \"PID\": 534176060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 982.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 1161.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1381, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1381, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 117, \"PID\": 534176230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 715, \"LowQualFinSF\": 0, \"GrLivArea\": 1645, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 118, \"PID\": 534202160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142250}, {\"Order\": 119, \"PID\": 534251320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 451.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 81.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1328.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 120, \"PID\": 534276360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128950}, {\"Order\": 121, \"PID\": 534401110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1209, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 122, \"PID\": 534401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 9680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1510, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 123, \"PID\": 534403360, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10600, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136300}, {\"Order\": 124, \"PID\": 534403410, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14112, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1014.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 227, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 125, \"PID\": 534425310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 156.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 126, \"PID\": 534427010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 13260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 127, \"PID\": 534430080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 49.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1029.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142125}, {\"Order\": 128, \"PID\": 534431050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 670.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1929, \"2ndFlrSF\": 532, \"LowQualFinSF\": 0, \"GrLivArea\": 2461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197600}, {\"Order\": 129, \"PID\": 534431070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 17360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1019, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 130, \"PID\": 534450180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 131, \"PID\": 534451150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1940, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 263, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76500}, {\"Order\": 132, \"PID\": 534475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 133, \"PID\": 534476260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 132.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 189, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 134, \"PID\": 534479320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 244.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 135, \"PID\": 535101020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 136, \"PID\": 535106190, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 361.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1169, \"LowQualFinSF\": 0, \"GrLivArea\": 2274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154300}, {\"Order\": 137, \"PID\": 535125010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 287.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 912.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1947.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2207, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 301, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 138, \"PID\": 535126040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 137.0, \"LotArea\": 16492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 713.0, \"BsmtUnfSF\": 557.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 139, \"PID\": 535152010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1604.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 140, \"PID\": 535152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 300, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 141, \"PID\": 535152130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 142, \"PID\": 535152150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 143, \"PID\": 535152250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 144, \"PID\": 535153070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1194.0, \"TotalBsmtSF\": 1194.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 145, \"PID\": 535154050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142000}, {\"Order\": 146, \"PID\": 535175070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 324.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 571.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 143, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 147, \"PID\": 535175180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10725, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 91.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1206, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108538}, {\"Order\": 148, \"PID\": 535179020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 149, \"PID\": 535180130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 832, \"2ndFlrSF\": 505, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 263.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 150, \"PID\": 535302080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 339.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 151, \"PID\": 535302200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 119.0, \"LotArea\": 10895, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 152, \"PID\": 535304060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 153, \"PID\": 535304180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 731.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109000}, {\"Order\": 154, \"PID\": 535325400, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 155, \"PID\": 535327140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 156, \"PID\": 535350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 362.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 157, \"PID\": 535350040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 5868, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 158, \"PID\": 535353190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 17503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97500}, {\"Order\": 159, \"PID\": 535377090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 160, \"PID\": 535401080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 72.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 258.0, \"BsmtUnfSF\": 733.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 161, \"PID\": 535425010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 1080, \"LowQualFinSF\": 0, \"GrLivArea\": 2978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 162, \"PID\": 535450210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 481.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 163, \"PID\": 535453070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 906.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 164, \"PID\": 535454070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 475, \"LowQualFinSF\": 0, \"GrLivArea\": 1385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 165, \"PID\": 535456110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 486.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134800}, {\"Order\": 166, \"PID\": 535457010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1116.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 385, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 167, \"PID\": 535457090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 7635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 350.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 168, \"PID\": 535476350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 263.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1395, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 657, \"OpenPorchSF\": 0, \"EnclosedPorch\": 113, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 169, \"PID\": 535477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 170, \"PID\": 902102100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 771.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80400}, {\"Order\": 171, \"PID\": 902104060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 172, \"PID\": 902106130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4485, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 579.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 51, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 173, \"PID\": 902106140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1028, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 130, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 174, \"PID\": 902110090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 5805, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1073.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1347, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 175, \"PID\": 902125080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1605, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107400}, {\"Order\": 176, \"PID\": 902125160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 4608, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 177, \"PID\": 902128170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 294.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 804, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 178, \"PID\": 902206040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 692.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 390, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 179, \"PID\": 902206130, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 827.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 180, \"PID\": 902206220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 606, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 181, \"PID\": 902206240, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 185, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 334, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 182, \"PID\": 902207130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1923, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 780.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 12789}, {\"Order\": 183, \"PID\": 902207140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1928, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105900}, {\"Order\": 184, \"PID\": 902305110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 228, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 185, \"PID\": 902327040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 966, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 186, \"PID\": 902329030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 187, \"PID\": 902401060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 18, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 188, \"PID\": 902402010, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 7407, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 923.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149700}, {\"Order\": 189, \"PID\": 902402130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 622, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 190, \"PID\": 902402250, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1885, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 777.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 191, \"PID\": 902403070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140750}, {\"Order\": 192, \"PID\": 903204040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1030, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 363.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 193, \"PID\": 903206120, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 194, \"PID\": 903225150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 765, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 765, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 195, \"PID\": 903226160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 452.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 12.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 134000}, {\"Order\": 196, \"PID\": 903227020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 197, \"PID\": 903227150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 955, \"2ndFlrSF\": 498, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 148, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 198, \"PID\": 903228150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 221, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 199, \"PID\": 903232190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 548, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 200, \"PID\": 903233120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 928, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138400}, {\"Order\": 201, \"PID\": 903234050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 164.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 202, \"PID\": 903425110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 10300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 11, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 203, \"PID\": 903426180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 888.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 1074, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 364, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 204, \"PID\": 903426200, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 205, \"PID\": 903430080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 3068, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 662, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 206, \"PID\": 903450110, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 110.0, \"LotArea\": 8472, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 207, \"PID\": 903454060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 372, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3500, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 208, \"PID\": 903476030, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 7630, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 209, \"PID\": 904100140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1032.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 1196, \"LowQualFinSF\": 0, \"GrLivArea\": 2403, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 0, \"EnclosedPorch\": 318, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 244400}, {\"Order\": 210, \"PID\": 904101110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 365.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 211, \"PID\": 904300150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 499, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Po\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 212, \"PID\": 904302260, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1026.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 180, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 213, \"PID\": 904350045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 214, \"PID\": 904351040, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 6449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1907, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 73.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93369}, {\"Order\": 215, \"PID\": 904352190, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 6048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114900}, {\"Order\": 216, \"PID\": 905101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 6342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1875, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94000}, {\"Order\": 217, \"PID\": 905101300, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1832, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 218, \"PID\": 905101310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1768.0, \"TotalBsmtSF\": 1768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 219, \"PID\": 905102060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 1039.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 220, \"PID\": 905103060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11341, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1302.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 221, \"PID\": 905104210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8521, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 842.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 222, \"PID\": 905105070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 668.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 223, \"PID\": 905105200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 47.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 474.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 224, \"PID\": 905106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 663, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 379, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 225, \"PID\": 905106170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137250}, {\"Order\": 226, \"PID\": 905107110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7424, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1373, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1373, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160250}, {\"Order\": 227, \"PID\": 905107250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 453.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 228, \"PID\": 905107320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 328.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1386, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 229, \"PID\": 905109130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 954, \"LowQualFinSF\": 0, \"GrLivArea\": 2260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 328000}, {\"Order\": 230, \"PID\": 905109170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1092.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1483, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1483, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 496, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 231, \"PID\": 905201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 756, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 232, \"PID\": 905202090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 233, \"PID\": 905325030, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23595, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 74.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 192, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 234, \"PID\": 905352140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 336, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 235, \"PID\": 905378040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 18600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 684.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 558, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 236, \"PID\": 905426060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 108.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 835, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 237, \"PID\": 905426200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11479, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 387.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 238, \"PID\": 905451320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 44, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 239, \"PID\": 905452110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 362, \"GrLivArea\": 1531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 209.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 240, \"PID\": 905452160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 954.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 1172.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1172, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 241, \"PID\": 905453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1176.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 242, \"PID\": 905453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 17485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1508, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Partial\", \"SalePrice\": 308030}, {\"Order\": 243, \"PID\": 905475510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1250.0, \"TotalBsmtSF\": 1250.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 244, \"PID\": 905478190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 245, \"PID\": 906201030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 977, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1732, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 246, \"PID\": 906201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 11980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 177.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1433.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1433.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 278, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 247, \"PID\": 906204230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 12361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 86.0, \"TotalBsmtSF\": 946.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1017.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 450, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 248, \"PID\": 906223090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 750.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 249, \"PID\": 906225210, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 250, \"PID\": 906378100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245350}, {\"Order\": 251, \"PID\": 906380190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 252, \"PID\": 906385010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 10402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 740.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198900}, {\"Order\": 253, \"PID\": 906385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1222.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1222, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 254, \"PID\": 906402200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12376, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1470.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 1523, \"LowQualFinSF\": 0, \"GrLivArea\": 3222, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 367, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 255, \"PID\": 906425045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 14235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 614, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 256, \"PID\": 906477110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 257, \"PID\": 907125090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 71, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 258, \"PID\": 907180050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 878.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 259, \"PID\": 907185060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 260, \"PID\": 907200280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 15240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 688.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 261, \"PID\": 907200290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161750}, {\"Order\": 262, \"PID\": 907200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 365, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128200}, {\"Order\": 263, \"PID\": 907203070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 264, \"PID\": 907250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 296.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 265, \"PID\": 907252120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 479.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1581.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 266, \"PID\": 907262050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 9548, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 223.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 458.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 613.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 267, \"PID\": 907280040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 331, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 268, \"PID\": 907290040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1649.0, \"TotalBsmtSF\": 1649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 269, \"PID\": 907290170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 270, \"PID\": 907290240, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 271, \"PID\": 907401090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 10635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 972.0, \"BsmtUnfSF\": 315.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 262, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 272, \"PID\": 907410080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 109.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 761.0, \"TotalBsmtSF\": 1473.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 273, \"PID\": 907414030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185500}, {\"Order\": 274, \"PID\": 908102060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 84900}, {\"Order\": 275, \"PID\": 908102110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 155891}, {\"Order\": 276, \"PID\": 908102130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 277, \"PID\": 908102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 278, \"PID\": 908102300, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 792, \"2ndFlrSF\": 328, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 64000}, {\"Order\": 279, \"PID\": 908103350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125200}, {\"Order\": 280, \"PID\": 908152080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 7819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 422.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 281, \"PID\": 908203100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 282, \"PID\": 908208020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 8546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1121.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 283, \"PID\": 908225320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 94.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1487, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 284, \"PID\": 908226130, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 285, \"PID\": 908275300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1526, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 286, \"PID\": 909100080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 4853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 974.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 287, \"PID\": 909100110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 841, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 288, \"PID\": 909101070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 289, \"PID\": 909176140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 242, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 290, \"PID\": 909176150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 166, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 291, \"PID\": 909177100, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 862, \"2ndFlrSF\": 1788, \"LowQualFinSF\": 0, \"GrLivArea\": 2650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 292, \"PID\": 909250030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 293, \"PID\": 909250060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 804.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 2447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 294, \"PID\": 909281080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 371.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 86, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 295, \"PID\": 909426080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 657.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1075, \"LowQualFinSF\": 0, \"GrLivArea\": 2177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 296, \"PID\": 909427230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 877.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 1152, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266500}, {\"Order\": 297, \"PID\": 909428280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 207, \"EnclosedPorch\": 162, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 298, \"PID\": 909452114, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 423.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203135}, {\"Order\": 299, \"PID\": 909455030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 300, \"PID\": 909455040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 76.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1115.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1191, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1191, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 301, \"PID\": 909475140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15602, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1801, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 289000}, {\"Order\": 302, \"PID\": 910202060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 61.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 358, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 303, \"PID\": 910203250, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 540, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 304, \"PID\": 910205120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 727, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 305, \"PID\": 911128180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 68400}, {\"Order\": 306, \"PID\": 911202100, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 859.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 859, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 102776}, {\"Order\": 307, \"PID\": 911204090, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 54, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 55993}, {\"Order\": 308, \"PID\": 911204100, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1896, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1896.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 265, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 50138}, {\"Order\": 309, \"PID\": 911370510, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246000}, {\"Order\": 310, \"PID\": 914467040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 615.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1916, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 741.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 311, \"PID\": 914475090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9620, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1243.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 375, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 80, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 312, \"PID\": 914476520, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 9196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 313, \"PID\": 914478045, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 473.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169900}, {\"Order\": 314, \"PID\": 914478110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1958.0, \"TotalBsmtSF\": 1958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 315, \"PID\": 916125360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 57200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 334.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 50, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 316, \"PID\": 916386010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 78.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1346, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 317, \"PID\": 916386020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1214.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179781}, {\"Order\": 318, \"PID\": 916386060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 319, \"PID\": 916386090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 774.0, \"TotalBsmtSF\": 774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 1194, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 269500}, {\"Order\": 320, \"PID\": 916455170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 1894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214900}, {\"Order\": 321, \"PID\": 916475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202900}, {\"Order\": 322, \"PID\": 921128020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 13214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2002.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2018, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2018, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378500}, {\"Order\": 323, \"PID\": 923201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 42.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 324, \"PID\": 923202105, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10114, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1430.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 325, \"PID\": 923204150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 326, \"PID\": 923205015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1344.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166500}, {\"Order\": 327, \"PID\": 923225300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83500}, {\"Order\": 328, \"PID\": 923225390, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 31.0, \"LotArea\": 2394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 945, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 329, \"PID\": 923225440, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 2592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 129.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 232.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 536, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 330, \"PID\": 923226250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 331, \"PID\": 923226320, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1491, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75500}, {\"Order\": 332, \"PID\": 923228270, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88250}, {\"Order\": 333, \"PID\": 923228370, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 334, \"PID\": 923230190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 469.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 335, \"PID\": 923251080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 26142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 336, \"PID\": 923276030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 207.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 337, \"PID\": 923276250, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1985, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1216.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 338, \"PID\": 923426070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 22, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 339, \"PID\": 924100050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 388.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 615, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 287, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 340, \"PID\": 924151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1341.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 284.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1679.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 64, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 341, \"PID\": 924152030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12961, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 342, \"PID\": 526302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 343, \"PID\": 526351100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 440.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 844.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 344, \"PID\": 526355080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 542.0, \"TotalBsmtSF\": 1952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 2704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 269, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 345, \"PID\": 527105070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 346, \"PID\": 527105130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 1275, \"LowQualFinSF\": 0, \"GrLivArea\": 2283, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 347, \"PID\": 527107130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1628, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 490, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 348, \"PID\": 527108070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 14892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1746, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377500}, {\"Order\": 349, \"PID\": 527110020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 22.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 350, \"PID\": 527127100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 28.0, \"LotArea\": 7296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 243.0, \"TotalBsmtSF\": 2208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2522, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 351, \"PID\": 527131030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 5664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1659, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 352, \"PID\": 527132090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 353, \"PID\": 527146010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 354, \"PID\": 527161040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 355, \"PID\": 527162110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 94, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 291, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 356, \"PID\": 527162120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 357, \"PID\": 527163040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 799.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 799, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 358, \"PID\": 527163070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 359, \"PID\": 527163130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181316}, {\"Order\": 360, \"PID\": 527164020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 7250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 361, \"PID\": 527164060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 362, \"PID\": 527164090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 702, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1481, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 363, \"PID\": 527165130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 364, \"PID\": 527166010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 694.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 1983, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 365, \"PID\": 527180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1424.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 508, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 366, \"PID\": 527182110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 187500}, {\"Order\": 367, \"PID\": 527214050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 17423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 748.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 2216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1166.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 501837}, {\"Order\": 368, \"PID\": 527254020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 464.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2046.0, \"TotalBsmtSF\": 2046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372500}, {\"Order\": 369, \"PID\": 527258020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 16158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 370, \"PID\": 527276160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1934, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 371, \"PID\": 527301320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 692.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 1200, \"LowQualFinSF\": 0, \"GrLivArea\": 2353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 372, \"PID\": 527302175, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 17043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1586, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 373, \"PID\": 527326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 82500}, {\"Order\": 374, \"PID\": 527326150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 375, \"PID\": 527352150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 154000}, {\"Order\": 376, \"PID\": 527353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 363.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 377, \"PID\": 527353060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 229.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1539, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2673, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 378, \"PID\": 527354100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 225.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 379, \"PID\": 527354200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 380, \"PID\": 527355150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1420.0, \"TotalBsmtSF\": 2524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 381, \"PID\": 527356040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157000}, {\"Order\": 382, \"PID\": 527359050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 383, \"PID\": 527359180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 448, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 384, \"PID\": 527364030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1016, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 581.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240900}, {\"Order\": 385, \"PID\": 527365030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 8004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 1103, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 263435}, {\"Order\": 386, \"PID\": 527366030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1058.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 387, \"PID\": 527368010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 225.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 471.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 839, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 388, \"PID\": 527375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1333.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 490, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 389, \"PID\": 527375180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 888.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 390, \"PID\": 527375210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 391, \"PID\": 527376100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 392, \"PID\": 527378140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 333.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 2119, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158000}, {\"Order\": 393, \"PID\": 527401160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 394, \"PID\": 527402220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1002, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 902.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 395, \"PID\": 527403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 439.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 472.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 396, \"PID\": 527404020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1180.0, \"TotalBsmtSF\": 1180.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 397, \"PID\": 527404030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 398, \"PID\": 527405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 726.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 399, \"PID\": 527405160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 239.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 400, \"PID\": 527405180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 401, \"PID\": 527425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97000}, {\"Order\": 402, \"PID\": 527425110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 403, \"PID\": 527450280, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 254.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 404, \"PID\": 527451110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 312.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 405, \"PID\": 527451320, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 406, \"PID\": 527451540, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 79.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 407, \"PID\": 527451640, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 510.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 408, \"PID\": 527451650, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 409, \"PID\": 527452060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 410, \"PID\": 527453050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 411, \"PID\": 527453060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 87, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 412, \"PID\": 527453140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 622.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 413, \"PID\": 527454050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 260, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 414, \"PID\": 527454130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2349, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 389.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 415, \"PID\": 527455050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 416, \"PID\": 527455060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 586, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 417, \"PID\": 527455080, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 279.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 418, \"PID\": 527455090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 345.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 419, \"PID\": 527455240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 420, \"PID\": 527455280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 421, \"PID\": 528102040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1172.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337500}, {\"Order\": 422, \"PID\": 528102140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 726.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1794, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 462000}, {\"Order\": 423, \"PID\": 528104070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 13518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 860.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1926.0, \"TotalBsmtSF\": 1926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 1174, \"LowQualFinSF\": 0, \"GrLivArea\": 3140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 485000}, {\"Order\": 424, \"PID\": 528106020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1767.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 3094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2402, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 555000}, {\"Order\": 425, \"PID\": 528106070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 404, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 426, \"PID\": 528108010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 640.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1566.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 890.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256300}, {\"Order\": 427, \"PID\": 528108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2042.0, \"TotalBsmtSF\": 2042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 253293}, {\"Order\": 428, \"PID\": 528108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1365, \"2ndFlrSF\": 1325, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 197, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 398800}, {\"Order\": 429, \"PID\": 528108070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 154.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 430, \"PID\": 528108130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 2020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 404000}, {\"Order\": 431, \"PID\": 528108140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 2006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 402861}, {\"Order\": 432, \"PID\": 528110010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 13478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1722.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 2296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 842.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 451950}, {\"Order\": 433, \"PID\": 528110020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 2630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2674, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2674, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 610000}, {\"Order\": 434, \"PID\": 528110090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 424.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1734.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 1088, \"LowQualFinSF\": 0, \"GrLivArea\": 2822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1020.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 582933}, {\"Order\": 435, \"PID\": 528112040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1736.0, \"TotalBsmtSF\": 1736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1736, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1736, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 436, \"PID\": 528116010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 99, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 296000}, {\"Order\": 437, \"PID\": 528118060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 23303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 273, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 409900}, {\"Order\": 438, \"PID\": 528120020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1709.0, \"TotalBsmtSF\": 1709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1717, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255500}, {\"Order\": 439, \"PID\": 528120030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1015.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 1739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 927.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 440, \"PID\": 528120160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 262.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274900}, {\"Order\": 441, \"PID\": 528120170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1037.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1531, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 700.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 442, \"PID\": 528138010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 13514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 285.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1142.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 1774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1808, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 443, \"PID\": 528142040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8834, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1170.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1462, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 444, \"PID\": 528142090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 11362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 862.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 185, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 445, \"PID\": 528142130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1124.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 479.0, \"BsmtUnfSF\": 1603.0, \"TotalBsmtSF\": 3206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 446, \"PID\": 528142150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12878, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 418.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 1760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1760, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 190, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 447, \"PID\": 528144020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1502.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233170}, {\"Order\": 448, \"PID\": 528166060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 922.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2336.0, \"TotalBsmtSF\": 2392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 386250}, {\"Order\": 449, \"PID\": 528166090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 724.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1972.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 2452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 886.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 445000}, {\"Order\": 450, \"PID\": 528168030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1295, \"LowQualFinSF\": 0, \"GrLivArea\": 2400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 451, \"PID\": 528172060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1598.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1606, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1606, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 452, \"PID\": 528174050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 6904, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 453, \"PID\": 528174060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 900.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 454, \"PID\": 528174070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 455, \"PID\": 528175050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 456, \"PID\": 528175060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 457, \"PID\": 528176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 730.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2146.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 2492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 949.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 552000}, {\"Order\": 458, \"PID\": 528178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 117.0, \"LotArea\": 15262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 470.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 643.0, \"TotalBsmtSF\": 2200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 685.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 382500}, {\"Order\": 459, \"PID\": 528180120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 308.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1084.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 460, \"PID\": 528180130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 461, \"PID\": 528186010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 1712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 183, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286500}, {\"Order\": 462, \"PID\": 528186180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 863.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 463, \"PID\": 528188020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 464, \"PID\": 528188060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2268, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 465, \"PID\": 528218090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 466, \"PID\": 528220040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 745.0, \"TotalBsmtSF\": 745.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 745, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167800}, {\"Order\": 467, \"PID\": 528221060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 12589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 468, \"PID\": 528221070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 469, \"PID\": 528228290, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1373.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 470, \"PID\": 528228295, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1569, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1569, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 471, \"PID\": 528228435, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1357.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 472, \"PID\": 528228450, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 473, \"PID\": 528228455, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 474, \"PID\": 528228460, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 11.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160200}, {\"Order\": 475, \"PID\": 528235010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 476, \"PID\": 528235090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1010.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1010, \"2ndFlrSF\": 1257, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 477, \"PID\": 528235200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 478, \"PID\": 528240030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 479, \"PID\": 528240060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 779, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184100}, {\"Order\": 480, \"PID\": 528240150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 481, \"PID\": 528250020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 482, \"PID\": 528250040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8174, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 483, \"PID\": 528253010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 484, \"PID\": 528275070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 1276, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 485, \"PID\": 528275160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 1126, \"LowQualFinSF\": 0, \"GrLivArea\": 2004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 486, \"PID\": 528280230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 487, \"PID\": 528290030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9734, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 113.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 488, \"PID\": 528290120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8123, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 489, \"PID\": 528290180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 8433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 683.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1514, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 490, \"PID\": 528290190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 491, \"PID\": 528292030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1177.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2312, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 492, \"PID\": 528292040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 841.0, \"TotalBsmtSF\": 841.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 493, \"PID\": 528292070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 772.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1038, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 494, \"PID\": 528294050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7848, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 495, \"PID\": 528315090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 673.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1163.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337000}, {\"Order\": 496, \"PID\": 528321010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 15138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 689.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 773.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1490, \"2ndFlrSF\": 1304, \"LowQualFinSF\": 0, \"GrLivArea\": 2794, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 403000}, {\"Order\": 497, \"PID\": 528327070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 1455.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1221, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 327000}, {\"Order\": 498, \"PID\": 528344040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 731.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2450, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1069.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 499, \"PID\": 528344100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 975.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 854.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1225.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 1336, \"LowQualFinSF\": 0, \"GrLivArea\": 2612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 336000}, {\"Order\": 500, \"PID\": 528354050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10208, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 921.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1264.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 1067, \"LowQualFinSF\": 0, \"GrLivArea\": 2344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 889.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 501, \"PID\": 528363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 634.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1526.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 2024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 815.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 502, \"PID\": 528365070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 987.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 1274, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 60, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 503, \"PID\": 528385050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 967, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 102, \"EnclosedPorch\": 209, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 504, \"PID\": 528387030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 372.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 623.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263550}, {\"Order\": 505, \"PID\": 528390100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 46589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 528.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 517, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 402000}, {\"Order\": 506, \"PID\": 528390210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 29959, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 507, \"PID\": 528427020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 244600}, {\"Order\": 508, \"PID\": 528431020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1696.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 972.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 509, \"PID\": 528431070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 294.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1614.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1658, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 510, \"PID\": 528435030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1573.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287090}, {\"Order\": 511, \"PID\": 528435050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 512, \"PID\": 528439060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 513, \"PID\": 528441020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 772.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 689.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 514, \"PID\": 528441090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2490, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 226, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 468000}, {\"Order\": 515, \"PID\": 528456180, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 920, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252678}, {\"Order\": 516, \"PID\": 528456220, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 517, \"PID\": 528456240, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7862, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 27.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208300}, {\"Order\": 518, \"PID\": 528458020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 90.0, \"LotArea\": 7993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 519, \"PID\": 528458040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229456}, {\"Order\": 520, \"PID\": 528458060, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1402.0, \"TotalBsmtSF\": 1402.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 205, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229800}, {\"Order\": 521, \"PID\": 528458140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 984.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 522, \"PID\": 528458160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 645.0, \"TotalBsmtSF\": 1766.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 195, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370878}, {\"Order\": 523, \"PID\": 528458180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1348.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1448, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1448, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238500}, {\"Order\": 524, \"PID\": 528477050, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 981, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 310000}, {\"Order\": 525, \"PID\": 528477070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 121.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 526, \"PID\": 528480040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1043.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 527, \"PID\": 528480130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 438, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241000}, {\"Order\": 528, \"PID\": 528480170, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264500}, {\"Order\": 529, \"PID\": 528482040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1662, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1662, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 530, \"PID\": 528482130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 531, \"PID\": 528488100, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1221.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 532, \"PID\": 528490040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 8736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 771.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 360.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1553.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234500}, {\"Order\": 533, \"PID\": 528490070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8127, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 841, \"LowQualFinSF\": 0, \"GrLivArea\": 1653, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 534, \"PID\": 531363010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 178, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 535, \"PID\": 531363030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1087.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 536, \"PID\": 531363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 537, \"PID\": 531369010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 871, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 538, \"PID\": 531369020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 774.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1512.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 845.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 539, \"PID\": 531371050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10083, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 540, \"PID\": 531375040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 541, \"PID\": 531375090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 542, \"PID\": 531375130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 543, \"PID\": 531376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1450, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224243}, {\"Order\": 544, \"PID\": 531379050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 11492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 1209, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 559.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 545, \"PID\": 531382070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10994, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 366.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 257000}, {\"Order\": 546, \"PID\": 531385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1434.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 547, \"PID\": 531450120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 364.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1730, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 548, \"PID\": 531452010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 626, \"2ndFlrSF\": 591, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 549, \"PID\": 531452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1332.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1332, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 550, \"PID\": 531452260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 786, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 551, \"PID\": 531453100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 141.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 465.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 552, \"PID\": 531475220, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 553, \"PID\": 531477020, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 721.0, \"TotalBsmtSF\": 721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 841, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 841, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 554, \"PID\": 531479020, \"MSSubClass\": 45, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 91, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 555, \"PID\": 532353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 884.0, \"BsmtUnfSF\": 28.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 556, \"PID\": 532353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 557, \"PID\": 532354160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 558, \"PID\": 532354230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9079, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 559, \"PID\": 532376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Family\", \"SalePrice\": 124100}, {\"Order\": 560, \"PID\": 532376110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 561, \"PID\": 532377130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131400}, {\"Order\": 562, \"PID\": 532378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 311.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 62383}, {\"Order\": 563, \"PID\": 532378180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 140.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 564, \"PID\": 532478020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15676, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1733.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 92.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 2014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 462, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 255, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 565, \"PID\": 533135020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11949, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1991, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 601.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 216.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 502, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 566, \"PID\": 533206020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 2880, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1376.0, \"TotalBsmtSF\": 1376.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1376, \"2ndFlrSF\": 1629, \"LowQualFinSF\": 0, \"GrLivArea\": 3005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 177, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280750}, {\"Order\": 567, \"PID\": 533210010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164500}, {\"Order\": 568, \"PID\": 533210020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173733}, {\"Order\": 569, \"PID\": 533213010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 3830, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1726.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 254, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 570, \"PID\": 533213020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4217, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 183.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 571, \"PID\": 533213040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 894.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1471, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 572, \"PID\": 533221040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 249.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 573, \"PID\": 533223030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 574, \"PID\": 533236050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1739, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 172500}, {\"Order\": 575, \"PID\": 533252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1252.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 136.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 501, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 225, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318750}, {\"Order\": 576, \"PID\": 533253070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 3782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211500}, {\"Order\": 577, \"PID\": 533254050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15417, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1619.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 20, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241600}, {\"Order\": 578, \"PID\": 533254110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1487, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180500}, {\"Order\": 579, \"PID\": 533352150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1281.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 580, \"PID\": 534125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 727.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 829, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 581, \"PID\": 534127130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 571.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1442.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 371, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 582, \"PID\": 534127170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9156, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185750}, {\"Order\": 583, \"PID\": 534128010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 859.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 32.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 204, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 350, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 584, \"PID\": 534128020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 782, \"LowQualFinSF\": 0, \"GrLivArea\": 2067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 585, \"PID\": 534128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 735, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 586, \"PID\": 534128190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1369, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256900}, {\"Order\": 587, \"PID\": 534129080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1724, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 588, \"PID\": 534129370, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 589, \"PID\": 534129380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 955.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113000}, {\"Order\": 590, \"PID\": 534151120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 283.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 2288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 591, \"PID\": 534152120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 592, \"PID\": 534175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1127.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 78, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213250}, {\"Order\": 593, \"PID\": 534177230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 594, \"PID\": 534200030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 595, \"PID\": 534202170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 596, \"PID\": 534226120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 466.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 597, \"PID\": 534250400, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 168500}, {\"Order\": 598, \"PID\": 534251030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 509.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 599, \"PID\": 534252240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 251.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 630.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 197, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 600, \"PID\": 534275060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 360, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 601, \"PID\": 534275100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 602, \"PID\": 534276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 603, \"PID\": 534277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 604, \"PID\": 534278070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 201.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177625}, {\"Order\": 605, \"PID\": 534278230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 606, \"PID\": 534400050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 345.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 1516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 152, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 607, \"PID\": 534400290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 217.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 512.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1313, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 121, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 608, \"PID\": 534402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1292.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1292, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145100}, {\"Order\": 609, \"PID\": 534402140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 230.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1154.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 610, \"PID\": 534402170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 549.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 611, \"PID\": 534403370, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 563.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 612, \"PID\": 534426110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 991.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 50.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 613, \"PID\": 534429150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 614, \"PID\": 534431130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 100.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 613.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 615, \"PID\": 534450150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 616, \"PID\": 534451110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 185.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 224, \"LowQualFinSF\": 0, \"GrLivArea\": 1203, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 617, \"PID\": 534475185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 1505.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1505, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 162, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 618, \"PID\": 534475250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 260, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 619, \"PID\": 534476150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 1416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 620, \"PID\": 534476320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 621, \"PID\": 534477110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 556, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 622, \"PID\": 534478230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 607.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 623, \"PID\": 535101120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 624, \"PID\": 535104120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10573, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 3.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 625, \"PID\": 535105100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 247.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1394.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1394, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 185, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 626, \"PID\": 535125070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 1562.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 342, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 627, \"PID\": 535125090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 314.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1186, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 628, \"PID\": 535126010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 576.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 2142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 252, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 629, \"PID\": 535126100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1392.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 630, \"PID\": 535150070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1281, \"2ndFlrSF\": 457, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 631, \"PID\": 535151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 313.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 632, \"PID\": 535152230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 661.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 633, \"PID\": 535154060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 203, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 634, \"PID\": 535154130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 635, \"PID\": 535175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 620.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 636, \"PID\": 535175050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1215.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 234, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 637, \"PID\": 535178040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 565.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1202, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1202, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 638, \"PID\": 535178120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 172.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 727.0, \"TotalBsmtSF\": 1382.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 639, \"PID\": 535179160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 155.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 750.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144000}, {\"Order\": 640, \"PID\": 535300120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 19296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 399.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 690.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 641, \"PID\": 535301170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 1297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1297, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1297, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 642, \"PID\": 535302120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 657.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1866.0, \"TotalBsmtSF\": 1866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 643, \"PID\": 535303110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 8128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 644, \"PID\": 535303150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10634, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1319, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1319, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 645, \"PID\": 535304100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 631.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 646, \"PID\": 535325290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1005.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 647, \"PID\": 535351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 178.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 648, \"PID\": 535352090, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 793, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 649, \"PID\": 535353040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1952, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1031.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1031, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 650, \"PID\": 535353060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102900}, {\"Order\": 651, \"PID\": 535353140, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1699, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 95000}, {\"Order\": 652, \"PID\": 535353240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 699.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 801, \"2ndFlrSF\": 726, \"LowQualFinSF\": 0, \"GrLivArea\": 1527, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 653, \"PID\": 535354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 654, \"PID\": 535354100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 655, \"PID\": 535375010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 656, \"PID\": 535375050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 704, \"LowQualFinSF\": 144, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 140, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 657, \"PID\": 535376060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 658, \"PID\": 535377150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 717, \"2ndFlrSF\": 322, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 111, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 659, \"PID\": 535378020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 9022, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1924, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 660, \"PID\": 535378120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10230, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 661, \"PID\": 535381040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 1064, \"GrLivArea\": 2377, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 432, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142900}, {\"Order\": 662, \"PID\": 535382100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 760, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 663, \"PID\": 535383060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 599, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 599, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 59000}, {\"Order\": 664, \"PID\": 535383070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 198, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 665, \"PID\": 535383110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 666, \"PID\": 535383120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 725, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78500}, {\"Order\": 667, \"PID\": 535402010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1248.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 907.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 668, \"PID\": 535402090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 996.0, \"TotalBsmtSF\": 1380.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1380, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 669, \"PID\": 535402270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 670, \"PID\": 535402330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2634, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 671, \"PID\": 535403190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1958, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 672, \"PID\": 535403210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 559.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1105, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 673, \"PID\": 535403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 674, \"PID\": 535425070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1270.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 675, \"PID\": 535426150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 676, \"PID\": 535450070, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 232, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 677, \"PID\": 535450160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 92900}, {\"Order\": 678, \"PID\": 535450200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 231, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 679, \"PID\": 535451170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 680, \"PID\": 535451250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 352.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 681, \"PID\": 535452090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1041.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 682, \"PID\": 535452100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 683, \"PID\": 535452140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 102.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 732, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118900}, {\"Order\": 684, \"PID\": 535453100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 433.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 95.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1183, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 685, \"PID\": 535453200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 686, \"PID\": 535454100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 832, \"2ndFlrSF\": 629, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 687, \"PID\": 535454160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 431, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 688, \"PID\": 535475010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 7570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1806, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144750}, {\"Order\": 689, \"PID\": 535476110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 124.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 690, \"PID\": 535476240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 7936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 826.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 691, \"PID\": 535477150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 692, \"PID\": 902101010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3950, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 693, \"PID\": 902102080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 682, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 694, \"PID\": 902103100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 4080, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 695, \"PID\": 902103120, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 972, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 696, \"PID\": 902103170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 5720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 455, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 66500}, {\"Order\": 697, \"PID\": 902105050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 496, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 698, \"PID\": 902105060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 699, \"PID\": 902106010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6406, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 269.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 868, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 700, \"PID\": 902106060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1892, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 994, \"LowQualFinSF\": 0, \"GrLivArea\": 2372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 287, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 701, \"PID\": 902109130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94550}, {\"Order\": 702, \"PID\": 902109140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7596, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1000, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 703, \"PID\": 902110080, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3378, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1946, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 651.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 682, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 704, \"PID\": 902134120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 801, \"2ndFlrSF\": 646, \"LowQualFinSF\": 0, \"GrLivArea\": 1447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 705, \"PID\": 902135020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 706, \"PID\": 902201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 707, \"PID\": 902202150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 811.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 811, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 708, \"PID\": 902204080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 709, \"PID\": 902205010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 25, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 45000}, {\"Order\": 710, \"PID\": 902205030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 37900}, {\"Order\": 711, \"PID\": 902206260, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1938, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 886, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91300}, {\"Order\": 712, \"PID\": 902207170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 713, \"PID\": 902300090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 4456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 113000}, {\"Order\": 714, \"PID\": 902301060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 677.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 715, \"PID\": 902301080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 716, \"PID\": 902325070, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1898, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 849.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 1063, \"LowQualFinSF\": 0, \"GrLivArea\": 2138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 717, \"PID\": 902326030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 181, \"OpenPorchSF\": 0, \"EnclosedPorch\": 386, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265979}, {\"Order\": 718, \"PID\": 902327070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 917.0, \"TotalBsmtSF\": 917.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 719, \"PID\": 902329080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1917, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 720, \"PID\": 902330040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 121.0, \"LotArea\": 17671, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1882, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 826, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 424.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 721, \"PID\": 902331010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 3300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 722, \"PID\": 902401130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1920, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 26.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 723, \"PID\": 902402150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 226, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 724, \"PID\": 902405100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 98.0, \"LotArea\": 8820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 561, \"LowQualFinSF\": 120, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 725, \"PID\": 902405120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 436, \"GrLivArea\": 1480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 207.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 119000}, {\"Order\": 726, \"PID\": 902406070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 238, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 727, \"PID\": 902477120, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 523, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 34900}, {\"Order\": 728, \"PID\": 902477130, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 72.0, \"LotArea\": 9392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 245.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 44000}, {\"Order\": 729, \"PID\": 903200080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 144.0, \"LotArea\": 21384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 15.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 730, \"PID\": 903201020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1022.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 731, \"PID\": 903201080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 732, \"PID\": 903202170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 244, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 733, \"PID\": 903205040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 192.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 40, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 734, \"PID\": 903226130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 735, \"PID\": 903226170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 390, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 736, \"PID\": 903227070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 737, \"PID\": 903227090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 825, \"2ndFlrSF\": 587, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 45, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 738, \"PID\": 903228070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 444.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 320, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 739, \"PID\": 903228120, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 740, \"PID\": 903230100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 741, \"PID\": 903231010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 927.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 742, \"PID\": 903231030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 989, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 54, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 743, \"PID\": 903231060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 744, \"PID\": 903231130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1931, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 745, \"PID\": 903232060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 995, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 15, \"EnclosedPorch\": 51, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 746, \"PID\": 903234220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 679.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 994, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 189, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 150, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 747, \"PID\": 903236040, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 134.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 1072.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 5.0, \"GarageArea\": 1184.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 748, \"PID\": 903400220, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11888, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 2134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 268, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214500}, {\"Order\": 749, \"PID\": 903425245, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 883, \"LowQualFinSF\": 0, \"GrLivArea\": 2019, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 509, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 750, \"PID\": 903427120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 751, \"PID\": 903429080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 2500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 752, \"PID\": 903429110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 753, \"PID\": 903430060, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 92.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 929, \"LowQualFinSF\": 371, \"GrLivArea\": 2229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 198, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 104000}, {\"Order\": 754, \"PID\": 903430070, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Sev\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 62500}, {\"Order\": 755, \"PID\": 903451090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 316.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 213, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 756, \"PID\": 903458170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 757, \"PID\": 903475100, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 758, \"PID\": 903476090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1902, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 169.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 978, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 759, \"PID\": 903481120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 760, \"PID\": 903481130, \"MSSubClass\": 85, \"MSZoning\": \"RM\", \"LotFrontage\": 86.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 749.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 63.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 70000}, {\"Order\": 761, \"PID\": 903484110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 262.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 754, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 288, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 762, \"PID\": 904100190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1946, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 704, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88750}, {\"Order\": 763, \"PID\": 904301060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 764, \"PID\": 904301070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 765, \"PID\": 904301100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 766, \"PID\": 904301375, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61000}, {\"Order\": 767, \"PID\": 904351200, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 54.0, \"LotArea\": 6629, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 551.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103600}, {\"Order\": 768, \"PID\": 904351240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 687, \"2ndFlrSF\": 425, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 226.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63000}, {\"Order\": 769, \"PID\": 905101260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12886, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 770, \"PID\": 905101490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 771, \"PID\": 905103040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 92.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 500.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1683, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 772, \"PID\": 905103070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 215, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113500}, {\"Order\": 773, \"PID\": 905105190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 774, \"PID\": 905107310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 775, \"PID\": 905108190, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7252, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 776, \"PID\": 905108220, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 860, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 777, \"PID\": 905200220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 170.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 778, \"PID\": 905200260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 611, \"LowQualFinSF\": 259, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 779, \"PID\": 905200350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15312, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 780, \"PID\": 905225090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 366.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2071, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2071, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 781, \"PID\": 905228050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63900}, {\"Order\": 782, \"PID\": 905229040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1104.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 783, \"PID\": 905325020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 25095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1473, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1473, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 60, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 143000}, {\"Order\": 784, \"PID\": 905377010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 284.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 785, \"PID\": 905377130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 786, \"PID\": 905401100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10708, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 768.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1867, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1867, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 476, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 787, \"PID\": 905402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139600}, {\"Order\": 788, \"PID\": 905402070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 789, \"PID\": 905450020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 790, \"PID\": 905451300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 340.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 791, \"PID\": 905451340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1276, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 60000}, {\"Order\": 792, \"PID\": 905452040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 747, \"LowQualFinSF\": 0, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154400}, {\"Order\": 793, \"PID\": 905452050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 344.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 794, \"PID\": 905475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1089.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1089, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 795, \"PID\": 905475500, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 290.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84000}, {\"Order\": 796, \"PID\": 905476230, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 393.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1049, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 266.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 797, \"PID\": 905478030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11409, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 798, \"PID\": 905480030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 799, \"PID\": 905480210, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 800, \"PID\": 906201021, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 286.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 801, \"PID\": 906201050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 19255, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 450.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 802, \"PID\": 906201130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1983, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 2132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316600}, {\"Order\": 803, \"PID\": 906203120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 177.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 2158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271900}, {\"Order\": 804, \"PID\": 906223060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 137.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 227.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 769, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 425.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 234, \"OpenPorchSF\": 72, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 805, \"PID\": 906223080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1879, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 100, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 806, \"PID\": 906223210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 807, \"PID\": 906226060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 26400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 2016, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 808, \"PID\": 906226070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118964}, {\"Order\": 809, \"PID\": 906226080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1086.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 153337}, {\"Order\": 810, \"PID\": 906226090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 1114, \"LowQualFinSF\": 0, \"GrLivArea\": 2228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 73, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 147983}, {\"Order\": 811, \"PID\": 906226100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 812, \"PID\": 906226110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 813, \"PID\": 906226120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 1120, \"LowQualFinSF\": 0, \"GrLivArea\": 2240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 142953}, {\"Order\": 814, \"PID\": 906226130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1094.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 148325}, {\"Order\": 815, \"PID\": 906226140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 113722}, {\"Order\": 816, \"PID\": 906230010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 817, \"PID\": 906230020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7939, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 818, \"PID\": 906230030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 819, \"PID\": 906340100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10933, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1021.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1555.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1138.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 323262}, {\"Order\": 820, \"PID\": 906340110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 417.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 297000}, {\"Order\": 821, \"PID\": 906340120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1622.0, \"TotalBsmtSF\": 1622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 860.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295493}, {\"Order\": 822, \"PID\": 906340130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 364.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 332000}, {\"Order\": 823, \"PID\": 906378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 904.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 824, \"PID\": 906380050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 825, \"PID\": 906380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11422, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1359.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 222, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272500}, {\"Order\": 826, \"PID\": 906380100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 827, \"PID\": 906380130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 828, \"PID\": 906380210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1282.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 829, \"PID\": 906380220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 10324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 382.0, \"TotalBsmtSF\": 1254.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221800}, {\"Order\": 830, \"PID\": 906392070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 82.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 831, \"PID\": 906392110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1474.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 832, \"PID\": 906392130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 704, \"2ndFlrSF\": 718, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 833, \"PID\": 906402060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 396, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 834, \"PID\": 906426210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 1449.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 815, \"LowQualFinSF\": 0, \"GrLivArea\": 1759, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 193, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233500}, {\"Order\": 835, \"PID\": 906475070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 28698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 764.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 966, \"LowQualFinSF\": 0, \"GrLivArea\": 2126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 836, \"PID\": 907126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 837, \"PID\": 907126050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9757, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 838, \"PID\": 907130100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 15426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 836, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 839, \"PID\": 907131090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 834, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 840, \"PID\": 907131190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14753, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 950.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1463, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1463, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 841, \"PID\": 907135040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 10859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1097.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 392, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 842, \"PID\": 907135170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 746.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 843, \"PID\": 907175100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 866.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 913, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 844, \"PID\": 907180130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1490.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 845, \"PID\": 907181100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9017, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 871.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 846, \"PID\": 907185050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 847, \"PID\": 907192030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8935, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 848, \"PID\": 907192090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 9808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1573, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 849, \"PID\": 907194010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1840, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 850, \"PID\": 907194110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 16285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1413.0, \"TotalBsmtSF\": 1413.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187100}, {\"Order\": 851, \"PID\": 907194160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10739, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 852, \"PID\": 907196060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11166, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 201000}, {\"Order\": 853, \"PID\": 907200230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 854, \"PID\": 907201220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16269, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 855, \"PID\": 907201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 6950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 710.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 856, \"PID\": 907202050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150500}, {\"Order\": 857, \"PID\": 907202080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 858, \"PID\": 907202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1072.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 859, \"PID\": 907227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 15523, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 860, \"PID\": 907227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 215, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 861, \"PID\": 907227110, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 862, \"PID\": 907227290, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8445, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 863, \"PID\": 907250070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 335.0, \"TotalBsmtSF\": 1569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 864, \"PID\": 907252060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1068.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254750}, {\"Order\": 865, \"PID\": 907252210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 866, \"PID\": 907252220, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 990.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 309.0, \"TotalBsmtSF\": 1299.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 573, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 261500}, {\"Order\": 867, \"PID\": 907253130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 2153, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 313000}, {\"Order\": 868, \"PID\": 907260030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 869, \"PID\": 907265010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 944.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 926, \"LowQualFinSF\": 0, \"GrLivArea\": 1870, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 870, \"PID\": 907275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 871, \"PID\": 907275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 814.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 872, \"PID\": 907275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 873, \"PID\": 907280170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1111.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1417, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1417, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 117, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 874, \"PID\": 907285020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 573.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 977, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 576, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 875, \"PID\": 907285050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 876, \"PID\": 907290070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1212.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 877, \"PID\": 907290090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1630.0, \"TotalBsmtSF\": 1630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 878, \"PID\": 907290180, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 879, \"PID\": 907290210, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 880, \"PID\": 907410130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1478.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 293200}, {\"Order\": 881, \"PID\": 907412020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 882, \"PID\": 907414020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1480.0, \"TotalBsmtSF\": 1500.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 883, \"PID\": 907414080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 193.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 884, \"PID\": 907420040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 885, \"PID\": 908102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 886, \"PID\": 908102270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1486.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 887, \"PID\": 908102290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 888, \"PID\": 908128060, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 495, \"2ndFlrSF\": 1427, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 177, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 889, \"PID\": 908151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 155.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 890, \"PID\": 908152035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 615.0, \"TotalBsmtSF\": 1014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 891, \"PID\": 908152100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 255.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 631.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 892, \"PID\": 908154040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 13286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 464.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 327, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 893, \"PID\": 908186080, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 894, \"PID\": 908201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1947, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 895, \"PID\": 908203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 332.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 243.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 896, \"PID\": 908225290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 900, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 897, \"PID\": 908225370, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 441, \"LowQualFinSF\": 0, \"GrLivArea\": 1529, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 898, \"PID\": 908229020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 899, \"PID\": 908250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 900, \"PID\": 908275040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1678.0, \"TotalBsmtSF\": 1678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1678, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1678, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 901, \"PID\": 908275110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 902, \"PID\": 908276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 903, \"PID\": 909101010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12354, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 800, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 904, \"PID\": 909101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 444, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 905, \"PID\": 909101140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10998, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 420.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 906, \"PID\": 909129090, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 907, \"PID\": 909129100, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1932, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 159434}, {\"Order\": 908, \"PID\": 909175080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 438, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 438, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 909, \"PID\": 909178160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 545, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 910, \"PID\": 909179020, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 15863, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 3, \"YearBuilt\": 1920, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 998, \"LowQualFinSF\": 397, \"GrLivArea\": 3082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 911, \"PID\": 909250080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 583.0, \"TotalBsmtSF\": 583.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 647, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 329, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 912, \"PID\": 909250220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 913, \"PID\": 909251050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 914, \"PID\": 909251170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137450}, {\"Order\": 915, \"PID\": 909252020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1936, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 575, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1135, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 916, \"PID\": 909253010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7558, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1913, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 917, \"PID\": 909253180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 877, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1477, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 918, \"PID\": 909254010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 919, \"PID\": 909257050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 10918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 920, \"PID\": 909275080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 921, \"PID\": 909276110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 753, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 213.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 922, \"PID\": 909276200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 332, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 923, \"PID\": 909277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1273, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 307.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 924, \"PID\": 909277100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13360, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 713.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 44, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 925, \"PID\": 909278020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7681, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 731.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 523, \"LowQualFinSF\": 0, \"GrLivArea\": 1343, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 186.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154900}, {\"Order\": 926, \"PID\": 909279010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 674.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 13, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 57, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 927, \"PID\": 909282130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 154.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 694.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144800}, {\"Order\": 928, \"PID\": 909425060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 929, \"PID\": 909425130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 65.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 875.0, \"BsmtUnfSF\": 621.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 930, \"PID\": 909426090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 507.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 295.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 931, \"PID\": 909427200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 158500}, {\"Order\": 932, \"PID\": 909428240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 91.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1906, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1906, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 201, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 933, \"PID\": 909451040, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 279, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 934, \"PID\": 909451100, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 935, \"PID\": 909451140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 561.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 936, \"PID\": 909451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 937, \"PID\": 909452050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13607, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 118.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208000}, {\"Order\": 938, \"PID\": 909475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17597, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1971, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 419.0, \"BsmtUnfSF\": 581.0, \"TotalBsmtSF\": 1803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2365, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 939, \"PID\": 909475300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1988, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 808.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 182, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 940, \"PID\": 910202070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 10690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 941, \"PID\": 910204050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 760.0, \"TotalBsmtSF\": 760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 928, \"LowQualFinSF\": 312, \"GrLivArea\": 2168, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 160, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 942, \"PID\": 910205020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 596, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 189.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 943, \"PID\": 911103050, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 105.0, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1915, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1013.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 513, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85000}, {\"Order\": 944, \"PID\": 911104060, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 72, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 945, \"PID\": 911370500, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230000}, {\"Order\": 946, \"PID\": 912251110, \"MSSubClass\": 30, \"MSZoning\": \"I (all)\", \"LotFrontage\": 109.0, \"LotArea\": 21780, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 119, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 57625}, {\"Order\": 947, \"PID\": 914465020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 250.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 948, \"PID\": 914465040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 2149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 239686}, {\"Order\": 949, \"PID\": 914465055, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1710.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 950, \"PID\": 914474070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 12209, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 1157, \"LowQualFinSF\": 0, \"GrLivArea\": 1961, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 951, \"PID\": 914475010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 926, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156450}, {\"Order\": 952, \"PID\": 914475030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 953, \"PID\": 914476020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 954, \"PID\": 914476380, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9947, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 955, \"PID\": 914476430, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 55.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1527.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 152000}, {\"Order\": 956, \"PID\": 916176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSeWa\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 541.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 118, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 233, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 957, \"PID\": 916176125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 215245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 820.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 958, \"PID\": 916380070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1022.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315500}, {\"Order\": 959, \"PID\": 916382010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224500}, {\"Order\": 960, \"PID\": 916382100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 13438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 2190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 780.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 961, \"PID\": 916382110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 406.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1115.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316500}, {\"Order\": 962, \"PID\": 916386140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 963, \"PID\": 916403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 387.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1412, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 964, \"PID\": 916403200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2237, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 965, \"PID\": 916403250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 14419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 624.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 1645.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 966, \"PID\": 916455070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 967, \"PID\": 916460110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 968, \"PID\": 916475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14601, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 584.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 578.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 969, \"PID\": 921128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1640.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 308, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 425000}, {\"Order\": 970, \"PID\": 923201100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 971, \"PID\": 923202060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1771, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 972, \"PID\": 923203110, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 247, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 973, \"PID\": 923203190, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 883.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 974, \"PID\": 923225360, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 975, \"PID\": 923225490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 9858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 33, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 976, \"PID\": 923226270, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 515.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 977, \"PID\": 923227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13383, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1404, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 978, \"PID\": 923228110, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 979, \"PID\": 923228150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 980, \"PID\": 923228230, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 981, \"PID\": 923230200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7689, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 76.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131900}, {\"Order\": 982, \"PID\": 923252075, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7706, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131250}, {\"Order\": 983, \"PID\": 923275040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1097.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 602.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 303, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 984, \"PID\": 923275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 985, \"PID\": 923276260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 718.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 883, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 883, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 698.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 986, \"PID\": 923400025, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 566, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 320, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 987, \"PID\": 923400110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10429, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 988, \"PID\": 924100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1567.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 989, \"PID\": 924100060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 496.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 368, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 990, \"PID\": 526351030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 411.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 601.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 190, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 991, \"PID\": 526353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1205.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237500}, {\"Order\": 992, \"PID\": 526354070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 2112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206900}, {\"Order\": 993, \"PID\": 527105050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 994, \"PID\": 527106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 995, \"PID\": 527106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 996, \"PID\": 527106150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 997, \"PID\": 527107010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 998, \"PID\": 527107090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 898.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177900}, {\"Order\": 999, \"PID\": 527107210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 21872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1446, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 406.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1000, \"PID\": 527127140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1593.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1593, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 1001, \"PID\": 527131110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 6264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247900}, {\"Order\": 1002, \"PID\": 527140090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1003, \"PID\": 527145090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1280.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1004, \"PID\": 527161010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 926.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1005, \"PID\": 527162180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 183000}, {\"Order\": 1006, \"PID\": 527163100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1007, \"PID\": 527164120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1895, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 1008, \"PID\": 527165010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1009, \"PID\": 527183030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1010, \"PID\": 527183060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 5950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1011, \"PID\": 527208010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 13543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 1012, \"PID\": 527212050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1122.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 1370, \"LowQualFinSF\": 0, \"GrLivArea\": 2504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1013, \"PID\": 527214030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 15401, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 547.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 387000}, {\"Order\": 1014, \"PID\": 527226020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 31220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 2, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1474, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 750, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1015, \"PID\": 527252080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1034.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 557.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 1016, \"PID\": 527276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 47280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1488.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 133000}, {\"Order\": 1017, \"PID\": 527301170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 20544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 791.0, \"TotalBsmtSF\": 791.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 2093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1018, \"PID\": 527301245, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 983.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 1675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1688, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 141, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1019, \"PID\": 527302050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 228.0, \"BsmtUnfSF\": 606.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1020, \"PID\": 527302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1021, \"PID\": 527302185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 18559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 186.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 2048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1022, \"PID\": 527302210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 449.0, \"BsmtUnfSF\": 469.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 1023, \"PID\": 527325070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 424.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 896.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 550, \"OpenPorchSF\": 282, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 1024, \"PID\": 527325240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 48.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 1211.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 174, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1025, \"PID\": 527326130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1026, \"PID\": 527354160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 2044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1027, \"PID\": 527357110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9743, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146900}, {\"Order\": 1028, \"PID\": 527357180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12511, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1420, \"2ndFlrSF\": 1420, \"LowQualFinSF\": 0, \"GrLivArea\": 2840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1314.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 208, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 292500}, {\"Order\": 1029, \"PID\": 527358120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 11361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1193.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1523, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1030, \"PID\": 527359030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1444.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1031, \"PID\": 527359070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1032, \"PID\": 527378020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1033, \"PID\": 527380240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1236.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 787.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 180, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 1034, \"PID\": 527401130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1035, \"PID\": 527402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 438.0, \"BsmtUnfSF\": 14.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 80, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1036, \"PID\": 527402130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 16, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111900}, {\"Order\": 1037, \"PID\": 527403360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 613.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1038, \"PID\": 527425035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111250}, {\"Order\": 1039, \"PID\": 527427110, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1040, \"PID\": 527450110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103400}, {\"Order\": 1041, \"PID\": 527450250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1042, \"PID\": 527450520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 411, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100500}, {\"Order\": 1043, \"PID\": 527451060, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 127.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1044, \"PID\": 527451290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85400}, {\"Order\": 1045, \"PID\": 527451400, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 604.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1046, \"PID\": 527451550, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111750}, {\"Order\": 1047, \"PID\": 527452150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 559.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1048, \"PID\": 527453160, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 286.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 275.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1049, \"PID\": 527454120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 1050, \"PID\": 527455270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1051, \"PID\": 528102030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12444, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 426.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 304, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394617}, {\"Order\": 1052, \"PID\": 528102110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 590, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 426000}, {\"Order\": 1053, \"PID\": 528104050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 816.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 442.0, \"TotalBsmtSF\": 2078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2084, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 385000}, {\"Order\": 1054, \"PID\": 528104080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 14948, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 1237, \"LowQualFinSF\": 0, \"GrLivArea\": 2713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 858.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 446261}, {\"Order\": 1055, \"PID\": 528108150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 317500}, {\"Order\": 1056, \"PID\": 528110080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 436.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372402}, {\"Order\": 1057, \"PID\": 528110110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1728.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 2418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 358, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 417500}, {\"Order\": 1058, \"PID\": 528114040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 14418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 1950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 383000}, {\"Order\": 1059, \"PID\": 528118030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 2748, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 390000}, {\"Order\": 1060, \"PID\": 528118090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12539, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 468.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 1158, \"LowQualFinSF\": 0, \"GrLivArea\": 2790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1150.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 460000}, {\"Order\": 1061, \"PID\": 528120130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12151, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2331, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1003.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 379000}, {\"Order\": 1062, \"PID\": 528142020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 908.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1063, \"PID\": 528142140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1162, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316000}, {\"Order\": 1064, \"PID\": 528164060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 680.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 2535.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2470, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2470, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 144, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 615000}, {\"Order\": 1065, \"PID\": 528166120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 664.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 1096, \"LowQualFinSF\": 0, \"GrLivArea\": 2668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 412500}, {\"Order\": 1066, \"PID\": 528170070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1067, \"PID\": 528172080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 454.0, \"TotalBsmtSF\": 1603.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1068, \"PID\": 528178070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 16900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1075.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1515, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2649, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 421250}, {\"Order\": 1069, \"PID\": 528178090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 16451, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 221.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1765.0, \"TotalBsmtSF\": 1765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1804, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1070, \"PID\": 528180110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1486.0, \"TotalBsmtSF\": 1858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336860}, {\"Order\": 1071, \"PID\": 528180140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 766.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 367294}, {\"Order\": 1072, \"PID\": 528181010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 135.0, \"LotArea\": 12304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1347.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1367, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1073, \"PID\": 528186030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 12677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1074, \"PID\": 528186080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 616.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1684, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1684, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 495, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266000}, {\"Order\": 1075, \"PID\": 528186130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 8232, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 714.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370967}, {\"Order\": 1076, \"PID\": 528186160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234250}, {\"Order\": 1077, \"PID\": 528186170, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1318.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1078, \"PID\": 528188090, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1079, \"PID\": 528188150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 1080, \"PID\": 528190010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1081, \"PID\": 528228345, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1073.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 1415.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1455, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1455, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1082, \"PID\": 528228405, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1087.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219990}, {\"Order\": 1083, \"PID\": 528228445, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1084, \"PID\": 528228465, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159895}, {\"Order\": 1085, \"PID\": 528228540, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1146.0, \"TotalBsmtSF\": 1146.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 428.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187687}, {\"Order\": 1086, \"PID\": 528235020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1515, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1087, \"PID\": 528235120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7415, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 759.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 839.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1088, \"PID\": 528235180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1166, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1089, \"PID\": 528240040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 8029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1090, \"PID\": 528240050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1091, \"PID\": 528250030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8396, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1139, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1092, \"PID\": 528253020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 217300}, {\"Order\": 1093, \"PID\": 528280130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1094, \"PID\": 528280180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 647.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226750}, {\"Order\": 1095, \"PID\": 528290010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 15384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1096, \"PID\": 528290090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1097, \"PID\": 528292060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12460, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1098, \"PID\": 528294060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 873, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1099, \"PID\": 528315060, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1173.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284500}, {\"Order\": 1100, \"PID\": 528315110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1470, \"2ndFlrSF\": 1160, \"LowQualFinSF\": 0, \"GrLivArea\": 2630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 696.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 1101, \"PID\": 528326030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 14260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 1053, \"LowQualFinSF\": 0, \"GrLivArea\": 2198, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1102, \"PID\": 528326110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1519.0, \"TotalBsmtSF\": 1519.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 687.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 1103, \"PID\": 528346050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 136.0, \"LotArea\": 11675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 495.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2006, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1104, \"PID\": 528354100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 1061, \"LowQualFinSF\": 0, \"GrLivArea\": 2125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 1105, \"PID\": 528363020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1242.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1250, \"LowQualFinSF\": 0, \"GrLivArea\": 2501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1106, \"PID\": 528363110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10437, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 2109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 236, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1107, \"PID\": 528365060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 651.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1311.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 1093, \"LowQualFinSF\": 0, \"GrLivArea\": 2418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 983.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 154, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 341000}, {\"Order\": 1108, \"PID\": 528365080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 852.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2197, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 783.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 385, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287500}, {\"Order\": 1109, \"PID\": 528387050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 448.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 904, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1110, \"PID\": 528390020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 1986.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1987, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301500}, {\"Order\": 1111, \"PID\": 528427010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11932, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 830.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235128}, {\"Order\": 1112, \"PID\": 528427070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14598, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 74.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 1039, \"LowQualFinSF\": 0, \"GrLivArea\": 1933, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1113, \"PID\": 528429050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1574, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 824.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 1114, \"PID\": 528429070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13253, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1115, \"PID\": 528429080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264132}, {\"Order\": 1116, \"PID\": 528431060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 468.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 33.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1563.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1563, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1563, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1117, \"PID\": 528431080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 12274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1417.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227680}, {\"Order\": 1118, \"PID\": 528431120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1341.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 851.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 1119, \"PID\": 528435020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 919, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 297900}, {\"Order\": 1120, \"PID\": 528439010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1460.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1460, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1460, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247000}, {\"Order\": 1121, \"PID\": 528458030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1363.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212700}, {\"Order\": 1122, \"PID\": 528458050, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1372.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250580}, {\"Order\": 1123, \"PID\": 528462040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 95.0, \"LotArea\": 11639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1428.0, \"TotalBsmtSF\": 1428.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 182000}, {\"Order\": 1124, \"PID\": 528477040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226700}, {\"Order\": 1125, \"PID\": 528478030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 768.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1053.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 939, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1126, \"PID\": 528478040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 932, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1127, \"PID\": 528480060, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1034.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 1028, \"LowQualFinSF\": 0, \"GrLivArea\": 2078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 339750}, {\"Order\": 1128, \"PID\": 528480160, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 843, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 562.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205950}, {\"Order\": 1129, \"PID\": 528482020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1660.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1130, \"PID\": 528488140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230348}, {\"Order\": 1131, \"PID\": 528490080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 64.0, \"LotArea\": 8791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 361.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 673.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1132, \"PID\": 531363060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1133, \"PID\": 531371070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 555.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 861, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1134, \"PID\": 531373060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 1135, \"PID\": 531375050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1136, \"PID\": 531375110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1137, \"PID\": 531375120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1138, \"PID\": 531376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1139, \"PID\": 531376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1162.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1162, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1140, \"PID\": 531382090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 362.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1141, \"PID\": 531382110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 886.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 794, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1142, \"PID\": 531382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 258.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1679, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1679, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 1143, \"PID\": 531384030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 14565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 537.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1144, \"PID\": 531385060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1677, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190500}, {\"Order\": 1145, \"PID\": 531450030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 439.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1146, \"PID\": 531450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1147, \"PID\": 531450170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1148, \"PID\": 531451020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 165.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1617, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1617, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1149, \"PID\": 531452140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 899.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1199, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1150, \"PID\": 532351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 53.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 799.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1151, \"PID\": 532353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12968, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1152, \"PID\": 532354150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 764.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1153, \"PID\": 532376170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 890.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 890, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 890, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1154, \"PID\": 532377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119916}, {\"Order\": 1155, \"PID\": 532378200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1156, \"PID\": 532477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 19508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 108, \"EnclosedPorch\": 165, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1157, \"PID\": 532479020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 811.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 92, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1158, \"PID\": 533125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 1319, \"LowQualFinSF\": 0, \"GrLivArea\": 2683, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 251, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1159, \"PID\": 533125140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1328.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1827, \"2ndFlrSF\": 959, \"LowQualFinSF\": 0, \"GrLivArea\": 2786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372500}, {\"Order\": 1160, \"PID\": 533206050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 59.0, \"LotArea\": 4282, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1391, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 1161, \"PID\": 533208080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4017, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171900}, {\"Order\": 1162, \"PID\": 533208140, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3435, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1211.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 1163, \"PID\": 533212050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1164, \"PID\": 533212140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1165, \"PID\": 533212150, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3604, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1166, \"PID\": 533213070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179400}, {\"Order\": 1167, \"PID\": 533213120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 194.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 792, \"LowQualFinSF\": 0, \"GrLivArea\": 1549, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172900}, {\"Order\": 1168, \"PID\": 533215020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1027.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 587.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1638, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1169, \"PID\": 533215030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4538, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 179.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1170, \"PID\": 533215040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 42.0, \"LotArea\": 4385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1171, \"PID\": 533215070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1557.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1172, \"PID\": 533215080, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 50.0, \"LotArea\": 5119, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1709, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 97, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"CWD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 328900}, {\"Order\": 1173, \"PID\": 533217050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 628, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1174, \"PID\": 533217060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 20, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1175, \"PID\": 533234020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 79.0, \"LotArea\": 10646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 1789, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 1176, \"PID\": 533236060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1177, \"PID\": 533236070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 147.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1607, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1178, \"PID\": 533236090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 36.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 128.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 842.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1469, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2393, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 94, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 1179, \"PID\": 533250050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 14963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245500}, {\"Order\": 1180, \"PID\": 533250110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 22.0, \"LotArea\": 11064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1230.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1239, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1239, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 1181, \"PID\": 533250160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 32.0, \"LotArea\": 10846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1719.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1719, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1719, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 1182, \"PID\": 533251120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1183, \"PID\": 533350090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1050.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 584.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1599, \"2ndFlrSF\": 1345, \"LowQualFinSF\": 0, \"GrLivArea\": 2944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 70, \"EnclosedPorch\": 16, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1184, \"PID\": 533350120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 16280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1044.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 382.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1426.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1185, \"PID\": 534104100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 469.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1186, \"PID\": 534126090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1304.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 98, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1187, \"PID\": 534127210, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1427, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1188, \"PID\": 534127230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1439.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1189, \"PID\": 534128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1190, \"PID\": 534129060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 62, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1191, \"PID\": 534175140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1625.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1192, \"PID\": 534177180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1522.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 1066, \"LowQualFinSF\": 0, \"GrLivArea\": 2614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 243, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1193, \"PID\": 534201240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1194, \"PID\": 534202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1195, \"PID\": 534204030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 456.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1196, \"PID\": 534225110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1728.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1197, \"PID\": 534225120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1497.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142600}, {\"Order\": 1198, \"PID\": 534250010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 9246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 564.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1199, \"PID\": 534250335, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1200, \"PID\": 534250370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 1540, \"LowQualFinSF\": 0, \"GrLivArea\": 2715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 299800}, {\"Order\": 1201, \"PID\": 534250410, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 933, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1202, \"PID\": 534251280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 800, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1203, \"PID\": 534252090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 867.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178400}, {\"Order\": 1204, \"PID\": 534252270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1205, \"PID\": 534276190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7785, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 267.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1206, \"PID\": 534277060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 619.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109008}, {\"Order\": 1207, \"PID\": 534277070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135750}, {\"Order\": 1208, \"PID\": 534400030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 20, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1209, \"PID\": 534400060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 407, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 1210, \"PID\": 534401130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1165, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 129, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174900}, {\"Order\": 1211, \"PID\": 534401190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 892.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 426, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1212, \"PID\": 534403050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 305.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1213, \"PID\": 534403080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 1219.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1265, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 96, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1214, \"PID\": 534403100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 336.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1215, \"PID\": 534403260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 164, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1216, \"PID\": 534426040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 806.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 1217, \"PID\": 534427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10721, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 243.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1252.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1218, \"PID\": 534428020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12493, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 306.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1219, \"PID\": 534428100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1118.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1220, \"PID\": 534451080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Floor\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72500}, {\"Order\": 1221, \"PID\": 534451170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52000}, {\"Order\": 1222, \"PID\": 534452060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 4, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1223, \"PID\": 534453140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 453, \"2ndFlrSF\": 453, \"LowQualFinSF\": 0, \"GrLivArea\": 906, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 1224, \"PID\": 534455030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1225, \"PID\": 534477080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 220, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 1226, \"PID\": 534477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 32.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 308.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1227, \"PID\": 534477270, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 377.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 178, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1228, \"PID\": 534479150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 505.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112900}, {\"Order\": 1229, \"PID\": 535103050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 273, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201800}, {\"Order\": 1230, \"PID\": 535104020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 491.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1231, \"PID\": 535105030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139950}, {\"Order\": 1232, \"PID\": 535105060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1962, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 237.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1319.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1233, \"PID\": 535105090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 9150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1234, \"PID\": 535126140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 529.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 230, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1235, \"PID\": 535150210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 151.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 1098.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1236, \"PID\": 535150280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 25.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 872.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1237, \"PID\": 535151160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1283, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1283, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1238, \"PID\": 535152200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8856, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 52.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1239, \"PID\": 535153140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1240, \"PID\": 535153150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1261.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1261, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1261, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1400, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1241, \"PID\": 535176100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 187.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1570, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1570, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 490, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166800}, {\"Order\": 1242, \"PID\": 535178060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 580.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1243, \"PID\": 535179060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 387.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 458.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 1244, \"PID\": 535180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 135.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 130, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1245, \"PID\": 535180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1104, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1246, \"PID\": 535301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1247, \"PID\": 535302130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 196.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1248, \"PID\": 535302140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1249, \"PID\": 535303030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 14250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 998.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1250, \"PID\": 535305030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 852.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 1251, \"PID\": 535305160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 773, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 1252, \"PID\": 535327230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1253, \"PID\": 535352080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 1254, \"PID\": 535354200, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1255, \"PID\": 535375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 66, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89900}, {\"Order\": 1256, \"PID\": 535375160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 7506, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1257, \"PID\": 535380050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10930, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1258, \"PID\": 535380110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 1259, \"PID\": 535380140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 182, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 1488.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1260, \"PID\": 535383100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 694, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 114, \"EnclosedPorch\": 210, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106250}, {\"Order\": 1261, \"PID\": 535402120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9247, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 539.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1262, \"PID\": 535403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1263, \"PID\": 535425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Othr\", \"MiscVal\": 6500, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 1264, \"PID\": 535426260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1253.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 213, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1265, \"PID\": 535426350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 276.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1081.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1081, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 401.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1266, \"PID\": 535427070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 27650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2069, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 1267, \"PID\": 535451010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 910, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 414.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1268, \"PID\": 535451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 94000}, {\"Order\": 1269, \"PID\": 535451230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98300}, {\"Order\": 1270, \"PID\": 535452120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1507, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1507, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1271, \"PID\": 535453020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 488.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1272, \"PID\": 535453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 319.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125900}, {\"Order\": 1273, \"PID\": 535453210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 532.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1269.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1274, \"PID\": 535454150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 453.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 501, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1275, \"PID\": 535455060, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1276, \"PID\": 535455080, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 1277, \"PID\": 535455090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 181.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1278, \"PID\": 535456050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 8513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1279, \"PID\": 535456070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1280, \"PID\": 535456100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1281, \"PID\": 535475020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 415.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1282, \"PID\": 535476370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 106.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 1283, \"PID\": 535477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136870}, {\"Order\": 1284, \"PID\": 902100020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 96.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143000}, {\"Order\": 1285, \"PID\": 902100030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 30.0, \"LotArea\": 5232, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 1286, \"PID\": 902102060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1904, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 78, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1287, \"PID\": 902103150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9184, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 375, \"LowQualFinSF\": 0, \"GrLivArea\": 1323, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122600}, {\"Order\": 1288, \"PID\": 902105010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 680, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 1289, \"PID\": 902105020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 547, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 480, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1150, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1290, \"PID\": 902105130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1291, \"PID\": 902107030, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1292, \"PID\": 902109080, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 828.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 828, \"2ndFlrSF\": 658, \"LowQualFinSF\": 108, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 109, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1293, \"PID\": 902109110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 2082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1294, \"PID\": 902109120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 561, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119164}, {\"Order\": 1295, \"PID\": 902109160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 7308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122250}, {\"Order\": 1296, \"PID\": 902128075, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 931.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1297, \"PID\": 902128150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 590.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 552, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1298, \"PID\": 902134100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6756, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 481.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 1299, \"PID\": 902136110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 5914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 396, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 165, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1300, \"PID\": 902201120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 169.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 115000}, {\"Order\": 1301, \"PID\": 902201140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 608.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1302, \"PID\": 902202090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 904.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 869.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1303, \"PID\": 902205070, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 407.0, \"TotalBsmtSF\": 407.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 407, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 407, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 46500}, {\"Order\": 1304, \"PID\": 902205090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 620.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1305, \"PID\": 902205140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 901, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107900}, {\"Order\": 1306, \"PID\": 902207120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 103.0, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 1, \"YearBuilt\": 1949, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 65000}, {\"Order\": 1307, \"PID\": 902207220, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 87.0, \"LotArea\": 18386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1880, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1470.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 1818, \"LowQualFinSF\": 0, \"GrLivArea\": 3493, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295000}, {\"Order\": 1308, \"PID\": 902300110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 797.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 830, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1627, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1309, \"PID\": 902300215, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 540, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 418, \"OpenPorchSF\": 0, \"EnclosedPorch\": 194, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1310, \"PID\": 902300260, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 730, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1311, \"PID\": 902301140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 34.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 513.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98000}, {\"Order\": 1312, \"PID\": 902301150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9143, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 709, \"2ndFlrSF\": 308, \"LowQualFinSF\": 0, \"GrLivArea\": 1017, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 139, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1313, \"PID\": 902304060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 973, \"LowQualFinSF\": 0, \"GrLivArea\": 2350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 219, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1314, \"PID\": 902305080, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2058, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 259, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1315, \"PID\": 902306120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1905, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129400}, {\"Order\": 1316, \"PID\": 902306130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1928, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1317, \"PID\": 902326060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1905, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 691, \"LowQualFinSF\": 0, \"GrLivArea\": 1912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1318, \"PID\": 902328040, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 291, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1319, \"PID\": 902330010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5250, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1872, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 205, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 1320, \"PID\": 902401010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 572, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1321, \"PID\": 902401120, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1893, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1521, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 880.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 502, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1322, \"PID\": 902402260, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 2, \"OverallCond\": 1, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 723, \"2ndFlrSF\": 363, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1323, \"PID\": 902405070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 299, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1324, \"PID\": 902406020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1325, \"PID\": 902406090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1050.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 1326, \"PID\": 902427045, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 12702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 1327, \"PID\": 902427150, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8516, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 869.0, \"TotalBsmtSF\": 869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115500}, {\"Order\": 1328, \"PID\": 903201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7111, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1329, \"PID\": 903204010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 1330, \"PID\": 903204095, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 156, \"GrLivArea\": 935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 1331, \"PID\": 903206070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 175.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 594, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1332, \"PID\": 903225050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1333, \"PID\": 903225140, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1334, \"PID\": 903225160, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 554, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106900}, {\"Order\": 1335, \"PID\": 903226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 658, \"LowQualFinSF\": 0, \"GrLivArea\": 1672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 1336, \"PID\": 903226150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 949.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1337, \"PID\": 903227080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 862.0, \"TotalBsmtSF\": 862.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 208.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1338, \"PID\": 903228040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 201.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1497, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1339, \"PID\": 903228060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1340, \"PID\": 903228090, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 992.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1013, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 101, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1341, \"PID\": 903230110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 565, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1342, \"PID\": 903230120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 99.0, \"LotArea\": 5940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": null, \"BsmtFinType2\": null, \"BsmtFinSF2\": null, \"BsmtUnfSF\": null, \"TotalBsmtSF\": null, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79000}, {\"Order\": 1343, \"PID\": 903231080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 365, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1344, \"PID\": 903232030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81300}, {\"Order\": 1345, \"PID\": 903232090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1078.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 1346, \"PID\": 903233080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 989.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1347, \"PID\": 903234090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 897.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 139, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 1348, \"PID\": 903234100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129900}, {\"Order\": 1349, \"PID\": 903235010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 611.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1350, \"PID\": 903235100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 87, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68500}, {\"Order\": 1351, \"PID\": 903236010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 213, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1352, \"PID\": 903400180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 13053, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 220, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1353, \"PID\": 903401020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1354, \"PID\": 903401030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1355, \"PID\": 903401050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 883.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1356, \"PID\": 903425420, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 606.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1357, \"PID\": 903426160, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1000, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1358, \"PID\": 903427090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5100, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1359, \"PID\": 903429010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 4347, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1360, \"PID\": 903452025, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6291, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93850}, {\"Order\": 1361, \"PID\": 903453050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10266, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 216, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 136000}, {\"Order\": 1362, \"PID\": 903454100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1272.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 0, \"LowQualFinSF\": 697, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1363, \"PID\": 903455030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 428, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 117, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1364, \"PID\": 903455140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1365, \"PID\": 903456130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 647.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 127000}, {\"Order\": 1366, \"PID\": 903458110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 371, \"LowQualFinSF\": 0, \"GrLivArea\": 1406, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1367, \"PID\": 903475020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 645.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1368, \"PID\": 903476110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5586, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 110, \"LowQualFinSF\": 0, \"GrLivArea\": 1198, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79900}, {\"Order\": 1369, \"PID\": 903481010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 451.0, \"TotalBsmtSF\": 451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 759, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Family\", \"SalePrice\": 85000}, {\"Order\": 1370, \"PID\": 903481100, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 808, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 204, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82375}, {\"Order\": 1371, \"PID\": 903484020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1906, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 1469, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1906.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 57, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1372, \"PID\": 904100020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 122, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 1373, \"PID\": 904100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 1374, \"PID\": 904100160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 21286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1271, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1375, \"PID\": 904101170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134432}, {\"Order\": 1376, \"PID\": 904351280, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10106, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 181.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 547, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1377, \"PID\": 905100020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 64, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 148000}, {\"Order\": 1378, \"PID\": 905102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 906.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1379, \"PID\": 905103030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 39.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1380, \"PID\": 905104080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109900}, {\"Order\": 1381, \"PID\": 905104110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1382, \"PID\": 905104180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 702.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1383, \"PID\": 905107280, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 311, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1384, \"PID\": 905107380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9981, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 221.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 852.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1385, \"PID\": 905108170, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 956.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1386, \"PID\": 905200090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1198.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 108959}, {\"Order\": 1387, \"PID\": 905200100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 95541}, {\"Order\": 1388, \"PID\": 905200160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 1006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1006, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 1389, \"PID\": 905200510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149350}, {\"Order\": 1390, \"PID\": 905201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 634.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 1391, \"PID\": 905201110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 102, \"OpenPorchSF\": 89, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1392, \"PID\": 905201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1064.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 354.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 511, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1393, \"PID\": 905202230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 429.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1080.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 409, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1394, \"PID\": 905225040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1021, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1395, \"PID\": 905226030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1396, \"PID\": 905226110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1397, \"PID\": 905227050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 486, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152400}, {\"Order\": 1398, \"PID\": 905300020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1399, \"PID\": 905351089, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1003.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1291.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1291, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1400, \"PID\": 905352030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 299.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 2022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 117, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1401, \"PID\": 905352070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 20270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1402, \"PID\": 905401045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 39104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Membran\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1063.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1403, \"PID\": 905401060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1663, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1404, \"PID\": 905402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 11512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1019.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1357, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1357, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 163, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1405, \"PID\": 905403060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 617, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1079, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 249.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125600}, {\"Order\": 1406, \"PID\": 905403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 287, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1407, \"PID\": 905425125, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 45600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 907.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1307, \"2ndFlrSF\": 1051, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1908.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1408, \"PID\": 905426030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"PreCast\", \"Exterior2nd\": \"PreCast\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1035.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1409, \"PID\": 905427050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1163.0, \"TotalBsmtSF\": 1163.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 511, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1410, \"PID\": 905427070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 2108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1411, \"PID\": 905451330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1509.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 576, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1412, \"PID\": 905452070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99600}, {\"Order\": 1413, \"PID\": 905452120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 621, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1414, \"PID\": 905476120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1415, \"PID\": 905477050, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 969.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 527, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 1416, \"PID\": 905479110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1417, \"PID\": 905480150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 572, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 8, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 1418, \"PID\": 905480240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 380.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1419, \"PID\": 906204150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1475.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1532, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2329, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262280}, {\"Order\": 1420, \"PID\": 906204280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9771, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 1721, \"LowQualFinSF\": 0, \"GrLivArea\": 2814, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1421, \"PID\": 906223110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 251.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1626, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1422, \"PID\": 906223140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 355.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 1099, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1423, \"PID\": 906223220, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 735, \"LowQualFinSF\": 0, \"GrLivArea\": 2037, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 1424, \"PID\": 906378190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 628.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177439}, {\"Order\": 1425, \"PID\": 906380030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1615.0, \"TotalBsmtSF\": 1615.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1615, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1615, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 1426, \"PID\": 906412010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 2271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2276, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1348.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 475000}, {\"Order\": 1427, \"PID\": 906412050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1751.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395039}, {\"Order\": 1428, \"PID\": 906420130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 531.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 187, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 1429, \"PID\": 906424010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 631.0, \"TotalBsmtSF\": 1401.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 811.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1430, \"PID\": 906475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1182.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1643, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1643, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 339, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1431, \"PID\": 906476030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12798, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 154.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 1072, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 403, \"OpenPorchSF\": 114, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1432, \"PID\": 907126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 722.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1433, \"PID\": 907135020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1099.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1099, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1099, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1434, \"PID\": 907135260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1435, \"PID\": 907175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226001}, {\"Order\": 1436, \"PID\": 907176010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 688.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 899, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215700}, {\"Order\": 1437, \"PID\": 907181120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 782, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1438, \"PID\": 907181140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 873.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 193000}, {\"Order\": 1439, \"PID\": 907187030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1440, \"PID\": 907187080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 9382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1441, \"PID\": 907192130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 1442, \"PID\": 907194020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 963.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 963, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 245, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 1443, \"PID\": 907196040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1823, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 4500, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1444, \"PID\": 907196050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 1445, \"PID\": 907200110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 491.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 938, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130250}, {\"Order\": 1446, \"PID\": 907201060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 328.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 1447, \"PID\": 907202010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1174, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 211, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1448, \"PID\": 907202160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1449, \"PID\": 907202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1076, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143195}, {\"Order\": 1450, \"PID\": 907202240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 88.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1558, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1451, \"PID\": 907203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 7990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1452, \"PID\": 907227050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1453, \"PID\": 907227300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 780, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 1454, \"PID\": 907250020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1777.0, \"TotalBsmtSF\": 1777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 159, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1455, \"PID\": 907251090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9473, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 903, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 1456, \"PID\": 907253060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 257.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1457, \"PID\": 907253110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 1458, \"PID\": 907254020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9066, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 106, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1459, \"PID\": 907254090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 1460, \"PID\": 907255020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 396.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287000}, {\"Order\": 1461, \"PID\": 907255030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1357.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1366, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1462, \"PID\": 907255060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1786, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 715.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1463, \"PID\": 907260010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 1141, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 1464, \"PID\": 907262030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 334.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 1465, \"PID\": 907262060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 10905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1129.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1129, \"2ndFlrSF\": 1198, \"LowQualFinSF\": 0, \"GrLivArea\": 2327, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1466, \"PID\": 907262070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 595.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1467, \"PID\": 907265100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1468, \"PID\": 907285080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 642.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 933, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1469, \"PID\": 907290150, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1470, \"PID\": 907290250, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1471, \"PID\": 907295020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 215.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1493, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1493, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208900}, {\"Order\": 1472, \"PID\": 907295100, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 83.0, \"LotArea\": 10126, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1593.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 1473, \"PID\": 907405020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 726.0, \"TotalBsmtSF\": 1536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1536, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1474, \"PID\": 907405140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 854, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208500}, {\"Order\": 1475, \"PID\": 907412040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1421.0, \"TotalBsmtSF\": 1445.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1476, \"PID\": 907412070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 946.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 139, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1477, \"PID\": 907412080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 770, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1478, \"PID\": 907412090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1234, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1479, \"PID\": 907418010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1508.0, \"TotalBsmtSF\": 1564.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218836}, {\"Order\": 1480, \"PID\": 907418040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1327.0, \"TotalBsmtSF\": 1351.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1481, \"PID\": 907420080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1482, \"PID\": 907425010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149300}, {\"Order\": 1483, \"PID\": 907425015, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1484, \"PID\": 907425030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1485, \"PID\": 907425035, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 1486, \"PID\": 908102030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1487, \"PID\": 908102040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 928, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145900}, {\"Order\": 1488, \"PID\": 908102140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 259, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 123000}, {\"Order\": 1489, \"PID\": 908102260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 830.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 736, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1490, \"PID\": 908103260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 12102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 222.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1033, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1033, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 165000}, {\"Order\": 1491, \"PID\": 908103280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1033.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1127, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1492, \"PID\": 908127120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1493, \"PID\": 908128050, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 38.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1181, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1181, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1494, \"PID\": 908128110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 92.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165400}, {\"Order\": 1495, \"PID\": 908151040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 120.0, \"BsmtUnfSF\": 541.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1496, \"PID\": 908152110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1497, \"PID\": 908152270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1132.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1498, \"PID\": 908154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 123.0, \"LotArea\": 47007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3820, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3820, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 372, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284700}, {\"Order\": 1499, \"PID\": 908154235, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 63887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"ClyTile\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 796.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 5644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 6110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 4692, \"2ndFlrSF\": 950, \"LowQualFinSF\": 0, \"GrLivArea\": 5642, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 1418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 292, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 480, \"PoolQC\": \"Gd\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 160000}, {\"Order\": 1500, \"PID\": 908186040, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 459.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1501, \"PID\": 908201100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1502, \"PID\": 908201110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1503, \"PID\": 908201120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1307.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1504, \"PID\": 908204160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 1505, \"PID\": 908225170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91900}, {\"Order\": 1506, \"PID\": 908226120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 585, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 120000}, {\"Order\": 1507, \"PID\": 908250040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 1508, \"PID\": 908250090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 134, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Gar2\", \"MiscVal\": 3000, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1509, \"PID\": 908275130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1510, \"PID\": 908275180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1511, \"PID\": 908275280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 521, \"LowQualFinSF\": 0, \"GrLivArea\": 1393, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 265, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 1512, \"PID\": 908276140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1513, \"PID\": 909100150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 343, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1514, \"PID\": 909100170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1515, \"PID\": 909101060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 41.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 823.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67000}, {\"Order\": 1516, \"PID\": 909101180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5687, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135900}, {\"Order\": 1517, \"PID\": 909131170, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 254, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1518, \"PID\": 909175050, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 720, \"LowQualFinSF\": 420, \"GrLivArea\": 2192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179500}, {\"Order\": 1519, \"PID\": 909175100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 423.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 758.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 304, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1520, \"PID\": 909177120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1521, \"PID\": 909201110, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 8525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1911, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 940.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1522, \"PID\": 909250040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 1611, \"LowQualFinSF\": 0, \"GrLivArea\": 2601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 183, \"OpenPorchSF\": 0, \"EnclosedPorch\": 301, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1523, \"PID\": 909250230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 679.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 161900}, {\"Order\": 1524, \"PID\": 909251080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8969, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 369.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1525, \"PID\": 909251090, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1423, \"2ndFlrSF\": 748, \"LowQualFinSF\": 384, \"GrLivArea\": 2555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1526, \"PID\": 909252110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1527, \"PID\": 909252220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15564, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1528, \"PID\": 909253190, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 1529, \"PID\": 909254050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7609, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 16, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 1530, \"PID\": 909256060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 473, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1531, \"PID\": 909275040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 599.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 217, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1532, \"PID\": 909275050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1533, \"PID\": 909276170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1934, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 389.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 849, \"2ndFlrSF\": 811, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188700}, {\"Order\": 1534, \"PID\": 909277040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 673, \"LowQualFinSF\": 0, \"GrLivArea\": 1938, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 1535, \"PID\": 909277070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 932, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1536, \"PID\": 909281030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 7801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 591.0, \"TotalBsmtSF\": 1091.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 344.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 221, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 1537, \"PID\": 909281110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 786.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 207, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 257076}, {\"Order\": 1538, \"PID\": 909282030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1935, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1968, \"2ndFlrSF\": 1479, \"LowQualFinSF\": 0, \"GrLivArea\": 3447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1014.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 381000}, {\"Order\": 1539, \"PID\": 909425010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 817, \"LowQualFinSF\": 0, \"GrLivArea\": 1954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 311500}, {\"Order\": 1540, \"PID\": 909425085, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 943, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263400}, {\"Order\": 1541, \"PID\": 909428170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 26073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1898.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1898, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 1542, \"PID\": 909428190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 568.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 924.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 1543, \"PID\": 909451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 366.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 213, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 1544, \"PID\": 909451150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 612.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1545, \"PID\": 910200080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 555.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 919, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1546, \"PID\": 910201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 330, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1547, \"PID\": 910202050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1548, \"PID\": 910202100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1549, \"PID\": 910203020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 71.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 125.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 778, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 924.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1550, \"PID\": 910203090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 780, \"2ndFlrSF\": 420, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1551, \"PID\": 910205010, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1552, \"PID\": 910206110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 1553, \"PID\": 910226040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1955, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1554, \"PID\": 910251050, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 80.0, \"LotArea\": 14584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Po\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 13100}, {\"Order\": 1555, \"PID\": 911102090, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 5280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1895, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1895.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 185.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 1556, \"PID\": 911102170, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 649, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1317, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 172, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 40000}, {\"Order\": 1557, \"PID\": 911102180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 52.0, \"LotArea\": 5150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 671, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80900}, {\"Order\": 1558, \"PID\": 911226010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 120.0, \"LotArea\": 18000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 560, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1559, \"PID\": 911226030, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 432, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 65000}, {\"Order\": 1560, \"PID\": 911370410, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 5587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392500}, {\"Order\": 1561, \"PID\": 911370490, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294464}, {\"Order\": 1562, \"PID\": 911370520, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1563, \"PID\": 911370540, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 1564, \"PID\": 914453045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 668.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2032, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1565, \"PID\": 914465060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 857.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1566, \"PID\": 914467050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 910.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 318, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1567, \"PID\": 914475020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 574.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 358.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 576, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1568, \"PID\": 914476010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 83, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 1569, \"PID\": 914476080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1570, \"PID\": 914476450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 428, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 1571, \"PID\": 916125425, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 164660, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 1499.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1619, \"2ndFlrSF\": 167, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 670, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228950}, {\"Order\": 1572, \"PID\": 916226030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 893.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1573, \"PID\": 916325080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15498, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1165.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 665.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 174, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 287000}, {\"Order\": 1574, \"PID\": 916380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 258.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1575, \"PID\": 916382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293077}, {\"Order\": 1576, \"PID\": 916384100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264966}, {\"Order\": 1577, \"PID\": 916386040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 712, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 1578, \"PID\": 916386080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": null, \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 1579, \"PID\": 916386180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 12018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 218689}, {\"Order\": 1580, \"PID\": 916402015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1495.0, \"TotalBsmtSF\": 1495.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1495, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1581, \"PID\": 916402115, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 12416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1398.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 208.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1582, \"PID\": 916402215, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 18265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1583, \"PID\": 916403230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 219.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 783.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1584, \"PID\": 916455120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11202, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1029.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 1432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232500}, {\"Order\": 1585, \"PID\": 916460060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7915, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1586, \"PID\": 916477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 2262, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 749.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1587, \"PID\": 921126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1011.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 873.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 276, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 298751}, {\"Order\": 1588, \"PID\": 921201060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1571.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 393.0, \"TotalBsmtSF\": 1964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 892.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1589, \"PID\": 923202005, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 97.0, \"LotArea\": 8940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 209200}, {\"Order\": 1590, \"PID\": 923202015, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 206300}, {\"Order\": 1591, \"PID\": 923202137, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9278, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1592, \"PID\": 923203140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 197.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 1189.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1189, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1189, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1593, \"PID\": 923204040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 171, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1594, \"PID\": 923225080, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 271.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1595, \"PID\": 923225150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1596, \"PID\": 923225200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 318.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1597, \"PID\": 923225310, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 501.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 526.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1598, \"PID\": 923225370, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 120, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94900}, {\"Order\": 1599, \"PID\": 923227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1160, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 257.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 1600, \"PID\": 923228080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1970, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1601, \"PID\": 923228420, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1602, \"PID\": 923250210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 988.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1603, \"PID\": 923252100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 6490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1604, \"PID\": 923275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 6951, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 362, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1605, \"PID\": 923277030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1982, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1606, \"PID\": 923277040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1982, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1607, \"PID\": 923277080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1608, \"PID\": 923400040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 983.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1300, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1609, \"PID\": 923426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 647.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 889, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1610, \"PID\": 924100020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 562.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 193.0, \"BsmtUnfSF\": 29.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1611, \"PID\": 1007100110, \"MSSubClass\": 70, \"MSZoning\": \"I (all)\", \"LotFrontage\": null, \"LotArea\": 56600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1612, \"PID\": 526352080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 838.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 749.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1587, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1587, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167300}, {\"Order\": 1613, \"PID\": 526352090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1277, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 526.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 1614, \"PID\": 526355170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 2223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2223, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2223, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 1615, \"PID\": 526355190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 15865, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 823.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 2217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 1616, \"PID\": 527105140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 225000}, {\"Order\": 1617, \"PID\": 527107040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 373.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1618, \"PID\": 527110080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 794, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1619, \"PID\": 527110120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 1620, \"PID\": 527110130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 1621, \"PID\": 527126030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 1622, \"PID\": 527158090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 770, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1623, \"PID\": 527161090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 947, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1624, \"PID\": 527162080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178750}, {\"Order\": 1625, \"PID\": 527162090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1626, \"PID\": 527162140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 957, \"2ndFlrSF\": 1342, \"LowQualFinSF\": 0, \"GrLivArea\": 2299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1627, \"PID\": 527163080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1168.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1628, \"PID\": 527165020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1629, \"PID\": 527165100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163900}, {\"Order\": 1630, \"PID\": 527165170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 903.0, \"TotalBsmtSF\": 903.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1631, \"PID\": 527175130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 18160, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 154204}, {\"Order\": 1632, \"PID\": 527182040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1633, \"PID\": 527182170, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1634, \"PID\": 527184020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 4740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1166.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 135, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1635, \"PID\": 527184110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 5118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 926.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1321, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1321, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 1636, \"PID\": 527210060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377426}, {\"Order\": 1637, \"PID\": 527212060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1377, \"LowQualFinSF\": 0, \"GrLivArea\": 2541, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 729.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 349265}, {\"Order\": 1638, \"PID\": 527216080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 51974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 710.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1101.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1559.0, \"TotalBsmtSF\": 2660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1110.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 591587}, {\"Order\": 1639, \"PID\": 527226040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 195.0, \"LotArea\": 41600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1047.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 53.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1640, \"PID\": 527252050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8035, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 797.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 164, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 1641, \"PID\": 527252070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8089, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 1642, \"PID\": 527256030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 945.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1558.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 2220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 441929}, {\"Order\": 1643, \"PID\": 527256040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 13870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 174, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 455000}, {\"Order\": 1644, \"PID\": 527301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 99, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182900}, {\"Order\": 1645, \"PID\": 527301280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1028.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1646, \"PID\": 527302020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 178000}, {\"Order\": 1647, \"PID\": 527302060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 167, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1648, \"PID\": 527302090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1328.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 1529.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1649, \"PID\": 527325090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 11339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 549.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 22.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1650, \"PID\": 527325110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11952, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1161, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 276, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1651, \"PID\": 527327050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12046, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 2030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1652, \"PID\": 527328020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 605.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1653, \"PID\": 527328050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1177, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1654, \"PID\": 527353080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 539.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 1655, \"PID\": 527354050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 253.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1259.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1353, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192350}, {\"Order\": 1656, \"PID\": 527356050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 263.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1657, \"PID\": 527357020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 13001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 249, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1658, \"PID\": 527358060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1659, \"PID\": 527359010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 175.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1660, \"PID\": 527359080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 1661, \"PID\": 527359160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 604.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 585.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 407, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1662, \"PID\": 527377110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 153.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1877, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 1663, \"PID\": 527402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 349.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 533, \"LowQualFinSF\": 0, \"GrLivArea\": 1109, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 35, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1664, \"PID\": 527402150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 35.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143250}, {\"Order\": 1665, \"PID\": 527402240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1972, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1666, \"PID\": 527403310, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1667, \"PID\": 527404050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 619.0, \"BsmtUnfSF\": 214.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1668, \"PID\": 527404100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 412.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1669, \"PID\": 527404140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8294, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1670, \"PID\": 527404150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 322.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1671, \"PID\": 527425025, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1672, \"PID\": 527425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1673, \"PID\": 527427090, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 139.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 767, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 367.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1674, \"PID\": 527427160, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 33.0, \"LotArea\": 4113, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1337.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1675, \"PID\": 527427200, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 10943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1676, \"PID\": 527450030, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 1677, \"PID\": 527450150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 356.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1678, \"PID\": 527450220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113700}, {\"Order\": 1679, \"PID\": 527451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2016, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1680, \"PID\": 527451170, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 376.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 1681, \"PID\": 527452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 958.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 205, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1682, \"PID\": 527453010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 556.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1683, \"PID\": 527455030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 6.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 1061.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 1684, \"PID\": 527455250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 725.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129250}, {\"Order\": 1685, \"PID\": 528102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12469, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1151.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1790.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356000}, {\"Order\": 1686, \"PID\": 528102090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 452.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1774.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 260, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 314813}, {\"Order\": 1687, \"PID\": 528102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1688, \"PID\": 528102120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 322400}, {\"Order\": 1689, \"PID\": 528102130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 328.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 730.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1690, \"PID\": 528104010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 2108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345474}, {\"Order\": 1691, \"PID\": 528106040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 315.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2121.0, \"TotalBsmtSF\": 2121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 415298}, {\"Order\": 1692, \"PID\": 528106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13641, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1304.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1934.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1943, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 2656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1040.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 492000}, {\"Order\": 1693, \"PID\": 528106060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1108.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 1402, \"LowQualFinSF\": 0, \"GrLivArea\": 2550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338931}, {\"Order\": 1694, \"PID\": 528106110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 400.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 450000}, {\"Order\": 1695, \"PID\": 528108160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 14154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1063.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1071, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 947.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 280000}, {\"Order\": 1696, \"PID\": 528110040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 2552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 479069}, {\"Order\": 1697, \"PID\": 528110070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 375.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1935.0, \"TotalBsmtSF\": 1935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1973, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1973, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395000}, {\"Order\": 1698, \"PID\": 528110100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 772.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2153.0, \"TotalBsmtSF\": 2153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 2643, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 694.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 380000}, {\"Order\": 1699, \"PID\": 528112150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1626.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1634, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1634, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1700, \"PID\": 528114050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14977, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 1976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 440000}, {\"Order\": 1701, \"PID\": 528118040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13654, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1704.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1722, \"2ndFlrSF\": 1036, \"LowQualFinSF\": 0, \"GrLivArea\": 2758, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 418000}, {\"Order\": 1702, \"PID\": 528118050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 17169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 970.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 2320.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1174.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 500067}, {\"Order\": 1703, \"PID\": 528120010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1582.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 570, \"LowQualFinSF\": 0, \"GrLivArea\": 2152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 368, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260116}, {\"Order\": 1704, \"PID\": 528120150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 317000}, {\"Order\": 1705, \"PID\": 528142050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9709, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319500}, {\"Order\": 1706, \"PID\": 528144050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325624}, {\"Order\": 1707, \"PID\": 528150040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 510.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1802.0, \"TotalBsmtSF\": 1802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1802, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372000}, {\"Order\": 1708, \"PID\": 528150110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 13069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 502.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1706.0, \"TotalBsmtSF\": 1706.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 1238, \"LowQualFinSF\": 0, \"GrLivArea\": 2956, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 916.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 342000}, {\"Order\": 1709, \"PID\": 528150120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 388.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 970.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 872.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 354000}, {\"Order\": 1710, \"PID\": 528166150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14277, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1317.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1711, \"PID\": 528168040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11999, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1712, \"PID\": 528172030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 669.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 895.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 895, \"2ndFlrSF\": 923, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281500}, {\"Order\": 1713, \"PID\": 528172050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1178.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245700}, {\"Order\": 1714, \"PID\": 528172070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9254, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1602.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232698}, {\"Order\": 1715, \"PID\": 528172075, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1298.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 876.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 1716, \"PID\": 528174010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194700}, {\"Order\": 1717, \"PID\": 528174020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3901, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204000}, {\"Order\": 1718, \"PID\": 528174030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 272.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1719, \"PID\": 528174040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 6289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1720, \"PID\": 528181060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1721, \"PID\": 528181070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1722, \"PID\": 528181080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 1723, \"PID\": 528186050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 7841, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 394.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 848.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 729.0, \"TotalBsmtSF\": 1577.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1577, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 1724, \"PID\": 528186090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 1725, \"PID\": 528186120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1869.0, \"TotalBsmtSF\": 1869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318061}, {\"Order\": 1726, \"PID\": 528186190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1300.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221370}, {\"Order\": 1727, \"PID\": 528188160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 235.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1728, \"PID\": 528218010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 15810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181755}, {\"Order\": 1729, \"PID\": 528218020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1730, \"PID\": 528218050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 783, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 178900}, {\"Order\": 1731, \"PID\": 528218100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 13204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 168165}, {\"Order\": 1732, \"PID\": 528221030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8857, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 757, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 171925}, {\"Order\": 1733, \"PID\": 528221040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9729, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 1048, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198444}, {\"Order\": 1734, \"PID\": 528221050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 918.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 1735, \"PID\": 528221090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179540}, {\"Order\": 1736, \"PID\": 528222030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 176485}, {\"Order\": 1737, \"PID\": 528222040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1340.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181134}, {\"Order\": 1738, \"PID\": 528222050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 796, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156932}, {\"Order\": 1739, \"PID\": 528222060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8229, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 22.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1740, \"PID\": 528222080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7713, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177594}, {\"Order\": 1741, \"PID\": 528222090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1246.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173500}, {\"Order\": 1742, \"PID\": 528228270, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172500}, {\"Order\": 1743, \"PID\": 528228275, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194201}, {\"Order\": 1744, \"PID\": 528228375, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3621, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1589, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1745, \"PID\": 528228555, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185485}, {\"Order\": 1746, \"PID\": 528231010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 182.0, \"LotArea\": 14572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 259000}, {\"Order\": 1747, \"PID\": 528231030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 16219, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1119, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1119, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1748, \"PID\": 528235000, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 175000}, {\"Order\": 1749, \"PID\": 528235160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11796, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1112, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1750, \"PID\": 528235170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1510.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 206580}, {\"Order\": 1751, \"PID\": 528240020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 1752, \"PID\": 528250010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1753, \"PID\": 528250070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 1754, \"PID\": 528275035, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1755, \"PID\": 528275110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 1131, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1756, \"PID\": 528280110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 694, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1757, \"PID\": 528280150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1758, \"PID\": 528290060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 1759, \"PID\": 528290170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1760, \"PID\": 528294010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9649, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1761, \"PID\": 528320050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 15623, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2411, \"2ndFlrSF\": 2065, \"LowQualFinSF\": 0, \"GrLivArea\": 4476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 813.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 555, \"PoolQC\": \"Ex\", \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 745000}, {\"Order\": 1762, \"PID\": 528322020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 515.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 2551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 384500}, {\"Order\": 1763, \"PID\": 528326060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 1288, \"LowQualFinSF\": 0, \"GrLivArea\": 2285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 1764, \"PID\": 528327060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 705.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1351.0, \"TotalBsmtSF\": 2633.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2633, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2633, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 804.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 466500}, {\"Order\": 1765, \"PID\": 528340030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10557, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 1407, \"LowQualFinSF\": 0, \"GrLivArea\": 3078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 806.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 1766, \"PID\": 528344020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1048.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 1171, \"LowQualFinSF\": 0, \"GrLivArea\": 2582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 322500}, {\"Order\": 1767, \"PID\": 528348030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 275.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1066.0, \"TotalBsmtSF\": 1066.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1277, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 1768, \"PID\": 528351010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 21535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1170.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 989.0, \"TotalBsmtSF\": 2444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2444, \"2ndFlrSF\": 1872, \"LowQualFinSF\": 0, \"GrLivArea\": 4316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 832.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 755000}, {\"Order\": 1769, \"PID\": 528354060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 862.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2013, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 455.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269790}, {\"Order\": 1770, \"PID\": 528354110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11787, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 594.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 1379.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 1015, \"LowQualFinSF\": 0, \"GrLivArea\": 2398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315750}, {\"Order\": 1771, \"PID\": 528358040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1203.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 290000}, {\"Order\": 1772, \"PID\": 528364110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1318.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 752.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1773, \"PID\": 528366050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1969.0, \"TotalBsmtSF\": 3200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 75, \"EnclosedPorch\": 291, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 430000}, {\"Order\": 1774, \"PID\": 528366070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 335.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2202, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 1775, \"PID\": 528376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 526.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1225.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1325.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2538, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 933.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 1776, \"PID\": 528427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1369.0, \"TotalBsmtSF\": 1369.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1369, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 203, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 213133}, {\"Order\": 1777, \"PID\": 528427100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1542, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260261}, {\"Order\": 1778, \"PID\": 528429090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 11670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1905.0, \"TotalBsmtSF\": 1905.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1905, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1905, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 1779, \"PID\": 528429110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282922}, {\"Order\": 1780, \"PID\": 528431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1534, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 215000}, {\"Order\": 1781, \"PID\": 528431040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 754.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 394.0, \"TotalBsmtSF\": 1966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1966, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1092.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 419005}, {\"Order\": 1782, \"PID\": 528431050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13501, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 63.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1623.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1783, \"PID\": 528431110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9986, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 428.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1795.0, \"TotalBsmtSF\": 1795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 1784, \"PID\": 528435010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1528, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235876}, {\"Order\": 1785, \"PID\": 528435040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1126.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 311872}, {\"Order\": 1786, \"PID\": 528435060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 954.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248328}, {\"Order\": 1787, \"PID\": 528435070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 825.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1788, \"PID\": 528439040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8847, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 1538.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1538, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1538, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1789, \"PID\": 528439050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 1790, \"PID\": 528439080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8251, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 1791, \"PID\": 528441080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 255, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 307000}, {\"Order\": 1792, \"PID\": 528445020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 982, \"2ndFlrSF\": 995, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 250000}, {\"Order\": 1793, \"PID\": 528445070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 528, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 859.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221300}, {\"Order\": 1794, \"PID\": 528456190, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1314.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1795, \"PID\": 528456230, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1335.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1335, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210400}, {\"Order\": 1796, \"PID\": 528458080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 255000}, {\"Order\": 1797, \"PID\": 528458090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 10411, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212109}, {\"Order\": 1798, \"PID\": 528458120, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1025.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 1799, \"PID\": 528458130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 64.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1120.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1184, \"2ndFlrSF\": 1426, \"LowQualFinSF\": 0, \"GrLivArea\": 2610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 364, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 303477}, {\"Order\": 1800, \"PID\": 528458150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1880, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310013}, {\"Order\": 1801, \"PID\": 528477020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 11096, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249700}, {\"Order\": 1802, \"PID\": 528480020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 874.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1761, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227875}, {\"Order\": 1803, \"PID\": 528480180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1574.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 256, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 261329}, {\"Order\": 1804, \"PID\": 528482010, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 11824, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1685.0, \"TotalBsmtSF\": 1685.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1685, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1685, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 1805, \"PID\": 528482030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 353.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2443, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 744.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 1806, \"PID\": 528482090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 102.0, \"LotArea\": 11143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 159, \"OpenPorchSF\": 214, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 1807, \"PID\": 531363020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 146000}, {\"Order\": 1808, \"PID\": 531363040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1809, \"PID\": 531375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1810, \"PID\": 531376060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1461.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1811, \"PID\": 531380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 1812, \"PID\": 531384070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11613, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191750}, {\"Order\": 1813, \"PID\": 531385070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1349.0, \"TotalBsmtSF\": 1349.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1349, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1349, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1814, \"PID\": 531385130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 39.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 402, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1815, \"PID\": 531451030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1145.0, \"TotalBsmtSF\": 1575.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1816, \"PID\": 531451150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1817, \"PID\": 531453140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1818, \"PID\": 531477040, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1819, \"PID\": 532353120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 351.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120750}, {\"Order\": 1820, \"PID\": 532354010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1821, \"PID\": 532354060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1822, \"PID\": 532354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 999.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1823, \"PID\": 532376040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 6970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1824, \"PID\": 532376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 13673, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143900}, {\"Order\": 1825, \"PID\": 532377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 7476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1826, \"PID\": 532377140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 57.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 827.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1827, \"PID\": 532378240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1828, \"PID\": 532476080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1232, \"LowQualFinSF\": 0, \"GrLivArea\": 2503, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1829, \"PID\": 532477040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 125.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1031.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 2167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1830, \"PID\": 532479050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 10751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1037, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1831, \"PID\": 532479120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16647, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1701, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 611.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1832, \"PID\": 532479140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 968.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 455, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 147000}, {\"Order\": 1833, \"PID\": 533120030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 482.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 1357, \"LowQualFinSF\": 0, \"GrLivArea\": 2810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 500, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 1834, \"PID\": 533130170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10678, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 337.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 983.0, \"TotalBsmtSF\": 1683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2129, \"2ndFlrSF\": 743, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1835, \"PID\": 533205110, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 45.0, \"LotArea\": 4379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 527.0, \"TotalBsmtSF\": 1378.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1836, \"PID\": 533206060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 3523, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1081.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1151, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1837, \"PID\": 533206070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 3784, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1511.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193800}, {\"Order\": 1838, \"PID\": 533208010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 47.0, \"LotArea\": 4230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1352.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1839, \"PID\": 533208020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3606, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 937.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 1840, \"PID\": 533208030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1550, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 207500}, {\"Order\": 1841, \"PID\": 533208040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4274, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1106.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1241.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1241, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1241, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199900}, {\"Order\": 1842, \"PID\": 533208070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4251, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164700}, {\"Order\": 1843, \"PID\": 533213130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 1844, \"PID\": 533213140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1129.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1845, \"PID\": 533221030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1846, \"PID\": 533221060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1847, \"PID\": 533221100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1848, \"PID\": 533223050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 5105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 551.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 551, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 1849, \"PID\": 533236040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1850, \"PID\": 533241030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 66.0, \"LotArea\": 7399, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 1851, \"PID\": 533242080, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 73.0, \"LotArea\": 7321, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1339.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1852, \"PID\": 533242090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 1853, \"PID\": 533244040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 106.0, \"LotArea\": 8413, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 1105.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 1854, \"PID\": 533250190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1037.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 217, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279700}, {\"Order\": 1855, \"PID\": 533251110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1856, \"PID\": 533251130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 1857, \"PID\": 533252130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1157.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 1858, \"PID\": 533253180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 176.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 89, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213750}, {\"Order\": 1859, \"PID\": 533254100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 761, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1860, \"PID\": 533254130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 978.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181500}, {\"Order\": 1861, \"PID\": 533350020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 17778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1632.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 829.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 2461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2497, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2497, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 373000}, {\"Order\": 1862, \"PID\": 533352075, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAe\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 211.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 1361.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 1259, \"LowQualFinSF\": 0, \"GrLivArea\": 2620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 24, \"EnclosedPorch\": 145, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 8300, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1863, \"PID\": 534104090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 1929, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 1864, \"PID\": 534125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143450}, {\"Order\": 1865, \"PID\": 534127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 1008, \"LowQualFinSF\": 0, \"GrLivArea\": 2411, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240050}, {\"Order\": 1866, \"PID\": 534127140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 973.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1867, \"PID\": 534127260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 385.0, \"TotalBsmtSF\": 1295.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 194, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 1868, \"PID\": 534128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 11358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1869, \"PID\": 534151090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1594, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1870, \"PID\": 534151180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1871, \"PID\": 534175010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAn\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136905}, {\"Order\": 1872, \"PID\": 534176140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 792.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1873, \"PID\": 534177210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 916.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1874, \"PID\": 534178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1875, \"PID\": 534201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 38.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1876, \"PID\": 534202030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 519.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1877, \"PID\": 534204120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1878, \"PID\": 534252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1879, \"PID\": 534252060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10624, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1880, \"PID\": 534252070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1881, \"PID\": 534252110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 978.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 1882, \"PID\": 534275170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1960, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 15500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1883, \"PID\": 534275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 66.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1065, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 1884, \"PID\": 534276070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 63.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 81.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1885, \"PID\": 534276160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 285, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1886, \"PID\": 534276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 206.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1887, \"PID\": 534276290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 1888, \"PID\": 534278150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 167.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1889, \"PID\": 534278170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1890, \"PID\": 534278190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117600}, {\"Order\": 1891, \"PID\": 534401120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1174.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1892, \"PID\": 534401200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1893, \"PID\": 534403040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 270.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 580.0, \"BsmtUnfSF\": 452.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 309.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 333, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1894, \"PID\": 534403290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 1309, \"LowQualFinSF\": 0, \"GrLivArea\": 2154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 1895, \"PID\": 534403420, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 543.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1130.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1374, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1896, \"PID\": 534425015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 1592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 201, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1897, \"PID\": 534425080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 219.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1429, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1429, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1898, \"PID\": 534427140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1327, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1327, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150750}, {\"Order\": 1899, \"PID\": 534429030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101800}, {\"Order\": 1900, \"PID\": 534430090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 932, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 306.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 214, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1901, \"PID\": 534431020, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 259.0, \"BsmtUnfSF\": 433.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 908, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 1902, \"PID\": 534450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 2, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 39300}, {\"Order\": 1903, \"PID\": 534450110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1904, \"PID\": 534451020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 442, \"2ndFlrSF\": 228, \"LowQualFinSF\": 0, \"GrLivArea\": 670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1905, \"PID\": 534453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 404.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 1906, \"PID\": 534475170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1907, \"PID\": 534476080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1908, \"PID\": 534478140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Roll\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 708.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 992, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1909, \"PID\": 534479120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1910, \"PID\": 534479140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 1911, \"PID\": 535101150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1912, \"PID\": 535102010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 87.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1913, \"PID\": 535105110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 291.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1914, \"PID\": 535106140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 1915, \"PID\": 535106180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11344, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 874, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1916, \"PID\": 535126180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 1021.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1465, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Sev\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129000}, {\"Order\": 1917, \"PID\": 535151020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 873.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 63.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 219, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1918, \"PID\": 535151100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 908.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 1919, \"PID\": 535151110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 109, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142100}, {\"Order\": 1920, \"PID\": 535152060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1921, \"PID\": 535154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 243.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 834.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 275, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 1922, \"PID\": 535155110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 1923, \"PID\": 535176070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1244, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1244, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1924, \"PID\": 535177020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 69.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1144.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1925, \"PID\": 535177110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 138.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1331.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174850}, {\"Order\": 1926, \"PID\": 535179120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1927, \"PID\": 535180030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 586.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1928, \"PID\": 535181030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1237.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1657, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1929, \"PID\": 535181140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1930, \"PID\": 535300040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 928.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1931, \"PID\": 535301060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1932, \"PID\": 535301160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8078, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128600}, {\"Order\": 1933, \"PID\": 535302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1934, \"PID\": 535304170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 85.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 955.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 293.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1935, \"PID\": 535305180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1936, \"PID\": 535325090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 691.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1937, \"PID\": 535325280, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1938, \"PID\": 535325320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 500, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1939, \"PID\": 535327160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1940, \"PID\": 535327200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 377.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 551.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1941, \"PID\": 535353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 368, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1942, \"PID\": 535353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 324, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1943, \"PID\": 535353160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 14190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 544, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1944, \"PID\": 535354050, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 893, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 893, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1945, \"PID\": 535354260, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 512, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1946, \"PID\": 535355020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 21281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 1778, \"LowQualFinSF\": 0, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 208, \"EnclosedPorch\": 290, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 301600}, {\"Order\": 1947, \"PID\": 535375130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 735.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 735, \"2ndFlrSF\": 299, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 1948, \"PID\": 535376010, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 882.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103200}, {\"Order\": 1949, \"PID\": 535378080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 66.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 1950, \"PID\": 535379060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1951, \"PID\": 535379110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1895, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1952, \"PID\": 535382150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 691.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 86000}, {\"Order\": 1953, \"PID\": 535402140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 364.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 242.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1954, \"PID\": 535402180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 1955, \"PID\": 535403030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 952.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1956, \"PID\": 535426130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1957, \"PID\": 535450190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122900}, {\"Order\": 1958, \"PID\": 535450220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119200}, {\"Order\": 1959, \"PID\": 535450310, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10496, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1960, \"PID\": 535451040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 246.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1961, \"PID\": 535451100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1238, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 171, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 1962, \"PID\": 535451110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 398.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 149.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1963, \"PID\": 535452060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 254.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1964, \"PID\": 535453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1965, \"PID\": 535453150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7315, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1170.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1170, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1966, \"PID\": 535453180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 1967, \"PID\": 535457020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1098.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 154.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1377.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1377, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 1968, \"PID\": 535457040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1969, \"PID\": 535457050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1970, \"PID\": 535476360, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 831, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1971, \"PID\": 535477130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 1972, \"PID\": 535477180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 442.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1973, \"PID\": 535478040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 90, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1974, \"PID\": 902100010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1975, \"PID\": 902105110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 664, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 132000}, {\"Order\": 1976, \"PID\": 902106070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 175, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1977, \"PID\": 902106120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 782.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 184.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1978, \"PID\": 902107050, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1979, \"PID\": 902110010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 3153, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 26, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 1980, \"PID\": 902125120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1885, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1047, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1047, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1981, \"PID\": 902128160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 279.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1982, \"PID\": 902201090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 494, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 26, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1983, \"PID\": 902201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 679, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1984, \"PID\": 902202070, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 435.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 89471}, {\"Order\": 1985, \"PID\": 902205020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 122.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 448.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 761, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1986, \"PID\": 902205130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 1987, \"PID\": 902206270, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1075.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 642, \"LowQualFinSF\": 0, \"GrLivArea\": 1798, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1988, \"PID\": 902207010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1945, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 1989, \"PID\": 902207150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 968.0, \"TotalBsmtSF\": 968.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1990, \"PID\": 902300020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10337, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 1991, \"PID\": 902300040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 9863, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 374.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1992, \"PID\": 902301030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 842, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1993, \"PID\": 902301130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1994, \"PID\": 902302150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 1995, \"PID\": 902303100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 667.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 659, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144100}, {\"Order\": 1996, \"PID\": 902304040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1880, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 1997, \"PID\": 902305010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 316.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 687.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 687, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 124500}, {\"Order\": 1998, \"PID\": 902330090, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1879, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 819.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2454, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1999, \"PID\": 902332030, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1046.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 1031, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 99, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 2000, \"PID\": 902401030, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 779.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2001, \"PID\": 902404010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1221.0, \"TotalBsmtSF\": 1559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1559, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1559, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 230, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2002, \"PID\": 902408080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 718.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2003, \"PID\": 902427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 9439, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2004, \"PID\": 902427140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2005, \"PID\": 902427180, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2006, \"PID\": 903201090, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 6854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 227.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 916, \"2ndFlrSF\": 144, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 150, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2007, \"PID\": 903204030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8674, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1435, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128250}, {\"Order\": 2008, \"PID\": 903205085, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 8731, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 645.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2009, \"PID\": 903206170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 915, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2010, \"PID\": 903225040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2011, \"PID\": 903227140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 217.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 2012, \"PID\": 903228080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 349, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2013, \"PID\": 903231050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2014, \"PID\": 903231090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 809.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2015, \"PID\": 903231180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 423, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2016, \"PID\": 903232100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 966.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2017, \"PID\": 903233030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 903, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2018, \"PID\": 903233050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1933.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2019, \"PID\": 903233140, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 854, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2020, \"PID\": 903233180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 959, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 2021, \"PID\": 903234160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2022, \"PID\": 903236130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 7755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1164, \"LowQualFinSF\": 0, \"GrLivArea\": 2264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2023, \"PID\": 903400040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2024, \"PID\": 903401070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2025, \"PID\": 903425270, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 356, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2026, \"PID\": 903425280, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153575}, {\"Order\": 2027, \"PID\": 903426010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1929, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2028, \"PID\": 903427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 546.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 714.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 15, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136000}, {\"Order\": 2029, \"PID\": 903430040, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 933, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 113000}, {\"Order\": 2030, \"PID\": 903430050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 969, \"2ndFlrSF\": 245, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 117000}, {\"Order\": 2031, \"PID\": 903450060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 2032, \"PID\": 903451110, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 7449, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 2033, \"PID\": 903453080, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1497, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2034, \"PID\": 903454010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 0, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2035, \"PID\": 903454090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2036, \"PID\": 903456110, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 398.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 1952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 285, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212300}, {\"Order\": 2037, \"PID\": 903457040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 1042, \"LowQualFinSF\": 0, \"GrLivArea\": 2180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2038, \"PID\": 903457130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 4330, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 477, \"LowQualFinSF\": 0, \"GrLivArea\": 1315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 99500}, {\"Order\": 2039, \"PID\": 903458020, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 581, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101000}, {\"Order\": 2040, \"PID\": 903458060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 197.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 999.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2041, \"PID\": 903475040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 12358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 528, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2042, \"PID\": 903475060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 964, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2043, \"PID\": 903476100, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 4388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2044, \"PID\": 903484080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 771.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 504, \"LowQualFinSF\": 114, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 14, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 84, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 50000}, {\"Order\": 2045, \"PID\": 904100100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1937, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 1005, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 521, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219000}, {\"Order\": 2046, \"PID\": 904101070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 138.0, \"LotArea\": 18030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 977.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 971, \"LowQualFinSF\": 479, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 2047, \"PID\": 904301110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 756, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 126000}, {\"Order\": 2048, \"PID\": 904302010, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 4484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2049, \"PID\": 905100060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2050, \"PID\": 905100080, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158450}, {\"Order\": 2051, \"PID\": 905101070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 14299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115400}, {\"Order\": 2052, \"PID\": 905101200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1029, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 261.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2053, \"PID\": 905102010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 722.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2054, \"PID\": 905103110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 761.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2055, \"PID\": 905104030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 627.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 913, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2056, \"PID\": 905104090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 7094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2057, \"PID\": 905104170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 948.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 108000}, {\"Order\": 2058, \"PID\": 905104240, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 20.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2059, \"PID\": 905105040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 8665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 897, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2060, \"PID\": 905105170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 323.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 529.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2061, \"PID\": 905105260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 955, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2062, \"PID\": 905106150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 8724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2063, \"PID\": 905107140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 2064, \"PID\": 905200010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2065, \"PID\": 905201080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 522.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 323.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2066, \"PID\": 905225020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 16779, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 1087, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 570, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2067, \"PID\": 905226050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1416, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2068, \"PID\": 905226080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165250}, {\"Order\": 2069, \"PID\": 905226130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 231.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2070, \"PID\": 905226170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 873.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"VWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2071, \"PID\": 905228020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 998, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 998, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 2072, \"PID\": 905301050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 115149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 739.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 380, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 2073, \"PID\": 905352010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 891.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2074, \"PID\": 905352180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2075, \"PID\": 905376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 109.0, \"TotalBsmtSF\": 409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1325, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 2076, \"PID\": 905377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 587.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2077, \"PID\": 905377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 17808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2078, \"PID\": 905401020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2079, \"PID\": 905426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 12615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 477.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243000}, {\"Order\": 2080, \"PID\": 905451390, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 491.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 638, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 332.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 2081, \"PID\": 905475270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2082, \"PID\": 905475520, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11515, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2083, \"PID\": 905476160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 7711, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2084, \"PID\": 905476170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 605, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 605, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 2085, \"PID\": 905476225, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 3869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 755.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1038.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1038, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2086, \"PID\": 905478140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2087, \"PID\": 905478220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1080.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 400, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2088, \"PID\": 905480090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 951.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 376, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 2089, \"PID\": 905480180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2090, \"PID\": 906200230, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 23920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1105.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 1012, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 444, \"PoolQC\": \"TA\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2091, \"PID\": 906201022, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 10357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 719.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 244, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2092, \"PID\": 906201023, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 1121, \"LowQualFinSF\": 0, \"GrLivArea\": 2243, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 44, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2093, \"PID\": 906201200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1474.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2730, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 2094, \"PID\": 906203140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 634.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 833.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 192, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2095, \"PID\": 906204140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 807.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 196, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2096, \"PID\": 906223040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 497.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 929, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2097, \"PID\": 906340080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 984.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 1414, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 383970}, {\"Order\": 2098, \"PID\": 906340090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1362, \"LowQualFinSF\": 0, \"GrLivArea\": 2828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 424870}, {\"Order\": 2099, \"PID\": 906378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 2100, \"PID\": 906378150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10481, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2140.0, \"TotalBsmtSF\": 2140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 360000}, {\"Order\": 2101, \"PID\": 906378170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10652, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1494.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 279500}, {\"Order\": 2102, \"PID\": 906380010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 11175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 200141}, {\"Order\": 2103, \"PID\": 906380040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 10235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246500}, {\"Order\": 2104, \"PID\": 906380070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1482.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 1092, \"LowQualFinSF\": 0, \"GrLivArea\": 2574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 276000}, {\"Order\": 2105, \"PID\": 906380120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 349.0, \"TotalBsmtSF\": 1274.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1274, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203000}, {\"Order\": 2106, \"PID\": 906380140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11103, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155835}, {\"Order\": 2107, \"PID\": 906380160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2108, \"PID\": 906380200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 195400}, {\"Order\": 2109, \"PID\": 906382020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1526.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1546, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1546, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2110, \"PID\": 906382060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1453.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 674.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212999}, {\"Order\": 2111, \"PID\": 906392080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1270.0, \"TotalBsmtSF\": 1270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1270, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2112, \"PID\": 906394020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 916, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 2113, \"PID\": 906394050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176432}, {\"Order\": 2114, \"PID\": 906402070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1157.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 882, \"LowQualFinSF\": 0, \"GrLivArea\": 2062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 154, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2115, \"PID\": 906403060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 321.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 927, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2116, \"PID\": 906426060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 159000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 2144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2117, \"PID\": 906426195, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53107, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 985.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 874, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 231, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2118, \"PID\": 906475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2087, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2119, \"PID\": 906475170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 155.0, \"LotArea\": 20064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 51.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 915.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 646, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2120, \"PID\": 907125040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 472.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 747.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2121, \"PID\": 907125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2122, \"PID\": 907130060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11249, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 544.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 2123, \"PID\": 907131060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 10021, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 635.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 646, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2124, \"PID\": 907131120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9531, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 914, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2125, \"PID\": 907135050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2126, \"PID\": 907135080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 16561, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 242.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147900}, {\"Order\": 2127, \"PID\": 907135180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123600}, {\"Order\": 2128, \"PID\": 907180040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 905, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204750}, {\"Order\": 2129, \"PID\": 907187040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 646.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 597.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235500}, {\"Order\": 2130, \"PID\": 907187060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12352, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 853, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1753, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2131, \"PID\": 907192020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 845.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190550}, {\"Order\": 2132, \"PID\": 907192040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8826, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2133, \"PID\": 907192120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 167.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1013.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2134, \"PID\": 907192150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2135, \"PID\": 907200130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 131000}, {\"Order\": 2136, \"PID\": 907200190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 502.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2137, \"PID\": 907200250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1009, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2138, \"PID\": 907200270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 2139, \"PID\": 907202100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 16300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 417.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2140, \"PID\": 907202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 432.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2141, \"PID\": 907203060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 2142, \"PID\": 907203110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 10356, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 969, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2143, \"PID\": 907227060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 671.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2144, \"PID\": 907227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2145, \"PID\": 907250050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 2000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305900}, {\"Order\": 2146, \"PID\": 907252020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1284.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 2169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2147, \"PID\": 907252190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11354, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1412.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1673, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1673, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2148, \"PID\": 907260040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1459.0, \"TotalBsmtSF\": 1459.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1459, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1459, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 2149, \"PID\": 907260050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 2150, \"PID\": 907262020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 214.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2151, \"PID\": 907270040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 16226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 1242, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 267000}, {\"Order\": 2152, \"PID\": 907275080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 519.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 683.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1592, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1592, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2153, \"PID\": 907275150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 1531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2439, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2154, \"PID\": 907280090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2155, \"PID\": 907280100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 2156, \"PID\": 907285040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 438.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1079.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2157, \"PID\": 907290140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 2158, \"PID\": 907295040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 17227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246900}, {\"Order\": 2159, \"PID\": 907401060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1081, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2160, \"PID\": 907405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2161, \"PID\": 907410020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179400}, {\"Order\": 2162, \"PID\": 907410050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 639.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 2163, \"PID\": 907414060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1422.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179600}, {\"Order\": 2164, \"PID\": 907414070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 709.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 2165, \"PID\": 907420050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1330, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167840}, {\"Order\": 2166, \"PID\": 907420060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 753, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168675}, {\"Order\": 2167, \"PID\": 907420110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2168, \"PID\": 908102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2169, \"PID\": 908102160, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 405, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 2170, \"PID\": 908103090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 132.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2171, \"PID\": 908127040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 10921, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 48.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94750}, {\"Order\": 2172, \"PID\": 908127060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 16287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 450, \"LowQualFinSF\": 0, \"GrLivArea\": 1351, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 43, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2173, \"PID\": 908127070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1179.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2174, \"PID\": 908127100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 11841, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2175, \"PID\": 908152060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2176, \"PID\": 908152070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 751.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2177, \"PID\": 908152180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9555, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1133, \"LowQualFinSF\": 0, \"GrLivArea\": 2233, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2178, \"PID\": 908152260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1125.0, \"TotalBsmtSF\": 1125.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155000}, {\"Order\": 2179, \"PID\": 908152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2180, \"PID\": 908152290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 123.0, \"TotalBsmtSF\": 734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 674, \"LowQualFinSF\": 0, \"GrLivArea\": 1408, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 2181, \"PID\": 908154195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 39290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 4010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 5095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 5095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 5095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 15, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1154.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 546, \"OpenPorchSF\": 484, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Elev\", \"MiscVal\": 17000, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 183850}, {\"Order\": 2182, \"PID\": 908154205, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 40094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 762.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 3138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3138, \"2ndFlrSF\": 1538, \"LowQualFinSF\": 0, \"GrLivArea\": 4676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 406, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 184750}, {\"Order\": 2183, \"PID\": 908186050, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 467.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2184, \"PID\": 908204090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 77.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 831.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2185, \"PID\": 908204180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2186, \"PID\": 908225240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 2187, \"PID\": 908225310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1195, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 118, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98500}, {\"Order\": 2188, \"PID\": 908226180, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 4270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 286, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2189, \"PID\": 908228010, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 278.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 740, \"2ndFlrSF\": 125, \"LowQualFinSF\": 0, \"GrLivArea\": 865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2190, \"PID\": 908250100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 2191, \"PID\": 908275090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2192, \"PID\": 908275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2193, \"PID\": 908275240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 79275}, {\"Order\": 2194, \"PID\": 908276230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2195, \"PID\": 909176080, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 10896, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1184.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 1440, \"LowQualFinSF\": 515, \"GrLivArea\": 3395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 8, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 14, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 200000}, {\"Order\": 2196, \"PID\": 909176170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2592, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 742, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1512, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 150000}, {\"Order\": 2197, \"PID\": 909250150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 53, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2198, \"PID\": 909250160, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10594, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 2199, \"PID\": 909251030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7223, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2200, \"PID\": 909251040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6821, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 113.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2201, \"PID\": 909252010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 787, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2202, \"PID\": 909252150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 4000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 567, \"2ndFlrSF\": 531, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 2203, \"PID\": 909252170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 6720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 585, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 2204, \"PID\": 909254090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7642, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 514, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189950}, {\"Order\": 2205, \"PID\": 909254100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 775, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2206, \"PID\": 909254130, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 364.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2207, \"PID\": 909254140, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1913, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 365.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90350}, {\"Order\": 2208, \"PID\": 909254150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 661.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 661, \"2ndFlrSF\": 589, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 242, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2209, \"PID\": 909256120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 920.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119750}, {\"Order\": 2210, \"PID\": 909275020, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 7136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 979, \"2ndFlrSF\": 979, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2211, \"PID\": 909275030, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 6270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 1001, \"LowQualFinSF\": 0, \"GrLivArea\": 2002, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2212, \"PID\": 909275110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1927, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 867, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 291, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2213, \"PID\": 909275160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 126.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 24, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 228, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2214, \"PID\": 909275310, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 22420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1128.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2215, \"PID\": 909276160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12168, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 537.0, \"TotalBsmtSF\": 965.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 3194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 359100}, {\"Order\": 2216, \"PID\": 909276210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 7810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1230, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2217, \"PID\": 909279080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 557.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 19, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2218, \"PID\": 909281020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 6221, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2219, \"PID\": 909281130, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1549, \"2ndFlrSF\": 1178, \"LowQualFinSF\": 0, \"GrLivArea\": 2727, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2220, \"PID\": 909282020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1945, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 150.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 2320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259500}, {\"Order\": 2221, \"PID\": 909425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 1477.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1839, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 2222, \"PID\": 909425270, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2223, \"PID\": 909428120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 35.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 869.0, \"BsmtUnfSF\": 905.0, \"TotalBsmtSF\": 1809.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2259, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2259, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 217000}, {\"Order\": 2224, \"PID\": 909428180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1020.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 584, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 2225, \"PID\": 909428340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21579, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2226, \"PID\": 909451130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 529, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 2227, \"PID\": 909452102, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2228, \"PID\": 909455060, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 577.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2229, \"PID\": 909475050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 652.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 434.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1262.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 2230, \"PID\": 909475070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 2035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2515, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2515, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 200624}, {\"Order\": 2231, \"PID\": 909475230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 18044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 279.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 64, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 228, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2232, \"PID\": 910200040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 997, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2233, \"PID\": 910200110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2234, \"PID\": 910201020, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 803, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2235, \"PID\": 910201050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 176, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129850}, {\"Order\": 2236, \"PID\": 910201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 772, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1123, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 2237, \"PID\": 910201180, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": null, \"GarageArea\": null, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 150909}, {\"Order\": 2238, \"PID\": 910202030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 46.0, \"LotArea\": 3672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 100.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75200}, {\"Order\": 2239, \"PID\": 910203290, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118400}, {\"Order\": 2240, \"PID\": 910204090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 961.0, \"TotalBsmtSF\": 961.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"Mix\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 67000}, {\"Order\": 2241, \"PID\": 910205130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 910, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2242, \"PID\": 910206010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 11067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 205, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68104}, {\"Order\": 2243, \"PID\": 911103060, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1895, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 957.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 957, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 133, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119600}, {\"Order\": 2244, \"PID\": 911128010, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 65.0, \"LotArea\": 6565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 106.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 444, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2245, \"PID\": 911128020, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 837.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1001, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 86, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 2246, \"PID\": 911370450, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2247, \"PID\": 911370460, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 481.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 235000}, {\"Order\": 2248, \"PID\": 914452090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1001.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2249, \"PID\": 914452120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2250, \"PID\": 914452190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2251, \"PID\": 914460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 856.0, \"TotalBsmtSF\": 1441.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2252, \"PID\": 914460110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 12864, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 17.0, \"TotalBsmtSF\": 1409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1409, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 2253, \"PID\": 914476330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2254, \"PID\": 914478020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 530.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 852.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2255, \"PID\": 914478100, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 924.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2256, \"PID\": 916226090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 4054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 949.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 2257, \"PID\": 916253320, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 9763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 239.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1102.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 2258, \"PID\": 916326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 16905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2259, \"PID\": 916326090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 19958, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 274, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2260, \"PID\": 916384050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 231713}, {\"Order\": 2261, \"PID\": 916384070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8298, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 963.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2207.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267300}, {\"Order\": 2262, \"PID\": 916384080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1476.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265900}, {\"Order\": 2263, \"PID\": 916384150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1571.0, \"TotalBsmtSF\": 1571.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1571, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239000}, {\"Order\": 2264, \"PID\": 916386170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 274.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1638.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248900}, {\"Order\": 2265, \"PID\": 916403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 215.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 1265.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2266, \"PID\": 916403290, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2267, \"PID\": 916455010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 742.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1756, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 2268, \"PID\": 916455050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6718, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2269, \"PID\": 916455110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 82.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2270, \"PID\": 916455150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 886.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 593.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282000}, {\"Order\": 2271, \"PID\": 916460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2272, \"PID\": 916475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 808.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 252, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2273, \"PID\": 916477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 1340, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279900}, {\"Order\": 2274, \"PID\": 917425190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 35133, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 995.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 263, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 263, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186700}, {\"Order\": 2275, \"PID\": 921126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 15306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1652.0, \"TotalBsmtSF\": 1732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 283463}, {\"Order\": 2276, \"PID\": 921128030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 2277, \"PID\": 921205070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1094.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 1349, \"LowQualFinSF\": 0, \"GrLivArea\": 2482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 281213}, {\"Order\": 2278, \"PID\": 923202134, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 914.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 2279, \"PID\": 923202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 200.0, \"LotArea\": 43500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1041.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 561, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2280, \"PID\": 923203010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 6710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 904.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2281, \"PID\": 923204050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 25286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132250}, {\"Order\": 2282, \"PID\": 923204140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 25000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2283, \"PID\": 923205025, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 149.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1622, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 439, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2284, \"PID\": 923225040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 840.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2285, \"PID\": 923225050, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 874.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 536, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2286, \"PID\": 923226300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2287, \"PID\": 923228200, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 27.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 97, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 2288, \"PID\": 923228220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93900}, {\"Order\": 2289, \"PID\": 923228250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 2290, \"PID\": 923228290, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 131.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 499.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2291, \"PID\": 923228390, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 75190}, {\"Order\": 2292, \"PID\": 923229010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146800}, {\"Order\": 2293, \"PID\": 923229040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9129, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2294, \"PID\": 923229100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1356, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 1424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2295, \"PID\": 923229140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 33983, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1112.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1676, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 690, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2296, \"PID\": 923230010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 185.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2297, \"PID\": 923230120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 2298, \"PID\": 923230180, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 149.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2299, \"PID\": 923251160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 27697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"CBlock\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 811.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1608, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2300, \"PID\": 923252080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7599, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2301, \"PID\": 923275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1090.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 88, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2302, \"PID\": 923275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2303, \"PID\": 923276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 596.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 330, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2304, \"PID\": 923400150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 212.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 974.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 974, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 974, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93500}, {\"Order\": 2305, \"PID\": 923425030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 887, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2306, \"PID\": 526302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11027, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1178.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1293, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1293, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2307, \"PID\": 526302040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 280, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2308, \"PID\": 526302120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1127.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 963.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2309, \"PID\": 526303060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 39384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 902.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 252000}, {\"Order\": 2310, \"PID\": 526354020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11727, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 434.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1851.0, \"TotalBsmtSF\": 1851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1851, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192100}, {\"Order\": 2311, \"PID\": 527105060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8238, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2312, \"PID\": 527106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 964.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 1243, \"LowQualFinSF\": 0, \"GrLivArea\": 2236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2313, \"PID\": 527107020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 781, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2314, \"PID\": 527107030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13031, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 592.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2315, \"PID\": 527107120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 821.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 821, \"2ndFlrSF\": 955, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 443.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2316, \"PID\": 527107240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 714.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 413.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 95, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2317, \"PID\": 527108010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 19378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 2462, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2318, \"PID\": 527108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 14859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 27.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1670.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 240000}, {\"Order\": 2319, \"PID\": 527108030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 13128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 990, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2320, \"PID\": 527108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 893.0, \"TotalBsmtSF\": 893.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 2321, \"PID\": 527108060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 13751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1640.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 2212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 773.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 309000}, {\"Order\": 2322, \"PID\": 527108090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 168.0, \"LotArea\": 23257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2021, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 274725}, {\"Order\": 2323, \"PID\": 527146135, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2062.0, \"TotalBsmtSF\": 2062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2079, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2324, \"PID\": 527158020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8076, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2325, \"PID\": 527163020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165600}, {\"Order\": 2326, \"PID\": 527166030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 2327, \"PID\": 527182020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 3701, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2328, \"PID\": 527190050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 5306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 215.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 441, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2329, \"PID\": 527190220, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 28, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2330, \"PID\": 527210030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 1384, \"LowQualFinSF\": 0, \"GrLivArea\": 2798, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 37, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 457347}, {\"Order\": 2331, \"PID\": 527210040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 18062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 662.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 1862, \"LowQualFinSF\": 0, \"GrLivArea\": 3390, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 545224}, {\"Order\": 2332, \"PID\": 527210050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 205.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 889.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1371, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 246, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356383}, {\"Order\": 2333, \"PID\": 527212030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 16056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1752.0, \"TotalBsmtSF\": 1992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1992, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 2868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 716.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 556581}, {\"Order\": 2334, \"PID\": 527212040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 1312, \"LowQualFinSF\": 0, \"GrLivArea\": 2576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 361919}, {\"Order\": 2335, \"PID\": 527214060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 16052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 734.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 2698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 535000}, {\"Order\": 2336, \"PID\": 527216010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 15922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 550.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 1405, \"LowQualFinSF\": 0, \"GrLivArea\": 2795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 401179}, {\"Order\": 2337, \"PID\": 527216050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1031.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1410.0, \"TotalBsmtSF\": 1410.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 1519, \"LowQualFinSF\": 0, \"GrLivArea\": 2945, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 37, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 438780}, {\"Order\": 2338, \"PID\": 527226010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1547, \"2ndFlrSF\": 720, \"LowQualFinSF\": 53, \"GrLivArea\": 2320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2339, \"PID\": 527250040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 34650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2340, \"PID\": 527252090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 523.0, \"TotalBsmtSF\": 1714.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1714, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 2341, \"PID\": 527254070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11302, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Other\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1422.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1826, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319000}, {\"Order\": 2342, \"PID\": 527256120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 18261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 123, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 470000}, {\"Order\": 2343, \"PID\": 527301010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 995.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2344, \"PID\": 527302080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1002.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 2183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2345, \"PID\": 527325160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 34.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 795.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 250, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2346, \"PID\": 527327080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2347, \"PID\": 527328010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2348, \"PID\": 527354040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 604.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 2349, \"PID\": 527355060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1857, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188900}, {\"Order\": 2350, \"PID\": 527355280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 1061.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 384, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2351, \"PID\": 527356020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1392, \"LowQualFinSF\": 0, \"GrLivArea\": 2784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 440, \"PoolArea\": 519, \"PoolQC\": \"Fa\", \"Fence\": \"MnPrv\", \"MiscFeature\": \"TenC\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2352, \"PID\": 527356060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 811, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 208, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2353, \"PID\": 527358090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 42.0, \"TotalBsmtSF\": 1047.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1083, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1083, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 444, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2354, \"PID\": 527365010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1358, \"LowQualFinSF\": 0, \"GrLivArea\": 2318, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 246, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294323}, {\"Order\": 2355, \"PID\": 527375160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 127.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1109, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 485.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 2356, \"PID\": 527376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2357, \"PID\": 527376110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 2358, \"PID\": 527377030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 377.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1309, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1309, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 648, \"PoolQC\": \"Fa\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2359, \"PID\": 527378010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2360, \"PID\": 527402210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 75.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 791.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 138800}, {\"Order\": 2361, \"PID\": 527402380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9353, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 116050}, {\"Order\": 2362, \"PID\": 527403120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 614.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 2363, \"PID\": 527404180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 2364, \"PID\": 527427210, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 951.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1487.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2365, \"PID\": 527450010, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 514.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 2366, \"PID\": 527450080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2367, \"PID\": 527450210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 408.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83000}, {\"Order\": 2368, \"PID\": 527450460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 494, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2369, \"PID\": 527451200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 91500}, {\"Order\": 2370, \"PID\": 527451380, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2371, \"PID\": 527451450, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 465, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2372, \"PID\": 527451460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 382.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2373, \"PID\": 527451520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 297.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94500}, {\"Order\": 2374, \"PID\": 527452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 156.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146300}, {\"Order\": 2375, \"PID\": 527452290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 373.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1387, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2376, \"PID\": 527452310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 175, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2377, \"PID\": 527453070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2378, \"PID\": 527455100, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2379, \"PID\": 528102010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 66.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1447.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 770.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2380, \"PID\": 528102080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 16387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1738, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 2589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 412083}, {\"Order\": 2381, \"PID\": 528106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 111.0, \"LotArea\": 16259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 370.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1249.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1249, \"2ndFlrSF\": 1347, \"LowQualFinSF\": 0, \"GrLivArea\": 2596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 342643}, {\"Order\": 2382, \"PID\": 528106120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 16163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1618.0, \"TotalBsmtSF\": 1618.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1618, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1618, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 2383, \"PID\": 528110050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 690.0, \"TotalBsmtSF\": 2076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2076, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 229, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 465000}, {\"Order\": 2384, \"PID\": 528112010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 12228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1721.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293000}, {\"Order\": 2385, \"PID\": 528114010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 14780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1085.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 354, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2386, \"PID\": 528116030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 16033, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1261.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 519, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 326000}, {\"Order\": 2387, \"PID\": 528118010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 14215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1218, \"LowQualFinSF\": 0, \"GrLivArea\": 2376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 853.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325300}, {\"Order\": 2388, \"PID\": 528118020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 309000}, {\"Order\": 2389, \"PID\": 528118110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13975, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 300000}, {\"Order\": 2390, \"PID\": 528120110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1030.0, \"TotalBsmtSF\": 1030.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 1060, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 2391, \"PID\": 528120140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 385.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 466, \"LowQualFinSF\": 0, \"GrLivArea\": 2091, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338500}, {\"Order\": 2392, \"PID\": 528138030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345000}, {\"Order\": 2393, \"PID\": 528142010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 12867, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1209.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 344133}, {\"Order\": 2394, \"PID\": 528142060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 10672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 1335, \"LowQualFinSF\": 0, \"GrLivArea\": 2389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 298236}, {\"Order\": 2395, \"PID\": 528142070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 814, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 329900}, {\"Order\": 2396, \"PID\": 528142110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 1896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 708.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 2397, \"PID\": 528144030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11065, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 788.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 1085.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 753.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281000}, {\"Order\": 2398, \"PID\": 528150080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372397}, {\"Order\": 2399, \"PID\": 528150090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 131.0, \"LotArea\": 14828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 1780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378000}, {\"Order\": 2400, \"PID\": 528164040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 562.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 374000}, {\"Order\": 2401, \"PID\": 528170040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 20431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 870.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1848, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 2728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 437154}, {\"Order\": 2402, \"PID\": 528172020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 512.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 179, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2403, \"PID\": 528172150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 488, \"LowQualFinSF\": 0, \"GrLivArea\": 1914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2404, \"PID\": 528174080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 705.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185850}, {\"Order\": 2405, \"PID\": 528180080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 5911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282500}, {\"Order\": 2406, \"PID\": 528181030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6955, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202500}, {\"Order\": 2407, \"PID\": 528181040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 6792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202665}, {\"Order\": 2408, \"PID\": 528186100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 518.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 899.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 332200}, {\"Order\": 2409, \"PID\": 528186110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 572.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1251.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310090}, {\"Order\": 2410, \"PID\": 528188040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171750}, {\"Order\": 2411, \"PID\": 528218030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 23, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169990}, {\"Order\": 2412, \"PID\": 528218060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 170440}, {\"Order\": 2413, \"PID\": 528218080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169985}, {\"Order\": 2414, \"PID\": 528218130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 17104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 426.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179665}, {\"Order\": 2415, \"PID\": 528218140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 14054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 1863, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 219210}, {\"Order\": 2416, \"PID\": 528221010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 11660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1326.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 174190}, {\"Order\": 2417, \"PID\": 528221100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172785}, {\"Order\": 2418, \"PID\": 528222010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11631, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1052.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 1321, \"LowQualFinSF\": 0, \"GrLivArea\": 2373, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 258000}, {\"Order\": 2419, \"PID\": 528222020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185101}, {\"Order\": 2420, \"PID\": 528228280, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3087, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 767.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210250}, {\"Order\": 2421, \"PID\": 528228325, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1374.0, \"TotalBsmtSF\": 1374.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 2422, \"PID\": 528228340, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1273.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2423, \"PID\": 528228360, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1038.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246990}, {\"Order\": 2424, \"PID\": 528228415, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1375.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178740}, {\"Order\": 2425, \"PID\": 528228430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2426, \"PID\": 528228545, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167240}, {\"Order\": 2427, \"PID\": 528228550, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1126.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156820}, {\"Order\": 2428, \"PID\": 528228565, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213490}, {\"Order\": 2429, \"PID\": 528228575, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1154.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 1520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264561}, {\"Order\": 2430, \"PID\": 528228580, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246578}, {\"Order\": 2431, \"PID\": 528231050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 21930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192140}, {\"Order\": 2432, \"PID\": 528235050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7861, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183200}, {\"Order\": 2433, \"PID\": 528235130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2434, \"PID\": 528235190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1598, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201490}, {\"Order\": 2435, \"PID\": 528240080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1406.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1454, \"2ndFlrSF\": 482, \"LowQualFinSF\": 0, \"GrLivArea\": 1936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 2436, \"PID\": 528250060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2437, \"PID\": 528275060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8121, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 711, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172400}, {\"Order\": 2438, \"PID\": 528275080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2439, \"PID\": 528280100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 930, \"LowQualFinSF\": 0, \"GrLivArea\": 1886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 89, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199900}, {\"Order\": 2440, \"PID\": 528290140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 959.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 2441, \"PID\": 528292080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287602}, {\"Order\": 2442, \"PID\": 528294070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 1286, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2443, \"PID\": 528315030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1074.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1407, \"2ndFlrSF\": 985, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 348000}, {\"Order\": 2444, \"PID\": 528315070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 31, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 2445, \"PID\": 528315080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 322.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 655.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1205, \"2ndFlrSF\": 1029, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2446, \"PID\": 528320060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 35760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1831, \"2ndFlrSF\": 1796, \"LowQualFinSF\": 0, \"GrLivArea\": 3627, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 807.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 361, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 625000}, {\"Order\": 2447, \"PID\": 528327010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9233, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 877.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 358.0, \"TotalBsmtSF\": 1540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1540, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2855, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 247, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 405000}, {\"Order\": 2448, \"PID\": 528344060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 530.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 374, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2449, \"PID\": 528348010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 258000}, {\"Order\": 2450, \"PID\": 528358030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 397.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 1368, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 169, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 2451, \"PID\": 528360050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 17242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 738.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1393.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1733.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1933, \"2ndFlrSF\": 1567, \"LowQualFinSF\": 0, \"GrLivArea\": 3500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 959.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 870, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 584500}, {\"Order\": 2452, \"PID\": 528363070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 501.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1305, \"2ndFlrSF\": 1189, \"LowQualFinSF\": 0, \"GrLivArea\": 2494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 803.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 321000}, {\"Order\": 2453, \"PID\": 528365090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 391.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1203, \"2ndFlrSF\": 1323, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 309, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 2454, \"PID\": 528366040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1039.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 1234, \"LowQualFinSF\": 0, \"GrLivArea\": 2799, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 432, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2455, \"PID\": 528429060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 760.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252000}, {\"Order\": 2456, \"PID\": 528429100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1562.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336820}, {\"Order\": 2457, \"PID\": 528429120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 20896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1721.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 2077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1134.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 267, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 423000}, {\"Order\": 2458, \"PID\": 528429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290000}, {\"Order\": 2459, \"PID\": 528439030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1616.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 2460, \"PID\": 528445010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1504.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199000}, {\"Order\": 2461, \"PID\": 528456200, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1254.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 584.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198600}, {\"Order\": 2462, \"PID\": 528477010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 13162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 2036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 405749}, {\"Order\": 2463, \"PID\": 528477030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 11216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 232600}, {\"Order\": 2464, \"PID\": 528480070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1053.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 266000}, {\"Order\": 2465, \"PID\": 528480100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186500}, {\"Order\": 2466, \"PID\": 528480110, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200825}, {\"Order\": 2467, \"PID\": 528480150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 798, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 197000}, {\"Order\": 2468, \"PID\": 528488110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 905.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185000}, {\"Order\": 2469, \"PID\": 528488120, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2470, \"PID\": 528488130, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1293.0, \"TotalBsmtSF\": 1293.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187750}, {\"Order\": 2471, \"PID\": 531363080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1118.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 4, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2472, \"PID\": 531367010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 118.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1400.0, \"TotalBsmtSF\": 1400.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1400, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186800}, {\"Order\": 2473, \"PID\": 531375060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1131.0, \"TotalBsmtSF\": 1131.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 132000}, {\"Order\": 2474, \"PID\": 531375070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2475, \"PID\": 531375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 158000}, {\"Order\": 2476, \"PID\": 531376030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 891.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 891, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 2477, \"PID\": 531376050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1585, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 449.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 2478, \"PID\": 531379030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1837, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 688.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2479, \"PID\": 531450040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 761.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2480, \"PID\": 531451290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1731, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3000, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 248500}, {\"Order\": 2481, \"PID\": 531452080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1398, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2482, \"PID\": 531452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 278.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 1217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2483, \"PID\": 531452210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 362.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 636, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2484, \"PID\": 531478010, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 8900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107000}, {\"Order\": 2485, \"PID\": 531479030, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2486, \"PID\": 532351060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2487, \"PID\": 532351090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1332.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2488, \"PID\": 532351150, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1286, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2489, \"PID\": 532353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2490, \"PID\": 532353180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 8471, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 46.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 506.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2491, \"PID\": 532376080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2492, \"PID\": 532376180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2493, \"PID\": 532376250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2494, \"PID\": 532378050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120875}, {\"Order\": 2495, \"PID\": 532378070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 375.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 935, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2496, \"PID\": 532378130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2497, \"PID\": 532378160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 465.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 447.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2498, \"PID\": 532378220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8789, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129200}, {\"Order\": 2499, \"PID\": 532476050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 497.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1748.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2151, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 4, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 641, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 800, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2500, \"PID\": 533110130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 16059, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2417, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2501, \"PID\": 533125120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 692.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1118.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 208, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 2502, \"PID\": 533127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 310000}, {\"Order\": 2503, \"PID\": 533128030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13346, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 1129, \"LowQualFinSF\": 0, \"GrLivArea\": 2295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 2504, \"PID\": 533128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"ImStucc\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 757.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262000}, {\"Order\": 2505, \"PID\": 533206040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3628, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176400}, {\"Order\": 2506, \"PID\": 533208050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3316, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1247.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1247, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1247, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2507, \"PID\": 533212100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2508, \"PID\": 533212110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147400}, {\"Order\": 2509, \"PID\": 533212120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2510, \"PID\": 533212130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 144152}, {\"Order\": 2511, \"PID\": 533221080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 2512, \"PID\": 533223010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 241.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183900}, {\"Order\": 2513, \"PID\": 533223080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 673, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 153, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2514, \"PID\": 533223110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2515, \"PID\": 533241010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 114.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 382, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2516, \"PID\": 533242030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 2517, \"PID\": 533250130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 9549, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1057.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2518, \"PID\": 533252020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2519, \"PID\": 533253030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1009.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 44.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2520, \"PID\": 533253050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 3640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2521, \"PID\": 533253090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3874, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 807.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 419.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2522, \"PID\": 533253160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 526.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2523, \"PID\": 533350050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 50271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 1842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1842, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 857, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 385000}, {\"Order\": 2524, \"PID\": 534125210, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 13110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2525, \"PID\": 534126060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 10192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2526, \"PID\": 534127190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 1203.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2156, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2156, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 290, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 2527, \"PID\": 534127270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 404.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 708.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 708, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 119, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2528, \"PID\": 534128210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 435.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 222, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2529, \"PID\": 534129230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165150}, {\"Order\": 2530, \"PID\": 534175100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 264, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164500}, {\"Order\": 2531, \"PID\": 534176250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1164.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2532, \"PID\": 534201130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2533, \"PID\": 534201230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2534, \"PID\": 534201250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1770, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 270, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 455, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2535, \"PID\": 534201260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 94, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157500}, {\"Order\": 2536, \"PID\": 534201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 2537, \"PID\": 534201300, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2538, \"PID\": 534202020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124400}, {\"Order\": 2539, \"PID\": 534202180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 402.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 568.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2540, \"PID\": 534226060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 661.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2541, \"PID\": 534250300, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1993, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2542, \"PID\": 534275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 319, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2543, \"PID\": 534276010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2544, \"PID\": 534276230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1098.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 145000}, {\"Order\": 2545, \"PID\": 534400120, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 34.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 25, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 460, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185900}, {\"Order\": 2546, \"PID\": 534403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2547, \"PID\": 534403400, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 748.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2548, \"PID\": 534403440, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2549, \"PID\": 534427090, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2550, \"PID\": 534428060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 8973, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 28.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2551, \"PID\": 534429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 2552, \"PID\": 534430050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129800}, {\"Order\": 2553, \"PID\": 534430110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2554, \"PID\": 534431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1043, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1043, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2555, \"PID\": 534451050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 4712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 456, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 63, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 121600}, {\"Order\": 2556, \"PID\": 534451120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 5900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2557, \"PID\": 534451130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 5825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79900}, {\"Order\": 2558, \"PID\": 534453150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 7438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 316, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2559, \"PID\": 534455080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2560, \"PID\": 534475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1404.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 324, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 146500}, {\"Order\": 2561, \"PID\": 534476100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2562, \"PID\": 534477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 756.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1380.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 2136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 2563, \"PID\": 534479130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 165.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 958, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2564, \"PID\": 534479240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2565, \"PID\": 534479300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2566, \"PID\": 535101110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2567, \"PID\": 535103070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 939.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 307.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2568, \"PID\": 535105160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98600}, {\"Order\": 2569, \"PID\": 535125060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 2157, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2570, \"PID\": 535150240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 118000}, {\"Order\": 2571, \"PID\": 535150300, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 25419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 4, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 184.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 1360, \"LowQualFinSF\": 392, \"GrLivArea\": 3112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 552, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 512, \"PoolQC\": \"Ex\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 235000}, {\"Order\": 2572, \"PID\": 535151080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 9723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 332.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2573, \"PID\": 535151130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 303.0, \"TotalBsmtSF\": 1106.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2574, \"PID\": 535152070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 86, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2575, \"PID\": 535152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2576, \"PID\": 535176050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 175.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145250}, {\"Order\": 2577, \"PID\": 535177100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9610, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 2578, \"PID\": 535178100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 281.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 191, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2579, \"PID\": 535179050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 14850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 895.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 122, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2580, \"PID\": 535180020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 914.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 353.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 2581, \"PID\": 535180070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 64.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134450}, {\"Order\": 2582, \"PID\": 535301010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 943.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135960}, {\"Order\": 2583, \"PID\": 535301150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8092, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 156000}, {\"Order\": 2584, \"PID\": 535303050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1367.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2585, \"PID\": 535304020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2586, \"PID\": 535305120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 522.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2587, \"PID\": 535325130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 301.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2588, \"PID\": 535325340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 488.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 517.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2589, \"PID\": 535325350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 912.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2590, \"PID\": 535325450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2591, \"PID\": 535325460, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 21299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 929.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 791.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2592, \"PID\": 535327210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 521.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 75, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 323, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2593, \"PID\": 535353180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 22136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1153.0, \"TotalBsmtSF\": 2171.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1248, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1008.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 631, \"OpenPorchSF\": 48, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2594, \"PID\": 535354130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 900, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2595, \"PID\": 535355100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 865, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2596, \"PID\": 535375040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 713, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 161, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99800}, {\"Order\": 2597, \"PID\": 535376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 418.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2598, \"PID\": 535376100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1073.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108480}, {\"Order\": 2599, \"PID\": 535377070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 715, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 75, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68000}, {\"Order\": 2600, \"PID\": 535377100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 448, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 2601, \"PID\": 535379100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1130, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 229, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2602, \"PID\": 535380010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 821, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155500}, {\"Order\": 2603, \"PID\": 535380130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10818, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 981, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2604, \"PID\": 535381060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 105000}, {\"Order\": 2605, \"PID\": 535382020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 2414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2606, \"PID\": 535382130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1936, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 370, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 436, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2607, \"PID\": 535401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 445.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 2608, \"PID\": 535402070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1047.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159950}, {\"Order\": 2609, \"PID\": 535402100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 379.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1083.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 345, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2610, \"PID\": 535402220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 128, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2611, \"PID\": 535402230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 701.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1135.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1207, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 2612, \"PID\": 535403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 600.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2613, \"PID\": 535403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 8910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 655.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2614, \"PID\": 535403200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 207.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 2615, \"PID\": 535404080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 7100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2616, \"PID\": 535425040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1773, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 2617, \"PID\": 535425050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2618, \"PID\": 535425080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 802.0, \"TotalBsmtSF\": 1438.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1900, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 520, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 2619, \"PID\": 535426195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 16321, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1277.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 258, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2620, \"PID\": 535450100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 597.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 2621, \"PID\": 535450180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 2622, \"PID\": 535451190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 2623, \"PID\": 535451210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2624, \"PID\": 535453160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133700}, {\"Order\": 2625, \"PID\": 535454030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81400}, {\"Order\": 2626, \"PID\": 535454050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 2627, \"PID\": 535454060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2628, \"PID\": 535456010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1556.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1556, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2629, \"PID\": 535456020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 179.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 506.0, \"BsmtUnfSF\": 465.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2630, \"PID\": 535457070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 162, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2631, \"PID\": 535477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2632, \"PID\": 535478010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 10205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2633, \"PID\": 535478070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 809.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 236.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2634, \"PID\": 535478090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2635, \"PID\": 535478110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 953.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 1025.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2636, \"PID\": 902100110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 9856, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 1007, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 167, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2637, \"PID\": 902100130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9906, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 518, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 107000}, {\"Order\": 2638, \"PID\": 902101050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2639, \"PID\": 902103090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 863.0, \"TotalBsmtSF\": 1147.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1147, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2640, \"PID\": 902104020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 476, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2641, \"PID\": 902106040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2642, \"PID\": 902106090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6451, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 208.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 2643, \"PID\": 902108060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 66.0, \"LotArea\": 3960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 502.0, \"TotalBsmtSF\": 502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 502, \"2ndFlrSF\": 502, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2644, \"PID\": 902109010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 813, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 813, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2645, \"PID\": 902110120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7745, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 867, \"LowQualFinSF\": 0, \"GrLivArea\": 1951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 6, \"EnclosedPorch\": 28, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2646, \"PID\": 902110130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7741, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 143.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 2647, \"PID\": 902111010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5633, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 81, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2648, \"PID\": 902125020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1880, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 661, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 293, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 2649, \"PID\": 902128020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2650, \"PID\": 902128100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 648.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 734, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2651, \"PID\": 902134060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 7614, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1905, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 714, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 104, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96900}, {\"Order\": 2652, \"PID\": 902204060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2653, \"PID\": 902204120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 296, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2654, \"PID\": 902206020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2655, \"PID\": 902206090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 297, \"LowQualFinSF\": 0, \"GrLivArea\": 1182, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 378.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2656, \"PID\": 902207080, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 5820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 906.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1163, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126175}, {\"Order\": 2657, \"PID\": 902207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 48.0, \"LotArea\": 5747, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 2658, \"PID\": 902301120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 908, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2659, \"PID\": 902305090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 2, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 679, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2660, \"PID\": 902325050, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 2661, \"PID\": 902325100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2104, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2662, \"PID\": 902325160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 889, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2663, \"PID\": 902328100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 815.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 815, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 330, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2664, \"PID\": 902329070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 684, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114504}, {\"Order\": 2665, \"PID\": 902329090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 998, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 0, \"EnclosedPorch\": 221, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2666, \"PID\": 902400090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 84.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1200.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 125000}, {\"Order\": 2667, \"PID\": 902400110, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 22950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1892, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1107.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 1518, \"LowQualFinSF\": 572, \"GrLivArea\": 3608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 260, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 410, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 475000}, {\"Order\": 2668, \"PID\": 902401090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 5976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 624, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 256, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2669, \"PID\": 902406030, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 4500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2670, \"PID\": 902456015, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 63.0, \"LotArea\": 4761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 2671, \"PID\": 903200050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7446, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 2672, \"PID\": 903202120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 605, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140200}, {\"Order\": 2673, \"PID\": 903206160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1017, \"2ndFlrSF\": 810, \"LowQualFinSF\": 0, \"GrLivArea\": 1827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1943.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 27, \"OpenPorchSF\": 36, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2674, \"PID\": 903225090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2675, \"PID\": 903229040, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 325, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 271, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2676, \"PID\": 903231070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 2677, \"PID\": 903231190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2678, \"PID\": 903231220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 347.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 434, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 258.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 75000}, {\"Order\": 2679, \"PID\": 903231240, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1015, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1015, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 620, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 88000}, {\"Order\": 2680, \"PID\": 903232170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80500}, {\"Order\": 2681, \"PID\": 903233100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1042.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 149000}, {\"Order\": 2682, \"PID\": 903233220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 583, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2683, \"PID\": 903234030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 2684, \"PID\": 903235020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 129, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2685, \"PID\": 903236200, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 993.0, \"TotalBsmtSF\": 993.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2686, \"PID\": 903400030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 11672, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 2687, \"PID\": 903425190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 33120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2688, \"PID\": 903425340, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9873, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 288, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2689, \"PID\": 903430090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 634, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 255.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 394, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2690, \"PID\": 903430130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 153.0, \"LotArea\": 4118, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 693.0, \"TotalBsmtSF\": 693.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 693, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 693, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52500}, {\"Order\": 2691, \"PID\": 903451050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 834, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 2692, \"PID\": 903452090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 665, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 2693, \"PID\": 903454020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 819, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 819, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 72000}, {\"Order\": 2694, \"PID\": 903454080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 198.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2695, \"PID\": 903455090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 803.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 803, \"2ndFlrSF\": 557, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2696, \"PID\": 903456060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1007.0, \"TotalBsmtSF\": 1007.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 2697, \"PID\": 903456090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 234, \"GrLivArea\": 754, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 53, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2698, \"PID\": 903458010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2699, \"PID\": 904100030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 477.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 341, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2700, \"PID\": 904100090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 11136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1921.0, \"TotalBsmtSF\": 1921.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1921, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1921, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2701, \"PID\": 904100170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 225, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2702, \"PID\": 904101040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 6930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 294, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 2703, \"PID\": 904301410, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2704, \"PID\": 904302020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 830.0, \"TotalBsmtSF\": 830.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2705, \"PID\": 904302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 373.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2706, \"PID\": 905100030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 459.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2707, \"PID\": 905101330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 2708, \"PID\": 905101450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154500}, {\"Order\": 2709, \"PID\": 905103130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153600}, {\"Order\": 2710, \"PID\": 905103140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 97.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 328.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 68, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 164500}, {\"Order\": 2711, \"PID\": 905103180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 934, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 934, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 77, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2712, \"PID\": 905105010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1059, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1059, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2713, \"PID\": 905106210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11553, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1159, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 466, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2714, \"PID\": 905107070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 463.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 2715, \"PID\": 905107220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 982.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1458, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2716, \"PID\": 905107240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2717, \"PID\": 905107300, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 794.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 2718, \"PID\": 905108090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9662, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1967.0, \"TotalBsmtSF\": 1967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2719, \"PID\": 905108120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1466.0, \"TotalBsmtSF\": 1949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2720, \"PID\": 905200280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 441.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 2721, \"PID\": 905200290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 682.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2722, \"PID\": 905200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 17920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1085.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 418, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 312, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 2723, \"PID\": 905200380, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2724, \"PID\": 905200490, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1965, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2725, \"PID\": 905201090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 304, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2726, \"PID\": 905202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 826.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 1865.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1830, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 115, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 2727, \"PID\": 905202210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 13050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 850.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2728, \"PID\": 905225080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 15593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 701.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1304, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 667.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2729, \"PID\": 905300010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2730, \"PID\": 905300080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 241, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2731, \"PID\": 905351045, \"MSSubClass\": 150, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 1700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 33.0, \"TotalBsmtSF\": 430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 680, \"LowQualFinSF\": 140, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148400}, {\"Order\": 2732, \"PID\": 905351150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 445.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 190000}, {\"Order\": 2733, \"PID\": 905402110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2734, \"PID\": 905403050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 6488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 799, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 128000}, {\"Order\": 2735, \"PID\": 905426100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 103, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2736, \"PID\": 905426150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 626, \"LowQualFinSF\": 0, \"GrLivArea\": 2201, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 586, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 738, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 274970}, {\"Order\": 2737, \"PID\": 905427010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 19950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2738, \"PID\": 905427030, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 19800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1411.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 1836, \"LowQualFinSF\": 0, \"GrLivArea\": 3672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 684, \"OpenPorchSF\": 80, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2739, \"PID\": 905427140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11679, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1164.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 453, \"OpenPorchSF\": 253, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2740, \"PID\": 905451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 348, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2741, \"PID\": 905451410, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10519, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1057.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2742, \"PID\": 905452140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 325.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136900}, {\"Order\": 2743, \"PID\": 905452150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 532.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 541, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2744, \"PID\": 905475150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 6420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 2745, \"PID\": 905477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 2746, \"PID\": 905480160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 454, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91500}, {\"Order\": 2747, \"PID\": 906202040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 40.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2748, \"PID\": 906204180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1246, \"LowQualFinSF\": 0, \"GrLivArea\": 2559, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 245, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 209000}, {\"Order\": 2749, \"PID\": 906223180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9554, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1911, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2750, \"PID\": 906225180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 261.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1083.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 2751, \"PID\": 906380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 133.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1308.0, \"TotalBsmtSF\": 1308.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 848.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229800}, {\"Order\": 2752, \"PID\": 906380150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 393.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 183600}, {\"Order\": 2753, \"PID\": 906380170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7406, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 515.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 2754, \"PID\": 906380180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193879}, {\"Order\": 2755, \"PID\": 906382030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221500}, {\"Order\": 2756, \"PID\": 906382040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204900}, {\"Order\": 2757, \"PID\": 906382050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 571, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239799}, {\"Order\": 2758, \"PID\": 906392090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13377, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 260.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233555}, {\"Order\": 2759, \"PID\": 906392100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2760, \"PID\": 906392120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1122.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 1570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1590, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294900}, {\"Order\": 2761, \"PID\": 906394010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1809, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 209700}, {\"Order\": 2762, \"PID\": 906394040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1558.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2763, \"PID\": 906394060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 532.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2764, \"PID\": 906420020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 119.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 927, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1915, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 2765, \"PID\": 906426090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 36500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 812.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 198, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2766, \"PID\": 906475050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Metal\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 130, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2767, \"PID\": 906475200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 70761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 1533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1533, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2768, \"PID\": 906476140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 853.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 535.0, \"TotalBsmtSF\": 1388.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1388, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 2769, \"PID\": 907125020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2770, \"PID\": 907125080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2771, \"PID\": 907130110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 795, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 413, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2772, \"PID\": 907131070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 579.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 2773, \"PID\": 907135230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 13568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 274.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2774, \"PID\": 907175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2775, \"PID\": 907175060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2776, \"PID\": 907180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2777, \"PID\": 907181090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9272, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1749, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2778, \"PID\": 907187010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 13426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 57.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 107, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2779, \"PID\": 907192010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2780, \"PID\": 907194130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 2781, \"PID\": 907196020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1541.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 468, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 2782, \"PID\": 907200170, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 428.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2783, \"PID\": 907201160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 62.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 317.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2784, \"PID\": 907201230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2785, \"PID\": 907202140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 971.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 971, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2786, \"PID\": 907203010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 9560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2787, \"PID\": 907203040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 149900}, {\"Order\": 2788, \"PID\": 907227090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2789, \"PID\": 907230240, \"MSSubClass\": 160, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 3612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Landmrk\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2790, \"PID\": 907251100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 1989, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2791, \"PID\": 907252050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 199.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 826.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2792, \"PID\": 907254050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 9468, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2793, \"PID\": 907255010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2794, \"PID\": 907255050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1787, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1787, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2795, \"PID\": 907262080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8726, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 1909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2796, \"PID\": 907265030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 668.0, \"TotalBsmtSF\": 1654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1654, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2797, \"PID\": 907270050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10566, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 1124, \"LowQualFinSF\": 0, \"GrLivArea\": 2214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 646.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268500}, {\"Order\": 2798, \"PID\": 907275030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210900}, {\"Order\": 2799, \"PID\": 907285010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 258.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1070, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 2800, \"PID\": 907285100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 1045, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 2801, \"PID\": 907290020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 989, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274300}, {\"Order\": 2802, \"PID\": 907290080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216837}, {\"Order\": 2803, \"PID\": 907290160, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2804, \"PID\": 907290230, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155900}, {\"Order\": 2805, \"PID\": 907290260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1079.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 685.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233230}, {\"Order\": 2806, \"PID\": 907401050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2807, \"PID\": 907401080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2808, \"PID\": 907405030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2809, \"PID\": 907410040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8581, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203160}, {\"Order\": 2810, \"PID\": 907410100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 827, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195800}, {\"Order\": 2811, \"PID\": 907410110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212900}, {\"Order\": 2812, \"PID\": 907412010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2813, \"PID\": 907414040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198000}, {\"Order\": 2814, \"PID\": 907418020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 750, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173900}, {\"Order\": 2815, \"PID\": 907420070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 163990}, {\"Order\": 2816, \"PID\": 907420090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164990}, {\"Order\": 2817, \"PID\": 908102020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 337.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 420, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 2818, \"PID\": 908102320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 17755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2819, \"PID\": 908102330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2820, \"PID\": 908103310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 7840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 355.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2821, \"PID\": 908103320, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2822, \"PID\": 908127050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 16133, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2823, \"PID\": 908128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2824, \"PID\": 908130020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 475.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 297.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117250}, {\"Order\": 2825, \"PID\": 908178050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1150.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1150, \"LowQualFinSF\": 0, \"GrLivArea\": 2314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2826, \"PID\": 908186060, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2827, \"PID\": 908186070, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 140000}, {\"Order\": 2828, \"PID\": 908186090, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 142500}, {\"Order\": 2829, \"PID\": 908188110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2830, \"PID\": 908188120, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2831, \"PID\": 908188130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2832, \"PID\": 908188140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2833, \"PID\": 908188150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 3363, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 976.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2834, \"PID\": 908225180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6956, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 312, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 265.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97900}, {\"Order\": 2835, \"PID\": 908227010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 846, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 92000}, {\"Order\": 2836, \"PID\": 908227030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1669, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 107000}, {\"Order\": 2837, \"PID\": 908227040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 658.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 658, \"2ndFlrSF\": 526, \"LowQualFinSF\": 0, \"GrLivArea\": 1184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 81000}, {\"Order\": 2838, \"PID\": 908228040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 2839, \"PID\": 908275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 167.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2840, \"PID\": 908275290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 16012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 691.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 609.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2841, \"PID\": 909101050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 207, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2842, \"PID\": 909101080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 450, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 2843, \"PID\": 909101190, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 795.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 795, \"LowQualFinSF\": 481, \"GrLivArea\": 2230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2844, \"PID\": 909101330, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8088, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1922, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 35000}, {\"Order\": 2845, \"PID\": 909103020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 218, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2846, \"PID\": 909131125, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 7082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 980, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2847, \"PID\": 909175030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1192, \"2ndFlrSF\": 403, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2848, \"PID\": 909176180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 128.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 493, \"LowQualFinSF\": 0, \"GrLivArea\": 1551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2849, \"PID\": 909201180, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 58.0, \"LotArea\": 6430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 816, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128000}, {\"Order\": 2850, \"PID\": 909250070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 424.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 743, \"2ndFlrSF\": 736, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 530, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2851, \"PID\": 909250120, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 892, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138887}, {\"Order\": 2852, \"PID\": 909250200, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 4899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 2853, \"PID\": 909250210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 514, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2854, \"PID\": 909253080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9399, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 818, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1919.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2855, \"PID\": 909254070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 901, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200100}, {\"Order\": 2856, \"PID\": 909256010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10164, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2857, \"PID\": 909256020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2858, \"PID\": 909275230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 272, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2859, \"PID\": 909275250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 940, \"2ndFlrSF\": 610, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 429, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2860, \"PID\": 909276010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 725, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2861, \"PID\": 909276070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 113, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2862, \"PID\": 909279040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 67, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2863, \"PID\": 909280030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2864, \"PID\": 909280070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 8170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 526.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 549, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 2865, \"PID\": 909281010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1175, \"LowQualFinSF\": 0, \"GrLivArea\": 2345, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2866, \"PID\": 909282060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 104, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 2867, \"PID\": 909282110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 14210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 697, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 365.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2868, \"PID\": 909425120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 296.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 547.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1811, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 230000}, {\"Order\": 2869, \"PID\": 909425180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 459.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1283.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2870, \"PID\": 909426060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 405.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2871, \"PID\": 909428110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 375.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2872, \"PID\": 909475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 734.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 2873, \"PID\": 910200020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 102000}, {\"Order\": 2874, \"PID\": 910200060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 132, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145400}, {\"Order\": 2875, \"PID\": 910203100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 61.0, \"LotArea\": 8534, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72000}, {\"Order\": 2876, \"PID\": 910203230, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 272.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 2877, \"PID\": 910207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8765, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 327.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 106500}, {\"Order\": 2878, \"PID\": 910226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 327.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2879, \"PID\": 911175360, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 439, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 47, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2880, \"PID\": 911175410, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 69.0, \"LotArea\": 12366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 23, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 51689}, {\"Order\": 2881, \"PID\": 911175430, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 35311}, {\"Order\": 2882, \"PID\": 911175440, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2883, \"PID\": 911225110, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 360, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 2884, \"PID\": 911370430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5748, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1778, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2885, \"PID\": 911370530, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2886, \"PID\": 913350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 23580, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242500}, {\"Order\": 2887, \"PID\": 914452060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1664.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2888, \"PID\": 914474020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9116, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 2889, \"PID\": 914476050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2890, \"PID\": 914476130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 11080, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 257.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2891, \"PID\": 914476500, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1907.0, \"TotalBsmtSF\": 1907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1959, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 766.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 171000}, {\"Order\": 2892, \"PID\": 916225130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 26178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 293.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1210.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 1281, \"LowQualFinSF\": 0, \"GrLivArea\": 2519, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 2893, \"PID\": 916252170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2894, \"PID\": 916325040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 50102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 909.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1650, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 250764}, {\"Order\": 2895, \"PID\": 916326010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 653.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1686.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 574, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2896, \"PID\": 916402125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 13811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2897, \"PID\": 916403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1309.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2898, \"PID\": 916403130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2514, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 693.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2899, \"PID\": 916460070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1136.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 129.0, \"TotalBsmtSF\": 1381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2900, \"PID\": 916475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 630.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 2901, \"PID\": 916477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13618, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2902, \"PID\": 921205030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11443, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2028, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 326, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 369900}, {\"Order\": 2903, \"PID\": 921205050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 382.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 225, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 359900}, {\"Order\": 2904, \"PID\": 923125030, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 125.0, \"LotArea\": 31250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81500}, {\"Order\": 2905, \"PID\": 923202025, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1243.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 45.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2906, \"PID\": 923203090, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 897.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 125, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2907, \"PID\": 923203100, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 443.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 405.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 199, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2908, \"PID\": 923205120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 17217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84500}, {\"Order\": 2909, \"PID\": 923225190, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2910, \"PID\": 923225240, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 173.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 757.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2911, \"PID\": 923225260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 3964, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 837.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 1230, \"LowQualFinSF\": 0, \"GrLivArea\": 2521, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 728, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151400}, {\"Order\": 2912, \"PID\": 923225510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 2913, \"PID\": 923226150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1503.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2914, \"PID\": 923226180, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 2915, \"PID\": 923226290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79400}, {\"Order\": 2916, \"PID\": 923227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2917, \"PID\": 923228130, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 92000}, {\"Order\": 2918, \"PID\": 923228180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 87550}, {\"Order\": 2919, \"PID\": 923228210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 2920, \"PID\": 923228260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90500}, {\"Order\": 2921, \"PID\": 923228310, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1894, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 71000}, {\"Order\": 2922, \"PID\": 923229110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 12640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 396.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150900}, {\"Order\": 2923, \"PID\": 923230040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9297, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 188000}, {\"Order\": 2924, \"PID\": 923250060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2925, \"PID\": 923251180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 20000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 131000}, {\"Order\": 2926, \"PID\": 923275080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 7937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1003.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1003, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1003, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2927, \"PID\": 923276100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 324.0, \"BsmtUnfSF\": 239.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2928, \"PID\": 923400125, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2929, \"PID\": 924100070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1071.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 123.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1389, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2930, \"PID\": 924151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 1004, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "alt.Chart(train).mark_circle().encode(\n",
        "    alt.X(alt.repeat(\"column\"), type='quantitative'),\n",
        "    alt.Y(alt.repeat(\"row\"), type='quantitative'),\n",
        "    color='KitchenQual'\n",
        ").properties(\n",
        "    width=300,\n",
        "    height=300\n",
        ").repeat(\n",
        "    # Here we tell Altair we want to repeat out scatter plots for each row-column pair\n",
        "    row=['GrLivArea', 'GarageArea', 'TotalBsmtSF'],\n",
        "    column=['TotalBsmtSF', 'GarageArea', 'GrLivArea']\n",
        ").configure_axis(\n",
        "    grid=False\n",
        ")"
      ],
      "id": "cell-23"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Layered Histogram\n",
        "\n",
        "Using Altair, we can make overlapping histograms or layers histograms\n",
        "from data:"
      ],
      "id": "a4ff606a-42da-4591-9233-df57d57d2a83"
    },
    {
      "cell_type": "code",
      "execution_count": 24,
      "metadata": {
        "cell_id": "1746d25d38334745bf8460f647b94978",
        "deepnote_cell_type": "code",
        "deepnote_to_be_reexecuted": false,
        "execution_millis": 1869,
        "execution_start": 1685107275503,
        "papermill": {
          "duration": 0.812835,
          "end_time": "2023-01-11T23:38:37.865314",
          "exception": false,
          "start_time": "2023-01-11T23:38:37.052479",
          "status": "completed"
        },
        "source_hash": "b5e8a315",
        "tags": []
      },
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-afce767e7ef34141bae67a8878f595f0.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-afce767e7ef34141bae67a8878f595f0.vega-embed details,\n",
              "  #altair-viz-afce767e7ef34141bae67a8878f595f0.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-afce767e7ef34141bae67a8878f595f0\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-afce767e7ef34141bae67a8878f595f0\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-afce767e7ef34141bae67a8878f595f0\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-bd4440f2bd659840503c9701cdb81363\"}, \"mark\": {\"type\": \"bar\", \"binSpacing\": 0, \"opacity\": 0.5}, \"encoding\": {\"color\": {\"field\": \"MSZoning\", \"type\": \"nominal\"}, \"x\": {\"bin\": {\"maxbins\": 50}, \"field\": \"SalePrice\", \"type\": \"quantitative\"}, \"y\": {\"aggregate\": \"count\", \"stack\": null, \"type\": \"quantitative\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-bd4440f2bd659840503c9701cdb81363\": [{\"Order\": 1, \"PID\": 526301100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 141.0, \"LotArea\": 31770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2, \"PID\": 526350040, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 80.0, \"LotArea\": 11622, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 3, \"PID\": 526351010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 393, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 12500, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 4, \"PID\": 526353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1045.0, \"TotalBsmtSF\": 2110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 5, \"PID\": 527105010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189900}, {\"Order\": 6, \"PID\": 527105030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 7, \"PID\": 527127150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 8, \"PID\": 527145080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 263.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191500}, {\"Order\": 9, \"PID\": 527146030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1180.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 10, \"PID\": 527162130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 776, \"LowQualFinSF\": 0, \"GrLivArea\": 1804, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 11, \"PID\": 527163010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 763, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1655, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 157, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 12, \"PID\": 527165230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1992, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 935.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 233.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 13, \"PID\": 527166040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180400}, {\"Order\": 14, \"PID\": 527180040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 15, \"PID\": 527182190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 1120.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 16, \"PID\": 527216070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 53504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 603.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1690, \"2ndFlrSF\": 1589, \"LowQualFinSF\": 0, \"GrLivArea\": 3279, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 841.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 503, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 538000}, {\"Order\": 17, \"PID\": 527225035, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 152.0, \"LotArea\": 12134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1988, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 427.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 325, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 18, \"PID\": 527258010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 2, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 1856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394432}, {\"Order\": 19, \"PID\": 527276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 19138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 20, \"PID\": 527302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 163.0, \"BsmtUnfSF\": 589.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 21, \"PID\": 527358140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 22, \"PID\": 527358200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 81.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 885.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1173, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 170000}, {\"Order\": 23, \"PID\": 527368020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 814, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 24, \"PID\": 527402200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11241, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 25, \"PID\": 527402250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12537, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 26, \"PID\": 527403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 281.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 27, \"PID\": 527404120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 78.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 28, \"PID\": 527425090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 29, \"PID\": 527427230, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 5858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1051.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 30, \"PID\": 527451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 327.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 31, \"PID\": 527451330, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 32, \"PID\": 527451410, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 381.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 88000}, {\"Order\": 33, \"PID\": 527452190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 709.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 34, \"PID\": 527453130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 514.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 35, \"PID\": 527453150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 836.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 36, \"PID\": 527454200, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 37, \"PID\": 528108120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1590.0, \"TotalBsmtSF\": 1590.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1627, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 2334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 376162}, {\"Order\": 38, \"PID\": 528112020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 39, \"PID\": 528120060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1940, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395192}, {\"Order\": 40, \"PID\": 528120090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1544.0, \"TotalBsmtSF\": 1544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290941}, {\"Order\": 41, \"PID\": 528120100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 220000}, {\"Order\": 42, \"PID\": 528120120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 615.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 43, \"PID\": 528138020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1794.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1822, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259000}, {\"Order\": 44, \"PID\": 528138060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1515.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 45, \"PID\": 528150070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12919, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 760.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 2330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 611657}, {\"Order\": 46, \"PID\": 528175010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6371, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224000}, {\"Order\": 47, \"PID\": 528176010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1095.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1473.0, \"TotalBsmtSF\": 2846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 958.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 500000}, {\"Order\": 48, \"PID\": 528176070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 563, \"LowQualFinSF\": 0, \"GrLivArea\": 2250, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 49, \"PID\": 528180070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 412.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1296.0, \"TotalBsmtSF\": 1752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 50, \"PID\": 528181050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 7132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 51, \"PID\": 528188120, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 52, \"PID\": 528218150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 18494, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1324.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 53, \"PID\": 528228285, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 54, \"PID\": 528228440, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 55, \"PID\": 528231020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 58.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 56, \"PID\": 528240070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 1100, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216500}, {\"Order\": 57, \"PID\": 528240130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185088}, {\"Order\": 58, \"PID\": 528250100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 59, \"PID\": 528292020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9505, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 1151, \"LowQualFinSF\": 0, \"GrLivArea\": 2035, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 60, \"PID\": 528328100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 14774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1393.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2599, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 668, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 333168}, {\"Order\": 61, \"PID\": 528344070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 17433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1629.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1645, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 2475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 962.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 23, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 62, \"PID\": 528358010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 919.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 56, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260400}, {\"Order\": 63, \"PID\": 528363130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 1122, \"LowQualFinSF\": 0, \"GrLivArea\": 2622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 64, \"PID\": 528382020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1999, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 348.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1106, \"LowQualFinSF\": 0, \"GrLivArea\": 2270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 671.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 65, \"PID\": 528382030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 66, \"PID\": 528386040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 14720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 579.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1217.0, \"TotalBsmtSF\": 2033.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2053, \"2ndFlrSF\": 1185, \"LowQualFinSF\": 0, \"GrLivArea\": 3238, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 283, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 67, \"PID\": 528445060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8987, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221500}, {\"Order\": 68, \"PID\": 528456160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 92.0, \"LotArea\": 9215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204500}, {\"Order\": 69, \"PID\": 528458070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1547, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215200}, {\"Order\": 70, \"PID\": 528458110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 488.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1566, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 71, \"PID\": 528477080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 12552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 222.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 956, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 72, \"PID\": 528480090, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271500}, {\"Order\": 73, \"PID\": 531367050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 956.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233000}, {\"Order\": 74, \"PID\": 531369060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 75, \"PID\": 531380080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 2110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 76, \"PID\": 531451110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 543.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 119.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 77, \"PID\": 531451280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 635, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 78, \"PID\": 531452020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 79, \"PID\": 531452050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 752, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 353, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 80, \"PID\": 531452180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1744, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 238, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 81, \"PID\": 531453010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 82, \"PID\": 531453040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 83, \"PID\": 531477050, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67500}, {\"Order\": 84, \"PID\": 532351140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1318, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 85, \"PID\": 532354090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 899.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1155, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1155, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 86, \"PID\": 532376160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 416, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 87, \"PID\": 532377060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 31.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 88, \"PID\": 532377100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 220, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 89, \"PID\": 532378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6897, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 90, \"PID\": 532479070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 15410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 126.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 859.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 169000}, {\"Order\": 91, \"PID\": 533130020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10186, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 92, \"PID\": 533130130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 981.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1231.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2349, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 362500}, {\"Order\": 93, \"PID\": 533130160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1129.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 823, \"LowQualFinSF\": 0, \"GrLivArea\": 2225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 713.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 94, \"PID\": 533205060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 25.0, \"LotArea\": 4835, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 95, \"PID\": 533208090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 39.0, \"LotArea\": 3515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 96, \"PID\": 533210060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3215, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 97, \"PID\": 533212010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 98, \"PID\": 533212020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 99, \"PID\": 533212060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 376.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 100, \"PID\": 533213030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 578.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 101, \"PID\": 533221090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 102, \"PID\": 533221110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1159.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 466.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 103, \"PID\": 533223020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 696, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 104, \"PID\": 533223100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2403, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 244.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147110}, {\"Order\": 105, \"PID\": 533238045, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 57.0, \"LotArea\": 12853, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1032.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 1642.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 224, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267916}, {\"Order\": 106, \"PID\": 533244030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 7379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 107, \"PID\": 533253060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 4420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 108, \"PID\": 533253210, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1052.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 223, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 109, \"PID\": 533352170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13517, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 475.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 110, \"PID\": 534102025, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 659.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 111, \"PID\": 534129040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1323.0, \"TotalBsmtSF\": 1829.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1829, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 535.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218500}, {\"Order\": 112, \"PID\": 534151175, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1137.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243500}, {\"Order\": 113, \"PID\": 534152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 114, \"PID\": 534152070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 687.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 46.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 1891, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 115, \"PID\": 534152100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10421, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 394.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 734, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 66, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 116, \"PID\": 534176060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 982.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 1161.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1381, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1381, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 117, \"PID\": 534176230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 715, \"LowQualFinSF\": 0, \"GrLivArea\": 1645, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 118, \"PID\": 534202160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142250}, {\"Order\": 119, \"PID\": 534251320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 451.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 81.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1328.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 120, \"PID\": 534276360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1225, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128950}, {\"Order\": 121, \"PID\": 534401110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1209, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 122, \"PID\": 534401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 9680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1510, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 204, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 123, \"PID\": 534403360, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10600, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136300}, {\"Order\": 124, \"PID\": 534403410, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14112, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1014.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 227, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 125, \"PID\": 534425310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 156.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 126, \"PID\": 534427010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 13260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 127, \"PID\": 534430080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 49.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1029.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142125}, {\"Order\": 128, \"PID\": 534431050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 670.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1929, \"2ndFlrSF\": 532, \"LowQualFinSF\": 0, \"GrLivArea\": 2461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197600}, {\"Order\": 129, \"PID\": 534431070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 17360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1019, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 130, \"PID\": 534450180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 131, \"PID\": 534451150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1940, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 263, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76500}, {\"Order\": 132, \"PID\": 534475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 133, \"PID\": 534476260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 132.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 189, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 134, \"PID\": 534479320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 244.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 135, \"PID\": 535101020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 136, \"PID\": 535106190, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 361.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1169, \"LowQualFinSF\": 0, \"GrLivArea\": 2274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154300}, {\"Order\": 137, \"PID\": 535125010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 287.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 912.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1947.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2207, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 301, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 138, \"PID\": 535126040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 137.0, \"LotArea\": 16492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 713.0, \"BsmtUnfSF\": 557.0, \"TotalBsmtSF\": 1517.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 139, \"PID\": 535152010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1604.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 140, \"PID\": 535152050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 300, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 141, \"PID\": 535152130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 142, \"PID\": 535152150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10552, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 143, \"PID\": 535152250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 144, \"PID\": 535153070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1194.0, \"TotalBsmtSF\": 1194.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 145, \"PID\": 535154050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142000}, {\"Order\": 146, \"PID\": 535175070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 324.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 571.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 143, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 147, \"PID\": 535175180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10725, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 91.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1206, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108538}, {\"Order\": 148, \"PID\": 535179020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 432.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 149, \"PID\": 535180130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 832, \"2ndFlrSF\": 505, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 263.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 150, \"PID\": 535302080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 339.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 151, \"PID\": 535302200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 119.0, \"LotArea\": 10895, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 152, \"PID\": 535304060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 153, \"PID\": 535304180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 731.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109000}, {\"Order\": 154, \"PID\": 535325400, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 155, \"PID\": 535327140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 156, \"PID\": 535350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 362.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 157, \"PID\": 535350040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 5868, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 158, \"PID\": 535353190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 17503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97500}, {\"Order\": 159, \"PID\": 535377090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 160, \"PID\": 535401080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 72.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 258.0, \"BsmtUnfSF\": 733.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 161, \"PID\": 535425010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 1080, \"LowQualFinSF\": 0, \"GrLivArea\": 2978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 162, \"PID\": 535450210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 481.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 163, \"PID\": 535453070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 906.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 164, \"PID\": 535454070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 475, \"LowQualFinSF\": 0, \"GrLivArea\": 1385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 165, \"PID\": 535456110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 486.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134800}, {\"Order\": 166, \"PID\": 535457010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1116.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 385, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 167, \"PID\": 535457090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 7635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 350.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 168, \"PID\": 535476350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 263.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1395, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 657, \"OpenPorchSF\": 0, \"EnclosedPorch\": 113, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 169, \"PID\": 535477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 170, \"PID\": 902102100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 771.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80400}, {\"Order\": 171, \"PID\": 902104060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 172, \"PID\": 902106130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4485, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 579.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 51, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 173, \"PID\": 902106140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1028, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 130, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 174, \"PID\": 902110090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 5805, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1073.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1347, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 175, \"PID\": 902125080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1605, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107400}, {\"Order\": 176, \"PID\": 902125160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 4608, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 177, \"PID\": 902128170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 294.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 804, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 178, \"PID\": 902206040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 692.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 390, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 179, \"PID\": 902206130, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 827.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 180, \"PID\": 902206220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 606, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 181, \"PID\": 902206240, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 185, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 334, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 182, \"PID\": 902207130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1923, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 780.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 12789}, {\"Order\": 183, \"PID\": 902207140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1928, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105900}, {\"Order\": 184, \"PID\": 902305110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 228, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 185, \"PID\": 902327040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 966, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 186, \"PID\": 902329030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1157, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 187, \"PID\": 902401060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 1128, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 18, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 188, \"PID\": 902402010, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 7407, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 923.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149700}, {\"Order\": 189, \"PID\": 902402130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 622, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 190, \"PID\": 902402250, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1885, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 777.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 191, \"PID\": 902403070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140750}, {\"Order\": 192, \"PID\": 903204040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1030, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 363.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 193, \"PID\": 903206120, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 194, \"PID\": 903225150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 765, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 765, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 195, \"PID\": 903226160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 452.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 12.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 134000}, {\"Order\": 196, \"PID\": 903227020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 348, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 197, \"PID\": 903227150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 955, \"2ndFlrSF\": 498, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 148, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 198, \"PID\": 903228150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 221, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 199, \"PID\": 903232190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 548, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 200, \"PID\": 903233120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 928, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138400}, {\"Order\": 201, \"PID\": 903234050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 164.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 202, \"PID\": 903425110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 10300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 11, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 203, \"PID\": 903426180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 888.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 1074, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 364, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 204, \"PID\": 903426200, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 205, \"PID\": 903430080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 3068, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 662, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 206, \"PID\": 903450110, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 110.0, \"LotArea\": 8472, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 106, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 207, \"PID\": 903454060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 372, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3500, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 208, \"PID\": 903476030, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 7630, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 344, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 209, \"PID\": 904100140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1032.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 1196, \"LowQualFinSF\": 0, \"GrLivArea\": 2403, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 0, \"EnclosedPorch\": 318, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 244400}, {\"Order\": 210, \"PID\": 904101110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 365.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 211, \"PID\": 904300150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 499, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Po\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 212, \"PID\": 904302260, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1026.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 180, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 213, \"PID\": 904350045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 214, \"PID\": 904351040, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 6449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1907, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 73.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 634.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93369}, {\"Order\": 215, \"PID\": 904352190, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 6048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 56, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114900}, {\"Order\": 216, \"PID\": 905101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 6342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1875, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94000}, {\"Order\": 217, \"PID\": 905101300, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1832, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 218, \"PID\": 905101310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1768.0, \"TotalBsmtSF\": 1768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 219, \"PID\": 905102060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 1039.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 220, \"PID\": 905103060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11341, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1302.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 221, \"PID\": 905104210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8521, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 842.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 222, \"PID\": 905105070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 188.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 668.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 223, \"PID\": 905105200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 47.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 474.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 224, \"PID\": 905106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 663, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 379, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 225, \"PID\": 905106170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137250}, {\"Order\": 226, \"PID\": 905107110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7424, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1373, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1373, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160250}, {\"Order\": 227, \"PID\": 905107250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 453.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 228, \"PID\": 905107320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 328.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1386, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 229, \"PID\": 905109130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 954, \"LowQualFinSF\": 0, \"GrLivArea\": 2260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 328000}, {\"Order\": 230, \"PID\": 905109170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1092.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1483, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1483, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 496, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 231, \"PID\": 905201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 756, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 232, \"PID\": 905202090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 233, \"PID\": 905325030, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23595, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 74.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 192, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 234, \"PID\": 905352140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 336, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 235, \"PID\": 905378040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 18600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 684.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 558, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 236, \"PID\": 905426060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 108.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 835, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 237, \"PID\": 905426200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11479, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 387.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 238, \"PID\": 905451320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 44, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 239, \"PID\": 905452110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 362, \"GrLivArea\": 1531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 209.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 240, \"PID\": 905452160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 954.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 1172.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1172, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 241, \"PID\": 905453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1176.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 242, \"PID\": 905453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 17485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1508, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Con\", \"SaleCondition\": \"Partial\", \"SalePrice\": 308030}, {\"Order\": 243, \"PID\": 905475510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1250.0, \"TotalBsmtSF\": 1250.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 244, \"PID\": 905478190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84900}, {\"Order\": 245, \"PID\": 906201030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 977, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1732, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 246, \"PID\": 906201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 11980, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 177.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1433.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1433.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 278, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 247, \"PID\": 906204230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 12361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 86.0, \"TotalBsmtSF\": 946.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1017.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 450, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 248, \"PID\": 906223090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 750.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 249, \"PID\": 906225210, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 250, \"PID\": 906378100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245350}, {\"Order\": 251, \"PID\": 906380190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 252, \"PID\": 906385010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 10402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 740.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198900}, {\"Order\": 253, \"PID\": 906385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2010, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1222.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1222, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 254, \"PID\": 906402200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12376, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1470.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 1523, \"LowQualFinSF\": 0, \"GrLivArea\": 3222, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 367, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 255, \"PID\": 906425045, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 14235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 614, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 256, \"PID\": 906477110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 257, \"PID\": 907125090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 71, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 258, \"PID\": 907180050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 878.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 259, \"PID\": 907185060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 260, \"PID\": 907200280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 15240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 688.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 261, \"PID\": 907200290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161750}, {\"Order\": 262, \"PID\": 907200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 712.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 365, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128200}, {\"Order\": 263, \"PID\": 907203070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 264, \"PID\": 907250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10389, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 296.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 265, \"PID\": 907252120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 479.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1581.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 266, \"PID\": 907262050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 9548, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 223.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 458.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1829, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 613.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 267, \"PID\": 907280040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 331, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 268, \"PID\": 907290040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1649.0, \"TotalBsmtSF\": 1649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 269, \"PID\": 907290170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 270, \"PID\": 907290240, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 271, \"PID\": 907401090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 10635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 972.0, \"BsmtUnfSF\": 315.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 262, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 272, \"PID\": 907410080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 109.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 761.0, \"TotalBsmtSF\": 1473.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 606.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 273, \"PID\": 907414030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185500}, {\"Order\": 274, \"PID\": 908102060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 84900}, {\"Order\": 275, \"PID\": 908102110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 155891}, {\"Order\": 276, \"PID\": 908102130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 277, \"PID\": 908102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 278, \"PID\": 908102300, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 792, \"2ndFlrSF\": 328, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 64000}, {\"Order\": 279, \"PID\": 908103350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125200}, {\"Order\": 280, \"PID\": 908152080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 7819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 422.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 281, \"PID\": 908203100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 282, \"PID\": 908208020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 8546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1121.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 283, \"PID\": 908225320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 94.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1487, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 284, \"PID\": 908226130, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 285, \"PID\": 908275300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1526, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 286, \"PID\": 909100080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 4853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 974.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 287, \"PID\": 909100110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 841, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 288, \"PID\": 909101070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 289, \"PID\": 909176140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 242, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 290, \"PID\": 909176150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 856, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 166, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 291, \"PID\": 909177100, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 862, \"2ndFlrSF\": 1788, \"LowQualFinSF\": 0, \"GrLivArea\": 2650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 292, \"PID\": 909250030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 293, \"PID\": 909250060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 804.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1699, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 2447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 294, \"PID\": 909281080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 371.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1225, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 86, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 295, \"PID\": 909426080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 657.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1075, \"LowQualFinSF\": 0, \"GrLivArea\": 2177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 296, \"PID\": 909427230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 877.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 1152, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266500}, {\"Order\": 297, \"PID\": 909428280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 207, \"EnclosedPorch\": 162, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 298, \"PID\": 909452114, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 423.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203135}, {\"Order\": 299, \"PID\": 909455030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 300, \"PID\": 909455040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 76.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1115.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1191, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1191, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 301, \"PID\": 909475140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 15602, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1801, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 289000}, {\"Order\": 302, \"PID\": 910202060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 61.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 358, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 303, \"PID\": 910203250, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 540, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 304, \"PID\": 910205120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 727, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 305, \"PID\": 911128180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 68400}, {\"Order\": 306, \"PID\": 911202100, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 859.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 859, \"2ndFlrSF\": 319, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 102776}, {\"Order\": 307, \"PID\": 911204090, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 54, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 55993}, {\"Order\": 308, \"PID\": 911204100, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 66.0, \"LotArea\": 8712, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1896, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1896.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 265, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 50138}, {\"Order\": 309, \"PID\": 911370510, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246000}, {\"Order\": 310, \"PID\": 914467040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 615.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1916, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 741.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254900}, {\"Order\": 311, \"PID\": 914475090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9620, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1243.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 375, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 80, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 312, \"PID\": 914476520, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 9196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 313, \"PID\": 914478045, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 473.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169900}, {\"Order\": 314, \"PID\": 914478110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1958.0, \"TotalBsmtSF\": 1958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 315, \"PID\": 916125360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 57200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 334.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 50, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 316, \"PID\": 916386010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 78.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1346, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 317, \"PID\": 916386020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1214.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2010.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179781}, {\"Order\": 318, \"PID\": 916386060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 319, \"PID\": 916386090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2010, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 774.0, \"TotalBsmtSF\": 774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 1194, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 269500}, {\"Order\": 320, \"PID\": 916455170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 1894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214900}, {\"Order\": 321, \"PID\": 916475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202900}, {\"Order\": 322, \"PID\": 921128020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 13214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2002.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2018, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2018, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378500}, {\"Order\": 323, \"PID\": 923201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 42.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 324, \"PID\": 923202105, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10114, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1430.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 325, \"PID\": 923204150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 326, \"PID\": 923205015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1344.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166500}, {\"Order\": 327, \"PID\": 923225300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83500}, {\"Order\": 328, \"PID\": 923225390, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 31.0, \"LotArea\": 2394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 945, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 329, \"PID\": 923225440, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 2592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 129.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 232.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 536, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 330, \"PID\": 923226250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 331, \"PID\": 923226320, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1491, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75500}, {\"Order\": 332, \"PID\": 923228270, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88250}, {\"Order\": 333, \"PID\": 923228370, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 334, \"PID\": 923230190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 469.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2010, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 335, \"PID\": 923251080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 26142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 336, \"PID\": 923276030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 207.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 337, \"PID\": 923276250, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1985, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Po\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1216.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 338, \"PID\": 923426070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 22, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 339, \"PID\": 924100050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 388.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 615, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 287, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 340, \"PID\": 924151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1341.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 284.0, \"BsmtUnfSF\": 54.0, \"TotalBsmtSF\": 1679.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 64, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 341, \"PID\": 924152030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12961, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 944.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2010, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 342, \"PID\": 526302110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 343, \"PID\": 526351100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 440.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 844.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 344, \"PID\": 526355080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 542.0, \"TotalBsmtSF\": 1952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 2704, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 269, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 345, \"PID\": 527105070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 346, \"PID\": 527105130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 1275, \"LowQualFinSF\": 0, \"GrLivArea\": 2283, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 347, \"PID\": 527107130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1628, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 490, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 348, \"PID\": 527108070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 14892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1746, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377500}, {\"Order\": 349, \"PID\": 527110020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 22.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 350, \"PID\": 527127100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 28.0, \"LotArea\": 7296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 243.0, \"TotalBsmtSF\": 2208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2522, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 351, \"PID\": 527131030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 5664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1659, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1659, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 352, \"PID\": 527132090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 353, \"PID\": 527146010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 354, \"PID\": 527161040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 355, \"PID\": 527162110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 94, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 291, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 356, \"PID\": 527162120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 357, \"PID\": 527163040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 799.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 799, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 358, \"PID\": 527163070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 359, \"PID\": 527163130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181316}, {\"Order\": 360, \"PID\": 527164020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 7250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 361, \"PID\": 527164060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 362, \"PID\": 527164090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 702, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1481, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 363, \"PID\": 527165130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 364, \"PID\": 527166010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 694.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 1983, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 365, \"PID\": 527180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 11851, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1424.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 508, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 366, \"PID\": 527182110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 187500}, {\"Order\": 367, \"PID\": 527214050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 17423, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 748.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 2216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1166.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 501837}, {\"Order\": 368, \"PID\": 527254020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 464.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2046.0, \"TotalBsmtSF\": 2046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372500}, {\"Order\": 369, \"PID\": 527258020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 16158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 370, \"PID\": 527276160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 722.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1934, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 371, \"PID\": 527301320, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 692.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 1200, \"LowQualFinSF\": 0, \"GrLivArea\": 2353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 372, \"PID\": 527302175, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 17043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1586, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 373, \"PID\": 527326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 82500}, {\"Order\": 374, \"PID\": 527326150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 375, \"PID\": 527352150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 154000}, {\"Order\": 376, \"PID\": 527353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 363.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 377, \"PID\": 527353060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1980, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 229.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1539, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2673, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 378, \"PID\": 527354100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 225.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 379, \"PID\": 527354200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 380, \"PID\": 527355150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1420.0, \"TotalBsmtSF\": 2524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 381, \"PID\": 527356040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1601, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157000}, {\"Order\": 382, \"PID\": 527359050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 479.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 383, \"PID\": 527359180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 448, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197500}, {\"Order\": 384, \"PID\": 527364030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1016, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 581.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240900}, {\"Order\": 385, \"PID\": 527365030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 8004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 1103, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 263435}, {\"Order\": 386, \"PID\": 527366030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1058.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 387, \"PID\": 527368010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 225.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 471.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 839, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 388, \"PID\": 527375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1333.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 490, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 389, \"PID\": 527375180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 888.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1116.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1116, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 390, \"PID\": 527375210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 391, \"PID\": 527376100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 392, \"PID\": 527378140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 333.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 2119, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158000}, {\"Order\": 393, \"PID\": 527401160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 394, \"PID\": 527402220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 1002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1002, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 902.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 395, \"PID\": 527403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 439.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 472.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 396, \"PID\": 527404020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1180.0, \"TotalBsmtSF\": 1180.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 397, \"PID\": 527404030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1043.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 398, \"PID\": 527405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 726.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 76500}, {\"Order\": 399, \"PID\": 527405160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 239.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 400, \"PID\": 527405180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 401, \"PID\": 527425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 524.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 97000}, {\"Order\": 402, \"PID\": 527425110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 403, \"PID\": 527450280, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 254.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 404, \"PID\": 527451110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 312.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 405, \"PID\": 527451320, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 406, \"PID\": 527451540, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 79.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 407, \"PID\": 527451640, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 510.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 408, \"PID\": 527451650, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 409, \"PID\": 527452060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143750}, {\"Order\": 410, \"PID\": 527453050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 411, \"PID\": 527453060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 87, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 412, \"PID\": 527453140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 622.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 413, \"PID\": 527454050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 260, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 414, \"PID\": 527454130, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2349, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 389.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 415, \"PID\": 527455050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 320.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 416, \"PID\": 527455060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 586, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 417, \"PID\": 527455080, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 279.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 418, \"PID\": 527455090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 345.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 419, \"PID\": 527455240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 420, \"PID\": 527455280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 421, \"PID\": 528102040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1172.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337500}, {\"Order\": 422, \"PID\": 528102140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 726.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1794, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 462000}, {\"Order\": 423, \"PID\": 528104070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 13518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 860.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1926.0, \"TotalBsmtSF\": 1926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 1174, \"LowQualFinSF\": 0, \"GrLivArea\": 3140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 485000}, {\"Order\": 424, \"PID\": 528106020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1767.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 3094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2402, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 555000}, {\"Order\": 425, \"PID\": 528106070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 404, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 426, \"PID\": 528108010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 640.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1566.0, \"TotalBsmtSF\": 1566.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 890.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256300}, {\"Order\": 427, \"PID\": 528108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2042.0, \"TotalBsmtSF\": 2042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 253293}, {\"Order\": 428, \"PID\": 528108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1365, \"2ndFlrSF\": 1325, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 197, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 398800}, {\"Order\": 429, \"PID\": 528108070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 154.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 1054, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 430, \"PID\": 528108130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 12350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 788.0, \"TotalBsmtSF\": 2020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 404000}, {\"Order\": 431, \"PID\": 528108140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 12220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 2006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 402861}, {\"Order\": 432, \"PID\": 528110010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 13478, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1722.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 2296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 842.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 451950}, {\"Order\": 433, \"PID\": 528110020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 2630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2674, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2674, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 762.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 360, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 610000}, {\"Order\": 434, \"PID\": 528110090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 424.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1734.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 1088, \"LowQualFinSF\": 0, \"GrLivArea\": 2822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1020.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 582933}, {\"Order\": 435, \"PID\": 528112040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1736.0, \"TotalBsmtSF\": 1736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1736, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1736, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 436, \"PID\": 528116010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 99, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 296000}, {\"Order\": 437, \"PID\": 528118060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 23303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1508.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1508, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 273, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 409900}, {\"Order\": 438, \"PID\": 528120020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1709.0, \"TotalBsmtSF\": 1709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1717, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255500}, {\"Order\": 439, \"PID\": 528120030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1015.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 1739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 927.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 440, \"PID\": 528120160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 262.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 1713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 170, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274900}, {\"Order\": 441, \"PID\": 528120170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 122.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1037.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1531, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 700.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 442, \"PID\": 528138010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 13514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 285.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1142.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 1774.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1808, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 443, \"PID\": 528142040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8834, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1170.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1462, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 444, \"PID\": 528142090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 11362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 862.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 185, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 445, \"PID\": 528142130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1124.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 479.0, \"BsmtUnfSF\": 1603.0, \"TotalBsmtSF\": 3206.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 446, \"PID\": 528142150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12878, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 418.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 1760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1760, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 190, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 447, \"PID\": 528144020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1502.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233170}, {\"Order\": 448, \"PID\": 528166060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 922.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2336.0, \"TotalBsmtSF\": 2392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 386250}, {\"Order\": 449, \"PID\": 528166090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 724.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1972.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 2452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 886.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 445000}, {\"Order\": 450, \"PID\": 528168030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1295, \"LowQualFinSF\": 0, \"GrLivArea\": 2400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 451, \"PID\": 528172060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1598.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1606, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1606, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 452, \"PID\": 528174050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 6904, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 453, \"PID\": 528174060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 900.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 454, \"PID\": 528174070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 135.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1306.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 455, \"PID\": 528175050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212500}, {\"Order\": 456, \"PID\": 528175060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 457, \"PID\": 528176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 730.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2146.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 2492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 949.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 226, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 552000}, {\"Order\": 458, \"PID\": 528178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 117.0, \"LotArea\": 15262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 470.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 643.0, \"TotalBsmtSF\": 2200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 685.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 382500}, {\"Order\": 459, \"PID\": 528180120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 308.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1084.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 460, \"PID\": 528180130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 461, \"PID\": 528186010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 1712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 183, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286500}, {\"Order\": 462, \"PID\": 528186180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 863.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254000}, {\"Order\": 463, \"PID\": 528188020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 464, \"PID\": 528188060, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2268, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 465, \"PID\": 528218090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 466, \"PID\": 528220040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 745.0, \"TotalBsmtSF\": 745.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 745, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167800}, {\"Order\": 467, \"PID\": 528221060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 12589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 468, \"PID\": 528221070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 469, \"PID\": 528228290, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1373.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 470, \"PID\": 528228295, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 1386.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1569, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1569, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 471, \"PID\": 528228435, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1357.0, \"TotalBsmtSF\": 1373.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1555, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 472, \"PID\": 528228450, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 473, \"PID\": 528228455, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 474, \"PID\": 528228460, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 11.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160200}, {\"Order\": 475, \"PID\": 528235010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 476, \"PID\": 528235090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1010.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1010, \"2ndFlrSF\": 1257, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 477, \"PID\": 528235200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 478, \"PID\": 528240030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189500}, {\"Order\": 479, \"PID\": 528240060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 779, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184100}, {\"Order\": 480, \"PID\": 528240150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 748, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 481, \"PID\": 528250020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 482, \"PID\": 528250040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8174, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 483, \"PID\": 528253010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 5063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 484, \"PID\": 528275070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8795, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 1276, \"LowQualFinSF\": 0, \"GrLivArea\": 2256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236000}, {\"Order\": 485, \"PID\": 528275160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 1126, \"LowQualFinSF\": 0, \"GrLivArea\": 2004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 486, \"PID\": 528280230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 487, \"PID\": 528290030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9734, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 113.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 488, \"PID\": 528290120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8123, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 489, \"PID\": 528290180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 8433, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 683.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1514, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 490, \"PID\": 528290190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 491, \"PID\": 528292030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1177.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2312, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 492, \"PID\": 528292040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 841.0, \"TotalBsmtSF\": 841.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 493, \"PID\": 528292070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 772.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 1038, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 494, \"PID\": 528294050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7848, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 495, \"PID\": 528315090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 673.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1163.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 337000}, {\"Order\": 496, \"PID\": 528321010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 15138, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 506.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 689.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 773.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1490, \"2ndFlrSF\": 1304, \"LowQualFinSF\": 0, \"GrLivArea\": 2794, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 202, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 403000}, {\"Order\": 497, \"PID\": 528327070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 1455.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1221, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 327000}, {\"Order\": 498, \"PID\": 528344040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 731.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2450, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1069.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 499, \"PID\": 528344100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12203, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 975.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 854.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1225.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 1336, \"LowQualFinSF\": 0, \"GrLivArea\": 2612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 336000}, {\"Order\": 500, \"PID\": 528354050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10208, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 921.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1264.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 1067, \"LowQualFinSF\": 0, \"GrLivArea\": 2344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 889.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 501, \"PID\": 528363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 634.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1526.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 2024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2063, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2063, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 815.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 502, \"PID\": 528365070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 987.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 1347.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 1274, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 60, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 503, \"PID\": 528385050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 967, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 102, \"EnclosedPorch\": 209, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 504, \"PID\": 528387030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 372.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 623.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263550}, {\"Order\": 505, \"PID\": 528390100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 46589, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 528.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1629.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 762, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 517, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 402000}, {\"Order\": 506, \"PID\": 528390210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 29959, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 507, \"PID\": 528427020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 244600}, {\"Order\": 508, \"PID\": 528431020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1696.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 972.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 509, \"PID\": 528431070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 294.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1614.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1658, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 510, \"PID\": 528435030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9262, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1573.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287090}, {\"Order\": 511, \"PID\": 528435050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 512, \"PID\": 528439060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 513, \"PID\": 528441020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 772.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 689.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 514, \"PID\": 528441090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2158.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2458.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2490, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 226, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 468000}, {\"Order\": 515, \"PID\": 528456180, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 822.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 920, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252678}, {\"Order\": 516, \"PID\": 528456220, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 517, \"PID\": 528456240, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7862, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 27.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208300}, {\"Order\": 518, \"PID\": 528458020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 90.0, \"LotArea\": 7993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 519, \"PID\": 528458040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229456}, {\"Order\": 520, \"PID\": 528458060, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1402.0, \"TotalBsmtSF\": 1402.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 205, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229800}, {\"Order\": 521, \"PID\": 528458140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 984.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 522, \"PID\": 528458160, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 645.0, \"TotalBsmtSF\": 1766.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 195, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370878}, {\"Order\": 523, \"PID\": 528458180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1348.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1448, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1448, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238500}, {\"Order\": 524, \"PID\": 528477050, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 160.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 765.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 981, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 310000}, {\"Order\": 525, \"PID\": 528477070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10603, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 121.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 526, \"PID\": 528480040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1082.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1043.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 527, \"PID\": 528480130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 438, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241000}, {\"Order\": 528, \"PID\": 528480170, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264500}, {\"Order\": 529, \"PID\": 528482040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1662, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1662, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 711.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 530, \"PID\": 528482130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 531, \"PID\": 528488100, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1221.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 532, \"PID\": 528490040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 68.0, \"LotArea\": 8736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 771.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 360.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1553.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234500}, {\"Order\": 533, \"PID\": 528490070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8127, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 841, \"LowQualFinSF\": 0, \"GrLivArea\": 1653, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 534, \"PID\": 531363010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1218.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 178, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 535, \"PID\": 531363030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1087.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 536, \"PID\": 531363050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 537, \"PID\": 531369010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 871, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 538, \"PID\": 531369020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10141, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 774.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1512.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 845.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 539, \"PID\": 531371050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10083, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 833.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 540, \"PID\": 531375040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 541, \"PID\": 531375090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 542, \"PID\": 531375130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 543, \"PID\": 531376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1450, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224243}, {\"Order\": 544, \"PID\": 531379050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 11492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 1209, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 559.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 545, \"PID\": 531382070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10994, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 366.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 620.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 257000}, {\"Order\": 546, \"PID\": 531385020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1434.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1434, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1434, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 547, \"PID\": 531450120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 364.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1730, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 548, \"PID\": 531452010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 626, \"2ndFlrSF\": 591, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 549, \"PID\": 531452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1332.0, \"TotalBsmtSF\": 1332.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1332, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1332, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 550, \"PID\": 531452260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 786, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 551, \"PID\": 531453100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 141.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 465.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 552, \"PID\": 531475220, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 553, \"PID\": 531477020, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 721.0, \"TotalBsmtSF\": 721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 841, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 841, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 554, \"PID\": 531479020, \"MSSubClass\": 45, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 91, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 76000}, {\"Order\": 555, \"PID\": 532353020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 884.0, \"BsmtUnfSF\": 28.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 556, \"PID\": 532353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 557, \"PID\": 532354160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 558, \"PID\": 532354230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9079, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 559, \"PID\": 532376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Family\", \"SalePrice\": 124100}, {\"Order\": 560, \"PID\": 532376110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 561, \"PID\": 532377130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131400}, {\"Order\": 562, \"PID\": 532378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 311.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 62383}, {\"Order\": 563, \"PID\": 532378180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 140.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 590.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 564, \"PID\": 532478020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15676, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1733.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 92.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 2014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 462, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 255, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 565, \"PID\": 533135020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11949, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1991, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 601.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 216.0, \"BsmtUnfSF\": 158.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 502, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 566, \"PID\": 533206020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 2880, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1376.0, \"TotalBsmtSF\": 1376.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1376, \"2ndFlrSF\": 1629, \"LowQualFinSF\": 0, \"GrLivArea\": 3005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 177, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280750}, {\"Order\": 567, \"PID\": 533210010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164500}, {\"Order\": 568, \"PID\": 533210020, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 612, \"2ndFlrSF\": 612, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173733}, {\"Order\": 569, \"PID\": 533213010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 3830, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1726.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 254, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 222000}, {\"Order\": 570, \"PID\": 533213020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4217, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 183.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 571, \"PID\": 533213040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 894.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1471, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 572, \"PID\": 533221040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 249.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 573, \"PID\": 533223030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 574, \"PID\": 533236050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 321.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1739, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 172500}, {\"Order\": 575, \"PID\": 533252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1252.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 136.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 501, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 225, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318750}, {\"Order\": 576, \"PID\": 533253070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 3782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 960.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211500}, {\"Order\": 577, \"PID\": 533254050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 15417, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1619.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 20, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241600}, {\"Order\": 578, \"PID\": 533254110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1487, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180500}, {\"Order\": 579, \"PID\": 533352150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1281.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 580, \"PID\": 534125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 727.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 829, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 581, \"PID\": 534127130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11717, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 571.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1442.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 371, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 582, \"PID\": 534127170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9156, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185750}, {\"Order\": 583, \"PID\": 534128010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 859.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 32.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 204, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 350, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 584, \"PID\": 534128020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 42.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 782, \"LowQualFinSF\": 0, \"GrLivArea\": 2067, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 297, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206000}, {\"Order\": 585, \"PID\": 534128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 593.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 735, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 586, \"PID\": 534128190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1369, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256900}, {\"Order\": 587, \"PID\": 534129080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1724, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 588, \"PID\": 534129370, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 589, \"PID\": 534129380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 955.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113000}, {\"Order\": 590, \"PID\": 534151120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 283.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 2288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 591, \"PID\": 534152120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 592, \"PID\": 534175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1127.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 78, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213250}, {\"Order\": 593, \"PID\": 534177230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 594, \"PID\": 534200030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 595, \"PID\": 534202170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 596, \"PID\": 534226120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 466.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 597, \"PID\": 534250400, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2061, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 168500}, {\"Order\": 598, \"PID\": 534251030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 509.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 599, \"PID\": 534252240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 251.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 630.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 457.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 197, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 600, \"PID\": 534275060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 360, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 601, \"PID\": 534275100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 602, \"PID\": 534276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 603, \"PID\": 534277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 775.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 604, \"PID\": 534278070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 201.0, \"BsmtUnfSF\": 222.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177625}, {\"Order\": 605, \"PID\": 534278230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 606, \"PID\": 534400050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10004, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 345.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 1516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1516, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 152, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 607, \"PID\": 534400290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 217.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 512.0, \"BsmtUnfSF\": 491.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1313, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 121, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 608, \"PID\": 534402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1292.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1292, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145100}, {\"Order\": 609, \"PID\": 534402140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 230.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1154.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 610, \"PID\": 534402170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 549.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 611, \"PID\": 534403370, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 563.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 612, \"PID\": 534426110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 991.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 50.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 613, \"PID\": 534429150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 614, \"PID\": 534431130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 100.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 613.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 615, \"PID\": 534450150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 616, \"PID\": 534451110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 185.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 709.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 979, \"2ndFlrSF\": 224, \"LowQualFinSF\": 0, \"GrLivArea\": 1203, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 617, \"PID\": 534475185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 12160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 1505.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1505, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 162, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 618, \"PID\": 534475250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1691, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 67, \"EnclosedPorch\": 260, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 619, \"PID\": 534476150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 238.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 1416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 620, \"PID\": 534476320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 621, \"PID\": 534477110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 556, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 622, \"PID\": 534478230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 607.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 623, \"PID\": 535101120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 624, \"PID\": 535104120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10573, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 3.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 625, \"PID\": 535105100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 247.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1394.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1394, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 185, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 626, \"PID\": 535125070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 1562.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 342, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 627, \"PID\": 535125090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 314.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1186, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 628, \"PID\": 535126010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 576.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 448.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 2142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 252, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 629, \"PID\": 535126100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1392.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 630, \"PID\": 535150070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1281, \"2ndFlrSF\": 457, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 631, \"PID\": 535151040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 313.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 632, \"PID\": 535152230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 661.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 633, \"PID\": 535154060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1329.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1329, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1329, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 203, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 634, \"PID\": 535154130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 635, \"PID\": 535175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 620.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 636, \"PID\": 535175050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1215.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1215, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 234, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 637, \"PID\": 535178040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 565.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1202, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1202, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 638, \"PID\": 535178120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 172.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 727.0, \"TotalBsmtSF\": 1382.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 639, \"PID\": 535179160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 155.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 750.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144000}, {\"Order\": 640, \"PID\": 535300120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 19296, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 399.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 690.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 641, \"PID\": 535301170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 1297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1297, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1297, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 642, \"PID\": 535302120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 657.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1866.0, \"TotalBsmtSF\": 1866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 643, \"PID\": 535303110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 8128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 644, \"PID\": 535303150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10634, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1319, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1319, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 645, \"PID\": 535304100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 13070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 631.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 646, \"PID\": 535325290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10434, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1005.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 647, \"PID\": 535351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 178.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 648, \"PID\": 535352090, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 793, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 649, \"PID\": 535353040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1952, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1031.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1031, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 650, \"PID\": 535353060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102900}, {\"Order\": 651, \"PID\": 535353140, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 10615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1699, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 95000}, {\"Order\": 652, \"PID\": 535353240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 699.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 801, \"2ndFlrSF\": 726, \"LowQualFinSF\": 0, \"GrLivArea\": 1527, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 653, \"PID\": 535354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 654, \"PID\": 535354100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 972, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 655, \"PID\": 535375010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 366.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 656, \"PID\": 535375050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 704, \"LowQualFinSF\": 144, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 140, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 657, \"PID\": 535376060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 658, \"PID\": 535377150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8146, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 717, \"2ndFlrSF\": 322, \"LowQualFinSF\": 0, \"GrLivArea\": 1039, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 111, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 659, \"PID\": 535378020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 9022, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1924, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 660, \"PID\": 535378120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10230, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1078, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1078, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 661, \"PID\": 535381040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 0, \"LowQualFinSF\": 1064, \"GrLivArea\": 2377, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 432, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142900}, {\"Order\": 662, \"PID\": 535382100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 760, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 663, \"PID\": 535383060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 599, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 599, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 59000}, {\"Order\": 664, \"PID\": 535383070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 198, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 665, \"PID\": 535383110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 666, \"PID\": 535383120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 725, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78500}, {\"Order\": 667, \"PID\": 535402010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1248.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 907.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 668, \"PID\": 535402090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 996.0, \"TotalBsmtSF\": 1380.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1380, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 669, \"PID\": 535402270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 670, \"PID\": 535402330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2634, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 968.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 671, \"PID\": 535403190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1958, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 672, \"PID\": 535403210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 559.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1105, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 673, \"PID\": 535403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1306, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 674, \"PID\": 535425070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1270.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 675, \"PID\": 535426150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 676, \"PID\": 535450070, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 232, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 677, \"PID\": 535450160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 92900}, {\"Order\": 678, \"PID\": 535450200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 231, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 679, \"PID\": 535451170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 680, \"PID\": 535451250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 352.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 681, \"PID\": 535452090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1041.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1041, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 682, \"PID\": 535452100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 683, \"PID\": 535452140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 102.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 732, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118900}, {\"Order\": 684, \"PID\": 535453100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 433.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 95.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1183, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 685, \"PID\": 535453200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 686, \"PID\": 535454100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 832, \"2ndFlrSF\": 629, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 687, \"PID\": 535454160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 431, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 688, \"PID\": 535475010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 7570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1806, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144750}, {\"Order\": 689, \"PID\": 535476110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 124.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 690, \"PID\": 535476240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 7936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 826.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 691, \"PID\": 535477150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 692, \"PID\": 902101010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3950, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 693, \"PID\": 902102080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 682, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 694, \"PID\": 902103100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 4080, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 54, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128900}, {\"Order\": 695, \"PID\": 902103120, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 10307, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 972, \"2ndFlrSF\": 972, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 696, \"PID\": 902103170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 5720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 455, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 26, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 66500}, {\"Order\": 697, \"PID\": 902105050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 496, \"LowQualFinSF\": 0, \"GrLivArea\": 1306, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 698, \"PID\": 902105060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 699, \"PID\": 902106010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6406, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 269.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 868, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 700, \"PID\": 902106060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1892, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 994.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 994, \"LowQualFinSF\": 0, \"GrLivArea\": 2372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 287, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 701, \"PID\": 902109130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94550}, {\"Order\": 702, \"PID\": 902109140, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7596, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1000, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 703, \"PID\": 902110080, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3378, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1946, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 651.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 682, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 704, \"PID\": 902134120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 801, \"2ndFlrSF\": 646, \"LowQualFinSF\": 0, \"GrLivArea\": 1447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 705, \"PID\": 902135020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 706, \"PID\": 902201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 707, \"PID\": 902202150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 811.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 811, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 708, \"PID\": 902204080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"Oth\", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 709, \"PID\": 902205010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 25, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 45000}, {\"Order\": 710, \"PID\": 902205030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 37900}, {\"Order\": 711, \"PID\": 902206260, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1938, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 886, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91300}, {\"Order\": 712, \"PID\": 902207170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 713, \"PID\": 902300090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 4456, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 113000}, {\"Order\": 714, \"PID\": 902301060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 677.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 715, \"PID\": 902301080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 716, \"PID\": 902325070, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1898, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 849.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 1063, \"LowQualFinSF\": 0, \"GrLivArea\": 2138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 3, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 156, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 717, \"PID\": 902326030, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 181, \"OpenPorchSF\": 0, \"EnclosedPorch\": 386, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265979}, {\"Order\": 718, \"PID\": 902327070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 917.0, \"TotalBsmtSF\": 917.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2007, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 719, \"PID\": 902329080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1917, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1917.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 720, \"PID\": 902330040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 121.0, \"LotArea\": 17671, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1882, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 826, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 424.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 721, \"PID\": 902331010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": null, \"LotArea\": 3300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 58500}, {\"Order\": 722, \"PID\": 902401130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1920, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 26.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 723, \"PID\": 902402150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 226, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 724, \"PID\": 902405100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 98.0, \"LotArea\": 8820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1088.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 561, \"LowQualFinSF\": 120, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 725, \"PID\": 902405120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 436, \"GrLivArea\": 1480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 207.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 119000}, {\"Order\": 726, \"PID\": 902406070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 640.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 238, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 727, \"PID\": 902477120, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 523, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 34900}, {\"Order\": 728, \"PID\": 902477130, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 72.0, \"LotArea\": 9392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 245.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 44000}, {\"Order\": 729, \"PID\": 903200080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 144.0, \"LotArea\": 21384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 15.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 730, \"PID\": 903201020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1022.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 731, \"PID\": 903201080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 732, \"PID\": 903202170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 297.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 244, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 733, \"PID\": 903205040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 192.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 40, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 734, \"PID\": 903226130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 735, \"PID\": 903226170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 786, \"2ndFlrSF\": 390, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 736, \"PID\": 903227070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 737, \"PID\": 903227090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 825, \"2ndFlrSF\": 587, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 45, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 738, \"PID\": 903228070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 444.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 320, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 98, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 739, \"PID\": 903228120, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 740, \"PID\": 903230100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 741, \"PID\": 903231010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 927.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1067, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 742, \"PID\": 903231030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 989, \"2ndFlrSF\": 584, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 54, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 743, \"PID\": 903231060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 744, \"PID\": 903231130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1931, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 506.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 745, \"PID\": 903232060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 995, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 15, \"EnclosedPorch\": 51, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 746, \"PID\": 903234220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 679.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 994, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 189, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 150, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 747, \"PID\": 903236040, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 134.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 1072.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 5.0, \"GarageArea\": 1184.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 748, \"PID\": 903400220, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11888, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 2134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 268, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214500}, {\"Order\": 749, \"PID\": 903425245, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 883, \"LowQualFinSF\": 0, \"GrLivArea\": 2019, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 509, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 750, \"PID\": 903427120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 751, \"PID\": 903429080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 2500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 752, \"PID\": 903429110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 753, \"PID\": 903430060, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 92.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 929, \"LowQualFinSF\": 371, \"GrLivArea\": 2229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 198, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 104000}, {\"Order\": 754, \"PID\": 903430070, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 3000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Sev\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 62500}, {\"Order\": 755, \"PID\": 903451090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 198.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 316.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 213, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 756, \"PID\": 903458170, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 757, \"PID\": 903475100, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 758, \"PID\": 903476090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1902, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 169.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 978, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 759, \"PID\": 903481120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1204.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 760, \"PID\": 903481130, \"MSSubClass\": 85, \"MSZoning\": \"RM\", \"LotFrontage\": 86.0, \"LotArea\": 5160, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 749.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 63.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 70000}, {\"Order\": 761, \"PID\": 903484110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 262.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 754, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 288, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 762, \"PID\": 904100190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1946, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 704, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 704, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 24, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88750}, {\"Order\": 763, \"PID\": 904301060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 764, \"PID\": 904301070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 3.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 179000}, {\"Order\": 765, \"PID\": 904301100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 766, \"PID\": 904301375, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 1, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61000}, {\"Order\": 767, \"PID\": 904351200, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 54.0, \"LotArea\": 6629, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 551.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103600}, {\"Order\": 768, \"PID\": 904351240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 687, \"2ndFlrSF\": 425, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 226.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63000}, {\"Order\": 769, \"PID\": 905101260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12886, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 770, \"PID\": 905101490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 651.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1121, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 771, \"PID\": 905103040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 92.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 500.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 765, \"LowQualFinSF\": 0, \"GrLivArea\": 1683, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 772, \"PID\": 905103070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 215, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 113500}, {\"Order\": 773, \"PID\": 905105190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 774, \"PID\": 905107310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 775, \"PID\": 905108190, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7252, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 776, \"PID\": 905108220, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 860, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 777, \"PID\": 905200220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 170.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 778, \"PID\": 905200260, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 611, \"LowQualFinSF\": 259, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 779, \"PID\": 905200350, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 15312, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 140, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 780, \"PID\": 905225090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 366.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2071, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2071, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 781, \"PID\": 905228050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 2, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 63900}, {\"Order\": 782, \"PID\": 905229040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1104.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 304.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 783, \"PID\": 905325020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 25095, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1473, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1473, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 60, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 143000}, {\"Order\": 784, \"PID\": 905377010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 284.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 785, \"PID\": 905377130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 786, \"PID\": 905401100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10708, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 768.0, \"BsmtUnfSF\": 470.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1867, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1867, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 476, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 787, \"PID\": 905402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139600}, {\"Order\": 788, \"PID\": 905402070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 789, \"PID\": 905450020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1436.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 790, \"PID\": 905451300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 340.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121500}, {\"Order\": 791, \"PID\": 905451340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1276, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 60000}, {\"Order\": 792, \"PID\": 905452040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 747, \"LowQualFinSF\": 0, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154400}, {\"Order\": 793, \"PID\": 905452050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 344.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 794, \"PID\": 905475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1089.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1089, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 795, \"PID\": 905475500, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 290.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84000}, {\"Order\": 796, \"PID\": 905476230, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 393.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1049.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1049, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 266.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 797, \"PID\": 905478030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11409, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 798, \"PID\": 905480030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 799, \"PID\": 905480210, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 755.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 800, \"PID\": 906201021, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 286.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1061, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1061, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 801, \"PID\": 906201050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 19255, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 450.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 802, \"PID\": 906201130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1983, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 2132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 349, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316600}, {\"Order\": 803, \"PID\": 906203120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 177.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 2158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 701.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271900}, {\"Order\": 804, \"PID\": 906223060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 137.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 227.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 769, \"LowQualFinSF\": 0, \"GrLivArea\": 1775, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 425.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 234, \"OpenPorchSF\": 72, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 805, \"PID\": 906223080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1879, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 100, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 806, \"PID\": 906223210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239500}, {\"Order\": 807, \"PID\": 906226060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 26400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1880, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 2016, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 808, \"PID\": 906226070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118964}, {\"Order\": 809, \"PID\": 906226080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1086.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 153337}, {\"Order\": 810, \"PID\": 906226090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 1114, \"LowQualFinSF\": 0, \"GrLivArea\": 2228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 73, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 147983}, {\"Order\": 811, \"PID\": 906226100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 812, \"PID\": 906226110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1535, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1535, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 118858}, {\"Order\": 813, \"PID\": 906226120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 1120, \"LowQualFinSF\": 0, \"GrLivArea\": 2240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 142953}, {\"Order\": 814, \"PID\": 906226130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1094.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1229, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 148325}, {\"Order\": 815, \"PID\": 906226140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 113722}, {\"Order\": 816, \"PID\": 906230010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11855, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 817, \"PID\": 906230020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7939, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 818, \"PID\": 906230030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 23.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 820.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1619, \"LowQualFinSF\": 0, \"GrLivArea\": 2787, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 4, \"HalfBath\": 2, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 820.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269500}, {\"Order\": 819, \"PID\": 906340100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10933, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1021.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 534.0, \"TotalBsmtSF\": 1555.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1138.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 323262}, {\"Order\": 820, \"PID\": 906340110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 417.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 297000}, {\"Order\": 821, \"PID\": 906340120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 10226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1622.0, \"TotalBsmtSF\": 1622.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 860.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295493}, {\"Order\": 822, \"PID\": 906340130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10816, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 364.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1104.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 332000}, {\"Order\": 823, \"PID\": 906378110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1468, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 904.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 824, \"PID\": 906380050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 825, \"PID\": 906380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11422, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1359.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 222, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272500}, {\"Order\": 826, \"PID\": 906380100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 122.0, \"LotArea\": 11923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 827, \"PID\": 906380130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1334.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1604, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 828, \"PID\": 906380210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1282.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 829, \"PID\": 906380220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 10324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 382.0, \"TotalBsmtSF\": 1254.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221800}, {\"Order\": 830, \"PID\": 906392070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 82.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 831, \"PID\": 906392110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1474.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 832, \"PID\": 906392130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 704, \"2ndFlrSF\": 718, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 833, \"PID\": 906402060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1644, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 396, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 834, \"PID\": 906426210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 1449.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 815, \"LowQualFinSF\": 0, \"GrLivArea\": 1759, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 193, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 233500}, {\"Order\": 835, \"PID\": 906475070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 28698, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 764.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 966, \"LowQualFinSF\": 0, \"GrLivArea\": 2126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 836, \"PID\": 907126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 308.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 837, \"PID\": 907126050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9757, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 92, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 838, \"PID\": 907130100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 15426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 107.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 836, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 839, \"PID\": 907131090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 70.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 834, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 840, \"PID\": 907131190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14753, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 950.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1463.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1463, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1463, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 841, \"PID\": 907135040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 10859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1097.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 392, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 842, \"PID\": 907135170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 746.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 843, \"PID\": 907175100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 866.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 913, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 844, \"PID\": 907180130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 679.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 811.0, \"TotalBsmtSF\": 1490.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 845, \"PID\": 907181100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9017, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 871.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 846, \"PID\": 907185050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 847, \"PID\": 907192030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8935, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 848, \"PID\": 907192090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 9808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1573, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 849, \"PID\": 907194010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1840, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 850, \"PID\": 907194110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 16285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1413.0, \"TotalBsmtSF\": 1413.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187100}, {\"Order\": 851, \"PID\": 907194160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10739, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 1431.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 852, \"PID\": 907196060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11166, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 201000}, {\"Order\": 853, \"PID\": 907200230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 854, \"PID\": 907201220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16269, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 343.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 855, \"PID\": 907201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 6950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 710.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 856, \"PID\": 907202050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 364.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150500}, {\"Order\": 857, \"PID\": 907202080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 858, \"PID\": 907202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1072.0, \"TotalBsmtSF\": 1268.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1268, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 173, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 859, \"PID\": 907227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 15523, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 860, \"PID\": 907227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 215, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 861, \"PID\": 907227110, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 862, \"PID\": 907227290, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8445, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 863, \"PID\": 907250070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 335.0, \"TotalBsmtSF\": 1569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1231.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 864, \"PID\": 907252060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1068.0, \"TotalBsmtSF\": 1068.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 254750}, {\"Order\": 865, \"PID\": 907252210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 866, \"PID\": 907252220, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 990.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 309.0, \"TotalBsmtSF\": 1299.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 573, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 261500}, {\"Order\": 867, \"PID\": 907253130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 2153, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 313000}, {\"Order\": 868, \"PID\": 907260030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 869, \"PID\": 907265010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 944.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 926, \"LowQualFinSF\": 0, \"GrLivArea\": 1870, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 870, \"PID\": 907275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1513, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 871, \"PID\": 907275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 814.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 115, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 872, \"PID\": 907275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 523.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 873, \"PID\": 907280170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 209.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1111.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1417, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1417, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 117, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 874, \"PID\": 907285020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 573.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 977, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 645.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 576, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 875, \"PID\": 907285050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 876, \"PID\": 907290070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1212.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 573.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 877, \"PID\": 907290090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 171.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1630.0, \"TotalBsmtSF\": 1630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 234, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 878, \"PID\": 907290180, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 879, \"PID\": 907290210, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 880, \"PID\": 907410130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1478.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1602, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1602, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 810.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 293200}, {\"Order\": 881, \"PID\": 907412020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 882, \"PID\": 907414020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1480.0, \"TotalBsmtSF\": 1500.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 883, \"PID\": 907414080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 193.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 884, \"PID\": 907420040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 788, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 885, \"PID\": 908102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 886, \"PID\": 908102270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1486.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 887, \"PID\": 908102290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 888, \"PID\": 908128060, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 500.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 495, \"2ndFlrSF\": 1427, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 177, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 198500}, {\"Order\": 889, \"PID\": 908151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 155.0, \"TotalBsmtSF\": 690.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 890, \"PID\": 908152035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 615.0, \"TotalBsmtSF\": 1014.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 891, \"PID\": 908152100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 255.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 631.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 1041.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 296, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 892, \"PID\": 908154040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 13286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 464.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 327, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 893, \"PID\": 908186080, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 894, \"PID\": 908201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1947, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 698, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 895, \"PID\": 908203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 332.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 243.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 896, \"PID\": 908225290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1078.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 41, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 900, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 897, \"PID\": 908225370, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 441, \"LowQualFinSF\": 0, \"GrLivArea\": 1529, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 898, \"PID\": 908229020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 899, \"PID\": 908250030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82000}, {\"Order\": 900, \"PID\": 908275040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1678.0, \"TotalBsmtSF\": 1678.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1678, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1678, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 901, \"PID\": 908275110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103500}, {\"Order\": 902, \"PID\": 908276150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 160, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 112000}, {\"Order\": 903, \"PID\": 909101010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12354, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 800, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 904, \"PID\": 909101100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8212, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 444, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 905, \"PID\": 909101140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10998, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 420.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 906, \"PID\": 909129090, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1268, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 907, \"PID\": 909129100, \"MSSubClass\": 50, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1932, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 159434}, {\"Order\": 908, \"PID\": 909175080, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 438, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 438, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 60000}, {\"Order\": 909, \"PID\": 909178160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 944, \"2ndFlrSF\": 545, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 910, \"PID\": 909179020, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 15863, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 3, \"YearBuilt\": 1920, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1687, \"2ndFlrSF\": 998, \"LowQualFinSF\": 397, \"GrLivArea\": 3082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 911, \"PID\": 909250080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 5707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 583.0, \"TotalBsmtSF\": 583.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 647, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 329, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 912, \"PID\": 909250220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 622.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 500.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 653, \"LowQualFinSF\": 0, \"GrLivArea\": 1981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 913, \"PID\": 909251050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 914, \"PID\": 909251170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137450}, {\"Order\": 915, \"PID\": 909252020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1936, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 575, \"2ndFlrSF\": 560, \"LowQualFinSF\": 0, \"GrLivArea\": 1135, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 916, \"PID\": 909253010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7558, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1172, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1913, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 917, \"PID\": 909253180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 861.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 877, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1477, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 918, \"PID\": 909254010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 919, \"PID\": 909257050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 10918, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1276.0, \"TotalBsmtSF\": 1276.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1276, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 920, \"PID\": 909275080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 727, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 921, \"PID\": 909276110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 753, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 213.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 922, \"PID\": 909276200, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 332, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 923, \"PID\": 909277090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1273, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 307.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 924, \"PID\": 909277100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13360, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 713.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 44, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 925, \"PID\": 909278020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7681, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 731.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 523, \"LowQualFinSF\": 0, \"GrLivArea\": 1343, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 186.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154900}, {\"Order\": 926, \"PID\": 909279010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 674.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2480, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 13, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 57, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 927, \"PID\": 909282130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 154.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 694.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 144800}, {\"Order\": 928, \"PID\": 909425060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 275.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 429.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174500}, {\"Order\": 929, \"PID\": 909425130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 65.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 875.0, \"BsmtUnfSF\": 621.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 930, \"PID\": 909426090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 507.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1067.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 537, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 295.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 931, \"PID\": 909427200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 14000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 158500}, {\"Order\": 932, \"PID\": 909428240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 17500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 91.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1906, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1906, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 201, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 933, \"PID\": 909451040, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 279, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 934, \"PID\": 909451100, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 935, \"PID\": 909451140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 561.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 936, \"PID\": 909451180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 561, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1229, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 937, \"PID\": 909452050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13607, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 118.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208000}, {\"Order\": 938, \"PID\": 909475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17597, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1971, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 419.0, \"BsmtUnfSF\": 581.0, \"TotalBsmtSF\": 1803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2365, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 939, \"PID\": 909475300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1988, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 808.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 182, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 940, \"PID\": 910202070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 10690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 941, \"PID\": 910204050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 760.0, \"TotalBsmtSF\": 760.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 928, \"LowQualFinSF\": 312, \"GrLivArea\": 2168, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 160, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 942, \"PID\": 910205020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 596, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 189.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 943, \"PID\": 911103050, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 105.0, \"LotArea\": 8470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 2, \"YearBuilt\": 1915, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1013.0, \"TotalBsmtSF\": 1013.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 513, \"GrLivArea\": 1526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85000}, {\"Order\": 944, \"PID\": 911104060, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 72, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 945, \"PID\": 911370500, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230000}, {\"Order\": 946, \"PID\": 912251110, \"MSSubClass\": 30, \"MSZoning\": \"I (all)\", \"LotFrontage\": 109.0, \"LotArea\": 21780, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 119, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 57625}, {\"Order\": 947, \"PID\": 914465020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 250.0, \"BsmtUnfSF\": 412.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1012, \"LowQualFinSF\": 0, \"GrLivArea\": 2052, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 948, \"PID\": 914465040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 12822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1434.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 631, \"LowQualFinSF\": 0, \"GrLivArea\": 2149, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 239686}, {\"Order\": 949, \"PID\": 914465055, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1710.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 950, \"PID\": 914474070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 12209, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 690.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 1157, \"LowQualFinSF\": 0, \"GrLivArea\": 1961, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 951, \"PID\": 914475010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 902.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 926, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 319, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156450}, {\"Order\": 952, \"PID\": 914475030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1287, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 953, \"PID\": 914476020, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 954, \"PID\": 914476380, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9947, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 577.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 955, \"PID\": 914476430, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 55.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1527.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1595, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 152000}, {\"Order\": 956, \"PID\": 916176030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"NoSeWa\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 541.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 118, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 233, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 137500}, {\"Order\": 957, \"PID\": 916176125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 215245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 820.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 513.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 375000}, {\"Order\": 958, \"PID\": 916380070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12898, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 70.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1022.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315500}, {\"Order\": 959, \"PID\": 916382010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13159, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2009, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 846.0, \"TotalBsmtSF\": 846.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 846, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1692, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2009.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 224500}, {\"Order\": 960, \"PID\": 916382100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 13438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 2190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 780.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 961, \"PID\": 916382110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 14463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 406.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1115.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316500}, {\"Order\": 962, \"PID\": 916386140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1450.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 963, \"PID\": 916403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 387.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1412, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 964, \"PID\": 916403200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1980, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2237, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2500, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 965, \"PID\": 916403250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 14419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 624.0, \"BsmtUnfSF\": 117.0, \"TotalBsmtSF\": 1645.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 966, \"PID\": 916455070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6853, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 262.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 967, \"PID\": 916460110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 942, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 968, \"PID\": 916475040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14601, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 584.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 578.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 969, \"PID\": 921128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1640.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1978, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 308, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 425000}, {\"Order\": 970, \"PID\": 923201100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 532.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 971, \"PID\": 923202060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1771, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 972, \"PID\": 923203110, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 338.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 247, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 973, \"PID\": 923203190, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 883.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 974, \"PID\": 923225360, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 975, \"PID\": 923225490, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 9858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 33, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 11, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 976, \"PID\": 923226270, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 515.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 977, \"PID\": 923227080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 13383, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1404, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 978, \"PID\": 923228110, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 121.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 979, \"PID\": 923228150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 980, \"PID\": 923228230, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 273.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 981, \"PID\": 923230200, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7689, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 76.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131900}, {\"Order\": 982, \"PID\": 923252075, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7706, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131250}, {\"Order\": 983, \"PID\": 923275040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1097.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1110, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1110, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 602.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 303, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 984, \"PID\": 923275140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 985, \"PID\": 923276260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 718.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 883, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 883, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 698.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 986, \"PID\": 923400025, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 566, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 320, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 10, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 987, \"PID\": 923400110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10429, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 663, \"LowQualFinSF\": 0, \"GrLivArea\": 1287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 988, \"PID\": 924100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9819, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1567.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 989, \"PID\": 924100060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 496.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 898.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 368, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2009, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 990, \"PID\": 526351030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 411.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 601.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 190, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 991, \"PID\": 526353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1205.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237500}, {\"Order\": 992, \"PID\": 526354070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 276.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 2112, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 206900}, {\"Order\": 993, \"PID\": 527105050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 994, \"PID\": 527106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8139, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 119.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 204.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 790, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 995, \"PID\": 527106140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195500}, {\"Order\": 996, \"PID\": 527106150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 695, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 997, \"PID\": 527107010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15038, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 998, \"PID\": 527107090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 898.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177900}, {\"Order\": 999, \"PID\": 527107210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 21872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 604.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1446, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 406.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1000, \"PID\": 527127140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 4923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1593.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1593, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 1001, \"PID\": 527131110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 6264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247900}, {\"Order\": 1002, \"PID\": 527140090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1003, \"PID\": 527145090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 5070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1280.0, \"TotalBsmtSF\": 1280.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1004, \"PID\": 527161010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 926.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 926, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1604, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1005, \"PID\": 527162180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 932, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1633, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 183000}, {\"Order\": 1006, \"PID\": 527163100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1658, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1007, \"PID\": 527164120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10832, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1895, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194500}, {\"Order\": 1008, \"PID\": 527165010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1009, \"PID\": 527183030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 461.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1010, \"PID\": 527183060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 5950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 154, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1011, \"PID\": 527208010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 13543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1152.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 355000}, {\"Order\": 1012, \"PID\": 527212050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 11198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1122.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 1370, \"LowQualFinSF\": 0, \"GrLivArea\": 2504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1013, \"PID\": 527214030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 15401, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 296.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 547.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 387000}, {\"Order\": 1014, \"PID\": 527226020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 31220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"NoSewr\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 2, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1474, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1474, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 750, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1015, \"PID\": 527252080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1034.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 557.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 1016, \"PID\": 527276040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 47280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1488.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 738.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 133000}, {\"Order\": 1017, \"PID\": 527301170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 20544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 791.0, \"TotalBsmtSF\": 791.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 2093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 364, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1018, \"PID\": 527301245, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 983.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 1675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1688, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 141, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1019, \"PID\": 527302050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 228.0, \"BsmtUnfSF\": 606.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 276, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1020, \"PID\": 527302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1260, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1021, \"PID\": 527302185, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 18559, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 383.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 186.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 2048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1022, \"PID\": 527302210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 449.0, \"BsmtUnfSF\": 469.0, \"TotalBsmtSF\": 1782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1782, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1782, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 467, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 1023, \"PID\": 527325070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 424.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 896.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 550, \"OpenPorchSF\": 282, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 272000}, {\"Order\": 1024, \"PID\": 527325240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13068, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 48.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 1211.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 174, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1025, \"PID\": 527326130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 266.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1026, \"PID\": 527354160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 2044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 28, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1027, \"PID\": 527357110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9743, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146900}, {\"Order\": 1028, \"PID\": 527357180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12511, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1420, \"2ndFlrSF\": 1420, \"LowQualFinSF\": 0, \"GrLivArea\": 2840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1314.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 208, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 292500}, {\"Order\": 1029, \"PID\": 527358120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 11361, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 549.0, \"TotalBsmtSF\": 1193.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1523, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1523, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1030, \"PID\": 527359030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1444.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1444, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1031, \"PID\": 527359070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1032, \"PID\": 527378020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1033, \"PID\": 527380240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1236.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 2340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 787.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 180, \"EnclosedPorch\": 218, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 306000}, {\"Order\": 1034, \"PID\": 527401130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1035, \"PID\": 527402060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 438.0, \"BsmtUnfSF\": 14.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 80, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1036, \"PID\": 527402130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 16, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111900}, {\"Order\": 1037, \"PID\": 527403360, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 613.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1038, \"PID\": 527425035, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 111250}, {\"Order\": 1039, \"PID\": 527427110, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1139.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1040, \"PID\": 527450110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 359.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 458.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 52, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103400}, {\"Order\": 1041, \"PID\": 527450250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 153.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1042, \"PID\": 527450520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 411, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100500}, {\"Order\": 1043, \"PID\": 527451060, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 127.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1044, \"PID\": 527451290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 85400}, {\"Order\": 1045, \"PID\": 527451400, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 604.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1046, \"PID\": 527451550, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111750}, {\"Order\": 1047, \"PID\": 527452150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 559.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1048, \"PID\": 527453160, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 286.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 275.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1049, \"PID\": 527454120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 677.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 1050, \"PID\": 527455270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 524.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 892, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1051, \"PID\": 528102030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12444, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 426.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 304, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 394617}, {\"Order\": 1052, \"PID\": 528102110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 590, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 134, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 426000}, {\"Order\": 1053, \"PID\": 528104050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 816.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 442.0, \"TotalBsmtSF\": 2078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2084, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2084, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1220.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 385000}, {\"Order\": 1054, \"PID\": 528104080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 14948, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1452.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1476, \"2ndFlrSF\": 1237, \"LowQualFinSF\": 0, \"GrLivArea\": 2713, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 858.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 126, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 446261}, {\"Order\": 1055, \"PID\": 528108150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 317500}, {\"Order\": 1056, \"PID\": 528110080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 436.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 1710.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1710, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372402}, {\"Order\": 1057, \"PID\": 528110110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1728.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 495.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 2418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 358, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 417500}, {\"Order\": 1058, \"PID\": 528114040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 14418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 1950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 383000}, {\"Order\": 1059, \"PID\": 528118030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 2748, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 390000}, {\"Order\": 1060, \"PID\": 528118090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12539, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 468.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 1158, \"LowQualFinSF\": 0, \"GrLivArea\": 2790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1150.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 30, \"OpenPorchSF\": 200, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 460000}, {\"Order\": 1061, \"PID\": 528120130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12151, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 368.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 165.0, \"TotalBsmtSF\": 1414.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 2331, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1003.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 379000}, {\"Order\": 1062, \"PID\": 528142020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 908.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1063, \"PID\": 528142140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10574, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 856.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1162, \"LowQualFinSF\": 0, \"GrLivArea\": 2332, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 756.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 316000}, {\"Order\": 1064, \"PID\": 528164060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 12720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 680.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 2535.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2470, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2470, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 144, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 615000}, {\"Order\": 1065, \"PID\": 528166120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 664.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 1096, \"LowQualFinSF\": 0, \"GrLivArea\": 2668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 726.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 412500}, {\"Order\": 1066, \"PID\": 528170070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1067, \"PID\": 528172080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 454.0, \"TotalBsmtSF\": 1603.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284000}, {\"Order\": 1068, \"PID\": 528178070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 16900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1110.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1075.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1515, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2649, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 421250}, {\"Order\": 1069, \"PID\": 528178090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 112.0, \"LotArea\": 16451, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 221.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1765.0, \"TotalBsmtSF\": 1765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1804, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1070, \"PID\": 528180110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 492.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1486.0, \"TotalBsmtSF\": 1858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1866, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336860}, {\"Order\": 1071, \"PID\": 528180140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 766.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 1702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1702, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1702, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 367294}, {\"Order\": 1072, \"PID\": 528181010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 135.0, \"LotArea\": 12304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1347.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1367, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1073, \"PID\": 528186030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 12677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1074, \"PID\": 528186080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 616.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1684, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1684, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 495, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 266000}, {\"Order\": 1075, \"PID\": 528186130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 8232, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 714.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1204.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 370967}, {\"Order\": 1076, \"PID\": 528186160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234250}, {\"Order\": 1077, \"PID\": 528186170, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1318.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1078, \"PID\": 528188090, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1079, \"PID\": 528188150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 2448, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 1080, \"PID\": 528190010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 720.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1358.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1081, \"PID\": 528228345, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1073.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 1415.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1455, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1455, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 644.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1082, \"PID\": 528228405, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 24.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1087.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1393.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219990}, {\"Order\": 1083, \"PID\": 528228445, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1084, \"PID\": 528228465, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159895}, {\"Order\": 1085, \"PID\": 528228540, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 20.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1146.0, \"TotalBsmtSF\": 1146.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 428.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187687}, {\"Order\": 1086, \"PID\": 528235020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 789.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1515, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1087, \"PID\": 528235120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7415, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 759.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 839.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1593, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1088, \"PID\": 528235180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1166, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1089, \"PID\": 528240040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 8029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1090, \"PID\": 528240050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1091, \"PID\": 528250030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8396, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1139, \"LowQualFinSF\": 0, \"GrLivArea\": 1986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1092, \"PID\": 528253020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7301, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 876.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 217300}, {\"Order\": 1093, \"PID\": 528280130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 830, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1094, \"PID\": 528280180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 647.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1892, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226750}, {\"Order\": 1095, \"PID\": 528290010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 15384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 724.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 64.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1490, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1096, \"PID\": 528290090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1097, \"PID\": 528292060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12460, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1098, \"PID\": 528294060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 831.0, \"TotalBsmtSF\": 831.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 873, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1099, \"PID\": 528315060, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1173.0, \"TotalBsmtSF\": 1173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284500}, {\"Order\": 1100, \"PID\": 528315110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1470, \"2ndFlrSF\": 1160, \"LowQualFinSF\": 0, \"GrLivArea\": 2630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 696.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 1101, \"PID\": 528326030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 14260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1145.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 1053, \"LowQualFinSF\": 0, \"GrLivArea\": 2198, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1102, \"PID\": 528326110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1519.0, \"TotalBsmtSF\": 1519.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 687.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 291000}, {\"Order\": 1103, \"PID\": 528346050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 136.0, \"LotArea\": 11675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 495.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2006, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1104, \"PID\": 528354100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 1061, \"LowQualFinSF\": 0, \"GrLivArea\": 2125, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279500}, {\"Order\": 1105, \"PID\": 528363020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1242.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 1250, \"LowQualFinSF\": 0, \"GrLivArea\": 2501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 751.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1106, \"PID\": 528363110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10437, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 660.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1696.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 2109.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 236, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1107, \"PID\": 528365060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 10542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 651.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1173.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 1311.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 1093, \"LowQualFinSF\": 0, \"GrLivArea\": 2418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 983.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 154, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 341000}, {\"Order\": 1108, \"PID\": 528365080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 852.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2197, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 783.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 385, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287500}, {\"Order\": 1109, \"PID\": 528387050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10944, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 448.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 223.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1223, \"2ndFlrSF\": 904, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1110, \"PID\": 528390020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 1986.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1987, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1987, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301500}, {\"Order\": 1111, \"PID\": 528427010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11932, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1580, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 830.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235128}, {\"Order\": 1112, \"PID\": 528427070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14598, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 74.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 1039, \"LowQualFinSF\": 0, \"GrLivArea\": 1933, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 668.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1113, \"PID\": 528429050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1574, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 824.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 1114, \"PID\": 528429070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13253, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1578.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1578, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1115, \"PID\": 528429080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 14587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264132}, {\"Order\": 1116, \"PID\": 528431060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10206, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 468.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 33.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1563.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1563, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1563, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1117, \"PID\": 528431080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 12274, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1417.0, \"TotalBsmtSF\": 1417.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227680}, {\"Order\": 1118, \"PID\": 528431120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1341.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 851.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 1119, \"PID\": 528435020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 919, \"LowQualFinSF\": 0, \"GrLivArea\": 1874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 297900}, {\"Order\": 1120, \"PID\": 528439010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 10037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1460.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1460, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1460, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 247000}, {\"Order\": 1121, \"PID\": 528458030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1363.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212700}, {\"Order\": 1122, \"PID\": 528458050, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1372.0, \"TotalBsmtSF\": 1372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1372, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1372, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250580}, {\"Order\": 1123, \"PID\": 528462040, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 95.0, \"LotArea\": 11639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1428.0, \"TotalBsmtSF\": 1428.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1428, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 182000}, {\"Order\": 1124, \"PID\": 528477040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 866.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 902, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226700}, {\"Order\": 1125, \"PID\": 528478030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 768.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1053.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 939, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1126, \"PID\": 528478040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1026.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 932, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1127, \"PID\": 528480060, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1034.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 1028, \"LowQualFinSF\": 0, \"GrLivArea\": 2078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 339750}, {\"Order\": 1128, \"PID\": 528480160, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 822, \"2ndFlrSF\": 843, \"LowQualFinSF\": 0, \"GrLivArea\": 1665, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 562.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205950}, {\"Order\": 1129, \"PID\": 528482020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 292.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1660.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1130, \"PID\": 528488140, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 230348}, {\"Order\": 1131, \"PID\": 528490080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 64.0, \"LotArea\": 8791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 361.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 673.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1132, \"PID\": 531363060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1133, \"PID\": 531371070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 555.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 861, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1134, \"PID\": 531373060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 95.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 835.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 835, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 1135, \"PID\": 531375050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1175, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1136, \"PID\": 531375110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1137, \"PID\": 531375120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13695, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1138, \"PID\": 531376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1139, \"PID\": 531376070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1162.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1162, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1140, \"PID\": 531382090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 362.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 754.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 855, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1141, \"PID\": 531382110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 886.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 794, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1142, \"PID\": 531382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 258.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1138.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1679, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1679, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193500}, {\"Order\": 1143, \"PID\": 531384030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 14565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 537.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1144, \"PID\": 531385060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 827.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 827, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1677, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190500}, {\"Order\": 1145, \"PID\": 531450030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 439.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1146, \"PID\": 531450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1147, \"PID\": 531450170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 426.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 406.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1148, \"PID\": 531451020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 165.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1604.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1617, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1617, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 533.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1149, \"PID\": 531452140, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 899.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1199, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1199, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1150, \"PID\": 532351050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 53.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 799.0, \"BsmtUnfSF\": 132.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1151, \"PID\": 532353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12968, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1152, \"PID\": 532354150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 764.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1153, \"PID\": 532376170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 890.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 890.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 890, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 890, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1154, \"PID\": 532377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119916}, {\"Order\": 1155, \"PID\": 532378200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1961, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 832.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1156, \"PID\": 532477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 19508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 800.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1430, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 117, \"OpenPorchSF\": 108, \"EnclosedPorch\": 165, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1157, \"PID\": 532479020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 811.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 92, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1158, \"PID\": 533125080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 1319, \"LowQualFinSF\": 0, \"GrLivArea\": 2683, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 251, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 196, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1159, \"PID\": 533125140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1328.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1827, \"2ndFlrSF\": 959, \"LowQualFinSF\": 0, \"GrLivArea\": 2786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 294, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372500}, {\"Order\": 1160, \"PID\": 533206050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 59.0, \"LotArea\": 4282, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1391, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 1161, \"PID\": 533208080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4017, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171900}, {\"Order\": 1162, \"PID\": 533208140, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3435, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1211.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1245, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 1163, \"PID\": 533212050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 600, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1164, \"PID\": 533212140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1165, \"PID\": 533212150, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3604, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 689.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 703, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1166, \"PID\": 533213070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179400}, {\"Order\": 1167, \"PID\": 533213120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 194.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 792, \"LowQualFinSF\": 0, \"GrLivArea\": 1549, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172900}, {\"Order\": 1168, \"PID\": 533215020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1027.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 587.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1638, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 230, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1169, \"PID\": 533215030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4538, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 179.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 277, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1170, \"PID\": 533215040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 42.0, \"LotArea\": 4385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1171, \"PID\": 533215070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4109, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 260.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 1557.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1172, \"PID\": 533215080, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 50.0, \"LotArea\": 5119, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1238.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1709, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 97, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"CWD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 328900}, {\"Order\": 1173, \"PID\": 533217050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 628, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1174, \"PID\": 533217060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1404, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 20, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1175, \"PID\": 533234020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 79.0, \"LotArea\": 10646, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 917, \"LowQualFinSF\": 0, \"GrLivArea\": 1789, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 1176, \"PID\": 533236060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1586, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1177, \"PID\": 533236070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 147.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 962, \"2ndFlrSF\": 645, \"LowQualFinSF\": 0, \"GrLivArea\": 1607, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 169, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1178, \"PID\": 533236090, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 36.0, \"LotArea\": 3951, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 128.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 842.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1469, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2393, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 846.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 94, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 345000}, {\"Order\": 1179, \"PID\": 533250050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 14963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1260.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1288, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245500}, {\"Order\": 1180, \"PID\": 533250110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 22.0, \"LotArea\": 11064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 670.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1230.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1239, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1239, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 1181, \"PID\": 533250160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 32.0, \"LotArea\": 10846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1719.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1719, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1719, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 324000}, {\"Order\": 1182, \"PID\": 533251120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1232.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1232, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1183, \"PID\": 533350090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 24572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1050.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 584.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1599, \"2ndFlrSF\": 1345, \"LowQualFinSF\": 0, \"GrLivArea\": 2944, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 70, \"EnclosedPorch\": 16, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1184, \"PID\": 533350120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 16280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1044.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 382.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1426.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1185, \"PID\": 534104100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 469.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 1186, \"PID\": 534126090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1304.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1682, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1682, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 98, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1187, \"PID\": 534127210, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1427.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1427, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1427, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1188, \"PID\": 534127230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1439.0, \"TotalBsmtSF\": 1740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 150000}, {\"Order\": 1189, \"PID\": 534128050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 656.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 55, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1190, \"PID\": 534129060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1620.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1620, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 62, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1191, \"PID\": 534175140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1625.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1192, \"PID\": 534177180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1522.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 1066, \"LowQualFinSF\": 0, \"GrLivArea\": 2614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 243, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1193, \"PID\": 534201240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 732, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1194, \"PID\": 534202130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1195, \"PID\": 534204030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 456.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 233, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1196, \"PID\": 534225110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1728.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1197, \"PID\": 534225120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 13101, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1497.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142600}, {\"Order\": 1198, \"PID\": 534250010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 9246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 564.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1656.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1199, \"PID\": 534250335, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 825, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1200, \"PID\": 534250370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8963, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1976, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 1540, \"LowQualFinSF\": 0, \"GrLivArea\": 2715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 204, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 299800}, {\"Order\": 1201, \"PID\": 534250410, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 933, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1202, \"PID\": 534251280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 800, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1203, \"PID\": 534252090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1961, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 867.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 944.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178400}, {\"Order\": 1204, \"PID\": 534252270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1978, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1205, \"PID\": 534276190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7785, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 267.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1206, \"PID\": 534277060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 619.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109008}, {\"Order\": 1207, \"PID\": 534277070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 228.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 724.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135750}, {\"Order\": 1208, \"PID\": 534400030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 344.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 20, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1209, \"PID\": 534400060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 10175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 407, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 1210, \"PID\": 534401130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1165, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 129, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174900}, {\"Order\": 1211, \"PID\": 534401190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 892.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 426, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1212, \"PID\": 534403050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 305.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1213, \"PID\": 534403080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 586.0, \"TotalBsmtSF\": 1219.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1265, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 96, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1214, \"PID\": 534403100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 259.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 336.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1215, \"PID\": 534403260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1114.0, \"TotalBsmtSF\": 1114.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1114, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1114, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 164, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 1216, \"PID\": 534426040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 806.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145500}, {\"Order\": 1217, \"PID\": 534427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10721, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 243.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1252.0, \"TotalBsmtSF\": 1252.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1218, \"PID\": 534428020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12493, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 306.0, \"BsmtUnfSF\": 375.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1219, \"PID\": 534428100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1118.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1220, \"PID\": 534451080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Floor\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 287.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72500}, {\"Order\": 1221, \"PID\": 534451170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 4130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52000}, {\"Order\": 1222, \"PID\": 534452060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Artery\", \"Condition2\": \"Artery\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 991.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 4, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1223, \"PID\": 534453140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 4882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 453, \"2ndFlrSF\": 453, \"LowQualFinSF\": 0, \"GrLivArea\": 906, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 1224, \"PID\": 534455030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1225, \"PID\": 534477080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 220, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119000}, {\"Order\": 1226, \"PID\": 534477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 32.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 308.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 1227, \"PID\": 534477270, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1661, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1661, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 377.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 178, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1228, \"PID\": 534479150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 505.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112900}, {\"Order\": 1229, \"PID\": 535103050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 454.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 273, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201800}, {\"Order\": 1230, \"PID\": 535104020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 491.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1231, \"PID\": 535105030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139950}, {\"Order\": 1232, \"PID\": 535105060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1962, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 237.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1319.0, \"TotalBsmtSF\": 1319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1233, \"PID\": 535105090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 9150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1431, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1431, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 296.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1234, \"PID\": 535126140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 575.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 529.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 230, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1235, \"PID\": 535150210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 151.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 196.0, \"TotalBsmtSF\": 1098.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1098, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1236, \"PID\": 535150280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 25.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 872.0, \"BsmtUnfSF\": 247.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1237, \"PID\": 535151160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1283, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1283, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1238, \"PID\": 535152200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8856, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 621.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 52.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 95, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1239, \"PID\": 535153140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1240, \"PID\": 535153150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 599.0, \"TotalBsmtSF\": 1261.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1261, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1261, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1400, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1241, \"PID\": 535176100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 187.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 958.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 1395.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1570, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1570, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 490, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166800}, {\"Order\": 1242, \"PID\": 535178060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 580.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1243, \"PID\": 535179060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 387.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 458.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 1244, \"PID\": 535180100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 135.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 510.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 130, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1245, \"PID\": 535180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1104, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1246, \"PID\": 535301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1247, \"PID\": 535302130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 9373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 196.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 1152.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1248, \"PID\": 535302140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12774, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1249, \"PID\": 535303030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 14250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 998.0, \"TotalBsmtSF\": 998.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1500, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1250, \"PID\": 535305030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 852.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 139000}, {\"Order\": 1251, \"PID\": 535305160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 7677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 773.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 773, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 1252, \"PID\": 535327230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1253, \"PID\": 535352080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 102, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 1254, \"PID\": 535354200, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 12436, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 1255, \"PID\": 535375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10122, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 66, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89900}, {\"Order\": 1256, \"PID\": 535375160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 7506, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1257, \"PID\": 535380050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10930, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 913.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1258, \"PID\": 535380110, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 1259, \"PID\": 535380140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 892.0, \"TotalBsmtSF\": 892.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 182, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 1488.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1260, \"PID\": 535383100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 694, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 114, \"EnclosedPorch\": 210, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106250}, {\"Order\": 1261, \"PID\": 535402120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9247, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 318.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 539.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1262, \"PID\": 535403010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1263, \"PID\": 535425060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 304, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Othr\", \"MiscVal\": 6500, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186000}, {\"Order\": 1264, \"PID\": 535426260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 733.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1253.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 213, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1265, \"PID\": 535426350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12929, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 276.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1081.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1081, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 401.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1266, \"PID\": 535427070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 27650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2069, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242000}, {\"Order\": 1267, \"PID\": 535451010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 910, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 414.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1268, \"PID\": 535451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 94000}, {\"Order\": 1269, \"PID\": 535451230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98300}, {\"Order\": 1270, \"PID\": 535452120, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 666.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1507, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1507, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 404.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1271, \"PID\": 535453020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 476.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 488.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 1272, \"PID\": 535453040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 319.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1027.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125900}, {\"Order\": 1273, \"PID\": 535453210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 532.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1269.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1269, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1274, \"PID\": 535454150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 453.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 501, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1275, \"PID\": 535455060, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6390, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1276, \"PID\": 535455080, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 7227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 832, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 1277, \"PID\": 535455090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 181.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1278, \"PID\": 535456050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 8513, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1279, \"PID\": 535456070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1280, \"PID\": 535456100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 825.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1281, \"PID\": 535475020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 7056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 415.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 483.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1282, \"PID\": 535476370, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 674.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 106.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 813, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167900}, {\"Order\": 1283, \"PID\": 535477090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136870}, {\"Order\": 1284, \"PID\": 902100020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9836, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 96.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1133, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143000}, {\"Order\": 1285, \"PID\": 902100030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 30.0, \"LotArea\": 5232, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 764, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 1286, \"PID\": 902102060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1904, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 650.0, \"TotalBsmtSF\": 650.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1539, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 70, \"OpenPorchSF\": 78, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1287, \"PID\": 902103150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9184, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 375, \"LowQualFinSF\": 0, \"GrLivArea\": 1323, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122600}, {\"Order\": 1288, \"PID\": 902105010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 80.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 680.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 680, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 330.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 1289, \"PID\": 902105020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 547, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 480, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1150, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1290, \"PID\": 902105130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1291, \"PID\": 902107030, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1915.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 248, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1292, \"PID\": 902109080, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 828.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 828, \"2ndFlrSF\": 658, \"LowQualFinSF\": 108, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 109, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1293, \"PID\": 902109110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 11426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1362.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 2082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 238, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1294, \"PID\": 902109120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 7628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 801.0, \"TotalBsmtSF\": 801.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 561, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119164}, {\"Order\": 1295, \"PID\": 902109160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 7308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122250}, {\"Order\": 1296, \"PID\": 902128075, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 931.0, \"TotalBsmtSF\": 931.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1027, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1027, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1297, \"PID\": 902128150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 590.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 552, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1298, \"PID\": 902134100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6756, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 481.0, \"TotalBsmtSF\": 481.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 899, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 899, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 1299, \"PID\": 902136110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 5914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1890, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 396, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 165, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1300, \"PID\": 902201120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 169.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 789.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 115000}, {\"Order\": 1301, \"PID\": 902201140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 608.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1302, \"PID\": 902202090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 904.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 904, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 869.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1303, \"PID\": 902205070, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7311, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 407.0, \"TotalBsmtSF\": 407.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 407, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 407, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 46500}, {\"Order\": 1304, \"PID\": 902205090, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 620.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1305, \"PID\": 902205140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 901, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 281.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107900}, {\"Order\": 1306, \"PID\": 902207120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 103.0, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 1, \"YearBuilt\": 1949, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 65000}, {\"Order\": 1307, \"PID\": 902207220, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 87.0, \"LotArea\": 18386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1880, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1470.0, \"TotalBsmtSF\": 1470.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 1818, \"LowQualFinSF\": 0, \"GrLivArea\": 3493, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 302, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 295000}, {\"Order\": 1308, \"PID\": 902300110, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 797.0, \"TotalBsmtSF\": 797.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 830, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1627, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 1309, \"PID\": 902300215, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 100.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 540, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 418, \"OpenPorchSF\": 0, \"EnclosedPorch\": 194, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153900}, {\"Order\": 1310, \"PID\": 902300260, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 5350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 508.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 730, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1450, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1311, \"PID\": 902301140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 34.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 513.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98000}, {\"Order\": 1312, \"PID\": 902301150, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9143, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 346.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 709, \"2ndFlrSF\": 308, \"LowQualFinSF\": 0, \"GrLivArea\": 1017, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 139, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1313, \"PID\": 902304060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 234.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 973, \"LowQualFinSF\": 0, \"GrLivArea\": 2350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 219, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1314, \"PID\": 902305080, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1917, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 924, \"LowQualFinSF\": 0, \"GrLivArea\": 2058, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 259, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1315, \"PID\": 902306120, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1905, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129400}, {\"Order\": 1316, \"PID\": 902306130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1928, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 141.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 689, \"2ndFlrSF\": 689, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1317, \"PID\": 902326060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1905, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1221, \"2ndFlrSF\": 691, \"LowQualFinSF\": 0, \"GrLivArea\": 1912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1318, \"PID\": 902328040, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 742, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 291, \"EnclosedPorch\": 134, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1319, \"PID\": 902330010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5250, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1872, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"OthW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 205, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 1320, \"PID\": 902401010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 572, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 176, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1321, \"PID\": 902401120, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1893, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"Ex\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1521, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2775, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 880.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 502, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 325000}, {\"Order\": 1322, \"PID\": 902402260, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 2, \"OverallCond\": 1, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 723, \"2ndFlrSF\": 363, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1323, \"PID\": 902405070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1313.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1182, \"LowQualFinSF\": 0, \"GrLivArea\": 2495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 299, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1324, \"PID\": 902406020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1325, \"PID\": 902406090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 81.0, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 335.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1050.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 745, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 1326, \"PID\": 902427045, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 12702, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97000}, {\"Order\": 1327, \"PID\": 902427150, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8516, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 869.0, \"TotalBsmtSF\": 869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115500}, {\"Order\": 1328, \"PID\": 903201030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7111, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 273.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1329, \"PID\": 903204010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 1330, \"PID\": 903204095, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 156, \"GrLivArea\": 935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 1331, \"PID\": 903206070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 175.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 594, \"LowQualFinSF\": 0, \"GrLivArea\": 1738, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1332, \"PID\": 903225050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6130, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 1333, \"PID\": 903225140, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1334, \"PID\": 903225160, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1900, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 736, \"2ndFlrSF\": 554, \"LowQualFinSF\": 0, \"GrLivArea\": 1290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106900}, {\"Order\": 1335, \"PID\": 903226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 658, \"LowQualFinSF\": 0, \"GrLivArea\": 1672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 11, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164900}, {\"Order\": 1336, \"PID\": 903226150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 949.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1337, \"PID\": 903227080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 862.0, \"TotalBsmtSF\": 862.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1929.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 208.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1338, \"PID\": 903228040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 201.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1497, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 1339, \"PID\": 903228060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 264.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 739.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1340, \"PID\": 903228090, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 992.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1013, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1013, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 101, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1341, \"PID\": 903230110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 565, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1342, \"PID\": 903230120, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 99.0, \"LotArea\": 5940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"CBlock\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": null, \"BsmtFinType2\": null, \"BsmtFinSF2\": null, \"BsmtUnfSF\": null, \"TotalBsmtSF\": null, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 896, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79000}, {\"Order\": 1343, \"PID\": 903231080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 1136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 365, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1344, \"PID\": 903232030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 164.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81300}, {\"Order\": 1345, \"PID\": 903232090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1078.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 1346, \"PID\": 903233080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 240.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 989.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1245, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1347, \"PID\": 903234090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 897.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 139, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 1348, \"PID\": 903234100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129900}, {\"Order\": 1349, \"PID\": 903235010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 611.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1350, \"PID\": 903235100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6324, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 87, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68500}, {\"Order\": 1351, \"PID\": 903236010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8635, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 295.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 213, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1352, \"PID\": 903400180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 13053, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 833.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1848, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 220, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1353, \"PID\": 903401020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9120, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 1026.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 687, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1354, \"PID\": 903401030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1355, \"PID\": 903401050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9144, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 883.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 517, \"LowQualFinSF\": 0, \"GrLivArea\": 1505, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1356, \"PID\": 903425420, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10267, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 606.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1357, \"PID\": 903426160, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 8094, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1000, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1358, \"PID\": 903427090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5100, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 833, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1359, \"PID\": 903429010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 4347, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 182, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1360, \"PID\": 903452025, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6291, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93850}, {\"Order\": 1361, \"PID\": 903453050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10266, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 372.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 216, \"EnclosedPorch\": 80, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 136000}, {\"Order\": 1362, \"PID\": 903454100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1272.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 0, \"LowQualFinSF\": 697, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1363, \"PID\": 903455030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1915, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 428, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 117, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1364, \"PID\": 903455140, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1365, \"PID\": 903456130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 7006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 121.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 647.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 788, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 127000}, {\"Order\": 1366, \"PID\": 903458110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 319.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 371, \"LowQualFinSF\": 0, \"GrLivArea\": 1406, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1367, \"PID\": 903475020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRNn\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 645.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 825, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1368, \"PID\": 903476110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5586, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 110, \"LowQualFinSF\": 0, \"GrLivArea\": 1198, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 79900}, {\"Order\": 1369, \"PID\": 903481010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1912, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 451.0, \"TotalBsmtSF\": 451.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 759, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Family\", \"SalePrice\": 85000}, {\"Order\": 1370, \"PID\": 903481100, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsphShn\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 808, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 204, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82375}, {\"Order\": 1371, \"PID\": 903484020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1906, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 1469, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1906.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 57, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1372, \"PID\": 904100020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1046.0, \"TotalBsmtSF\": 1046.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1054, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 122, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 1373, \"PID\": 904100040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 1374, \"PID\": 904100160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 21286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1271, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1375, \"PID\": 904101170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 680.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134432}, {\"Order\": 1376, \"PID\": 904351280, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10106, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 181.0, \"BsmtUnfSF\": 112.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 547, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1377, \"PID\": 905100020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1075, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 64, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 148000}, {\"Order\": 1378, \"PID\": 905102170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 906.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 134.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1379, \"PID\": 905103030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13014, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 39.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 480.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 1380, \"PID\": 905104080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 876.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 109900}, {\"Order\": 1381, \"PID\": 905104110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 234.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1382, \"PID\": 905104180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9764, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 702.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1383, \"PID\": 905107280, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7703, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 450.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 311, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1384, \"PID\": 905107380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9981, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 221.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 852.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1385, \"PID\": 905108170, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 956.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1060.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1386, \"PID\": 905200090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1198.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 108959}, {\"Order\": 1387, \"PID\": 905200100, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1300.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 95541}, {\"Order\": 1388, \"PID\": 905200160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 1006.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1006, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1006, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 1389, \"PID\": 905200510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1228, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 271.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149350}, {\"Order\": 1390, \"PID\": 905201020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 9239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 634.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144900}, {\"Order\": 1391, \"PID\": 905201110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1188, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1188, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 102, \"OpenPorchSF\": 89, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1392, \"PID\": 905201120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1064.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 354.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 511, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1393, \"PID\": 905202230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 429.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1080.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 409, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1394, \"PID\": 905225040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1021, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1395, \"PID\": 905226030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1396, \"PID\": 905226110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 275.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1397, \"PID\": 905227050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 486, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152400}, {\"Order\": 1398, \"PID\": 905300020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 704.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 160.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 904, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 904, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 912.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1399, \"PID\": 905351089, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1003.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 288.0, \"TotalBsmtSF\": 1291.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1291, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1400, \"PID\": 905352030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10005, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 299.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 2022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 505.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 117, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1401, \"PID\": 905352070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 20270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1524, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 1402, \"PID\": 905401045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 39104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Membran\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 226.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1063.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1363, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1363, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 439.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1403, \"PID\": 905401060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1663, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1663, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 137, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 256000}, {\"Order\": 1404, \"PID\": 905402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 11512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 1019.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1357, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1357, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 163, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1405, \"PID\": 905403060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 617, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 1079, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 249.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125600}, {\"Order\": 1406, \"PID\": 905403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 216.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 287, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1407, \"PID\": 905425125, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 45600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 907.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1307, \"2ndFlrSF\": 1051, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1908.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 486, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1408, \"PID\": 905426030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 19550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"PreCast\", \"Exterior2nd\": \"PreCast\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1035.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1518, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1409, \"PID\": 905427050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1163.0, \"TotalBsmtSF\": 1163.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 511, \"LowQualFinSF\": 0, \"GrLivArea\": 1674, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1410, \"PID\": 905427070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 2108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1411, \"PID\": 905451330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9571, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 870.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1509.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 576, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159900}, {\"Order\": 1412, \"PID\": 905452070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99600}, {\"Order\": 1413, \"PID\": 905452120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 621.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 621, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1269, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1414, \"PID\": 905476120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8405, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 241.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 406, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1415, \"PID\": 905477050, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 969.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 820, \"2ndFlrSF\": 527, \"LowQualFinSF\": 0, \"GrLivArea\": 1347, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107500}, {\"Order\": 1416, \"PID\": 905479110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 10880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1040.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1417, \"PID\": 905480150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 572.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 572, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 8, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 1418, \"PID\": 905480240, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 236.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 380.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 95000}, {\"Order\": 1419, \"PID\": 906204150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11839, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1475.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1532, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2329, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262280}, {\"Order\": 1420, \"PID\": 906204280, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9771, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 1721, \"LowQualFinSF\": 0, \"GrLivArea\": 2814, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1421, \"PID\": 906223110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 251.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1626, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1422, \"PID\": 906223140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 355.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 812.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1101, \"2ndFlrSF\": 1099, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1423, \"PID\": 906223220, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 735, \"LowQualFinSF\": 0, \"GrLivArea\": 2037, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 1424, \"PID\": 906378190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10616, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 628.0, \"TotalBsmtSF\": 628.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 628, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177439}, {\"Order\": 1425, \"PID\": 906380030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 156.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1615.0, \"TotalBsmtSF\": 1615.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1615, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1615, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248500}, {\"Order\": 1426, \"PID\": 906412010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 554.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2085.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 2271.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2276, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2276, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1348.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 255, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 475000}, {\"Order\": 1427, \"PID\": 906412050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 402.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1751.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1766, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395039}, {\"Order\": 1428, \"PID\": 906420130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 531.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 1017, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 187, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 1429, \"PID\": 906424010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11454, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 631.0, \"TotalBsmtSF\": 1401.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 811.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 1430, \"PID\": 906475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 262.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1182.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1643, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1643, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 339, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1431, \"PID\": 906476030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 12798, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 462.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 154.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 1072, \"LowQualFinSF\": 0, \"GrLivArea\": 1688, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 603.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 403, \"OpenPorchSF\": 114, \"EnclosedPorch\": 185, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1432, \"PID\": 907126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 722.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1433, \"PID\": 907135020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1995, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1099.0, \"TotalBsmtSF\": 1099.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1099, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1099, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1434, \"PID\": 907135260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1435, \"PID\": 907175080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1308.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1418.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1418, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1418, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226001}, {\"Order\": 1436, \"PID\": 907176010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 688.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 899, \"LowQualFinSF\": 0, \"GrLivArea\": 1771, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215700}, {\"Order\": 1437, \"PID\": 907181120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 782, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1438, \"PID\": 907181140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 873.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 193000}, {\"Order\": 1439, \"PID\": 907187030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 880.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 1440, \"PID\": 907187080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 9382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1468.0, \"TotalBsmtSF\": 1468.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1441, \"PID\": 907192130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 922.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 1442, \"PID\": 907194020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 963.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 963, \"2ndFlrSF\": 829, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 245, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231500}, {\"Order\": 1443, \"PID\": 907196040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1823, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 4500, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1444, \"PID\": 907196050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 866, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223500}, {\"Order\": 1445, \"PID\": 907200110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 280.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 491.0, \"BsmtUnfSF\": 167.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 938, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 938, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 145, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130250}, {\"Order\": 1446, \"PID\": 907201060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 985, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 328.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 1447, \"PID\": 907202010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1174, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 211, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1448, \"PID\": 907202160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1449, \"PID\": 907202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 294.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1076, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 143195}, {\"Order\": 1450, \"PID\": 907202240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 88.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 596.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1558, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 239, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 1451, \"PID\": 907203090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 7990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1452, \"PID\": 907227050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1453, \"PID\": 907227300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 780, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 1454, \"PID\": 907250020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1777.0, \"TotalBsmtSF\": 1777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 159, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1455, \"PID\": 907251090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9473, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 804.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 903, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 1456, \"PID\": 907253060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 735.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 257.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 873, \"LowQualFinSF\": 0, \"GrLivArea\": 1865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 839.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 1457, \"PID\": 907253110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1290, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 1458, \"PID\": 907254020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9066, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1852, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 106, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 1459, \"PID\": 907254090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11404, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 901.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1153, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2031, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222500}, {\"Order\": 1460, \"PID\": 907255020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 396.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1055.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 1208, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 905.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 189, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 287000}, {\"Order\": 1461, \"PID\": 907255030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1357.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1366, \"2ndFlrSF\": 581, \"LowQualFinSF\": 0, \"GrLivArea\": 1947, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274000}, {\"Order\": 1462, \"PID\": 907255060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1778.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1786, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 715.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1463, \"PID\": 907260010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1128.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 1141, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 779.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255900}, {\"Order\": 1464, \"PID\": 907262030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 334.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224900}, {\"Order\": 1465, \"PID\": 907262060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 10905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1129.0, \"TotalBsmtSF\": 1129.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1129, \"2ndFlrSF\": 1198, \"LowQualFinSF\": 0, \"GrLivArea\": 2327, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 1466, \"PID\": 907262070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 842, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 595.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 1467, \"PID\": 907265100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 886, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 1764, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1468, \"PID\": 907285080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 642.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 273.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 933, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1908, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 493.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1469, \"PID\": 907290150, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 686.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1470, \"PID\": 907290250, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1471, \"PID\": 907295020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 215.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 1478.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1493, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1493, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208900}, {\"Order\": 1472, \"PID\": 907295100, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 83.0, \"LotArea\": 10126, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1593.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 162.0, \"BsmtUnfSF\": 83.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 67, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185000}, {\"Order\": 1473, \"PID\": 907405020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 726.0, \"TotalBsmtSF\": 1536.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1536, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 532.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1474, \"PID\": 907405140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 856.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 854, \"LowQualFinSF\": 0, \"GrLivArea\": 1710, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 208500}, {\"Order\": 1475, \"PID\": 907412040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1421.0, \"TotalBsmtSF\": 1445.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1445, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1445, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186500}, {\"Order\": 1476, \"PID\": 907412070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 946.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1436.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 139, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 1477, \"PID\": 907412080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 770, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185900}, {\"Order\": 1478, \"PID\": 907412090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1234, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 1479, \"PID\": 907418010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 212.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1508.0, \"TotalBsmtSF\": 1564.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218836}, {\"Order\": 1480, \"PID\": 907418040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1327.0, \"TotalBsmtSF\": 1351.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 1481, \"PID\": 907420080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1482, \"PID\": 907425010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149300}, {\"Order\": 1483, \"PID\": 907425015, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 147.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 151.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1484, \"PID\": 907425030, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 149, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1485, \"PID\": 907425035, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144500}, {\"Order\": 1486, \"PID\": 908102030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 328, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1487, \"PID\": 908102040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 1272.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1272, \"2ndFlrSF\": 928, \"LowQualFinSF\": 0, \"GrLivArea\": 2200, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145900}, {\"Order\": 1488, \"PID\": 908102140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 609.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 259, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 123000}, {\"Order\": 1489, \"PID\": 908102260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 830.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 290.0, \"BsmtUnfSF\": 136.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 736, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1490, \"PID\": 908103260, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 12102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 222.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 456.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1033, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1033, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 165000}, {\"Order\": 1491, \"PID\": 908103280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1033.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 94.0, \"TotalBsmtSF\": 1127.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1127, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1492, \"PID\": 908127120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 996, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1493, \"PID\": 908128050, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 180.0, \"BsmtUnfSF\": 38.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1181, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1181, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1494, \"PID\": 908128110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 92.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 746.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165400}, {\"Order\": 1495, \"PID\": 908151040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 120.0, \"BsmtUnfSF\": 541.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1117, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1496, \"PID\": 908152110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 684, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1497, \"PID\": 908152270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1024.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1132.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1132, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1498, \"PID\": 908154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 123.0, \"LotArea\": 47007, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3820, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3820, \"BsmtFullBath\": null, \"BsmtHalfBath\": null, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 372, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 284700}, {\"Order\": 1499, \"PID\": 908154235, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 313.0, \"LotArea\": 63887, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"ClyTile\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 796.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 5644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 6110.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 4692, \"2ndFlrSF\": 950, \"LowQualFinSF\": 0, \"GrLivArea\": 5642, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 1418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 292, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 480, \"PoolQC\": \"Gd\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 160000}, {\"Order\": 1500, \"PID\": 908186040, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 459.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1501, \"PID\": 908201100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1502, \"PID\": 908201110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 82000}, {\"Order\": 1503, \"PID\": 908201120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 12108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 133.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1307.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 1504, \"PID\": 908204160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6845, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 82500}, {\"Order\": 1505, \"PID\": 908225170, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6931, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 784, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91900}, {\"Order\": 1506, \"PID\": 908226120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 585, \"2ndFlrSF\": 468, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 120000}, {\"Order\": 1507, \"PID\": 908250040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1947, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 929, \"2ndFlrSF\": 208, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 1508, \"PID\": 908250090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 930, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 930, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 134, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Gar2\", \"MiscVal\": 3000, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1509, \"PID\": 908275130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1510, \"PID\": 908275180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 548.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1511, \"PID\": 908275280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 521, \"LowQualFinSF\": 0, \"GrLivArea\": 1393, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 121, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 265, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 1512, \"PID\": 908276140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 416.0, \"TotalBsmtSF\": 416.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1513, \"PID\": 909100150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5142, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 343, \"LowQualFinSF\": 0, \"GrLivArea\": 1292, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 1514, \"PID\": 909100170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 5604, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1515, \"PID\": 909101060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 41.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 823.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 67000}, {\"Order\": 1516, \"PID\": 909101180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5687, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1912, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135900}, {\"Order\": 1517, \"PID\": 909131170, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 516.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 254, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1518, \"PID\": 909175050, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 378.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 720, \"LowQualFinSF\": 420, \"GrLivArea\": 2192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 262, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179500}, {\"Order\": 1519, \"PID\": 909175100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 423.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 758.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 304, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 342, \"OpenPorchSF\": 0, \"EnclosedPorch\": 128, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 1520, \"PID\": 909177120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1228.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1521, \"PID\": 909201110, \"MSSubClass\": 70, \"MSZoning\": \"RH\", \"LotFrontage\": 55.0, \"LotArea\": 8525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1911, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 940.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 1522, \"PID\": 909250040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 1611, \"LowQualFinSF\": 0, \"GrLivArea\": 2601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 183, \"OpenPorchSF\": 0, \"EnclosedPorch\": 301, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189000}, {\"Order\": 1523, \"PID\": 909250230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7804, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 679.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 960, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 248, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 161900}, {\"Order\": 1524, \"PID\": 909251080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8969, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 379.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 265.0, \"TotalBsmtSF\": 644.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 644, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 369.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1525, \"PID\": 909251090, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1423, \"2ndFlrSF\": 748, \"LowQualFinSF\": 384, \"GrLivArea\": 2555, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 431, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 1526, \"PID\": 909252110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1527, \"PID\": 909252220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 15564, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 676.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 676, \"2ndFlrSF\": 588, \"LowQualFinSF\": 0, \"GrLivArea\": 1264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 1528, \"PID\": 909253190, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 6292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 790, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 1529, \"PID\": 909254050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7609, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1925, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 406.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 798, \"2ndFlrSF\": 714, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 85, \"OpenPorchSF\": 16, \"EnclosedPorch\": 41, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 231000}, {\"Order\": 1530, \"PID\": 909256060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 10480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1064.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 0, \"LowQualFinSF\": 473, \"GrLivArea\": 1639, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1531, \"PID\": 909275040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 819, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 599.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 217, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1532, \"PID\": 909275050, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1533, \"PID\": 909276170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1934, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 326.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 389.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 849, \"2ndFlrSF\": 811, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188700}, {\"Order\": 1534, \"PID\": 909277040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1265, \"2ndFlrSF\": 673, \"LowQualFinSF\": 0, \"GrLivArea\": 1938, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 1535, \"PID\": 909277070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9260, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 932, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1536, \"PID\": 909281030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 7801, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 591.0, \"TotalBsmtSF\": 1091.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1091, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 344.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 66, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 221, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104000}, {\"Order\": 1537, \"PID\": 909281110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 40.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 398.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 786.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 207, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 257076}, {\"Order\": 1538, \"PID\": 909282030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1935, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1968, \"2ndFlrSF\": 1479, \"LowQualFinSF\": 0, \"GrLivArea\": 3447, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1014.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 381000}, {\"Order\": 1539, \"PID\": 909425010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1939, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 341.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 457.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 817, \"LowQualFinSF\": 0, \"GrLivArea\": 1954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 311500}, {\"Order\": 1540, \"PID\": 909425085, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 435.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1218, \"2ndFlrSF\": 943, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263400}, {\"Order\": 1541, \"PID\": 909428170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 26073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 782.0, \"TotalBsmtSF\": 1898.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1898, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 236500}, {\"Order\": 1542, \"PID\": 909428190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 568.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 924.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 216, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224000}, {\"Order\": 1543, \"PID\": 909451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1879, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 366.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 516, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 213, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 1544, \"PID\": 909451150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 612.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 1545, \"PID\": 910200080, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 555.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 919, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 919, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1546, \"PID\": 910201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 330, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1547, \"PID\": 910202050, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3636, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 55000}, {\"Order\": 1548, \"PID\": 910202100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 538.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 278.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1549, \"PID\": 910203020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 71.0, \"LotArea\": 6900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 125.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 740.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 778, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 924.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1550, \"PID\": 910203090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 8155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 780, \"2ndFlrSF\": 420, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1551, \"PID\": 910205010, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 257.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1552, \"PID\": 910206110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7392, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99500}, {\"Order\": 1553, \"PID\": 910226040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1955, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1554, \"PID\": 910251050, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 80.0, \"LotArea\": 14584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Po\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 733, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 13100}, {\"Order\": 1555, \"PID\": 911102090, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 5280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1895, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 173.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 825, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1361, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1895.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 185.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 1556, \"PID\": 911102170, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 649.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 649, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1317, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 172, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 40000}, {\"Order\": 1557, \"PID\": 911102180, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 52.0, \"LotArea\": 5150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Po\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 671, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 195.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80900}, {\"Order\": 1558, \"PID\": 911226010, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 120.0, \"LotArea\": 18000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 560, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1559, \"PID\": 911226030, \"MSSubClass\": 70, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 432, \"2ndFlrSF\": 432, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 65000}, {\"Order\": 1560, \"PID\": 911370410, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 5587, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392500}, {\"Order\": 1561, \"PID\": 911370490, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3843, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1476.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1648, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1648, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 162, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 153, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294464}, {\"Order\": 1562, \"PID\": 911370520, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1474.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1563, \"PID\": 911370540, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 174.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1373.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 221.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 1564, \"PID\": 914453045, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 23730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 668.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2032, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1565, \"PID\": 914465060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 857.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 271000}, {\"Order\": 1566, \"PID\": 914467050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 910.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 910, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 318, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1567, \"PID\": 914475020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 574.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 358.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 576, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1568, \"PID\": 914476010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 83, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 1569, \"PID\": 914476080, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10260, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 1570, \"PID\": 914476450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 297.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 428, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 1571, \"PID\": 916125425, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 164660, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 103.0, \"TotalBsmtSF\": 1499.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1619, \"2ndFlrSF\": 167, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 670, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228950}, {\"Order\": 1572, \"PID\": 916226030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 4084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 893.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 1573, \"PID\": 916325080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15498, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1165.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1565.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 665.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 174, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 287000}, {\"Order\": 1574, \"PID\": 916380060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 258.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 482.0, \"TotalBsmtSF\": 1518.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1537, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1537, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1575, \"PID\": 916382120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 338.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293077}, {\"Order\": 1576, \"PID\": 916384100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 770.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 150.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264966}, {\"Order\": 1577, \"PID\": 916386040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9802, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 352.0, \"TotalBsmtSF\": 352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 712, \"2ndFlrSF\": 730, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 1578, \"PID\": 916386080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": null, \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167500}, {\"Order\": 1579, \"PID\": 916386180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 12018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 816, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 218689}, {\"Order\": 1580, \"PID\": 916402015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1495.0, \"TotalBsmtSF\": 1495.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1495, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1581, \"PID\": 916402115, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 12416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1398.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 208.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1582, \"PID\": 916402215, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 18265, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 60.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 1256.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1256, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1256, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 1583, \"PID\": 916403230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 219.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 783.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 678.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1509, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 175000}, {\"Order\": 1584, \"PID\": 916455120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11202, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1029.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 1432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 185, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232500}, {\"Order\": 1585, \"PID\": 916460060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7915, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1675, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1675, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1586, \"PID\": 916477020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 226.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 611.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 2262, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 749.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305000}, {\"Order\": 1587, \"PID\": 921126030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11449, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1011.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 873.0, \"TotalBsmtSF\": 1884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 276, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 298751}, {\"Order\": 1588, \"PID\": 921201060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1571.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 393.0, \"TotalBsmtSF\": 1964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 892.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 370000}, {\"Order\": 1589, \"PID\": 923202005, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 97.0, \"LotArea\": 8940, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 209200}, {\"Order\": 1590, \"PID\": 923202015, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 35.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 206300}, {\"Order\": 1591, \"PID\": 923202137, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9278, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1092.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 146000}, {\"Order\": 1592, \"PID\": 923203140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 197.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 864.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 1189.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1189, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1189, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 1593, \"PID\": 923204040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 150.0, \"LotArea\": 14137, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 865.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 247.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 171, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2008, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 1594, \"PID\": 923225080, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 271.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1595, \"PID\": 923225150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1596, \"PID\": 923225200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 318.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 232.0, \"TotalBsmtSF\": 550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1597, \"PID\": 923225310, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 501.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 526.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1598, \"PID\": 923225370, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1596, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 25.0, \"TotalBsmtSF\": 462.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 526, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 120, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94900}, {\"Order\": 1599, \"PID\": 923227030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17979, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1113.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1160, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1160, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 257.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152500}, {\"Order\": 1600, \"PID\": 923228080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1477, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 9, \"YearBuilt\": 1970, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 358.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 188.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 187, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 1601, \"PID\": 923228420, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81000}, {\"Order\": 1602, \"PID\": 923250210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 988.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1603, \"PID\": 923252100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 6490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1604, \"PID\": 923275090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 6951, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 218.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 923, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 923, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 362, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1605, \"PID\": 923277030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1982, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 175.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130500}, {\"Order\": 1606, \"PID\": 923277040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1982, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1607, \"PID\": 923277080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1608, \"PID\": 923400040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12508, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 660.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 323.0, \"TotalBsmtSF\": 983.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 983, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1300, \"MoSold\": 7, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1609, \"PID\": 923426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 12395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 647.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 889, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1610, \"PID\": 924100020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 562.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 193.0, \"BsmtUnfSF\": 29.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 800, \"LowQualFinSF\": 0, \"GrLivArea\": 1968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 305, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1611, \"PID\": 1007100110, \"MSSubClass\": 70, \"MSZoning\": \"I (all)\", \"LotFrontage\": null, \"LotArea\": 56600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 1, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 686, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2008, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1612, \"PID\": 526352080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10667, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 838.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 749.0, \"TotalBsmtSF\": 1587.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1587, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1587, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167300}, {\"Order\": 1613, \"PID\": 526352090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10628, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 499.0, \"TotalBsmtSF\": 1277.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1277, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1277, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 526.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 176, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 1614, \"PID\": 526355170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1115.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 343.0, \"TotalBsmtSF\": 2223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2223, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2223, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 1615, \"PID\": 526355190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 15865, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 823.0, \"BsmtUnfSF\": 1043.0, \"TotalBsmtSF\": 2217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2217, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 207, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 1616, \"PID\": 527105140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12394, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1733, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 225000}, {\"Order\": 1617, \"PID\": 527107040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 806.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 373.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1618, \"PID\": 527110080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 612.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 794, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1470, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1619, \"PID\": 527110120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 916, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 1620, \"PID\": 527110130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 8872, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161500}, {\"Order\": 1621, \"PID\": 527126030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 298.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 251000}, {\"Order\": 1622, \"PID\": 527158090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 770, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1623, \"PID\": 527161090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8637, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 871.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 947, \"2ndFlrSF\": 767, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 180000}, {\"Order\": 1624, \"PID\": 527162080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178750}, {\"Order\": 1625, \"PID\": 527162090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 38.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1237.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1253, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1626, \"PID\": 527162140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 957, \"2ndFlrSF\": 1342, \"LowQualFinSF\": 0, \"GrLivArea\": 2299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1627, \"PID\": 527163080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1168.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1628, \"PID\": 527165020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10784, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 76.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 1629, \"PID\": 527165100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 812, \"2ndFlrSF\": 670, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163900}, {\"Order\": 1630, \"PID\": 527165170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7655, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 903.0, \"TotalBsmtSF\": 903.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 290, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 1631, \"PID\": 527175130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 18160, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 246, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 154204}, {\"Order\": 1632, \"PID\": 527182040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3696, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 137, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1633, \"PID\": 527182170, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 828.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 577.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 1634, \"PID\": 527184020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 4740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 248.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1166.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 135, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 1635, \"PID\": 527184110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 5118, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 926.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 1312.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1321, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1321, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212000}, {\"Order\": 1636, \"PID\": 527210060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 14157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 200.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1249.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 673.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 377426}, {\"Order\": 1637, \"PID\": 527212060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12328, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 146.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1377, \"LowQualFinSF\": 0, \"GrLivArea\": 2541, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 729.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 349265}, {\"Order\": 1638, \"PID\": 527216080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 51974, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 710.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1101.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1559.0, \"TotalBsmtSF\": 2660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2338, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1110.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 135, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 591587}, {\"Order\": 1639, \"PID\": 527226040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 195.0, \"LotArea\": 41600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1047.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 53.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1424, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1424, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 828.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1640, \"PID\": 527252050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 8035, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 165.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 797.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1612.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1612, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1612, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 164, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 319900}, {\"Order\": 1641, \"PID\": 527252070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8089, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 474.0, \"TotalBsmtSF\": 1419.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 567.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 1642, \"PID\": 527256030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 945.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1558.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 2220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2234, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 441929}, {\"Order\": 1643, \"PID\": 527256040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 13870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1152.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2042, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 724.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 174, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 455000}, {\"Order\": 1644, \"PID\": 527301080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12546, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 310.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 99, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182900}, {\"Order\": 1645, \"PID\": 527301280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1028.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1284, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 174000}, {\"Order\": 1646, \"PID\": 527302020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 74.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 178000}, {\"Order\": 1647, \"PID\": 527302060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1981, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 321.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 167, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1648, \"PID\": 527302090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1328.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 1529.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 663.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 1649, \"PID\": 527325090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 11339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 549.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 22.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1930, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 1650, \"PID\": 527325110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 11952, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1161, \"2ndFlrSF\": 808, \"LowQualFinSF\": 0, \"GrLivArea\": 1969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 276, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1651, \"PID\": 527327050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12046, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 156.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 692.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1118, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 2030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 224, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 1652, \"PID\": 527328020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10395, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 605.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1653, \"PID\": 527328050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 11850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1177, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1177, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1654, \"PID\": 527353080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11584, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 315.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 110.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 539.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 685, \"LowQualFinSF\": 0, \"GrLivArea\": 1725, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 1655, \"PID\": 527354050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 253.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1259.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1353, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1353, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192350}, {\"Order\": 1656, \"PID\": 527356050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10793, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 263.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 493.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1657, \"PID\": 527357020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 13001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 121.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 944.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 249, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1658, \"PID\": 527358060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1659, \"PID\": 527359010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 175.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1041, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1660, \"PID\": 527359080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 233.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1935, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197900}, {\"Order\": 1661, \"PID\": 527359160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 624.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 604.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1228.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 585.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 407, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1662, \"PID\": 527377110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 931.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 153.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1877, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178900}, {\"Order\": 1663, \"PID\": 527402090, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"AsphShn\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 349.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 23.0, \"TotalBsmtSF\": 372.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 533, \"LowQualFinSF\": 0, \"GrLivArea\": 1109, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 35, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1664, \"PID\": 527402150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 35.0, \"BsmtUnfSF\": 664.0, \"TotalBsmtSF\": 981.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 981, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 312, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143250}, {\"Order\": 1665, \"PID\": 527402240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7472, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1972, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 138.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 1666, \"PID\": 527403310, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9457, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 566.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 252, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1667, \"PID\": 527404050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 81.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 619.0, \"BsmtUnfSF\": 214.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1668, \"PID\": 527404100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 9758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 412.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 287.0, \"BsmtUnfSF\": 251.0, \"TotalBsmtSF\": 950.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 1669, \"PID\": 527404140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8294, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 1670, \"PID\": 527404150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 322.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 1671, \"PID\": 527425025, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17199, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 314.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1672, \"PID\": 527425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120500}, {\"Order\": 1673, \"PID\": 527427090, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 34.0, \"LotArea\": 4058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 182.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 584.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 139.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 723.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 767, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 367.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 1674, \"PID\": 527427160, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 33.0, \"LotArea\": 4113, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1337.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1675, \"PID\": 527427200, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 10943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 475.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1676, \"PID\": 527450030, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 213.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113500}, {\"Order\": 1677, \"PID\": 527450150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 356.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 1678, \"PID\": 527450220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2058, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 265.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113700}, {\"Order\": 1679, \"PID\": 527451020, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2016, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106000}, {\"Order\": 1680, \"PID\": 527451170, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 376.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 471.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122500}, {\"Order\": 1681, \"PID\": 527452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 4928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 958.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 205, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1682, \"PID\": 527453010, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 556.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 248.0, \"TotalBsmtSF\": 804.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 804, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 1683, \"PID\": 527455030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 6.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 1061.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 1684, \"PID\": 527455250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 52.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 725.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129250}, {\"Order\": 1685, \"PID\": 528102050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 12469, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1151.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 639.0, \"TotalBsmtSF\": 1790.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 730.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 186, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356000}, {\"Order\": 1686, \"PID\": 528102090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11694, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 452.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1774.0, \"TotalBsmtSF\": 1822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1828, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 260, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 314813}, {\"Order\": 1687, \"PID\": 528102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1688, \"PID\": 528102120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1694.0, \"TotalBsmtSF\": 1694.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 856.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 322400}, {\"Order\": 1689, \"PID\": 528102130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12085, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 328.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1004.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 730.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318000}, {\"Order\": 1690, \"PID\": 528104010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 590.0, \"TotalBsmtSF\": 2108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2122, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2122, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 938.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345474}, {\"Order\": 1691, \"PID\": 528106040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 14450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 315.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2121.0, \"TotalBsmtSF\": 2121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2121, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2121, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 732.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 124, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 415298}, {\"Order\": 1692, \"PID\": 528106050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13641, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1304.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 1934.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1943, \"2ndFlrSF\": 713, \"LowQualFinSF\": 0, \"GrLivArea\": 2656, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1040.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 492000}, {\"Order\": 1693, \"PID\": 528106060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 13440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1108.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 1402, \"LowQualFinSF\": 0, \"GrLivArea\": 2550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338931}, {\"Order\": 1694, \"PID\": 528106110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 400.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 564.0, \"TotalBsmtSF\": 1994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2046, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2046, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 450000}, {\"Order\": 1695, \"PID\": 528108160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 14154, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 350.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1063.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1071, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 2172, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 947.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 62, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 280000}, {\"Order\": 1696, \"PID\": 528110040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 740.0, \"TotalBsmtSF\": 2552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 479069}, {\"Order\": 1697, \"PID\": 528110070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 375.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1935.0, \"TotalBsmtSF\": 1935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1973, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1973, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 395000}, {\"Order\": 1698, \"PID\": 528110100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 13693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 772.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2153.0, \"TotalBsmtSF\": 2153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2069, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 2643, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 694.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 414, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 380000}, {\"Order\": 1699, \"PID\": 528112150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 11428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1626.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1634, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1634, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 866.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 1700, \"PID\": 528114050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14977, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 304.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 626.0, \"TotalBsmtSF\": 1976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 908.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 440000}, {\"Order\": 1701, \"PID\": 528118040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13654, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 365.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1704.0, \"TotalBsmtSF\": 1704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1722, \"2ndFlrSF\": 1036, \"LowQualFinSF\": 0, \"GrLivArea\": 2758, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 814.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 282, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 418000}, {\"Order\": 1702, \"PID\": 528118050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 17169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 970.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 2320.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2290, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2290, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1174.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 500067}, {\"Order\": 1703, \"PID\": 528120010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1582.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 570, \"LowQualFinSF\": 0, \"GrLivArea\": 2152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 368, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260116}, {\"Order\": 1704, \"PID\": 528120150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9591, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 344.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 1330, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 317000}, {\"Order\": 1705, \"PID\": 528142050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9709, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2100, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319500}, {\"Order\": 1706, \"PID\": 528144050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10562, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 1582.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 2161, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 789.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 178, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325624}, {\"Order\": 1707, \"PID\": 528150040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 13615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 510.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1802.0, \"TotalBsmtSF\": 1802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1802, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 372000}, {\"Order\": 1708, \"PID\": 528150110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 13069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 502.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1706.0, \"TotalBsmtSF\": 1706.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1718, \"2ndFlrSF\": 1238, \"LowQualFinSF\": 0, \"GrLivArea\": 2956, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 916.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 342000}, {\"Order\": 1709, \"PID\": 528150120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 388.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 970.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 1136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1136, \"2ndFlrSF\": 1332, \"LowQualFinSF\": 0, \"GrLivArea\": 2468, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 872.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 354000}, {\"Order\": 1710, \"PID\": 528166150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14277, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 379.0, \"TotalBsmtSF\": 1317.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 818.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 1711, \"PID\": 528168040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 11999, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1181.0, \"TotalBsmtSF\": 1181.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1234, \"2ndFlrSF\": 1140, \"LowQualFinSF\": 0, \"GrLivArea\": 2374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 656.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1712, \"PID\": 528172030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 669.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 895.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 895, \"2ndFlrSF\": 923, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281500}, {\"Order\": 1713, \"PID\": 528172050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9926, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1178.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245700}, {\"Order\": 1714, \"PID\": 528172070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9254, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1602.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 554.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232698}, {\"Order\": 1715, \"PID\": 528172075, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10732, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1298.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 876.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 1716, \"PID\": 528174010, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194700}, {\"Order\": 1717, \"PID\": 528174020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3901, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 866.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 436.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204000}, {\"Order\": 1718, \"PID\": 528174030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 3903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 182.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 272.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 631.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 110, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1719, \"PID\": 528174040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 6289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 1720, \"PID\": 528181060, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1721, \"PID\": 528181070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 34.0, \"LotArea\": 4590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1530.0, \"TotalBsmtSF\": 1554.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1554, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 627.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 209500}, {\"Order\": 1722, \"PID\": 528181080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 6442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 1723, \"PID\": 528186050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 7841, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 394.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 848.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 729.0, \"TotalBsmtSF\": 1577.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1577, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 1724, \"PID\": 528186090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7313, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1153.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1561.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1561, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1561, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 1725, \"PID\": 528186120, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 362.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1869.0, \"TotalBsmtSF\": 1869.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 318061}, {\"Order\": 1726, \"PID\": 528186190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1300.0, \"TotalBsmtSF\": 1324.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221370}, {\"Order\": 1727, \"PID\": 528188160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 3242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 235.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1728, \"PID\": 528218010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 15810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181755}, {\"Order\": 1729, \"PID\": 528218020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1730, \"PID\": 528218050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 783, \"2ndFlrSF\": 701, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 178900}, {\"Order\": 1731, \"PID\": 528218100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 13204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 608.0, \"TotalBsmtSF\": 608.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 168165}, {\"Order\": 1732, \"PID\": 528221030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8857, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 757, \"LowQualFinSF\": 0, \"GrLivArea\": 1495, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 171925}, {\"Order\": 1733, \"PID\": 528221040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9729, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 698, \"2ndFlrSF\": 1048, \"LowQualFinSF\": 0, \"GrLivArea\": 1746, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 350.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198444}, {\"Order\": 1734, \"PID\": 528221050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 918.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 203000}, {\"Order\": 1735, \"PID\": 528221090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 9018, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179540}, {\"Order\": 1736, \"PID\": 528222030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 176485}, {\"Order\": 1737, \"PID\": 528222040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1340.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 181134}, {\"Order\": 1738, \"PID\": 528222050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8499, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 796, \"LowQualFinSF\": 0, \"GrLivArea\": 1412, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156932}, {\"Order\": 1739, \"PID\": 528222060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8229, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 22.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 752.0, \"TotalBsmtSF\": 752.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 752, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1740, \"PID\": 528222080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7713, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 177594}, {\"Order\": 1741, \"PID\": 528222090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1246.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173500}, {\"Order\": 1742, \"PID\": 528228270, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1258, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1258, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172500}, {\"Order\": 1743, \"PID\": 528228275, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1258.0, \"TotalBsmtSF\": 1258.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1402, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1402, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 0, \"HalfBath\": 2, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194201}, {\"Order\": 1744, \"PID\": 528228375, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3621, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1084.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1589, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226500}, {\"Order\": 1745, \"PID\": 528228555, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1266.0, \"TotalBsmtSF\": 1266.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185485}, {\"Order\": 1746, \"PID\": 528231010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 182.0, \"LotArea\": 14572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1530, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1530, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 259000}, {\"Order\": 1747, \"PID\": 528231030, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 16219, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 835.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1119, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1119, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1748, \"PID\": 528235000, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 11084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 744, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 175000}, {\"Order\": 1749, \"PID\": 528235160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 11796, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1112, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1750, \"PID\": 528235170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1510.0, \"TotalBsmtSF\": 1510.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 206580}, {\"Order\": 1751, \"PID\": 528240020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 1752, \"PID\": 528250010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 754, \"2ndFlrSF\": 640, \"LowQualFinSF\": 0, \"GrLivArea\": 1394, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165500}, {\"Order\": 1753, \"PID\": 528250070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 1754, \"PID\": 528275035, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8063, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 924.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 742, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 463.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 181000}, {\"Order\": 1755, \"PID\": 528275110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 1131, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 435.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 1756, \"PID\": 528280110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 694, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1757, \"PID\": 528280150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 656, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 1758, \"PID\": 528290060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 1759, \"PID\": 528290170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9487, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 395.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 442.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1760, \"PID\": 528294010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9649, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 683, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1761, \"PID\": 528320050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 15623, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2096.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 2396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2411, \"2ndFlrSF\": 2065, \"LowQualFinSF\": 0, \"GrLivArea\": 4476, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 813.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 555, \"PoolQC\": \"Ex\", \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 745000}, {\"Order\": 1762, \"PID\": 528322020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 12191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 515.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 598.0, \"TotalBsmtSF\": 1779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 772, \"LowQualFinSF\": 0, \"GrLivArea\": 2551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 61, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 384500}, {\"Order\": 1763, \"PID\": 528326060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 997, \"2ndFlrSF\": 1288, \"LowQualFinSF\": 0, \"GrLivArea\": 2285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 248000}, {\"Order\": 1764, \"PID\": 528327060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 705.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1351.0, \"TotalBsmtSF\": 2633.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2633, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2633, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 804.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 466500}, {\"Order\": 1765, \"PID\": 528340030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10557, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 422.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 672.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 1408.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1671, \"2ndFlrSF\": 1407, \"LowQualFinSF\": 0, \"GrLivArea\": 3078, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 806.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 410000}, {\"Order\": 1766, \"PID\": 528344020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 11002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1048.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 341.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 1171, \"LowQualFinSF\": 0, \"GrLivArea\": 2582, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 322500}, {\"Order\": 1767, \"PID\": 528348030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10790, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 275.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1066.0, \"TotalBsmtSF\": 1066.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 1277, \"LowQualFinSF\": 0, \"GrLivArea\": 2385, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 1768, \"PID\": 528351010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 21535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 6, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1170.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 989.0, \"TotalBsmtSF\": 2444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2444, \"2ndFlrSF\": 1872, \"LowQualFinSF\": 0, \"GrLivArea\": 4316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 832.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 382, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 755000}, {\"Order\": 1769, \"PID\": 528354060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 862.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 255.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2013, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 455.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 269790}, {\"Order\": 1770, \"PID\": 528354110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11787, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 594.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 719.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 1379.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 1015, \"LowQualFinSF\": 0, \"GrLivArea\": 2398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315750}, {\"Order\": 1771, \"PID\": 528358040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1203.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 721.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 290000}, {\"Order\": 1772, \"PID\": 528364110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 64.0, \"BsmtUnfSF\": 1198.0, \"TotalBsmtSF\": 1318.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2531, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 752.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 222, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 1773, \"PID\": 528366050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1231.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1969.0, \"TotalBsmtSF\": 3200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3228, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 3228, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 75, \"EnclosedPorch\": 291, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 430000}, {\"Order\": 1774, \"PID\": 528366070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 335.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 1097, \"LowQualFinSF\": 0, \"GrLivArea\": 2202, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 263000}, {\"Order\": 1775, \"PID\": 528376010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 526.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1225.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1325.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 1203, \"LowQualFinSF\": 0, \"GrLivArea\": 2538, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 933.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 1776, \"PID\": 528427040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1369.0, \"TotalBsmtSF\": 1369.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1369, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1369, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 605.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 203, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 213133}, {\"Order\": 1777, \"PID\": 528427100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1542.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1542, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1542, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 852.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 260261}, {\"Order\": 1778, \"PID\": 528429090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 11670, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1905.0, \"TotalBsmtSF\": 1905.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1905, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1905, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 788.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 320000}, {\"Order\": 1779, \"PID\": 528429110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15256, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1464, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1464, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 160, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282922}, {\"Order\": 1780, \"PID\": 528431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 10612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1534, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 215000}, {\"Order\": 1781, \"PID\": 528431040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 12291, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 754.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1572.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 394.0, \"TotalBsmtSF\": 1966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1966, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1966, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1092.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 76, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 419005}, {\"Order\": 1782, \"PID\": 528431050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13501, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 63.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1623.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1783, \"PID\": 528431110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9986, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 428.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1795.0, \"TotalBsmtSF\": 1795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1795, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 895.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 1784, \"PID\": 528435010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1528, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 2, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 235876}, {\"Order\": 1785, \"PID\": 528435040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9416, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 205.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1126.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 1726.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1726, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 171, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 266, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 311872}, {\"Order\": 1786, \"PID\": 528435060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9849, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 954.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248328}, {\"Order\": 1787, \"PID\": 528435070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 410.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1588.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 825.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 1788, \"PID\": 528439040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8847, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 769.0, \"TotalBsmtSF\": 1538.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1538, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1538, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 1789, \"PID\": 528439050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 9158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1496.0, \"TotalBsmtSF\": 1496.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1496, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 225000}, {\"Order\": 1790, \"PID\": 528439080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8251, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 778.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249000}, {\"Order\": 1791, \"PID\": 528441080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 636.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 255, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 307000}, {\"Order\": 1792, \"PID\": 528445020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9605, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 982.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 982, \"2ndFlrSF\": 995, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 250000}, {\"Order\": 1793, \"PID\": 528445070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1302.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 528, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 859.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221300}, {\"Order\": 1794, \"PID\": 528456190, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1314.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1338, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 598.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 141, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1795, \"PID\": 528456230, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1335.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1335, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1335, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 210, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210400}, {\"Order\": 1796, \"PID\": 528458080, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 896, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 255000}, {\"Order\": 1797, \"PID\": 528458090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 10411, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 725, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 561.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212109}, {\"Order\": 1798, \"PID\": 528458120, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 871, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1025.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 1799, \"PID\": 528458130, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 64.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1120.0, \"TotalBsmtSF\": 1184.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1184, \"2ndFlrSF\": 1426, \"LowQualFinSF\": 0, \"GrLivArea\": 2610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 364, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 303477}, {\"Order\": 1800, \"PID\": 528458150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 112.0, \"LotArea\": 12217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 745.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1880, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310013}, {\"Order\": 1801, \"PID\": 528477020, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 11096, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1656, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1656, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 249700}, {\"Order\": 1802, \"PID\": 528480020, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 874.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1761, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 227875}, {\"Order\": 1803, \"PID\": 528480180, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10440, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1574.0, \"TotalBsmtSF\": 1574.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 594.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 256, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 261329}, {\"Order\": 1804, \"PID\": 528482010, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 11824, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 298.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1685.0, \"TotalBsmtSF\": 1685.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1685, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1685, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 253000}, {\"Order\": 1805, \"PID\": 528482030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 85.0, \"LotArea\": 10625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 353.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1285, \"LowQualFinSF\": 0, \"GrLivArea\": 2443, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 744.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265000}, {\"Order\": 1806, \"PID\": 528482090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 102.0, \"LotArea\": 11143, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1580.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1580, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 2466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 159, \"OpenPorchSF\": 214, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 340000}, {\"Order\": 1807, \"PID\": 531363020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 146000}, {\"Order\": 1808, \"PID\": 531363040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1809, \"PID\": 531375140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 126.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 729.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1094, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 1810, \"PID\": 531376060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1461.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1486, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 1811, \"PID\": 531380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 814.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 114.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 785, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 300, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 1812, \"PID\": 531384070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11613, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1820, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191750}, {\"Order\": 1813, \"PID\": 531385070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1349.0, \"TotalBsmtSF\": 1349.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1349, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1349, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179000}, {\"Order\": 1814, \"PID\": 531385130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1443.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 39.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 514.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 402, \"OpenPorchSF\": 25, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 1815, \"PID\": 531451030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 430.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1145.0, \"TotalBsmtSF\": 1575.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 52, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179200}, {\"Order\": 1816, \"PID\": 531451150, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 630.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 636, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 283.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 340, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 1817, \"PID\": 531453140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 747.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 93.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1818, \"PID\": 531477040, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 630.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1819, \"PID\": 532353120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 351.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120750}, {\"Order\": 1820, \"PID\": 532354010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 630.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1821, \"PID\": 532354060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 640.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1822, \"PID\": 532354070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 999.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 1823, \"PID\": 532376040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 6970, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1824, \"PID\": 532376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 13673, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 349.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143900}, {\"Order\": 1825, \"PID\": 532377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 7476, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 686.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1826, \"PID\": 532377140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 57.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 827.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 161.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1827, \"PID\": 532378240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6173, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 75.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 599.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 277.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1828, \"PID\": 532476080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1223.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1271, \"2ndFlrSF\": 1232, \"LowQualFinSF\": 0, \"GrLivArea\": 2503, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 99, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 182, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 1829, \"PID\": 532477040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17542, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1974, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 125.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1031.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1192.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1516, \"2ndFlrSF\": 651, \"LowQualFinSF\": 0, \"GrLivArea\": 2167, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 220, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 294000}, {\"Order\": 1830, \"PID\": 532479050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 10751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 787.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 1037.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1037, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1037, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 47, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1831, \"PID\": 532479120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16647, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1701, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1701, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 611.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171000}, {\"Order\": 1832, \"PID\": 532479140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1973, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 968.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 455, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 147000}, {\"Order\": 1833, \"PID\": 533120030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9572, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 482.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 1357, \"LowQualFinSF\": 0, \"GrLivArea\": 2810, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 500, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 1834, \"PID\": 533130170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10678, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 337.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 983.0, \"TotalBsmtSF\": 1683.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2129, \"2ndFlrSF\": 743, \"LowQualFinSF\": 0, \"GrLivArea\": 2872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 1835, \"PID\": 533205110, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 45.0, \"LotArea\": 4379, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 851.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 527.0, \"TotalBsmtSF\": 1378.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1378, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1378, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 1836, \"PID\": 533206060, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 80.0, \"LotArea\": 3523, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 30.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1081.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1151, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1151, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 166000}, {\"Order\": 1837, \"PID\": 533206070, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 32.0, \"LotArea\": 3784, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 36.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1451.0, \"TotalBsmtSF\": 1511.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 476.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193800}, {\"Order\": 1838, \"PID\": 533208010, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 47.0, \"LotArea\": 4230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1352.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 208900}, {\"Order\": 1839, \"PID\": 533208020, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 40.0, \"LotArea\": 3606, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 937.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 415.0, \"TotalBsmtSF\": 1352.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 466.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 241, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 1840, \"PID\": 533208030, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 5330, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1550.0, \"TotalBsmtSF\": 1550.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1550, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 207500}, {\"Order\": 1841, \"PID\": 533208040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4274, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1106.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1241.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1241, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1241, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199900}, {\"Order\": 1842, \"PID\": 533208070, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 4251, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 625, \"2ndFlrSF\": 625, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164700}, {\"Order\": 1843, \"PID\": 533213130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 342.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 744.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 757, \"2ndFlrSF\": 744, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 1844, \"PID\": 533213140, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3230, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1129.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 419.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 310.0, \"TotalBsmtSF\": 729.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 729, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 1845, \"PID\": 533221030, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1512, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168500}, {\"Order\": 1846, \"PID\": 533221060, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 417.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 339.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1573, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1847, \"PID\": 533221100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2117, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 436.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 769, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177000}, {\"Order\": 1848, \"PID\": 533223050, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 5105, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 551.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 551, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148800}, {\"Order\": 1849, \"PID\": 533236040, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2645, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 776.0, \"TotalBsmtSF\": 776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 764, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1441, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 1850, \"PID\": 533241030, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 66.0, \"LotArea\": 7399, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 649.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 975, \"2ndFlrSF\": 975, \"LowQualFinSF\": 0, \"GrLivArea\": 1950, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 10, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 198, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 1851, \"PID\": 533242080, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 73.0, \"LotArea\": 7321, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1339.0, \"TotalBsmtSF\": 1339.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 174, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 1852, \"PID\": 533242090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 8010, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 964.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 2048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 1853, \"PID\": 533244040, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 106.0, \"LotArea\": 8413, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 1105.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 1854, \"PID\": 533250190, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 9466, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1037.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 217, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279700}, {\"Order\": 1855, \"PID\": 533251110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 2002.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2362, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2362, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1856, \"PID\": 533251130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16157, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 680.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 391.0, \"BsmtUnfSF\": 289.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1432, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 1857, \"PID\": 533252130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 10768, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1157.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1437.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 1858, \"PID\": 533253180, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 881.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 176.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 89, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213750}, {\"Order\": 1859, \"PID\": 533254100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 528.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1094, \"2ndFlrSF\": 761, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1860, \"PID\": 533254130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 978.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 298, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181500}, {\"Order\": 1861, \"PID\": 533350020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 17778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1632.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 829.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 2461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2497, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2497, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 676.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 373000}, {\"Order\": 1862, \"PID\": 533352075, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAe\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 211.0, \"BsmtUnfSF\": 652.0, \"TotalBsmtSF\": 1361.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1361, \"2ndFlrSF\": 1259, \"LowQualFinSF\": 0, \"GrLivArea\": 2620, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 24, \"EnclosedPorch\": 145, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 8300, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 1863, \"PID\": 534104090, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 7050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 872, \"LowQualFinSF\": 0, \"GrLivArea\": 1929, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 235, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 1864, \"PID\": 534125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 412.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 143450}, {\"Order\": 1865, \"PID\": 534127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 93.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 1008, \"LowQualFinSF\": 0, \"GrLivArea\": 2411, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 192, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240050}, {\"Order\": 1866, \"PID\": 534127140, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 973.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 973.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162500}, {\"Order\": 1867, \"PID\": 534127260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 385.0, \"TotalBsmtSF\": 1295.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 194, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 1868, \"PID\": 534128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 11358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 346.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 778.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1610, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1610, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 256, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1869, \"PID\": 534151090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9547, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1594, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1594, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188500}, {\"Order\": 1870, \"PID\": 534151180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1148.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2075, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 235, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 1871, \"PID\": 534175010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"RRAn\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136905}, {\"Order\": 1872, \"PID\": 534176140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 10738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 792.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 301.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1093, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1873, \"PID\": 534177210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 916.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175500}, {\"Order\": 1874, \"PID\": 534178010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 311.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 133, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1875, \"PID\": 534201040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 474.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 38.0, \"BsmtUnfSF\": 437.0, \"TotalBsmtSF\": 949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1107, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1107, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1876, \"PID\": 534202030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 695.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 519.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1877, \"PID\": 534204120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10289, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 237.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1878, \"PID\": 534252040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9503, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1344, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 316, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1879, \"PID\": 534252060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10624, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 84.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 264.0, \"BsmtUnfSF\": 1424.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1880, \"PID\": 534252070, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1881, \"PID\": 534252110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12342, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 978.0, \"TotalBsmtSF\": 978.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 1882, \"PID\": 534275170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1960, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 498.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 958.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 958, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 15500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 1883, \"PID\": 534275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8892, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 66.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1065, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 74, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 1884, \"PID\": 534276070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10482, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 63.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 81.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1138, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 1885, \"PID\": 534276160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 111.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 279.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 12, \"OpenPorchSF\": 285, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": \"Shed\", \"MiscVal\": 480, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1886, \"PID\": 534276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 438.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 206.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1887, \"PID\": 534276290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 1200, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 1888, \"PID\": 534278150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 311.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 167.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1187, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140500}, {\"Order\": 1889, \"PID\": 534278170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8243, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 1890, \"PID\": 534278190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 894.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117600}, {\"Order\": 1891, \"PID\": 534401120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 202.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 520.0, \"TotalBsmtSF\": 1174.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1892, \"PID\": 534401200, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1042, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 1893, \"PID\": 534403040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 270.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 580.0, \"BsmtUnfSF\": 452.0, \"TotalBsmtSF\": 1302.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1302, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 309.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 333, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 1894, \"PID\": 534403290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 306.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 1309, \"LowQualFinSF\": 0, \"GrLivArea\": 2154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 161, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 1895, \"PID\": 534403420, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 212.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 54.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 543.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1130.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1374, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1374, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 1896, \"PID\": 534425015, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22002, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 206.0, \"TotalBsmtSF\": 1592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 201, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 1897, \"PID\": 534425080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 594.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 219.0, \"BsmtUnfSF\": 331.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1429, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1429, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181900}, {\"Order\": 1898, \"PID\": 534427140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 7388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 405.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 1063.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1327, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1327, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150750}, {\"Order\": 1899, \"PID\": 534429030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101800}, {\"Order\": 1900, \"PID\": 534430090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 932.0, \"TotalBsmtSF\": 932.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 932, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 932, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 306.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 214, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 1901, \"PID\": 534431020, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 259.0, \"BsmtUnfSF\": 433.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 908, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 908, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 1902, \"PID\": 534450090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 334, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 2, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 39300}, {\"Order\": 1903, \"PID\": 534450110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 666, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1904, \"PID\": 534451020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 3500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 370.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 442, \"2ndFlrSF\": 228, \"LowQualFinSF\": 0, \"GrLivArea\": 670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 1905, \"PID\": 534453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 404.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 808, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 808, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 1906, \"PID\": 534475170, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 442.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1127, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1977, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 1907, \"PID\": 534476080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1078.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 175, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1908, \"PID\": 534478140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 11345, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Roll\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 567.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 708.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 928, \"2ndFlrSF\": 992, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1909, \"PID\": 534479120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9492, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 368.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 41.0, \"BsmtUnfSF\": 359.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 1910, \"PID\": 534479140, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1942, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1644, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 1911, \"PID\": 535101150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 1912, \"PID\": 535102010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 87.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1280, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1280, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 1913, \"PID\": 535105110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 291.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 618.0, \"TotalBsmtSF\": 1218.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1254, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1254, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158500}, {\"Order\": 1914, \"PID\": 535106140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 1915, \"PID\": 535106180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11344, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 414.0, \"TotalBsmtSF\": 874.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 874, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 1916, \"PID\": 535126180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 723.0, \"BsmtUnfSF\": 111.0, \"TotalBsmtSF\": 1021.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1465, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2380, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Sev\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 129000}, {\"Order\": 1917, \"PID\": 535151020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 873.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 63.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 219, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1918, \"PID\": 535151100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6860, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 908.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 1919, \"PID\": 535151110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1053.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 109, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142100}, {\"Order\": 1920, \"PID\": 535152060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 1921, \"PID\": 535154080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 243.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 834.0, \"TotalBsmtSF\": 1442.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 301.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 275, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 157900}, {\"Order\": 1922, \"PID\": 535155110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 480.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 390, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 1923, \"PID\": 535176070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11988, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 777.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 467.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1244, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1244, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 1924, \"PID\": 535177020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 69.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1144.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1925, \"PID\": 535177110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9736, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 289.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 668.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 138.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 1331.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 464.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174850}, {\"Order\": 1926, \"PID\": 535179120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 410.0, \"TotalBsmtSF\": 922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 1927, \"PID\": 535180030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 586.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 1048.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1928, \"PID\": 535181030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1237.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1657.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1657, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163500}, {\"Order\": 1929, \"PID\": 535181140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12198, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1411, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1411, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 278, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1930, \"PID\": 535300040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 928.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 1931, \"PID\": 535301060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1154, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1154, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 1932, \"PID\": 535301160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8078, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 260.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1560.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128600}, {\"Order\": 1933, \"PID\": 535302070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 507.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1934, \"PID\": 535304170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 85.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 955.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 293.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136000}, {\"Order\": 1935, \"PID\": 535305180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8923, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1953, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 365.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 1936, \"PID\": 535325090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1956, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 691.0, \"BsmtUnfSF\": 120.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 1937, \"PID\": 535325280, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 384.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1938, \"PID\": 535325320, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1040.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 500, \"LowQualFinSF\": 0, \"GrLivArea\": 1540, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 1939, \"PID\": 535327160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 793.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116900}, {\"Order\": 1940, \"PID\": 535327200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 377.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 551.0, \"TotalBsmtSF\": 928.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 928, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 261, \"OpenPorchSF\": 0, \"EnclosedPorch\": 156, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 1941, \"PID\": 535353050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9532, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 354.0, \"BsmtUnfSF\": 156.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 368, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 1942, \"PID\": 535353130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 632.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 924, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 324, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 1943, \"PID\": 535353160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 14190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1890, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 544, \"LowQualFinSF\": 0, \"GrLivArea\": 1544, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 231, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 1944, \"PID\": 535354050, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 625.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 893, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 893, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1945, \"PID\": 535354260, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12099, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1953, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1018.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 512, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 1946, \"PID\": 535355020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 113.0, \"LotArea\": 21281, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1935, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 1778, \"LowQualFinSF\": 0, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 1200.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 208, \"EnclosedPorch\": 290, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 301600}, {\"Order\": 1947, \"PID\": 535375130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10134, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 735.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 735, \"2ndFlrSF\": 299, \"LowQualFinSF\": 0, \"GrLivArea\": 1034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 1948, \"PID\": 535376010, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 882.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103200}, {\"Order\": 1949, \"PID\": 535378080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10284, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1030.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 66.0, \"BsmtUnfSF\": 55.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 436, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128500}, {\"Order\": 1950, \"PID\": 535379060, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 656.0, \"TotalBsmtSF\": 656.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 1951, \"PID\": 535379110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1895, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 736.0, \"TotalBsmtSF\": 736.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 751, \"2ndFlrSF\": 783, \"LowQualFinSF\": 0, \"GrLivArea\": 1534, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 1952, \"PID\": 535382150, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 691.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 691, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 691, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 94, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 86000}, {\"Order\": 1953, \"PID\": 535402140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 364.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 242.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1035, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 460, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 165, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 1954, \"PID\": 535402180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 53.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 192.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 888, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 1955, \"PID\": 535403030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 952.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 952, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 952, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 1956, \"PID\": 535426130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11606, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 650.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 1040, \"LowQualFinSF\": 0, \"GrLivArea\": 2080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 335, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1957, \"PID\": 535450190, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 252, \"LowQualFinSF\": 0, \"GrLivArea\": 924, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122900}, {\"Order\": 1958, \"PID\": 535450220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11664, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 206.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 746.0, \"TotalBsmtSF\": 1082.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1082, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119200}, {\"Order\": 1959, \"PID\": 535450310, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10496, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 320.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1168, \"2ndFlrSF\": 678, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 1960, \"PID\": 535451040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 534.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 246.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 276.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 1961, \"PID\": 535451100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 432.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1238, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 357.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 171, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 1962, \"PID\": 535451110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1950, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 398.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 149.0, \"BsmtUnfSF\": 317.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 1963, \"PID\": 535452060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1010.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1134, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 254.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 135000}, {\"Order\": 1964, \"PID\": 535453080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 466.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 1965, \"PID\": 535453150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7315, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 545.0, \"TotalBsmtSF\": 1170.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1170, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1966, \"PID\": 535453180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7903, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 739.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1242.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 324.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 152000}, {\"Order\": 1967, \"PID\": 535457020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1098.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 154.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1377.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1377, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 351.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 1968, \"PID\": 535457040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1800.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 1969, \"PID\": 535457050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99000}, {\"Order\": 1970, \"PID\": 535476360, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 536.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 117.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 822.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 831, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 1971, \"PID\": 535477130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 876, \"2ndFlrSF\": 936, \"LowQualFinSF\": 0, \"GrLivArea\": 1812, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 1972, \"PID\": 535477180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 110.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 442.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 1973, \"PID\": 535478040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 6760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 734.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 90, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1974, \"PID\": 902100010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 850.0, \"TotalBsmtSF\": 850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 103000}, {\"Order\": 1975, \"PID\": 902105110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 664, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 132000}, {\"Order\": 1976, \"PID\": 902106070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 430, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 175, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 1977, \"PID\": 902106120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 4480, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 782.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 184.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 122, \"EnclosedPorch\": 20, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 1978, \"PID\": 902107050, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 180.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 1979, \"PID\": 902110010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 3153, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 26, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99900}, {\"Order\": 1980, \"PID\": 902125120, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1885, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Mansard\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1047, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1047, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1981, \"PID\": 902128160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 279.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 808.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 1982, \"PID\": 902201090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 680, \"2ndFlrSF\": 494, \"LowQualFinSF\": 0, \"GrLivArea\": 1174, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 26, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 1983, \"PID\": 902201130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 331.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 318.0, \"TotalBsmtSF\": 649.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 679, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 1984, \"PID\": 902202070, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 435.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 739.0, \"TotalBsmtSF\": 907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 89471}, {\"Order\": 1985, \"PID\": 902205020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5925, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 122.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 448.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 761, \"2ndFlrSF\": 380, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 1986, \"PID\": 902205130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 1987, \"PID\": 902206270, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9639, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1075.0, \"TotalBsmtSF\": 1075.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1156, \"2ndFlrSF\": 642, \"LowQualFinSF\": 0, \"GrLivArea\": 1798, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 1988, \"PID\": 902207010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 3880, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1945, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 866, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 58, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 1989, \"PID\": 902207150, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 968.0, \"TotalBsmtSF\": 968.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 1990, \"PID\": 902300020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 10337, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 9, \"YearBuilt\": 1910, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 725.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 863, \"LowQualFinSF\": 0, \"GrLivArea\": 1772, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 1991, \"PID\": 902300040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 53.0, \"LotArea\": 9863, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1927, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 196.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 210.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1642, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 374.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 145000}, {\"Order\": 1992, \"PID\": 902301030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 702.0, \"TotalBsmtSF\": 702.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 842, \"2ndFlrSF\": 630, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 1993, \"PID\": 902301130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 4571, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 616, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114000}, {\"Order\": 1994, \"PID\": 902302150, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 662.0, \"TotalBsmtSF\": 662.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 2337, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 1995, \"PID\": 902303100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 259.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 667.0, \"TotalBsmtSF\": 926.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 991, \"2ndFlrSF\": 659, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 468.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144100}, {\"Order\": 1996, \"PID\": 902304040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 9900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1880, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 1032, \"LowQualFinSF\": 0, \"GrLivArea\": 2210, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117500}, {\"Order\": 1997, \"PID\": 902305010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 316.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 687.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 687, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 124500}, {\"Order\": 1998, \"PID\": 902330090, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13500, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1879, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 819.0, \"TotalBsmtSF\": 819.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2454, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 1999, \"PID\": 902332030, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1046.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1260, \"2ndFlrSF\": 1031, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 99, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133900}, {\"Order\": 2000, \"PID\": 902401030, \"MSSubClass\": 40, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 370.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 779.0, \"TotalBsmtSF\": 1149.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1149, \"2ndFlrSF\": 467, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 183, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2001, \"PID\": 902404010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 8100, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1221.0, \"TotalBsmtSF\": 1559.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1559, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1559, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 812.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 230, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2002, \"PID\": 902408080, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1890, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 718.0, \"TotalBsmtSF\": 718.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1576, \"2ndFlrSF\": 978, \"LowQualFinSF\": 0, \"GrLivArea\": 2554, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 143, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2003, \"PID\": 902427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 9439, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 324.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 588.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 912, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 160.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2004, \"PID\": 902427140, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 8626, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 1.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 968, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 968, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2005, \"PID\": 902427180, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 76.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1949, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2006, \"PID\": 903201090, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 6854, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 227.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 916, \"2ndFlrSF\": 144, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 150, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2007, \"PID\": 903204030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 8674, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRNn\", \"Condition2\": \"Artery\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 910.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1435, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128250}, {\"Order\": 2008, \"PID\": 903205085, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 8731, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 645.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 915.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1167, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1167, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2009, \"PID\": 903206170, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 765.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 915, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 144, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2010, \"PID\": 903225040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2011, \"PID\": 903227140, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 608, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1232, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 217.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128000}, {\"Order\": 2012, \"PID\": 903228080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 735.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 869, \"2ndFlrSF\": 349, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2013, \"PID\": 903231050, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 884.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 136, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2014, \"PID\": 903231090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 52.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 809.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2015, \"PID\": 903231180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1939, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 899, \"2ndFlrSF\": 423, \"LowQualFinSF\": 0, \"GrLivArea\": 1322, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2016, \"PID\": 903232100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 966.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1014, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2017, \"PID\": 903233030, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 351.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 405.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 903, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1281, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 379.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 25, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2018, \"PID\": 903233050, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 574, \"LowQualFinSF\": 0, \"GrLivArea\": 1513, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1933.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 150, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2019, \"PID\": 903233140, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1929, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 854, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2020, \"PID\": 903233180, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 459.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 959, \"2ndFlrSF\": 408, \"LowQualFinSF\": 0, \"GrLivArea\": 1367, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127500}, {\"Order\": 2021, \"PID\": 903234160, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6180, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 986, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 128, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2022, \"PID\": 903236130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 47.0, \"LotArea\": 7755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1164, \"LowQualFinSF\": 0, \"GrLivArea\": 2264, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 408.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 152, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2023, \"PID\": 903400040, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 13515, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 764.0, \"TotalBsmtSF\": 764.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2024, \"PID\": 903401070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 752, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 54, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2025, \"PID\": 903425270, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 356, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2026, \"PID\": 903425280, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8730, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1915, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 698.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 698, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153575}, {\"Order\": 2027, \"PID\": 903426010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 5700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1929, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 456.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2028, \"PID\": 903427040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 546.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 714.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 862, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 15, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Family\", \"SalePrice\": 136000}, {\"Order\": 2029, \"PID\": 903430040, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 592.0, \"TotalBsmtSF\": 592.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 933, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 1173, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 25, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 113000}, {\"Order\": 2030, \"PID\": 903430050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 5680, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1901, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 969.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 969, \"2ndFlrSF\": 245, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 117000}, {\"Order\": 2031, \"PID\": 903450060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 7758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1931, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1818, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169500}, {\"Order\": 2032, \"PID\": 903451110, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 7449, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1108, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139400}, {\"Order\": 2033, \"PID\": 903453080, \"MSSubClass\": 80, \"MSZoning\": \"RM\", \"LotFrontage\": 120.0, \"LotArea\": 13200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 234.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1497, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 2294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 658.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2034, \"PID\": 903454010, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 773, \"2ndFlrSF\": 582, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 0, \"EnclosedPorch\": 115, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2035, \"PID\": 903454090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2036, \"PID\": 903456110, \"MSSubClass\": 60, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9780, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 9, \"YearBuilt\": 1950, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 354.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 398.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 976, \"LowQualFinSF\": 0, \"GrLivArea\": 1952, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 285, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212300}, {\"Order\": 2037, \"PID\": 903457040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 763.0, \"TotalBsmtSF\": 1138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1138, \"2ndFlrSF\": 1042, \"LowQualFinSF\": 0, \"GrLivArea\": 2180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 170, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2038, \"PID\": 903457130, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 4330, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 681.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 127.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 808.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 838, \"2ndFlrSF\": 477, \"LowQualFinSF\": 0, \"GrLivArea\": 1315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 436.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 99500}, {\"Order\": 2039, \"PID\": 903458020, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 581, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1111, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 101000}, {\"Order\": 2040, \"PID\": 903458060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1916, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 197.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 999.0, \"TotalBsmtSF\": 1196.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1196, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1196, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2041, \"PID\": 903475040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 12358, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 0, \"LowQualFinSF\": 528, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2042, \"PID\": 903475060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 964, \"2ndFlrSF\": 925, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2043, \"PID\": 903476100, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 55.0, \"LotArea\": 4388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2044, \"PID\": 903484080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 1, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 771.0, \"TotalBsmtSF\": 771.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 866, \"2ndFlrSF\": 504, \"LowQualFinSF\": 114, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Sal\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 14, \"OpenPorchSF\": 211, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 84, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 50000}, {\"Order\": 2045, \"PID\": 904100100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 12888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1937, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 288.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 1005, \"LowQualFinSF\": 0, \"GrLivArea\": 2267, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 498.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 521, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219000}, {\"Order\": 2046, \"PID\": 904101070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 138.0, \"LotArea\": 18030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 152.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 977.0, \"TotalBsmtSF\": 1598.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1636, \"2ndFlrSF\": 971, \"LowQualFinSF\": 479, \"GrLivArea\": 3086, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 122, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200500}, {\"Order\": 2047, \"PID\": 904301110, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 444.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 756, \"2ndFlrSF\": 378, \"LowQualFinSF\": 0, \"GrLivArea\": 1134, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 126000}, {\"Order\": 2048, \"PID\": 904302010, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 4484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 485.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2049, \"PID\": 905100060, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 176, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2050, \"PID\": 905100080, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 30.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 785.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1452, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 92, \"OpenPorchSF\": 0, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158450}, {\"Order\": 2051, \"PID\": 905101070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 14299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 144.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115400}, {\"Order\": 2052, \"PID\": 905101200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7943, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 192.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 903.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 126.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1029, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 261.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2053, \"PID\": 905102010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1964, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 68.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 722.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2054, \"PID\": 905103110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11677, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 249.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 761.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2055, \"PID\": 905104030, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 187.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 627.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 913, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 913, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2056, \"PID\": 905104090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 7094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 180.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 374.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2057, \"PID\": 905104170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8978, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 948.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 108000}, {\"Order\": 2058, \"PID\": 905104240, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1971, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 20.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2059, \"PID\": 905105040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 8665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 89.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 288.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 897, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2060, \"PID\": 905105170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8398, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 323.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 114.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 529.0, \"BsmtUnfSF\": 300.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2061, \"PID\": 905105260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7742, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 763.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 192.0, \"TotalBsmtSF\": 955.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 955, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 386.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2062, \"PID\": 905106150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 8724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2063, \"PID\": 905107140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 8197, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1285, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 138, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143500}, {\"Order\": 2064, \"PID\": 905200010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8169, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 435.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 315.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2065, \"PID\": 905201080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 386.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 522.0, \"BsmtUnfSF\": 332.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 323.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2066, \"PID\": 905225020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 99.0, \"LotArea\": 16779, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 356.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 267.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 404.0, \"TotalBsmtSF\": 671.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 1087, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 570, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2067, \"PID\": 905226050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25339, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1416, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2068, \"PID\": 905226080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 6960, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1940, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 798, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 1302, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 224.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165250}, {\"Order\": 2069, \"PID\": 905226130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 736.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 231.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 494.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 81, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2070, \"PID\": 905226170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13770, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 190.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 873.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 303.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"VWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2071, \"PID\": 905228020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 998, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 998, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89500}, {\"Order\": 2072, \"PID\": 905301050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 115149, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 351.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 424.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 739.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 380, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 302000}, {\"Order\": 2073, \"PID\": 905352010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11075, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 136.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 299.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 891.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1190.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1522, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2074, \"PID\": 905352180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 10029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 268.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 831.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 320.0, \"TotalBsmtSF\": 1151.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2060, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 228, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2075, \"PID\": 905376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 109.0, \"TotalBsmtSF\": 409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1325, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1325, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216000}, {\"Order\": 2076, \"PID\": 905377020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 22692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 587.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 486.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1630, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2077, \"PID\": 905377050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 17808, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 484.0, \"TotalBsmtSF\": 484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1242, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1242, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2078, \"PID\": 905401020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 12671, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2079, \"PID\": 905426010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 12615, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 477.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 725.0, \"TotalBsmtSF\": 1202.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 39, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 243000}, {\"Order\": 2080, \"PID\": 905451390, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 491.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 497.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 638, \"LowQualFinSF\": 0, \"GrLivArea\": 1626, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 332.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 366, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154000}, {\"Order\": 2081, \"PID\": 905475270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 411.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 399.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2082, \"PID\": 905475520, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11515, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2083, \"PID\": 905476160, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 7711, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1440.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 321, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2084, \"PID\": 905476170, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 348.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 605, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 605, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86000}, {\"Order\": 2085, \"PID\": 905476225, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 3869, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 283.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 755.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1038.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1038, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2086, \"PID\": 905478140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 9280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 557.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1342, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1342, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2087, \"PID\": 905478220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 11100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1080.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1080.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 400, \"LowQualFinSF\": 0, \"GrLivArea\": 1480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2088, \"PID\": 905480090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 951.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 986, \"2ndFlrSF\": 376, \"LowQualFinSF\": 0, \"GrLivArea\": 1362, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96000}, {\"Order\": 2089, \"PID\": 905480180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 98.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1340, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 116, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2090, \"PID\": 906200230, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 104.0, \"LotArea\": 23920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1105.0, \"TotalBsmtSF\": 1105.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1105, \"2ndFlrSF\": 717, \"LowQualFinSF\": 0, \"GrLivArea\": 1822, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 195, \"EnclosedPorch\": 1012, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 444, \"PoolQC\": \"TA\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2091, \"PID\": 906201022, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 10357, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 738.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1442, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1442, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 719.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 244, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2092, \"PID\": 906201023, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 116.0, \"LotArea\": 13474, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 1121, \"LowQualFinSF\": 0, \"GrLivArea\": 2243, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 44, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2093, \"PID\": 906201200, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 10380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 1474.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1553, \"2ndFlrSF\": 1177, \"LowQualFinSF\": 0, \"GrLivArea\": 2730, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 301000}, {\"Order\": 2094, \"PID\": 906203140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 48.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 634.0, \"BsmtUnfSF\": 422.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 1215, \"LowQualFinSF\": 0, \"GrLivArea\": 2127, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 833.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 192, \"EnclosedPorch\": 224, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2095, \"PID\": 906204140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 421.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 386.0, \"TotalBsmtSF\": 807.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1175, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1982, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 196, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2096, \"PID\": 906223040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 497.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 282.0, \"TotalBsmtSF\": 779.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1029, \"2ndFlrSF\": 929, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 499.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2097, \"PID\": 906340080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 220.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 984.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 1264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 1414, \"LowQualFinSF\": 0, \"GrLivArea\": 2696, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 184, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 383970}, {\"Order\": 2098, \"PID\": 906340090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9965, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 340.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1150.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 1362, \"LowQualFinSF\": 0, \"GrLivArea\": 2828, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1052.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 424870}, {\"Order\": 2099, \"PID\": 906378120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 250000}, {\"Order\": 2100, \"PID\": 906378150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 10481, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2140.0, \"TotalBsmtSF\": 2140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 360000}, {\"Order\": 2101, \"PID\": 906378170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10652, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1494.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 279500}, {\"Order\": 2102, \"PID\": 906380010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 11175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1316.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 200141}, {\"Order\": 2103, \"PID\": 906380040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 10235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 306.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1643.0, \"TotalBsmtSF\": 1643.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1651, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1651, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246500}, {\"Order\": 2104, \"PID\": 906380070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1482.0, \"TotalBsmtSF\": 1482.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 1092, \"LowQualFinSF\": 0, \"GrLivArea\": 2574, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 148, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 276000}, {\"Order\": 2105, \"PID\": 906380120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8814, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 925.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 349.0, \"TotalBsmtSF\": 1274.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1274, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1274, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203000}, {\"Order\": 2106, \"PID\": 906380140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11103, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155835}, {\"Order\": 2107, \"PID\": 906380160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8556, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1240.0, \"TotalBsmtSF\": 1240.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 826.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 93, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2108, \"PID\": 906380200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 544.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 195400}, {\"Order\": 2109, \"PID\": 906382020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 204.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1526.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1546, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1546, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2110, \"PID\": 906382060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1453.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 674.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 212999}, {\"Order\": 2111, \"PID\": 906392080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1270.0, \"TotalBsmtSF\": 1270.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1270, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1270, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 524.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2112, \"PID\": 906394020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 916, \"LowQualFinSF\": 0, \"GrLivArea\": 1795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 191000}, {\"Order\": 2113, \"PID\": 906394050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1314.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1314, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176432}, {\"Order\": 2114, \"PID\": 906402070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14364, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1065.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1157.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 882, \"LowQualFinSF\": 0, \"GrLivArea\": 2062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 60, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 154, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2115, \"PID\": 906403060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8883, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 360.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 608.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 321.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 946, \"2ndFlrSF\": 927, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2116, \"PID\": 906426060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 159000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 472.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 697.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1444, \"2ndFlrSF\": 700, \"LowQualFinSF\": 0, \"GrLivArea\": 2144, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 389.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277000}, {\"Order\": 2117, \"PID\": 906426195, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 53107, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 985.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1580.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 874, \"LowQualFinSF\": 0, \"GrLivArea\": 1953, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 231, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2118, \"PID\": 906475110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1966, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 568.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 1111, \"LowQualFinSF\": 0, \"GrLivArea\": 2087, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 168, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2119, \"PID\": 906475170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 155.0, \"LotArea\": 20064, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 51.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 915.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 966.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1743, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1743, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 646, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2120, \"PID\": 907125040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 472.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1022, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1022, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 747.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2121, \"PID\": 907125120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8775, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2122, \"PID\": 907130060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11249, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 334.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 544.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 177500}, {\"Order\": 2123, \"PID\": 907131060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 10021, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1997, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 635.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 646, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1308, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 497.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2124, \"PID\": 907131120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9531, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 706.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 794.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 914, \"LowQualFinSF\": 0, \"GrLivArea\": 1796, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2125, \"PID\": 907135050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2126, \"PID\": 907135080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 16561, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 548.0, \"TotalBsmtSF\": 1097.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 242.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147900}, {\"Order\": 2127, \"PID\": 907135180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 588.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 402.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123600}, {\"Order\": 2128, \"PID\": 907180040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9337, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 905, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1786, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 162, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204750}, {\"Order\": 2129, \"PID\": 907187040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 342.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 646.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 1873, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 597.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 202, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235500}, {\"Order\": 2130, \"PID\": 907187060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 12352, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 290.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 638.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 853, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1753, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 534.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2131, \"PID\": 907192020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9543, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 845.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 845, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 103, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190550}, {\"Order\": 2132, \"PID\": 907192040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8826, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 144.0, \"TotalBsmtSF\": 985.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 985, \"2ndFlrSF\": 857, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2133, \"PID\": 907192120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 167.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1013.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1479, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 558.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2134, \"PID\": 907192150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11317, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 840.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2135, \"PID\": 907200130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 97.0, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 131000}, {\"Order\": 2136, \"PID\": 907200190, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 8660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 113.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 502.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 513.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2137, \"PID\": 907200250, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Ex\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 240.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1009, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2138, \"PID\": 907200270, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 501.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134900}, {\"Order\": 2139, \"PID\": 907202100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 39.0, \"LotArea\": 16300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 417.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 876.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 907, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 907, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2140, \"PID\": 907202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 432.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Con\", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2141, \"PID\": 907203060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 138.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 468.0, \"BsmtUnfSF\": 276.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 882, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 882, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112500}, {\"Order\": 2142, \"PID\": 907203110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 10356, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 969.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 969, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 969, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2143, \"PID\": 907227060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 671.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 193.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Ex\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 155, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2144, \"PID\": 907227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 385.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 385.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 875, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 728.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2145, \"PID\": 907250050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10386, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 246.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 2000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 305900}, {\"Order\": 2146, \"PID\": 907252020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 149.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1284.0, \"TotalBsmtSF\": 1284.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1284, \"2ndFlrSF\": 885, \"LowQualFinSF\": 0, \"GrLivArea\": 2169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 647.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228500}, {\"Order\": 2147, \"PID\": 907252190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11354, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1412.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 261.0, \"TotalBsmtSF\": 1673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1673, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1673, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 116, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2148, \"PID\": 907260040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1459.0, \"TotalBsmtSF\": 1459.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1459, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1459, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192000}, {\"Order\": 2149, \"PID\": 907260050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8749, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 654.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 940, \"LowQualFinSF\": 0, \"GrLivArea\": 1932, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213000}, {\"Order\": 2150, \"PID\": 907262020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8158, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 214.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2151, \"PID\": 907270040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 16226, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 281.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 1242, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 683.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 267000}, {\"Order\": 2152, \"PID\": 907275080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 11927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 519.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 465.0, \"BsmtUnfSF\": 683.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1592, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1592, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2153, \"PID\": 907275150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 256.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1198.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 333.0, \"TotalBsmtSF\": 1531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1531, \"2ndFlrSF\": 908, \"LowQualFinSF\": 0, \"GrLivArea\": 2439, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2154, \"PID\": 907280090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15295, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 254.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 608.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 225, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 211000}, {\"Order\": 2155, \"PID\": 907280100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11248, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 567.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1668, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 702.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 257, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 285000}, {\"Order\": 2156, \"PID\": 907285040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 438.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1079.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 870, \"LowQualFinSF\": 0, \"GrLivArea\": 2090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 240000}, {\"Order\": 2157, \"PID\": 907290140, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 36.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 189.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131500}, {\"Order\": 2158, \"PID\": 907295040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 17227, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 158.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1341.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1341, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1341, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246900}, {\"Order\": 2159, \"PID\": 907401060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1081, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2160, \"PID\": 907405130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 699.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 1337.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2161, \"PID\": 907410020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 738, \"LowQualFinSF\": 0, \"GrLivArea\": 1476, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179400}, {\"Order\": 2162, \"PID\": 907410050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9245, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 939.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 939, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 639.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213500}, {\"Order\": 2163, \"PID\": 907414060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1422.0, \"TotalBsmtSF\": 1422.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 626.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179600}, {\"Order\": 2164, \"PID\": 907414070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8769, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 709.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 1169.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173500}, {\"Order\": 2165, \"PID\": 907420050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8334, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1330.0, \"TotalBsmtSF\": 1330.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1330, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167840}, {\"Order\": 2166, \"PID\": 907420060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 8333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 753, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168675}, {\"Order\": 2167, \"PID\": 907420110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 768, \"LowQualFinSF\": 0, \"GrLivArea\": 1536, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2168, \"PID\": 908102100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 698.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 96.0, \"BsmtUnfSF\": 420.0, \"TotalBsmtSF\": 1214.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1214, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 184, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2169, \"PID\": 908102160, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 162.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 405, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 450, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 118500}, {\"Order\": 2170, \"PID\": 908103090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 20.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 132.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 841.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1088, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1088, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2171, \"PID\": 908127040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 10921, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 48.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 520.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94750}, {\"Order\": 2172, \"PID\": 908127060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 16287, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 130.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 105.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 450, \"LowQualFinSF\": 0, \"GrLivArea\": 1351, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 43, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 122000}, {\"Order\": 2173, \"PID\": 908127070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1179.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1179, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1179, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 622.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2174, \"PID\": 908127100, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 11841, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 816.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2175, \"PID\": 908152060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6285, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 504.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1044, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1044, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2176, \"PID\": 908152070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 174.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 751.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1113, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1113, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 370, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2177, \"PID\": 908152180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9555, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 1133, \"LowQualFinSF\": 0, \"GrLivArea\": 2233, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2178, \"PID\": 908152260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1125.0, \"TotalBsmtSF\": 1125.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1125, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 155000}, {\"Order\": 2179, \"PID\": 908152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 110.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1090, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2180, \"PID\": 908152290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 611.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 123.0, \"TotalBsmtSF\": 734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 674, \"LowQualFinSF\": 0, \"GrLivArea\": 1408, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 489.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171500}, {\"Order\": 2181, \"PID\": 908154195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 128.0, \"LotArea\": 39290, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2008, \"YearRemod/Add\": 2009, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 4010.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 5095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 5095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 5095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 15, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2008.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1154.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 546, \"OpenPorchSF\": 484, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Elev\", \"MiscVal\": 17000, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 183850}, {\"Order\": 2182, \"PID\": 908154205, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 130.0, \"LotArea\": 40094, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"PosN\", \"Condition2\": \"PosN\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2008, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 762.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 2260.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 3138.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 3138, \"2ndFlrSF\": 1538, \"LowQualFinSF\": 0, \"GrLivArea\": 4676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 406, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 184750}, {\"Order\": 2183, \"PID\": 908186050, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 76.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 467.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 80.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2184, \"PID\": 908204090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1959, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 77.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 831.0, \"BsmtUnfSF\": 52.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131750}, {\"Order\": 2185, \"PID\": 908204180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 6882, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1152, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1152, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2186, \"PID\": 908225240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 492.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 248.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111000}, {\"Order\": 2187, \"PID\": 908225310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 8741, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1195.0, \"TotalBsmtSF\": 1195.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1195, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1195, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 118, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98500}, {\"Order\": 2188, \"PID\": 908226180, \"MSSubClass\": 30, \"MSZoning\": \"RH\", \"LotFrontage\": 70.0, \"LotArea\": 4270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 6, \"YearBuilt\": 1931, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 544.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 774, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 286, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2189, \"PID\": 908228010, \"MSSubClass\": 40, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10042, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 278.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 740, \"2ndFlrSF\": 125, \"LowQualFinSF\": 0, \"GrLivArea\": 865, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108500}, {\"Order\": 2190, \"PID\": 908250100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 552.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 110000}, {\"Order\": 2191, \"PID\": 908275090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1346, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2192, \"PID\": 908275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 544.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 355.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 196, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2193, \"PID\": 908275240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 682.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 182.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Family\", \"SalePrice\": 79275}, {\"Order\": 2194, \"PID\": 908276230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8190, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 948.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2195, \"PID\": 909176080, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 10896, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1184.0, \"TotalBsmtSF\": 1440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 1440, \"LowQualFinSF\": 515, \"GrLivArea\": 3395, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 8, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 14, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 200000}, {\"Order\": 2196, \"PID\": 909176170, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 371.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 925.0, \"TotalBsmtSF\": 1296.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 1296, \"LowQualFinSF\": 0, \"GrLivArea\": 2592, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 742, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 1512, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 150000}, {\"Order\": 2197, \"PID\": 909250150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10592, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 602.0, \"TotalBsmtSF\": 602.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 602, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 53, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2198, \"PID\": 909250160, \"MSSubClass\": 45, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10594, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 768.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 789, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 789, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96500}, {\"Order\": 2199, \"PID\": 909251030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7223, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 319.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 971.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1422, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 64, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2200, \"PID\": 909251040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6821, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 113.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 538.0, \"TotalBsmtSF\": 651.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 759, \"2ndFlrSF\": 539, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2201, \"PID\": 909252010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 569.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 731.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 981, \"2ndFlrSF\": 787, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 264, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175000}, {\"Order\": 2202, \"PID\": 909252150, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 4000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 246.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 531.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 567, \"2ndFlrSF\": 531, \"LowQualFinSF\": 0, \"GrLivArea\": 1098, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148500}, {\"Order\": 2203, \"PID\": 909252170, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 6720, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 585, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 228.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 141500}, {\"Order\": 2204, \"PID\": 909254090, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7642, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1918, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 912.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 514, \"LowQualFinSF\": 0, \"GrLivArea\": 1426, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 189950}, {\"Order\": 2205, \"PID\": 909254100, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7155, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 775, \"LowQualFinSF\": 0, \"GrLivArea\": 1461, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2206, \"PID\": 909254130, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 7128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 364.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 918.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 126, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2207, \"PID\": 909254140, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 4280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1913, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 365.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 34, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90350}, {\"Order\": 2208, \"PID\": 909254150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 5362, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 661.0, \"TotalBsmtSF\": 661.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 661, \"2ndFlrSF\": 589, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 242, \"OpenPorchSF\": 0, \"EnclosedPorch\": 81, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2209, \"PID\": 909256120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 920.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119750}, {\"Order\": 2210, \"PID\": 909275020, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 7136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 484.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 495.0, \"TotalBsmtSF\": 979.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 979, \"2ndFlrSF\": 979, \"LowQualFinSF\": 0, \"GrLivArea\": 1958, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2211, \"PID\": 909275030, \"MSSubClass\": 90, \"MSZoning\": \"RH\", \"LotFrontage\": 82.0, \"LotArea\": 6270, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 717.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 1001, \"LowQualFinSF\": 0, \"GrLivArea\": 2002, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 871.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2212, \"PID\": 909275110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1927, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 867, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 1718, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1927.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 291, \"OpenPorchSF\": 0, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 238000}, {\"Order\": 2213, \"PID\": 909275160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 126.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 24, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 228, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2214, \"PID\": 909275310, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 22420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1128.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 1370.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 2624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 864.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2215, \"PID\": 909276160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12168, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 537.0, \"TotalBsmtSF\": 965.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1940, \"2ndFlrSF\": 1254, \"LowQualFinSF\": 0, \"GrLivArea\": 3194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1934.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 359100}, {\"Order\": 2216, \"PID\": 909276210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 7810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 189.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1230, \"2ndFlrSF\": 525, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 231.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2217, \"PID\": 909279080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 480.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 557.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 854.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 895, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 19, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2218, \"PID\": 909281020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 6221, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 533.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 595, \"LowQualFinSF\": 0, \"GrLivArea\": 1355, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2219, \"PID\": 909281130, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10570, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 853.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1549, \"2ndFlrSF\": 1178, \"LowQualFinSF\": 0, \"GrLivArea\": 2727, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2220, \"PID\": 909282020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1945, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 774.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 150.0, \"BsmtUnfSF\": 104.0, \"TotalBsmtSF\": 1028.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1436, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 2320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 259500}, {\"Order\": 2221, \"PID\": 909425140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 14442, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 106.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1186.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 291.0, \"TotalBsmtSF\": 1477.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1839, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1839, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 416.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 87, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257500}, {\"Order\": 2222, \"PID\": 909425270, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 780, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 219500}, {\"Order\": 2223, \"PID\": 909428120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 35.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 869.0, \"BsmtUnfSF\": 905.0, \"TotalBsmtSF\": 1809.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2259, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2259, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 217000}, {\"Order\": 2224, \"PID\": 909428180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 25485, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 540.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1020.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 584, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201000}, {\"Order\": 2225, \"PID\": 909428340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21579, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 813.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 675.0, \"TotalBsmtSF\": 1488.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"CWD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2226, \"PID\": 909451130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 1782, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 330.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 516.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 529, \"2ndFlrSF\": 516, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123900}, {\"Order\": 2227, \"PID\": 909452102, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17871, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1680.0, \"TotalBsmtSF\": 1680.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1680, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1680, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2228, \"PID\": 909455060, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3907, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Blueste\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 577.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 509.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 135, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2229, \"PID\": 909475050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20693, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 652.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 434.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1262.0, \"TotalBsmtSF\": 1696.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1696, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1696, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 198000}, {\"Order\": 2230, \"PID\": 909475070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32668, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1957, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1219.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 2035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2515, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2515, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Maj1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 200624}, {\"Order\": 2231, \"PID\": 909475230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 18044, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 279.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2726, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 691.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 64, \"EnclosedPorch\": 169, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 228, \"PoolQC\": \"Ex\", \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2232, \"PID\": 910200040, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1919, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 793.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 997, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2233, \"PID\": 910200110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 375.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 345.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 1215, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 30, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2234, \"PID\": 910201020, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 116.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 604.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 803, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 244, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2235, \"PID\": 910201050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1601, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 176, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129850}, {\"Order\": 2236, \"PID\": 910201110, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 772, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1123, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 100000}, {\"Order\": 2237, \"PID\": 910201180, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1923, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 311.0, \"TotalBsmtSF\": 859.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 942, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1828, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": null, \"GarageArea\": null, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 174, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 150909}, {\"Order\": 2238, \"PID\": 910202030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 46.0, \"LotArea\": 3672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 100.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75200}, {\"Order\": 2239, \"PID\": 910203290, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 8263, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1012.0, \"TotalBsmtSF\": 1012.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 22, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118400}, {\"Order\": 2240, \"PID\": 910204090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 8967, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 2, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Po\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 961.0, \"TotalBsmtSF\": 961.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"Mix\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 338.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 67000}, {\"Order\": 2241, \"PID\": 910205130, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 13710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 420.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 910, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 1558, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 282.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 289, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 152000}, {\"Order\": 2242, \"PID\": 910206010, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 64.0, \"LotArea\": 11067, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 2, \"OverallCond\": 4, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 205, \"GrLivArea\": 845, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Maj2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 256.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68104}, {\"Order\": 2243, \"PID\": 911103060, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 75.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1895, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 957.0, \"TotalBsmtSF\": 957.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1034, \"2ndFlrSF\": 957, \"LowQualFinSF\": 0, \"GrLivArea\": 1991, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 133, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119600}, {\"Order\": 2244, \"PID\": 911128010, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 65.0, \"LotArea\": 6565, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 106.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 444, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2245, \"PID\": 911128020, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 6060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 9, \"YearBuilt\": 1930, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 737.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 837.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1001, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 0, \"EnclosedPorch\": 42, \"3SsnPorch\": 86, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124900}, {\"Order\": 2246, \"PID\": 911370450, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2247, \"PID\": 911370460, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 481.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 538.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 235000}, {\"Order\": 2248, \"PID\": 914452090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12150, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1001.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1001.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1299, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1299, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 486.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 84, \"OpenPorchSF\": 0, \"EnclosedPorch\": 222, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2249, \"PID\": 914452120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7540, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 115.0, \"TotalBsmtSF\": 888.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2250, \"PID\": 914452190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9187, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 336.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 748.0, \"TotalBsmtSF\": 1084.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1080, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 158, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2251, \"PID\": 914460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 585.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 856.0, \"TotalBsmtSF\": 1441.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1392, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2252, \"PID\": 914460110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 12864, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 17.0, \"TotalBsmtSF\": 1409.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1409, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1409, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 145, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 245000}, {\"Order\": 2253, \"PID\": 914476330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9928, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1239.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 215.0, \"TotalBsmtSF\": 1454.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1478, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1478, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2254, \"PID\": 914478020, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 224.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 530.0, \"BsmtUnfSF\": 98.0, \"TotalBsmtSF\": 852.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 918, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 918, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2255, \"PID\": 914478100, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 924.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1026, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1026, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 193, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2256, \"PID\": 916226090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 46.0, \"LotArea\": 4054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 352.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 949.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1501.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1501, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 244000}, {\"Order\": 2257, \"PID\": 916253320, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 9763, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 239.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1102.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 328.0, \"TotalBsmtSF\": 1502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1502, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1502, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 330000}, {\"Order\": 2258, \"PID\": 916326040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 115.0, \"LotArea\": 16905, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 967.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1350.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1328, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 104, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2259, \"PID\": 916326090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 149.0, \"LotArea\": 19958, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1958, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1224.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 585.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2279, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2279, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 274, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2260, \"PID\": 916384050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1689.0, \"TotalBsmtSF\": 1689.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1689, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1689, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 231713}, {\"Order\": 2261, \"PID\": 916384070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8298, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 583.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 963.0, \"TotalBsmtSF\": 1546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1564, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1564, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2207.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 267300}, {\"Order\": 2262, \"PID\": 916384080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 9037, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 32.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 428.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1048.0, \"TotalBsmtSF\": 1476.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1484, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1484, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 265900}, {\"Order\": 2263, \"PID\": 916384150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10991, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1571.0, \"TotalBsmtSF\": 1571.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1571, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1571, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239000}, {\"Order\": 2264, \"PID\": 916386170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10656, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 274.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1638.0, \"TotalBsmtSF\": 1638.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2007.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 248900}, {\"Order\": 2265, \"PID\": 916403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 215.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 80.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 1265.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1240, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1240, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 232, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2266, \"PID\": 916403290, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 902.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 254.0, \"TotalBsmtSF\": 1156.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1187, \"2ndFlrSF\": 530, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2267, \"PID\": 916455010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9303, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 42.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 742.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 888, \"2ndFlrSF\": 868, \"LowQualFinSF\": 0, \"GrLivArea\": 1756, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 122, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 204000}, {\"Order\": 2268, \"PID\": 916455050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6718, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 86.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 250.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1017.0, \"TotalBsmtSF\": 1267.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1312, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180500}, {\"Order\": 2269, \"PID\": 916455110, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 442.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 82.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2270, \"PID\": 916455150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11305, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 886.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 593.0, \"TotalBsmtSF\": 1922.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1922, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1922, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 692.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282000}, {\"Order\": 2271, \"PID\": 916460020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 571.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2272, \"PID\": 916475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14536, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1629, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1629, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 808.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 252, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2273, \"PID\": 916477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 766.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 1122.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 1340, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279900}, {\"Order\": 2274, \"PID\": 917425190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 35133, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 226.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1572.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1572, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1572, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 995.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 263, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 263, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 186700}, {\"Order\": 2275, \"PID\": 921126010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 15306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 100.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 80.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1652.0, \"TotalBsmtSF\": 1732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1776, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 712.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 283463}, {\"Order\": 2276, \"PID\": 921128030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 12633, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"PosA\", \"Condition2\": \"PosA\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1824.0, \"TotalBsmtSF\": 1824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1824, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1824, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 932.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 108, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 392000}, {\"Order\": 2277, \"PID\": 921205070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 245.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1094.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1133, \"2ndFlrSF\": 1349, \"LowQualFinSF\": 0, \"GrLivArea\": 2482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 281213}, {\"Order\": 2278, \"PID\": 923202134, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8402, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2007, \"YearRemod/Add\": 2007, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 914.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1120, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 147000}, {\"Order\": 2279, \"PID\": 923202220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 200.0, \"LotArea\": 43500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2034, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2034, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 4.0, \"GarageArea\": 1041.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 483, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 561, \"PoolQC\": \"TA\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2280, \"PID\": 923203010, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 6710, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 134.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 904.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 920.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2281, \"PID\": 923204050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 25286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 633.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 431.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132250}, {\"Order\": 2282, \"PID\": 923204140, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 25000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1632.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1632, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2283, \"PID\": 923205025, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 32463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 149.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1159.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 90.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1622, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1622, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 1356.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 439, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2284, \"PID\": 923225040, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 840.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1060, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 110, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2285, \"PID\": 923225050, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 4224, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 874.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 536, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2286, \"PID\": 923226300, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1504, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2287, \"PID\": 923228200, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 27.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 462, \"LowQualFinSF\": 0, \"GrLivArea\": 992, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 97, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 106500}, {\"Order\": 2288, \"PID\": 923228220, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1495, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 189.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 162.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93900}, {\"Order\": 2289, \"PID\": 923228250, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 2001, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 75000}, {\"Order\": 2290, \"PID\": 923228290, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 131.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 499.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2291, \"PID\": 923228390, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 75190}, {\"Order\": 2292, \"PID\": 923229010, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11333, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 539.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1029.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1062, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1062, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146800}, {\"Order\": 2293, \"PID\": 923229040, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 9129, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 923.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 923.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 678.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2294, \"PID\": 923229100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15957, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 96.0, \"TotalBsmtSF\": 1244.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1356, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1356, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 1424, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2295, \"PID\": 923229140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 33983, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1112.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1676, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1676, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 690, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2296, \"PID\": 923230010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8286, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 531.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 185.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 716, \"2ndFlrSF\": 716, \"LowQualFinSF\": 0, \"GrLivArea\": 1432, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 531.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 240, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2297, \"PID\": 923230120, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 6723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 796, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 796, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 129, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138000}, {\"Order\": 2298, \"PID\": 923230180, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7244, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 149.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 768, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2299, \"PID\": 923251160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 124.0, \"LotArea\": 27697, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"CBlock\", \"MasVnrArea\": 198.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 811.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 585.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1608, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 444.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 152, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2007, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2300, \"PID\": 923252080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7599, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1982, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 280.0, \"TotalBsmtSF\": 845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 845, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 845, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2301, \"PID\": 923275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1976, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1090.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1178, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1178, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 88, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2302, \"PID\": 923275200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1982, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 270.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1982.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2303, \"PID\": 923276180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11625, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 596.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 220.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 330, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2304, \"PID\": 923400150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 10712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 212.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 762.0, \"TotalBsmtSF\": 974.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 974, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 974, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2007, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 93500}, {\"Order\": 2305, \"PID\": 923425030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 887, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2007, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124500}, {\"Order\": 2306, \"PID\": 526302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11027, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 28.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 539.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 1178.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1293, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1293, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 452.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2307, \"PID\": 526302040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 235.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 313.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 280, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2308, \"PID\": 526302120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11765, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 302.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1127.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 1617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1797, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1797, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 963.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2309, \"PID\": 526303060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 39384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 902.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 595.0, \"TotalBsmtSF\": 1705.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 252000}, {\"Order\": 2310, \"PID\": 526354020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11727, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 434.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1851.0, \"TotalBsmtSF\": 1851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1851, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1851, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 146, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192100}, {\"Order\": 2311, \"PID\": 527105060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8238, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 113.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 813, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2312, \"PID\": 527106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 285.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 964.0, \"TotalBsmtSF\": 964.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 993, \"2ndFlrSF\": 1243, \"LowQualFinSF\": 0, \"GrLivArea\": 2236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2313, \"PID\": 527107020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 781, \"2ndFlrSF\": 890, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 423.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2314, \"PID\": 527107030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13031, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 592.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 691, \"2ndFlrSF\": 807, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 409.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 315, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187500}, {\"Order\": 2315, \"PID\": 527107120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9783, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 821.0, \"TotalBsmtSF\": 821.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 821, \"2ndFlrSF\": 955, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 443.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 286, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2316, \"PID\": 527107240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 11207, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 714.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 802.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 802, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 413.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 95, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185000}, {\"Order\": 2317, \"PID\": 527108010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 19378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 456.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1335.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1070, \"LowQualFinSF\": 0, \"GrLivArea\": 2462, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 239, \"OpenPorchSF\": 132, \"EnclosedPorch\": 0, \"3SsnPorch\": 168, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2318, \"PID\": 527108020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 14859, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 27.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1670.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 690.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 240000}, {\"Order\": 2319, \"PID\": 527108030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 13128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 216.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1074.0, \"TotalBsmtSF\": 1074.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 990, \"LowQualFinSF\": 0, \"GrLivArea\": 2064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 527.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 119, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2320, \"PID\": 527108040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10463, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 893.0, \"TotalBsmtSF\": 893.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 900, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 800.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239900}, {\"Order\": 2321, \"PID\": 527108060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 13751, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 60.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1640.0, \"TotalBsmtSF\": 1700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 512, \"LowQualFinSF\": 0, \"GrLivArea\": 2212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 773.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 309000}, {\"Order\": 2322, \"PID\": 527108090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 168.0, \"LotArea\": 23257, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 868.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 887, \"2ndFlrSF\": 1134, \"LowQualFinSF\": 0, \"GrLivArea\": 2021, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 422.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 274725}, {\"Order\": 2323, \"PID\": 527146135, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 13108, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 2062.0, \"TotalBsmtSF\": 2062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2079, \"2ndFlrSF\": 608, \"LowQualFinSF\": 0, \"GrLivArea\": 2687, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 618.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2324, \"PID\": 527158020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8076, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 705.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1169, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1169, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183500}, {\"Order\": 2325, \"PID\": 527163020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 518.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 179.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 697, \"2ndFlrSF\": 804, \"LowQualFinSF\": 0, \"GrLivArea\": 1501, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 63, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165600}, {\"Order\": 2326, \"PID\": 527166030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 935.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 955, \"2ndFlrSF\": 677, \"LowQualFinSF\": 0, \"GrLivArea\": 1632, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176500}, {\"Order\": 2327, \"PID\": 527182020, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 3701, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1191.0, \"TotalBsmtSF\": 1191.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1204, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1204, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2328, \"PID\": 527190050, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 44.0, \"LotArea\": 5306, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 495.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 215.0, \"BsmtUnfSF\": 354.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 703, \"LowQualFinSF\": 0, \"GrLivArea\": 1767, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 441, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2329, \"PID\": 527190220, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 6563, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1148.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 594.0, \"TotalBsmtSF\": 1742.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1742, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1742, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 114, \"OpenPorchSF\": 28, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2330, \"PID\": 527210030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 16023, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 600.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Ex\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1218.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 180.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 1384, \"LowQualFinSF\": 0, \"GrLivArea\": 2798, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 37, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 457347}, {\"Order\": 2331, \"PID\": 527210040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 18062, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 662.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1528.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1528, \"2ndFlrSF\": 1862, \"LowQualFinSF\": 0, \"GrLivArea\": 3390, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 545224}, {\"Order\": 2332, \"PID\": 527210050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 12292, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 205.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 889.0, \"TotalBsmtSF\": 1094.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 1371, \"LowQualFinSF\": 0, \"GrLivArea\": 2473, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 246, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 356383}, {\"Order\": 2333, \"PID\": 527212030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 16056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 240.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1752.0, \"TotalBsmtSF\": 1992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1992, \"2ndFlrSF\": 876, \"LowQualFinSF\": 0, \"GrLivArea\": 2868, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 716.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 214, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 556581}, {\"Order\": 2334, \"PID\": 527212040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 466.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1234.0, \"TotalBsmtSF\": 1234.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1264, \"2ndFlrSF\": 1312, \"LowQualFinSF\": 0, \"GrLivArea\": 2576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 666.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 324, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 361919}, {\"Order\": 2335, \"PID\": 527214060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 16052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 734.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1206.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1850.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 2698, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 250, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 535000}, {\"Order\": 2336, \"PID\": 527216010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 15922, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 550.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 1405, \"LowQualFinSF\": 0, \"GrLivArea\": 2795, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 401179}, {\"Order\": 2337, \"PID\": 527216050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 13682, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1031.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1410.0, \"TotalBsmtSF\": 1410.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 1519, \"LowQualFinSF\": 0, \"GrLivArea\": 2945, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 641.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 37, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 438780}, {\"Order\": 2338, \"PID\": 527226010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1547, \"2ndFlrSF\": 720, \"LowQualFinSF\": 53, \"GrLivArea\": 2320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2339, \"PID\": 527250040, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 34650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2340, \"PID\": 527252090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8147, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 230.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1191.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 523.0, \"TotalBsmtSF\": 1714.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1714, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1714, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 517.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 156, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 318000}, {\"Order\": 2341, \"PID\": 527254070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11302, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Other\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 238.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1422.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 1814.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1826, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 758.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 319000}, {\"Order\": 2342, \"PID\": 527256120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 18261, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"StoneBr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 722.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 123, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 470000}, {\"Order\": 2343, \"PID\": 527301010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 14145, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1984, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 213.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 995.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1621, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1621, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2344, \"PID\": 527302080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13837, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1002.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 202.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1204.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1377, \"2ndFlrSF\": 806, \"LowQualFinSF\": 0, \"GrLivArea\": 2183, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 786.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2345, \"PID\": 527325160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 34.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 795.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1468, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 250, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2346, \"PID\": 527327080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 84.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 790, \"2ndFlrSF\": 784, \"LowQualFinSF\": 0, \"GrLivArea\": 1574, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 306, \"OpenPorchSF\": 111, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2347, \"PID\": 527328010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10464, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 130.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 850.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1102, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1102, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 582.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 22, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2348, \"PID\": 527354040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1988, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 102.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 929.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 916.0, \"TotalBsmtSF\": 1845.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1988.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 604.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 241500}, {\"Order\": 2349, \"PID\": 527355060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 912, \"LowQualFinSF\": 0, \"GrLivArea\": 1857, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 482.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188900}, {\"Order\": 2350, \"PID\": 527355280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 157.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 625.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 1061.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 384, \"OpenPorchSF\": 131, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2351, \"PID\": 527356020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16692, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 184.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 790.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 469.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1392.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1392, \"LowQualFinSF\": 0, \"GrLivArea\": 2784, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 440, \"PoolArea\": 519, \"PoolQC\": \"Fa\", \"Fence\": \"MnPrv\", \"MiscFeature\": \"TenC\", \"MiscVal\": 2000, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2352, \"PID\": 527356060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11475, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 550.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 163.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 811, \"2ndFlrSF\": 741, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 208, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2353, \"PID\": 527358090, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 252.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1005.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 42.0, \"TotalBsmtSF\": 1047.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1083, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1083, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 596.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 444, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2354, \"PID\": 527365010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 75.0, \"LotArea\": 9512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 172.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 1358, \"LowQualFinSF\": 0, \"GrLivArea\": 2318, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 246, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294323}, {\"Order\": 2355, \"PID\": 527375160, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 248.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 127.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1109, \"2ndFlrSF\": 766, \"LowQualFinSF\": 0, \"GrLivArea\": 1875, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 485.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 48, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184500}, {\"Order\": 2356, \"PID\": 527376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 788.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1074, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1074, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2357, \"PID\": 527376110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 638.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 259, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162900}, {\"Order\": 2358, \"PID\": 527377030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 377.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1309, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1309, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 265, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 648, \"PoolQC\": \"Fa\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2359, \"PID\": 527378010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 755.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 348.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2360, \"PID\": 527402210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 15870, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 75.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 791.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1096.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1096, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 138800}, {\"Order\": 2361, \"PID\": 527402380, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9353, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"Oth\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 116050}, {\"Order\": 2362, \"PID\": 527403120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 614.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 244.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 858, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 88000}, {\"Order\": 2363, \"PID\": 527404180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 620.0, \"BsmtUnfSF\": 224.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 63, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97500}, {\"Order\": 2364, \"PID\": 527427210, \"MSSubClass\": 120, \"MSZoning\": \"RH\", \"LotFrontage\": 26.0, \"LotArea\": 8773, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 951.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 536.0, \"TotalBsmtSF\": 1487.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1419, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1419, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 543.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2365, \"PID\": 527450010, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 514.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 525.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105500}, {\"Order\": 2366, \"PID\": 527450080, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2160, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 402.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 765.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 765, \"2ndFlrSF\": 600, \"LowQualFinSF\": 0, \"GrLivArea\": 1365, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2367, \"PID\": 527450210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1953, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 408.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 309.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 174.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 72, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 83000}, {\"Order\": 2368, \"PID\": 527450460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 282.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 212.0, \"TotalBsmtSF\": 494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 494, \"2ndFlrSF\": 536, \"LowQualFinSF\": 0, \"GrLivArea\": 1030, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2369, \"PID\": 527451200, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 201, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 91500}, {\"Order\": 2370, \"PID\": 527451380, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 281.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 317.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 355.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1218, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118000}, {\"Order\": 2371, \"PID\": 527451450, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 465, \"LowQualFinSF\": 0, \"GrLivArea\": 948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2372, \"PID\": 527451460, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 504.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 382.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 525, \"2ndFlrSF\": 567, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 352, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2373, \"PID\": 527451520, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrDale\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 297.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 483.0, \"TotalBsmtSF\": 483.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 483, \"2ndFlrSF\": 504, \"LowQualFinSF\": 0, \"GrLivArea\": 987, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 94500}, {\"Order\": 2374, \"PID\": 527452070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4043, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 727.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 156.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 1069.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1069, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1069, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146300}, {\"Order\": 2375, \"PID\": 527452290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7514, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 373.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 108.0, \"BsmtUnfSF\": 462.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1387, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1387, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2376, \"PID\": 527452310, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 7838, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 769.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 95.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 900, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 900, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 175, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123000}, {\"Order\": 2377, \"PID\": 527453070, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2280, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 120.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 492.0, \"BsmtUnfSF\": 443.0, \"TotalBsmtSF\": 1055.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1055, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2378, \"PID\": 527455100, \"MSSubClass\": 160, \"MSZoning\": \"RL\", \"LotFrontage\": 24.0, \"LotArea\": 2179, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NPkVill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Brk Cmn\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 70.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 785.0, \"TotalBsmtSF\": 855.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 855, \"2ndFlrSF\": 601, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2379, \"PID\": 528102010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 129.0, \"LotArea\": 16737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 66.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1447.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 533.0, \"TotalBsmtSF\": 1980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1980, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 770.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2380, \"PID\": 528102080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 16387, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 215.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1738, \"2ndFlrSF\": 851, \"LowQualFinSF\": 0, \"GrLivArea\": 2589, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 831.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 412083}, {\"Order\": 2381, \"PID\": 528106010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 111.0, \"LotArea\": 16259, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 370.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1249.0, \"TotalBsmtSF\": 1249.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1249, \"2ndFlrSF\": 1347, \"LowQualFinSF\": 0, \"GrLivArea\": 2596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 342643}, {\"Order\": 2382, \"PID\": 528106120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 110.0, \"LotArea\": 16163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1618.0, \"TotalBsmtSF\": 1618.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1618, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1618, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 252000}, {\"Order\": 2383, \"PID\": 528110050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 107.0, \"LotArea\": 13891, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1386.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 690.0, \"TotalBsmtSF\": 2076.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2076, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2076, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 850.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 229, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 465000}, {\"Order\": 2384, \"PID\": 528112010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 12228, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 206.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1721.0, \"TotalBsmtSF\": 1721.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1740, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1740, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 293000}, {\"Order\": 2385, \"PID\": 528114010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 14780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 568.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1868, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1868, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1085.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 354, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 156, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2386, \"PID\": 528116030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 98.0, \"LotArea\": 16033, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1261.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 1833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1850, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1850, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 772.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 519, \"OpenPorchSF\": 112, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 326000}, {\"Order\": 2387, \"PID\": 528118010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 101.0, \"LotArea\": 14215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 380.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1158.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 1218, \"LowQualFinSF\": 0, \"GrLivArea\": 2376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 853.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 325300}, {\"Order\": 2388, \"PID\": 528118020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 108.0, \"LotArea\": 13418, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 132.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1117.0, \"TotalBsmtSF\": 1117.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1132, \"2ndFlrSF\": 1320, \"LowQualFinSF\": 0, \"GrLivArea\": 2452, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 691.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 113, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 309000}, {\"Order\": 2389, \"PID\": 528118110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 13975, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 525.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1090.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1117, \"2ndFlrSF\": 1089, \"LowQualFinSF\": 0, \"GrLivArea\": 2206, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 670.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 300000}, {\"Order\": 2390, \"PID\": 528120110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1030.0, \"TotalBsmtSF\": 1030.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1038, \"2ndFlrSF\": 1060, \"LowQualFinSF\": 0, \"GrLivArea\": 2098, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 878.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 52, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275500}, {\"Order\": 2391, \"PID\": 528120140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9942, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 385.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1290.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 316.0, \"TotalBsmtSF\": 1606.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 466, \"LowQualFinSF\": 0, \"GrLivArea\": 2091, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 194, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 338500}, {\"Order\": 2392, \"PID\": 528138030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 11924, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 286.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 998.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 177.0, \"TotalBsmtSF\": 1175.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1182, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2324, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 345000}, {\"Order\": 2393, \"PID\": 528142010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 103.0, \"LotArea\": 12867, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1209.0, \"TotalBsmtSF\": 1209.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1209, \"2ndFlrSF\": 1044, \"LowQualFinSF\": 0, \"GrLivArea\": 2253, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 243, \"OpenPorchSF\": 142, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 344133}, {\"Order\": 2394, \"PID\": 528142060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 10672, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1054.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1054, \"2ndFlrSF\": 1335, \"LowQualFinSF\": 0, \"GrLivArea\": 2389, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 298236}, {\"Order\": 2395, \"PID\": 528142070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11643, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 142.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 880.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 644.0, \"TotalBsmtSF\": 1524.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1544, \"2ndFlrSF\": 814, \"LowQualFinSF\": 0, \"GrLivArea\": 2358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 329900}, {\"Order\": 2396, \"PID\": 528142110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 12378, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 622.0, \"TotalBsmtSF\": 1896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1944, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1944, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 708.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 175, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 360000}, {\"Order\": 2397, \"PID\": 528144030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11065, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 788.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1085.0, \"TotalBsmtSF\": 1085.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1120, \"2ndFlrSF\": 850, \"LowQualFinSF\": 0, \"GrLivArea\": 1970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 753.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 281000}, {\"Order\": 2398, \"PID\": 528150080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 13758, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 430.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1232.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 560.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 925.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 204, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 372397}, {\"Order\": 2399, \"PID\": 528150090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 131.0, \"LotArea\": 14828, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 674.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1383.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 1780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1780, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1780, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 816.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 378000}, {\"Order\": 2400, \"PID\": 528164040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 11846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 562.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1567.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 225.0, \"TotalBsmtSF\": 1792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1792, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1792, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 874.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 206, \"OpenPorchSF\": 49, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 374000}, {\"Order\": 2401, \"PID\": 528170040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 20431, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 870.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1410.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 438.0, \"TotalBsmtSF\": 1848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1848, \"2ndFlrSF\": 880, \"LowQualFinSF\": 0, \"GrLivArea\": 2728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 706.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 437154}, {\"Order\": 2402, \"PID\": 528172020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 10927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 280.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 546.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 512.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1904, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 736.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 179, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2403, \"PID\": 528172150, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13215, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 994.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1420.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1426, \"2ndFlrSF\": 488, \"LowQualFinSF\": 0, \"GrLivArea\": 1914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 746.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 127, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 279000}, {\"Order\": 2404, \"PID\": 528174080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 705.0, \"TotalBsmtSF\": 1364.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 185850}, {\"Order\": 2405, \"PID\": 528180080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 5911, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 278.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 472.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1088.0, \"TotalBsmtSF\": 1560.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 556.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 196, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 282500}, {\"Order\": 2406, \"PID\": 528181030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6955, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202500}, {\"Order\": 2407, \"PID\": 528181040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 6792, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 94.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1368.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 132, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 202665}, {\"Order\": 2408, \"PID\": 528186100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 61.0, \"LotArea\": 7740, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 518.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 663.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1686, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 899.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 266, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 332200}, {\"Order\": 2409, \"PID\": 528186110, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 48.0, \"LotArea\": 6373, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 572.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1251.0, \"TotalBsmtSF\": 1666.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1666, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1666, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 310090}, {\"Order\": 2410, \"PID\": 528188040, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NridgHt\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 163.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1405.0, \"TotalBsmtSF\": 1405.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1405, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1405, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 478.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 171750}, {\"Order\": 2411, \"PID\": 528218030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 28.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1316.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1316, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1316, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 397.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 23, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169990}, {\"Order\": 2412, \"PID\": 528218060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 170440}, {\"Order\": 2413, \"PID\": 528218080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 10237, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 169985}, {\"Order\": 2414, \"PID\": 528218130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 17104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 664, \"2ndFlrSF\": 832, \"LowQualFinSF\": 0, \"GrLivArea\": 1496, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 426.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 179665}, {\"Order\": 2415, \"PID\": 528218140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 14054, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 879.0, \"TotalBsmtSF\": 879.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 1863, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 17, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 219210}, {\"Order\": 2416, \"PID\": 528221010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 11660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1326.0, \"TotalBsmtSF\": 1326.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1326, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1326, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 427.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 174190}, {\"Order\": 2417, \"PID\": 528221100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 15578, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 172785}, {\"Order\": 2418, \"PID\": 528222010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11631, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 236.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1052.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 1321, \"LowQualFinSF\": 0, \"GrLivArea\": 2373, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 258000}, {\"Order\": 2419, \"PID\": 528222020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9073, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 738, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1492, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185101}, {\"Order\": 2420, \"PID\": 528228280, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3087, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 453.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 767.0, \"TotalBsmtSF\": 1220.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 437.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 16, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 210250}, {\"Order\": 2421, \"PID\": 528228325, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1374.0, \"TotalBsmtSF\": 1374.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1557, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1557, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 234000}, {\"Order\": 2422, \"PID\": 528228340, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3196, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1273.0, \"TotalBsmtSF\": 1273.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1456, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2423, \"PID\": 528228360, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 2938, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1038.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 330.0, \"TotalBsmtSF\": 1368.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1511, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1511, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 130, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 246990}, {\"Order\": 2424, \"PID\": 528228415, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1375.0, \"TotalBsmtSF\": 1375.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1414, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178740}, {\"Order\": 2425, \"PID\": 528228430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 3072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 18.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1059.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 306.0, \"TotalBsmtSF\": 1365.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1548, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1548, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 388.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2426, \"PID\": 528228545, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 16.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1232.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 438.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 108, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 167240}, {\"Order\": 2427, \"PID\": 528228550, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 14.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1126.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 90, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 156820}, {\"Order\": 2428, \"PID\": 528228565, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 3013, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1346.0, \"TotalBsmtSF\": 1362.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1506, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1506, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 213490}, {\"Order\": 2429, \"PID\": 528228575, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 3982, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1154.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 366.0, \"TotalBsmtSF\": 1520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1567, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1567, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 312, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 264561}, {\"Order\": 2430, \"PID\": 528228580, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 53.0, \"LotArea\": 4045, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Blmngtn\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 45.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1070.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1356.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1500, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 648.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 246578}, {\"Order\": 2431, \"PID\": 528231050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 21930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 732.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 734, \"2ndFlrSF\": 1104, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 372.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192140}, {\"Order\": 2432, \"PID\": 528235050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7861, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 457.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183200}, {\"Order\": 2433, \"PID\": 528235130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9056, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 707.0, \"TotalBsmtSF\": 707.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 707, \"2ndFlrSF\": 707, \"LowQualFinSF\": 0, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2434, \"PID\": 528235190, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 59.0, \"LotArea\": 9171, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1598, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 433.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 201490}, {\"Order\": 2435, \"PID\": 528240080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 106.0, \"LotArea\": 11194, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 40.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1406.0, \"TotalBsmtSF\": 1406.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1454, \"2ndFlrSF\": 482, \"LowQualFinSF\": 0, \"GrLivArea\": 1936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230500}, {\"Order\": 2436, \"PID\": 528250060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 7875, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 783.0, \"TotalBsmtSF\": 783.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 807, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1509, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 393.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2437, \"PID\": 528275060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8121, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 953.0, \"TotalBsmtSF\": 953.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 953, \"2ndFlrSF\": 711, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 460.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172400}, {\"Order\": 2438, \"PID\": 528275080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 732.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 250.0, \"TotalBsmtSF\": 982.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 881, \"LowQualFinSF\": 0, \"GrLivArea\": 1889, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2439, \"PID\": 528280100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11214, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 930.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 956, \"2ndFlrSF\": 930, \"LowQualFinSF\": 0, \"GrLivArea\": 1886, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 431.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 89, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199900}, {\"Order\": 2440, \"PID\": 528290140, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10852, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 786.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 173.0, \"TotalBsmtSF\": 959.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 712, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 173000}, {\"Order\": 2441, \"PID\": 528292080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12104, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1035.0, \"TotalBsmtSF\": 1035.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1082, \"2ndFlrSF\": 1240, \"LowQualFinSF\": 0, \"GrLivArea\": 2322, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 617.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 400, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 287602}, {\"Order\": 2442, \"PID\": 528294070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 8738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Gilbert\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 302.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 975.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 1286, \"LowQualFinSF\": 0, \"GrLivArea\": 2291, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 429.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2443, \"PID\": 528315030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9452, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 423.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1074.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 322.0, \"TotalBsmtSF\": 1396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1407, \"2ndFlrSF\": 985, \"LowQualFinSF\": 0, \"GrLivArea\": 2392, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 870.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 348000}, {\"Order\": 2444, \"PID\": 528315070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 9660, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 242.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 791.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 1044.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 897, \"LowQualFinSF\": 0, \"GrLivArea\": 1976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 885.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 210, \"OpenPorchSF\": 31, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 286000}, {\"Order\": 2445, \"PID\": 528315080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 9545, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 322.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 505.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 655.0, \"TotalBsmtSF\": 1160.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1205, \"2ndFlrSF\": 1029, \"LowQualFinSF\": 0, \"GrLivArea\": 2234, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 768.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2446, \"PID\": 528320060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 35760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 10, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1378.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 543.0, \"TotalBsmtSF\": 1930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1831, \"2ndFlrSF\": 1796, \"LowQualFinSF\": 0, \"GrLivArea\": 3627, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 807.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 361, \"OpenPorchSF\": 76, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 625000}, {\"Order\": 2447, \"PID\": 528327010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9233, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 877.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1182.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 358.0, \"TotalBsmtSF\": 1540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1540, \"2ndFlrSF\": 1315, \"LowQualFinSF\": 0, \"GrLivArea\": 2855, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 774.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 247, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 405000}, {\"Order\": 2448, \"PID\": 528344060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 12011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 530.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 956.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 130.0, \"TotalBsmtSF\": 1086.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 838, \"LowQualFinSF\": 0, \"GrLivArea\": 1924, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 592.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 374, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2449, \"PID\": 528348010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 93.0, \"LotArea\": 12090, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 650.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1165, \"2ndFlrSF\": 1098, \"LowQualFinSF\": 0, \"GrLivArea\": 2263, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 123, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 258000}, {\"Order\": 2450, \"PID\": 528358030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 397.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 527.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1342.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 1368, \"LowQualFinSF\": 0, \"GrLivArea\": 2726, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 725.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 169, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 350000}, {\"Order\": 2451, \"PID\": 528360050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 17242, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 738.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 292.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1393.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1733.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1933, \"2ndFlrSF\": 1567, \"LowQualFinSF\": 0, \"GrLivArea\": 3500, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 959.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 870, \"OpenPorchSF\": 86, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 584500}, {\"Order\": 2452, \"PID\": 528363070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 501.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 168.0, \"BsmtUnfSF\": 742.0, \"TotalBsmtSF\": 1290.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1305, \"2ndFlrSF\": 1189, \"LowQualFinSF\": 0, \"GrLivArea\": 2494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 803.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 95, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 321000}, {\"Order\": 2453, \"PID\": 528365090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 10120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 391.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 740.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 425.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1203, \"2ndFlrSF\": 1323, \"LowQualFinSF\": 0, \"GrLivArea\": 2526, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 844.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 309, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 290000}, {\"Order\": 2454, \"PID\": 528366040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1039.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 1234, \"LowQualFinSF\": 0, \"GrLivArea\": 2799, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 704.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 432, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 315000}, {\"Order\": 2455, \"PID\": 528429060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 12447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 192.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1116, \"2ndFlrSF\": 848, \"LowQualFinSF\": 0, \"GrLivArea\": 1964, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 760.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 252000}, {\"Order\": 2456, \"PID\": 528429100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 15218, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1562.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 1670.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1670, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1670, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 200, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 336820}, {\"Order\": 2457, \"PID\": 528429120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 49.0, \"LotArea\": 20896, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1721.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 356.0, \"TotalBsmtSF\": 2077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2097, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 1134.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 267, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 423000}, {\"Order\": 2458, \"PID\": 528429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10182, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"RRNn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 420.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1220.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 1660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1660, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1660, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 500.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 322, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 290000}, {\"Order\": 2459, \"PID\": 528439030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8688, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 228.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1616.0, \"TotalBsmtSF\": 1616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 834.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 232000}, {\"Order\": 2460, \"PID\": 528445010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 10936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1504.0, \"TotalBsmtSF\": 1504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1504, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1504, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 510.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 199000}, {\"Order\": 2461, \"PID\": 528456200, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1254.0, \"TotalBsmtSF\": 1278.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1278, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 584.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198600}, {\"Order\": 2462, \"PID\": 528477010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 100.0, \"LotArea\": 13162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 2036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2036, \"2ndFlrSF\": 604, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 11, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 792.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 265, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 405749}, {\"Order\": 2463, \"PID\": 528477030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 81.0, \"LotArea\": 11216, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1489.0, \"TotalBsmtSF\": 1489.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1489, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1489, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 232600}, {\"Order\": 2464, \"PID\": 528480070, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 84.0, \"LotArea\": 10728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 844, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1053.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 266000}, {\"Order\": 2465, \"PID\": 528480100, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 756.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 756, \"2ndFlrSF\": 797, \"LowQualFinSF\": 0, \"GrLivArea\": 1553, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186500}, {\"Order\": 2466, \"PID\": 528480110, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 858.0, \"TotalBsmtSF\": 858.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 858, \"2ndFlrSF\": 858, \"LowQualFinSF\": 0, \"GrLivArea\": 1716, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 615.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200825}, {\"Order\": 2467, \"PID\": 528480150, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 65.0, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 770.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 778, \"2ndFlrSF\": 798, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 614.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 197000}, {\"Order\": 2468, \"PID\": 528488110, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 905.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 357.0, \"TotalBsmtSF\": 1262.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1262, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1262, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 185000}, {\"Order\": 2469, \"PID\": 528488120, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 62.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1257.0, \"TotalBsmtSF\": 1257.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1266, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1266, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 38, \"OpenPorchSF\": 144, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2470, \"PID\": 528488130, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1293.0, \"TotalBsmtSF\": 1293.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1301, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 121, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 187750}, {\"Order\": 2471, \"PID\": 531363080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7733, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1118.0, \"TotalBsmtSF\": 1142.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1142, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1142, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 4, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2472, \"PID\": 531367010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 11024, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 118.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1400.0, \"TotalBsmtSF\": 1400.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1400, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 612.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 186800}, {\"Order\": 2473, \"PID\": 531375060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1131.0, \"TotalBsmtSF\": 1131.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1131, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1131, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 39, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 132000}, {\"Order\": 2474, \"PID\": 531375070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1141.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2475, \"PID\": 531375100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 13072, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 941.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 217.0, \"TotalBsmtSF\": 1158.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1158, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1158, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 158000}, {\"Order\": 2476, \"PID\": 531376030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 172.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 891.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 891, \"2ndFlrSF\": 795, \"LowQualFinSF\": 0, \"GrLivArea\": 1686, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 101, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184000}, {\"Order\": 2477, \"PID\": 531376050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7632, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 96.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 831, \"2ndFlrSF\": 754, \"LowQualFinSF\": 0, \"GrLivArea\": 1585, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 449.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 77, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 184900}, {\"Order\": 2478, \"PID\": 531379030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8304, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 941.0, \"TotalBsmtSF\": 941.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1837, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 688.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 165, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2479, \"PID\": 531450040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 7153, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 387.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 374.0, \"TotalBsmtSF\": 761.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 793, \"LowQualFinSF\": 0, \"GrLivArea\": 1603, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 124, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 175900}, {\"Order\": 2480, \"PID\": 531451290, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 78.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 887, \"LowQualFinSF\": 0, \"GrLivArea\": 1731, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 307, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 224, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Othr\", \"MiscVal\": 3000, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 248500}, {\"Order\": 2481, \"PID\": 531452080, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 904.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 494.0, \"TotalBsmtSF\": 1398.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1398, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1398, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 542.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 46, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2482, \"PID\": 531452100, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 278.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 939.0, \"TotalBsmtSF\": 1217.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1217, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1217, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2483, \"PID\": 531452210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9019, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 362.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 636, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2484, \"PID\": 531478010, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 8900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1056.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 107000}, {\"Order\": 2485, \"PID\": 531479030, \"MSSubClass\": 20, \"MSZoning\": \"RH\", \"LotFrontage\": 60.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 187.0, \"TotalBsmtSF\": 828.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 965, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 965, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 421, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2486, \"PID\": 532351060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 36.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 952.0, \"TotalBsmtSF\": 988.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129500}, {\"Order\": 2487, \"PID\": 532351090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 336.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1332.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2488, \"PID\": 532351150, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 68.0, \"LotArea\": 8927, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1286, \"2ndFlrSF\": 368, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2489, \"PID\": 532353030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1211, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1211, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2490, \"PID\": 532353180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 8471, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1977, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 46.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 506.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 506.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1212, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1212, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 292, \"OpenPorchSF\": 12, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2491, \"PID\": 532376080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9308, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRNe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 554.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 310.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126000}, {\"Order\": 2492, \"PID\": 532376180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 162.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 270.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 882.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 909, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 155, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2493, \"PID\": 532376250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8638, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"RRAe\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 181.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 744.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 925, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 74, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2494, \"PID\": 532378050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13052, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 712.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1024, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120875}, {\"Order\": 2495, \"PID\": 532378070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 114.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 560.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 375.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 935.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 935, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 935, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 180, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2496, \"PID\": 532378130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 644.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 268.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2497, \"PID\": 532378160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6993, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1961, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 465.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 447.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2498, \"PID\": 532378220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8789, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 659.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 253.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 941, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 941, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 64, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129200}, {\"Order\": 2499, \"PID\": 532476050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 14330, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1023.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 497.0, \"BsmtUnfSF\": 228.0, \"TotalBsmtSF\": 1748.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2151, \"2ndFlrSF\": 495, \"LowQualFinSF\": 0, \"GrLivArea\": 2646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Mod\", \"Fireplaces\": 4, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 641, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 800, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2500, \"PID\": 533110130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 121.0, \"LotArea\": 16059, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1991, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 284.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1288.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1301, \"2ndFlrSF\": 1116, \"LowQualFinSF\": 0, \"GrLivArea\": 2417, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1991.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 127, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2501, \"PID\": 533125120, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 105.0, \"LotArea\": 11025, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 692.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1118.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1520, \"2ndFlrSF\": 1306, \"LowQualFinSF\": 0, \"GrLivArea\": 2826, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 888.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 177, \"OpenPorchSF\": 208, \"EnclosedPorch\": 186, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 334000}, {\"Order\": 2502, \"PID\": 533127080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14541, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1012.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 326.0, \"TotalBsmtSF\": 1338.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 1168, \"LowQualFinSF\": 0, \"GrLivArea\": 2520, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 209, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 310000}, {\"Order\": 2503, \"PID\": 533128030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13346, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 728.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 367.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1166, \"2ndFlrSF\": 1129, \"LowQualFinSF\": 0, \"GrLivArea\": 2295, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 590.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268000}, {\"Order\": 2504, \"PID\": 533128090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 12461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NoRidge\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1994, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"ImStucc\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 757.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 114, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262000}, {\"Order\": 2505, \"PID\": 533206040, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 34.0, \"LotArea\": 3628, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1143.0, \"TotalBsmtSF\": 1143.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1143, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1143, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 191, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176400}, {\"Order\": 2506, \"PID\": 533208050, \"MSSubClass\": 120, \"MSZoning\": \"FV\", \"LotFrontage\": 37.0, \"LotArea\": 3316, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1039.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 208.0, \"TotalBsmtSF\": 1247.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1247, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1247, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 550.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2507, \"PID\": 533212100, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151000}, {\"Order\": 2508, \"PID\": 533212110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147400}, {\"Order\": 2509, \"PID\": 533212120, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 24.0, \"LotArea\": 2544, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 623, \"LowQualFinSF\": 80, \"GrLivArea\": 1223, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2510, \"PID\": 533212130, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 30.0, \"LotArea\": 3180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 600, \"LowQualFinSF\": 80, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 144152}, {\"Order\": 2511, \"PID\": 533221080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2998, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 513.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 353.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 403.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 768, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1524, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 166000}, {\"Order\": 2512, \"PID\": 533223010, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": 35.0, \"LotArea\": 3735, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 218.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 450.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 241.0, \"TotalBsmtSF\": 691.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1452, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183900}, {\"Order\": 2513, \"PID\": 533223080, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 2651, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 641.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 673.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 673, \"2ndFlrSF\": 709, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 153, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2514, \"PID\": 533223110, \"MSSubClass\": 160, \"MSZoning\": \"FV\", \"LotFrontage\": null, \"LotArea\": 4447, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 530.0, \"TotalBsmtSF\": 530.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 530, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1080, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 496.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 50, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2515, \"PID\": 533241010, \"MSSubClass\": 60, \"MSZoning\": \"FV\", \"LotFrontage\": 114.0, \"LotArea\": 8314, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 569.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 854, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1694, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 382, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 110, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2516, \"PID\": 533242030, \"MSSubClass\": 20, \"MSZoning\": \"FV\", \"LotFrontage\": 60.0, \"LotArea\": 7180, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Somerst\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1568.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1568, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1568, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 266, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 221000}, {\"Order\": 2517, \"PID\": 533250130, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 30.0, \"LotArea\": 9549, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1057.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1494.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 481.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 216, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 270000}, {\"Order\": 2518, \"PID\": 533252020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 767.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2519, \"PID\": 533253030, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 3760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1009.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 182.0, \"BsmtUnfSF\": 44.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2520, \"PID\": 533253050, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 36.0, \"LotArea\": 3640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 860.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 176.0, \"TotalBsmtSF\": 1036.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1036, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1036, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}, {\"Order\": 2521, \"PID\": 533253090, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3874, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 807.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 419.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2522, \"PID\": 533253160, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": 40.0, \"LotArea\": 3876, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Greens\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 652.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 526.0, \"BsmtUnfSF\": 48.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1226, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 133, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2523, \"PID\": 533350050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 50271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Veenker\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 1981, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1810.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 32.0, \"TotalBsmtSF\": 1842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1842, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1842, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 1, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 894.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 857, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 385000}, {\"Order\": 2524, \"PID\": 534125210, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 13110, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 962.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 191.0, \"TotalBsmtSF\": 1153.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1193, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1193, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 501.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 153, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2525, \"PID\": 534126060, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 10192, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 143.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 570.0, \"TotalBsmtSF\": 570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1222, \"2ndFlrSF\": 698, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2526, \"PID\": 534127190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 297.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 1203.0, \"TotalBsmtSF\": 1568.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2156, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2156, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 508.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 290, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 262500}, {\"Order\": 2527, \"PID\": 534127270, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 420.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 404.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 304.0, \"TotalBsmtSF\": 708.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 708, \"2ndFlrSF\": 708, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 776.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 169, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 119, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 179900}, {\"Order\": 2528, \"PID\": 534128210, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11029, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 220.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 619.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 435.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1512, \"2ndFlrSF\": 1142, \"LowQualFinSF\": 0, \"GrLivArea\": 2654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 619.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 222, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2529, \"PID\": 534129230, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 288.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 247.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 732.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 778, \"LowQualFinSF\": 0, \"GrLivArea\": 1790, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 2, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 148, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 147, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165150}, {\"Order\": 2530, \"PID\": 534175100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10140, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 68.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 1334.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1334, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1334, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 477.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 35, \"3SsnPorch\": 0, \"ScreenPorch\": 264, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164500}, {\"Order\": 2531, \"PID\": 534176250, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1164.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1164, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2532, \"PID\": 534201130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 400.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 480.0, \"BsmtUnfSF\": 100.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2533, \"PID\": 534201230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2534, \"PID\": 534201250, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 8640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 300.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 361.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 483.0, \"BsmtUnfSF\": 56.0, \"TotalBsmtSF\": 900.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1770, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 270, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 455, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2535, \"PID\": 534201260, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9360, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 94, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 157500}, {\"Order\": 2536, \"PID\": 534201280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 168.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1016.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1052, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1052, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 356, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138500}, {\"Order\": 2537, \"PID\": 534201300, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 744.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 89.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 898, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 898, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 143, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2538, \"PID\": 534202020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9759, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 252.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1051, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1051, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124400}, {\"Order\": 2539, \"PID\": 534202180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 402.0, \"BsmtUnfSF\": 137.0, \"TotalBsmtSF\": 1141.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1141, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1141, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 568.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2540, \"PID\": 534226060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 71.0, \"LotArea\": 9230, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1965, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 166.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 661.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 203.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 884.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2541, \"PID\": 534250300, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14803, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NWAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1971, \"YearRemod/Add\": 1971, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 252.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 409.0, \"TotalBsmtSF\": 825.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1097, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 1993, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1971.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2542, \"PID\": 534275010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10659, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 135.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 368.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 319, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 136500}, {\"Order\": 2543, \"PID\": 534276010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 521.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 174.0, \"BsmtUnfSF\": 169.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2544, \"PID\": 534276230, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 122.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 528.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1098.0, \"TotalBsmtSF\": 1626.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1712, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1712, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 272, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 145000}, {\"Order\": 2545, \"PID\": 534400120, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1965, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 901.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 252.0, \"BsmtUnfSF\": 34.0, \"TotalBsmtSF\": 1187.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1565, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1565, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 25, \"EnclosedPorch\": 211, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 460, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 185900}, {\"Order\": 2546, \"PID\": 534403280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 8800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 425.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 698.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1251, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1251, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 461.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 116, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2547, \"PID\": 534403400, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10368, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 112.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 260.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 748.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 154, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 167000}, {\"Order\": 2548, \"PID\": 534403440, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 9350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 360.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 720, \"2ndFlrSF\": 720, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2549, \"PID\": 534427090, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10382, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 105.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 513.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 75.0, \"TotalBsmtSF\": 588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1095, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2550, \"PID\": 534428060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 8973, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1958, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 567.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 28.0, \"BsmtUnfSF\": 413.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1053, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1053, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 750.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 180, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 150000}, {\"Order\": 2551, \"PID\": 534429130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 88.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 632.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 1248.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1248, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151500}, {\"Order\": 2552, \"PID\": 534430050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 574.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 242.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 228, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129800}, {\"Order\": 2553, \"PID\": 534430110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11425, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2554, \"PID\": 534431030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9724, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1043, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1043, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1947.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 273.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2555, \"PID\": 534451050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 4712, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1946, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 363.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 456, \"LowQualFinSF\": 0, \"GrLivArea\": 1230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1946.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 63, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 121600}, {\"Order\": 2556, \"PID\": 534451120, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 5900, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1923, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 440.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 869, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 869, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85500}, {\"Order\": 2557, \"PID\": 534451130, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 52.0, \"LotArea\": 5825, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 108.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 600.0, \"TotalBsmtSF\": 600.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 747, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 747, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79900}, {\"Order\": 2558, \"PID\": 534453150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 7438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1908, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 504.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 316, \"LowQualFinSF\": 0, \"GrLivArea\": 1252, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2559, \"PID\": 534455080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 915.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 336.0, \"TotalBsmtSF\": 1251.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1433, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1433, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 0, \"EnclosedPorch\": 205, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 161000}, {\"Order\": 2560, \"PID\": 534475160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10858, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 150.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 40.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1404.0, \"TotalBsmtSF\": 1444.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1624, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1624, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 324, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Partial\", \"SalePrice\": 146500}, {\"Order\": 2561, \"PID\": 534476100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 144.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 60.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2562, \"PID\": 534477030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 10680, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 44.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 756.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1380.0, \"TotalBsmtSF\": 2136.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 2136, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2136, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137900}, {\"Order\": 2563, \"PID\": 534479130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9490, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 403.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 165.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 958, \"2ndFlrSF\": 620, \"LowQualFinSF\": 0, \"GrLivArea\": 1578, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2564, \"PID\": 534479240, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9462, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1949, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 704.0, \"TotalBsmtSF\": 704.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1024, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 234.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 245, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2565, \"PID\": 534479300, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 9888, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1954, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 486.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 936, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2566, \"PID\": 535101110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8917, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1584.0, \"TotalBsmtSF\": 1584.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1584, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1584, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2567, \"PID\": 535103070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 12700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 939.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 307.0, \"TotalBsmtSF\": 1246.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1246, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1246, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 69, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172000}, {\"Order\": 2568, \"PID\": 535105160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 8500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 635.0, \"TotalBsmtSF\": 1235.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1235, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1235, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 480.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 98600}, {\"Order\": 2569, \"PID\": 535125060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 14200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 309.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 445.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 479.0, \"TotalBsmtSF\": 924.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 2157, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 487.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 226000}, {\"Order\": 2570, \"PID\": 535150240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 124.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1128, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1128, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 118000}, {\"Order\": 2571, \"PID\": 535150300, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 174.0, \"LotArea\": 25419, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 4, \"YearBuilt\": 1918, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1036.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 184.0, \"BsmtUnfSF\": 140.0, \"TotalBsmtSF\": 1360.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 1360, \"LowQualFinSF\": 392, \"GrLivArea\": 3112, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1918.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 16, \"EnclosedPorch\": 552, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 512, \"PoolQC\": \"Ex\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 235000}, {\"Order\": 2572, \"PID\": 535151080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 109.0, \"LotArea\": 9723, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 332.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 430.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2573, \"PID\": 535151130, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7728, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 803.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 303.0, \"TotalBsmtSF\": 1106.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1190, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1190, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 18, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2574, \"PID\": 535152070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8163, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 128.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 748.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 1144.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1144, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1144, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 796.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 86, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 143000}, {\"Order\": 2575, \"PID\": 535152280, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 623.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 556.0, \"TotalBsmtSF\": 1179.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1364, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1364, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 331.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2576, \"PID\": 535176050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 175.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 565.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 1383.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1383, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1383, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 292.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145250}, {\"Order\": 2577, \"PID\": 535177100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9610, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 632.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 203.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 918.0, \"TotalBsmtSF\": 1121.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 488.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 162000}, {\"Order\": 2578, \"PID\": 535178100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 125.0, \"LotArea\": 10000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 272.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 678.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 281.0, \"BsmtUnfSF\": 99.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1370, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1370, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Basment\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 191, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2579, \"PID\": 535179050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 14850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 895.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 197.0, \"TotalBsmtSF\": 1092.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1092, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 299.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 268, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 122, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnWw\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2580, \"PID\": 535180020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10152, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 914.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 210.0, \"TotalBsmtSF\": 1124.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 353.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 211, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 142, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153000}, {\"Order\": 2581, \"PID\": 535180070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10011, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 64.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 710.0, \"TotalBsmtSF\": 1070.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1236, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1236, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 447.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134450}, {\"Order\": 2582, \"PID\": 535301010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7032, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 943.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 943.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 943, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 943, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 600.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 42, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135960}, {\"Order\": 2583, \"PID\": 535301150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8092, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 176.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 824.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 226.0, \"TotalBsmtSF\": 1050.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1050, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1050, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 156000}, {\"Order\": 2584, \"PID\": 535303050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1367.0, \"TotalBsmtSF\": 1367.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1375, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1375, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2585, \"PID\": 535304020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 12778, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 658.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 350.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 154, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139500}, {\"Order\": 2586, \"PID\": 535305120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 10170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 522.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1575, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2587, \"PID\": 535325130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 7700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 271.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 301.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1145, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1145, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 684.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2588, \"PID\": 535325340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 11050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 1956, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 488.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 517.0, \"TotalBsmtSF\": 1005.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1005, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1005, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 288, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133500}, {\"Order\": 2589, \"PID\": 535325350, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 144.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 912.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1056.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1056, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1056, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 650, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2590, \"PID\": 535325450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 15428, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 741.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 143.0, \"TotalBsmtSF\": 884.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 884, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 884, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 195, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142000}, {\"Order\": 2591, \"PID\": 535325460, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 21299, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 929.0, \"TotalBsmtSF\": 929.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2039, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2039, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 791.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2592, \"PID\": 535327210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 13300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1956, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 494.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 521.0, \"TotalBsmtSF\": 1015.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1384, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1384, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 896.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 75, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 323, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2593, \"PID\": 535353180, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 94.0, \"LotArea\": 22136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1018.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1153.0, \"TotalBsmtSF\": 2171.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1392, \"2ndFlrSF\": 1248, \"LowQualFinSF\": 0, \"GrLivArea\": 2640, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 1008.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 631, \"OpenPorchSF\": 48, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2594, \"PID\": 535354130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 900, \"2ndFlrSF\": 412, \"LowQualFinSF\": 0, \"GrLivArea\": 1312, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 649.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2595, \"PID\": 535355100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 617.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 617.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 865, \"2ndFlrSF\": 445, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 398.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 126, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2596, \"PID\": 535375040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 713.0, \"TotalBsmtSF\": 713.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 713, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 713, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 371.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 75, \"EnclosedPorch\": 161, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 99800}, {\"Order\": 2597, \"PID\": 535376090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1954, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 415.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 418.0, \"TotalBsmtSF\": 833.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 833, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 833, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2598, \"PID\": 535376100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 5400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1921, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1073.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 326.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108480}, {\"Order\": 2599, \"PID\": 535377070, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10914, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 715.0, \"TotalBsmtSF\": 715.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 715, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 715, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 75, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 68000}, {\"Order\": 2600, \"PID\": 535377100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7008, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 448.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 448, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 86900}, {\"Order\": 2601, \"PID\": 535379100, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 821.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 1120.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1130, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1130, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 720.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 229, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2602, \"PID\": 535380010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Ex\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 325.0, \"TotalBsmtSF\": 663.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 774, \"2ndFlrSF\": 821, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 49, \"OpenPorchSF\": 0, \"EnclosedPorch\": 231, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155500}, {\"Order\": 2603, \"PID\": 535380130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10818, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1077.0, \"TotalBsmtSF\": 1077.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 981, \"2ndFlrSF\": 779, \"LowQualFinSF\": 0, \"GrLivArea\": 1760, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1935.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 648.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 80000}, {\"Order\": 2604, \"PID\": 535381060, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10410, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 694, \"2ndFlrSF\": 520, \"LowQualFinSF\": 0, \"GrLivArea\": 1214, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 936.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 216, \"OpenPorchSF\": 0, \"EnclosedPorch\": 160, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 105000}, {\"Order\": 2605, \"PID\": 535382020, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 664.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 290.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1766, \"2ndFlrSF\": 648, \"LowQualFinSF\": 0, \"GrLivArea\": 2414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 520.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2606, \"PID\": 535382130, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1936, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 626.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1096, \"2ndFlrSF\": 370, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 566.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 436, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2607, \"PID\": 535401140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 8658, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1965, \"YearRemod/Add\": 1965, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 101.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 643.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 445.0, \"TotalBsmtSF\": 1088.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1324, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 138, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 160000}, {\"Order\": 2608, \"PID\": 535402070, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 13400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 1047.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 516.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 128.0, \"BsmtUnfSF\": 380.0, \"TotalBsmtSF\": 1024.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1086, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1086, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159950}, {\"Order\": 2609, \"PID\": 535402100, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 83.0, \"LotArea\": 10184, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 379.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 580.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 503.0, \"TotalBsmtSF\": 1083.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1146, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1146, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 294.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 345, \"OpenPorchSF\": 75, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2610, \"PID\": 535402220, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1962, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 600.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 312.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1085, \"2ndFlrSF\": 649, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 128, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2611, \"PID\": 535402230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 9510, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 161.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 701.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1135.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1207, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1207, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 240, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147000}, {\"Order\": 2612, \"PID\": 535403040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 312.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 600.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 912, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2613, \"PID\": 535403150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 8910, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 655.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1194, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1194, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 539.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 192, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159500}, {\"Order\": 2614, \"PID\": 535403200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7332, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 207.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 414.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 120000}, {\"Order\": 2615, \"PID\": 535404080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 7100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 708.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129900}, {\"Order\": 2616, \"PID\": 535425040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1961, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 104.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 913.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 400.0, \"TotalBsmtSF\": 1313.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1773, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1773, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 355, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 144, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 183000}, {\"Order\": 2617, \"PID\": 535425050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosA\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 58.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1472, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1472, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 227, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2618, \"PID\": 535425080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 18275, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1962, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 636.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 802.0, \"TotalBsmtSF\": 1438.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1900, \"2ndFlrSF\": 548, \"LowQualFinSF\": 0, \"GrLivArea\": 2448, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 441.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 520, \"OpenPorchSF\": 102, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 277500}, {\"Order\": 2619, \"PID\": 535426195, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 47.0, \"LotArea\": 16321, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1957, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 1277.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 207.0, \"TotalBsmtSF\": 1484.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 319.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 258, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207500}, {\"Order\": 2620, \"PID\": 535450100, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 12144, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 455.0, \"TotalBsmtSF\": 910.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 910, \"2ndFlrSF\": 611, \"LowQualFinSF\": 0, \"GrLivArea\": 1521, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 597.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 0, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 147500}, {\"Order\": 2621, \"PID\": 535450180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 720.0, \"TotalBsmtSF\": 720.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 720, \"2ndFlrSF\": 472, \"LowQualFinSF\": 0, \"GrLivArea\": 1192, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 135000}, {\"Order\": 2622, \"PID\": 535451190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 625.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109500}, {\"Order\": 2623, \"PID\": 535451210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109900}, {\"Order\": 2624, \"PID\": 535453160, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 369.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 1040.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 252, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133700}, {\"Order\": 2625, \"PID\": 535454030, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81400}, {\"Order\": 2626, \"PID\": 535454050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 340.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"Wall\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87500}, {\"Order\": 2627, \"PID\": 535454060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8544, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1949.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2628, \"PID\": 535456010, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8512, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1960, \"YearRemod/Add\": 1960, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1556.0, \"TotalBsmtSF\": 1556.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1556, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1556, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119000}, {\"Order\": 2629, \"PID\": 535456020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7945, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 179.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 506.0, \"BsmtUnfSF\": 465.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 141000}, {\"Order\": 2630, \"PID\": 535457070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1961, \"YearRemod/Add\": 1961, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 781.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 369.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1150, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1961.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 162, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2631, \"PID\": 535477060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 7590, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 266.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 512.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 148.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 660, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1348, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 453.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2632, \"PID\": 535478010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 10205, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 784.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 141.0, \"TotalBsmtSF\": 925.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 999, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 999, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 150, \"OpenPorchSF\": 72, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134500}, {\"Order\": 2633, \"PID\": 535478070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 809.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 236.0, \"TotalBsmtSF\": 1045.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1045, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1045, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2634, \"PID\": 535478090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2635, \"PID\": 535478110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"NAmes\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 953.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 72.0, \"TotalBsmtSF\": 1025.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1025, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1025, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 124000}, {\"Order\": 2636, \"PID\": 902100110, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 62.0, \"LotArea\": 9856, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 716.0, \"TotalBsmtSF\": 716.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1007, \"2ndFlrSF\": 1007, \"LowQualFinSF\": 0, \"GrLivArea\": 2014, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1900.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 167, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 169000}, {\"Order\": 2637, \"PID\": 902100130, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 57.0, \"LotArea\": 9906, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 518, \"LowQualFinSF\": 0, \"GrLivArea\": 1328, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 172, \"EnclosedPorch\": 60, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 107000}, {\"Order\": 2638, \"PID\": 902101050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 264.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 276.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 1212.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 442, \"LowQualFinSF\": 0, \"GrLivArea\": 1668, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 140, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2639, \"PID\": 902103090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 5520, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 284.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 863.0, \"TotalBsmtSF\": 1147.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1147, \"2ndFlrSF\": 510, \"LowQualFinSF\": 0, \"GrLivArea\": 1657, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 162.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2640, \"PID\": 902104020, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1900, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 381.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 399.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 940, \"2ndFlrSF\": 476, \"LowQualFinSF\": 0, \"GrLivArea\": 1416, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2641, \"PID\": 902106040, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 16.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 712.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 832, \"2ndFlrSF\": 809, \"LowQualFinSF\": 0, \"GrLivArea\": 1641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 546.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 234, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 178000}, {\"Order\": 2642, \"PID\": 902106090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6451, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1900, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Stone\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 208.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 712.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 580, \"LowQualFinSF\": 0, \"GrLivArea\": 1428, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 84, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139900}, {\"Order\": 2643, \"PID\": 902108060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 66.0, \"LotArea\": 3960, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 502.0, \"TotalBsmtSF\": 502.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 502, \"2ndFlrSF\": 502, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 280, \"OpenPorchSF\": 0, \"EnclosedPorch\": 68, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2644, \"PID\": 902109010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 5684, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1930, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 813.0, \"TotalBsmtSF\": 813.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 813, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 813, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 113, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2645, \"PID\": 902110120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7745, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 938.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1084, \"2ndFlrSF\": 867, \"LowQualFinSF\": 0, \"GrLivArea\": 1951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 6, \"EnclosedPorch\": 28, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2646, \"PID\": 902110130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 7741, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 143.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 72.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 1032.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 108000}, {\"Order\": 2647, \"PID\": 902111010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5633, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 844.0, \"TotalBsmtSF\": 844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 844, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 50, \"OpenPorchSF\": 81, \"EnclosedPorch\": 123, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 111500}, {\"Order\": 2648, \"PID\": 902125020, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1880, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 636.0, \"TotalBsmtSF\": 636.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1089, \"2ndFlrSF\": 661, \"LowQualFinSF\": 0, \"GrLivArea\": 1750, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 293, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 124000}, {\"Order\": 2649, \"PID\": 902128020, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 576.0, \"TotalBsmtSF\": 576.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 115, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2650, \"PID\": 902128100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 40.0, \"LotArea\": 4400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 648.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 734, \"2ndFlrSF\": 384, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2651, \"PID\": 902134060, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 7614, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1905, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 738.0, \"TotalBsmtSF\": 738.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 714, \"2ndFlrSF\": 662, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 104, \"3SsnPorch\": 0, \"ScreenPorch\": 225, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 96900}, {\"Order\": 2652, \"PID\": 902204060, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 384.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135500}, {\"Order\": 2653, \"PID\": 902204120, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 145.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1566, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 24, \"OpenPorchSF\": 0, \"EnclosedPorch\": 296, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2654, \"PID\": 902206020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 7830, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 416.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 76.0, \"TotalBsmtSF\": 492.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 492, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 492, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 200.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 78, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 61500}, {\"Order\": 2655, \"PID\": 902206090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 56.0, \"LotArea\": 9576, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 310.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 460.0, \"TotalBsmtSF\": 770.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 885, \"2ndFlrSF\": 297, \"LowQualFinSF\": 0, \"GrLivArea\": 1182, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 378.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 120000}, {\"Order\": 2656, \"PID\": 902207080, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 49.0, \"LotArea\": 5820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 256.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 906.0, \"TotalBsmtSF\": 1162.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1163, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1163, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 220.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 142, \"OpenPorchSF\": 98, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126175}, {\"Order\": 2657, \"PID\": 902207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 48.0, \"LotArea\": 5747, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 798.0, \"TotalBsmtSF\": 798.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 840, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 250.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 64000}, {\"Order\": 2658, \"PID\": 902301120, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 69.0, \"LotArea\": 9142, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"Stone\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 908, \"2ndFlrSF\": 1020, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"Po\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 60, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2659, \"PID\": 902305090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 2, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1095.0, \"TotalBsmtSF\": 1095.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1095, \"2ndFlrSF\": 679, \"LowQualFinSF\": 0, \"GrLivArea\": 1774, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 779.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 90, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 87000}, {\"Order\": 2660, \"PID\": 902325050, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1914, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 390.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 490.0, \"TotalBsmtSF\": 880.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 888, \"LowQualFinSF\": 0, \"GrLivArea\": 1768, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 320.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 163000}, {\"Order\": 2661, \"PID\": 902325100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 70.0, \"LotArea\": 6300, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1226.0, \"TotalBsmtSF\": 1226.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1226, \"2ndFlrSF\": 878, \"LowQualFinSF\": 0, \"GrLivArea\": 2104, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 341, \"EnclosedPorch\": 88, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2662, \"PID\": 902325160, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 63.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1900, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 540.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 889, \"2ndFlrSF\": 551, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 352.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 77, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79000}, {\"Order\": 2663, \"PID\": 902328100, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 8850, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 815.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 815, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 1690, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1916.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 330, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"ConLw\", \"SaleCondition\": \"Normal\", \"SalePrice\": 144000}, {\"Order\": 2664, \"PID\": 902329070, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 3600, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 684.0, \"TotalBsmtSF\": 684.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 684, \"2ndFlrSF\": 684, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 158, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114504}, {\"Order\": 2665, \"PID\": 902329090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 998, \"2ndFlrSF\": 764, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 0, \"EnclosedPorch\": 221, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2666, \"PID\": 902400090, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 84.0, \"LotArea\": 11340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1923, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1200.0, \"TotalBsmtSF\": 1200.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1200, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1200, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1923.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 125000}, {\"Order\": 2667, \"PID\": 902400110, \"MSSubClass\": 75, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 22950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 10, \"OverallCond\": 9, \"YearBuilt\": 1892, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1107.0, \"TotalBsmtSF\": 1107.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1518, \"2ndFlrSF\": 1518, \"LowQualFinSF\": 572, \"GrLivArea\": 3608, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 12, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 840.0, \"GarageQual\": \"Ex\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 260, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 410, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 475000}, {\"Order\": 2668, \"PID\": 902401090, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 33.0, \"LotArea\": 5976, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 624, \"2ndFlrSF\": 624, \"LowQualFinSF\": 0, \"GrLivArea\": 1248, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 256, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93500}, {\"Order\": 2669, \"PID\": 902406030, \"MSSubClass\": 20, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 960.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 624.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Gar2\", \"MiscVal\": 4500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2670, \"PID\": 902456015, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 63.0, \"LotArea\": 4761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 3, \"OverallCond\": 3, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1020.0, \"TotalBsmtSF\": 1020.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseP\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1020, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 105, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 64500}, {\"Order\": 2671, \"PID\": 903200050, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7446, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 266.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 522.0, \"TotalBsmtSF\": 788.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 788, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 788, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 100000}, {\"Order\": 2672, \"PID\": 903202120, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 6435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 972.0, \"TotalBsmtSF\": 972.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 972, \"2ndFlrSF\": 605, \"LowQualFinSF\": 0, \"GrLivArea\": 1577, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140200}, {\"Order\": 2673, \"PID\": 903206160, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 11737, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkComm\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 848.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1017, \"2ndFlrSF\": 810, \"LowQualFinSF\": 0, \"GrLivArea\": 1827, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1943.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 27, \"OpenPorchSF\": 36, \"EnclosedPorch\": 42, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202500}, {\"Order\": 2674, \"PID\": 903225090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 5000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 399.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 605.0, \"TotalBsmtSF\": 1004.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 660, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 159000}, {\"Order\": 2675, \"PID\": 903229040, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 65.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 507.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 793, \"2ndFlrSF\": 325, \"LowQualFinSF\": 0, \"GrLivArea\": 1118, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 271, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2676, \"PID\": 903231070, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1934, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 360, \"GrLivArea\": 1176, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 112, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 400, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 114500}, {\"Order\": 2677, \"PID\": 903231190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 896.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 896, \"2ndFlrSF\": 448, \"LowQualFinSF\": 0, \"GrLivArea\": 1344, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 114, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2678, \"PID\": 903231220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 347.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 381.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 434, \"LowQualFinSF\": 0, \"GrLivArea\": 1162, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 258.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 75000}, {\"Order\": 2679, \"PID\": 903231240, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 489.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 768.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1015, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1015, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 120, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 620, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 88000}, {\"Order\": 2680, \"PID\": 903232170, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1947, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 240, \"LowQualFinSF\": 0, \"GrLivArea\": 912, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80500}, {\"Order\": 2681, \"PID\": 903233100, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 52.0, \"LotArea\": 6240, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1042.0, \"TotalBsmtSF\": 1042.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1042, \"2ndFlrSF\": 534, \"LowQualFinSF\": 0, \"GrLivArea\": 1576, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 225.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 149000}, {\"Order\": 2682, \"PID\": 903233220, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 51.0, \"LotArea\": 6120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 741.0, \"TotalBsmtSF\": 741.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 741, \"2ndFlrSF\": 583, \"LowQualFinSF\": 0, \"GrLivArea\": 1324, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 55, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110000}, {\"Order\": 2683, \"PID\": 903234030, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1980, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 706.0, \"TotalBsmtSF\": 1103.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1103, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1103, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 166, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 110500}, {\"Order\": 2684, \"PID\": 903235020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1921, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 616.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 616, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1921.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 205.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 129, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 89000}, {\"Order\": 2685, \"PID\": 903236200, \"MSSubClass\": 45, \"MSZoning\": \"RM\", \"LotFrontage\": 58.0, \"LotArea\": 6380, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Unf\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 993.0, \"TotalBsmtSF\": 993.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1048, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1048, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 113000}, {\"Order\": 2686, \"PID\": 903400030, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 11672, \"Street\": \"Pave\", \"Alley\": \"Pave\", \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 816.0, \"TotalBsmtSF\": 816.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 816, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 816, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 109000}, {\"Order\": 2687, \"PID\": 903425190, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 90.0, \"LotArea\": 33120, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR3\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"RRAn\", \"Condition2\": \"Feedr\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1595.0, \"TotalBsmtSF\": 1595.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1611, \"2ndFlrSF\": 875, \"LowQualFinSF\": 0, \"GrLivArea\": 2486, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2688, \"PID\": 903425340, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9873, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"BrkSide\", \"Condition1\": \"RRAn\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 160.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 171.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 288, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 129000}, {\"Order\": 2689, \"PID\": 903430090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 59.0, \"LotArea\": 5310, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 485.0, \"TotalBsmtSF\": 485.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1001, \"2ndFlrSF\": 634, \"LowQualFinSF\": 0, \"GrLivArea\": 1635, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 255.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 394, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117000}, {\"Order\": 2690, \"PID\": 903430130, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 153.0, \"LotArea\": 4118, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"OldTown\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 693.0, \"TotalBsmtSF\": 693.0, \"Heating\": \"Grav\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 693, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 693, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 52500}, {\"Order\": 2691, \"PID\": 903451050, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 10320, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 596.0, \"TotalBsmtSF\": 596.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Po\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 834, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1430, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 370.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 218, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 210, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 107000}, {\"Order\": 2692, \"PID\": 903452090, \"MSSubClass\": 70, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7518, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR3\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1910, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 396.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 665, \"2ndFlrSF\": 665, \"LowQualFinSF\": 0, \"GrLivArea\": 1330, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 72, \"EnclosedPorch\": 45, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116500}, {\"Order\": 2693, \"PID\": 903454020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 610.0, \"TotalBsmtSF\": 610.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 819, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 819, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 72000}, {\"Order\": 2694, \"PID\": 903454080, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1937, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 780.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 780, \"2ndFlrSF\": 596, \"LowQualFinSF\": 0, \"GrLivArea\": 1376, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 198.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119500}, {\"Order\": 2695, \"PID\": 903455090, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1938, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 803.0, \"TotalBsmtSF\": 803.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 803, \"2ndFlrSF\": 557, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 65, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125500}, {\"Order\": 2696, \"PID\": 903456060, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 9786, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1007.0, \"TotalBsmtSF\": 1007.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1077, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1077, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 210.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 100, \"EnclosedPorch\": 48, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91000}, {\"Order\": 2697, \"PID\": 903456090, \"MSSubClass\": 190, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 6780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1982, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 490.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 520.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 520, \"2ndFlrSF\": 0, \"LowQualFinSF\": 234, \"GrLivArea\": 754, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 53, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 84500}, {\"Order\": 2698, \"PID\": 903458010, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1930, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 343.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 984.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 984, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 984, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"ConLI\", \"SaleCondition\": \"Family\", \"SalePrice\": 90000}, {\"Order\": 2699, \"PID\": 904100030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 12375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 41.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 329.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 477.0, \"TotalBsmtSF\": 806.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1081, \"2ndFlrSF\": 341, \"LowQualFinSF\": 0, \"GrLivArea\": 1422, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2700, \"PID\": 904100090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 11136, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Feedr\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1921.0, \"TotalBsmtSF\": 1921.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1921, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1921, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 180, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150000}, {\"Order\": 2701, \"PID\": 904100170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 21370, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1950, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1640, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1640, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 394.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 225, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 600, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2702, \"PID\": 904101040, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 92.0, \"LotArea\": 6930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 300.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 294.0, \"BsmtUnfSF\": 468.0, \"TotalBsmtSF\": 1062.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1352, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1352, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 0, \"EnclosedPorch\": 294, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 130000}, {\"Order\": 2703, \"PID\": 904301410, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 8250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1935, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1032, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1032, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 260.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 121, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 125000}, {\"Order\": 2704, \"PID\": 904302020, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5220, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 830.0, \"TotalBsmtSF\": 830.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 879, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 879, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 80000}, {\"Order\": 2705, \"PID\": 904302030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 5500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Shed\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 510.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 373.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1073, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1073, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 246.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2706, \"PID\": 905100030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 11235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1963, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 51.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1382, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1382, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 459.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 82, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2707, \"PID\": 905101330, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10791, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1296, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1296, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 516.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90000}, {\"Order\": 2708, \"PID\": 905101450, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8414, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1963, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 663.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1068, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 264.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 154500}, {\"Order\": 2709, \"PID\": 905103130, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11327, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 305.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 779.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1064.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1064, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1064, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 314, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153600}, {\"Order\": 2710, \"PID\": 905103140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 11777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 97.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 328.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 285.0, \"TotalBsmtSF\": 1164.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1320, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 68, \"EnclosedPorch\": 240, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 164500}, {\"Order\": 2711, \"PID\": 905103180, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 456.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 934, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 934, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 77, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 500, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2712, \"PID\": 905105010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 773.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 286.0, \"TotalBsmtSF\": 1059.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1059, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1059, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 88, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 142500}, {\"Order\": 2713, \"PID\": 905106210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11553, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 188.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 673.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1051.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1159, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1159, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 466, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 158000}, {\"Order\": 2714, \"PID\": 905107070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 7844, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 203.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 209.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 463.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 672, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1400, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149500}, {\"Order\": 2715, \"PID\": 905107220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9535, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 450.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 194.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 982.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1458, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1458, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 512.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 284, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 165000}, {\"Order\": 2716, \"PID\": 905107240, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1968, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 570.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 891.0, \"TotalBsmtSF\": 1461.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1721, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1721, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 96, \"EnclosedPorch\": 180, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2717, \"PID\": 905107300, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 7176, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 794.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 960.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1040, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1040, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 131, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160500}, {\"Order\": 2718, \"PID\": 905108090, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9662, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1967.0, \"TotalBsmtSF\": 1967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1967, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1967, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 580.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 170, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156500}, {\"Order\": 2719, \"PID\": 905108120, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8235, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 99.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1466.0, \"TotalBsmtSF\": 1949.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1949, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1949, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 6, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2720, \"PID\": 905200280, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 13650, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 57.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 441.0, \"BsmtUnfSF\": 554.0, \"TotalBsmtSF\": 1052.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1252, \"2ndFlrSF\": 668, \"LowQualFinSF\": 0, \"GrLivArea\": 1920, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 172500}, {\"Order\": 2721, \"PID\": 905200290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 13125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1957, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 67.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 168.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 682.0, \"BsmtUnfSF\": 284.0, \"TotalBsmtSF\": 1134.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1803, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1803, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155000}, {\"Order\": 2722, \"PID\": 905200340, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 102.0, \"LotArea\": 17920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1955, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 306.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1085.0, \"BsmtUnfSF\": 372.0, \"TotalBsmtSF\": 1763.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1779, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 454.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 418, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 312, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 170000}, {\"Order\": 2723, \"PID\": 905200380, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 17529, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 65.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 872, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 872, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 322.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 116, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 105000}, {\"Order\": 2724, \"PID\": 905200490, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 10246, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 4, \"OverallCond\": 9, \"YearBuilt\": 1965, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 648.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 648.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 0, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 364.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 88, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2725, \"PID\": 905201090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14175, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1956, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 988.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 1188.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1437, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1437, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 304, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 168000}, {\"Order\": 2726, \"PID\": 905202190, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 20355, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1967, \"YearRemod/Add\": 1967, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 810.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 826.0, \"BsmtUnfSF\": 229.0, \"TotalBsmtSF\": 1865.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1830, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1830, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1967.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 521.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 115, \"EnclosedPorch\": 168, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 278000}, {\"Order\": 2727, \"PID\": 905202210, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 87.0, \"LotArea\": 13050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1963, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 104.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 850.0, \"BsmtUnfSF\": 46.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1000, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1000, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 575.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 238, \"OpenPorchSF\": 0, \"EnclosedPorch\": 148, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2728, \"PID\": 905225080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 15593, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 4, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 701.0, \"TotalBsmtSF\": 1304.0, \"Heating\": \"GasW\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1304, \"2ndFlrSF\": 983, \"LowQualFinSF\": 0, \"GrLivArea\": 2287, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 667.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 114, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2729, \"PID\": 905300010, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 10820, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1971, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 153.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 535.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 159.0, \"BsmtUnfSF\": 88.0, \"TotalBsmtSF\": 782.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 810, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 810, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2730, \"PID\": 905300080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 100.0, \"LotArea\": 13350, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Sawyer\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1974, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 762.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 102.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 241, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2731, \"PID\": 905351045, \"MSSubClass\": 150, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 1700, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1980, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 397.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 33.0, \"TotalBsmtSF\": 430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 880, \"2ndFlrSF\": 680, \"LowQualFinSF\": 140, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 1980.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 450.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 188, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 200, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148400}, {\"Order\": 2732, \"PID\": 905351150, \"MSSubClass\": 120, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 5271, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1082.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 371.0, \"TotalBsmtSF\": 1453.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1453, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1453, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 445.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 184, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 190000}, {\"Order\": 2733, \"PID\": 905402110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9375, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 799.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 168.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1350, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1350, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 237, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146000}, {\"Order\": 2734, \"PID\": 905403050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 6488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 230.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 569.0, \"TotalBsmtSF\": 799.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 799, \"2ndFlrSF\": 351, \"LowQualFinSF\": 0, \"GrLivArea\": 1150, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 264, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 128000}, {\"Order\": 2735, \"PID\": 905426100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 7800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1948, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 603.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 293.0, \"TotalBsmtSF\": 896.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1112, \"2ndFlrSF\": 896, \"LowQualFinSF\": 0, \"GrLivArea\": 2008, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 230.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 103, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2736, \"PID\": 905426150, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 19690, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1966, \"YearRemod/Add\": 1966, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1575, \"2ndFlrSF\": 626, \"LowQualFinSF\": 0, \"GrLivArea\": 2201, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1966.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 432.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 586, \"OpenPorchSF\": 236, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 738, \"PoolQC\": \"Gd\", \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 274970}, {\"Order\": 2737, \"PID\": 905427010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 114.0, \"LotArea\": 19950, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1928, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 672.0, \"TotalBsmtSF\": 672.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 672, \"LowQualFinSF\": 0, \"GrLivArea\": 2009, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1928.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 795.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 42, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 180, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2738, \"PID\": 905427030, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 19800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1935, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 425.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1411.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 1836, \"LowQualFinSF\": 0, \"GrLivArea\": 3672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 836.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 684, \"OpenPorchSF\": 80, \"EnclosedPorch\": 32, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 415000}, {\"Order\": 2739, \"PID\": 905427140, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11679, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1962, \"YearRemod/Add\": 1962, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 96.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 612.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 1164.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1776.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1560, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1560, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Fa\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1962.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 453, \"OpenPorchSF\": 253, \"EnclosedPorch\": 144, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 182000}, {\"Order\": 2740, \"PID\": 905451050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12048, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1952, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1488, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1488, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 569.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 189, \"EnclosedPorch\": 36, \"3SsnPorch\": 0, \"ScreenPorch\": 348, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2741, \"PID\": 905451410, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 10519, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1955, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 164.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1057.0, \"TotalBsmtSF\": 1057.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1057, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2742, \"PID\": 905452140, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 444.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 550.0, \"TotalBsmtSF\": 994.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 639, \"LowQualFinSF\": 0, \"GrLivArea\": 1855, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 325.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 136900}, {\"Order\": 2743, \"PID\": 905452150, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9525, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 468.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 532.0, \"TotalBsmtSF\": 1000.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1068, \"2ndFlrSF\": 541, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 305.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2744, \"PID\": 905475150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 6420, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1952, \"YearRemod/Add\": 1952, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 210.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 551.0, \"BsmtUnfSF\": 219.0, \"TotalBsmtSF\": 980.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1148, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1148, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1952.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 123500}, {\"Order\": 2745, \"PID\": 905477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 8335, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1954, \"YearRemod/Add\": 1954, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1124, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1124, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 36, \"EnclosedPorch\": 190, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 93000}, {\"Order\": 2746, \"PID\": 905480160, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 7585, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 810.0, \"TotalBsmtSF\": 810.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1002, \"2ndFlrSF\": 454, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1954.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 91500}, {\"Order\": 2747, \"PID\": 906202040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1985, \"YearRemod/Add\": 1985, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 85.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1258.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 40.0, \"TotalBsmtSF\": 1298.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1298, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1985.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 403.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 165, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2748, \"PID\": 906204180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 12128, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1989, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 232.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 549.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1313, \"2ndFlrSF\": 1246, \"LowQualFinSF\": 0, \"GrLivArea\": 2559, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 245, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 168, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 209000}, {\"Order\": 2749, \"PID\": 906223180, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 9554, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 125.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 380.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 397.0, \"TotalBsmtSF\": 777.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 846, \"LowQualFinSF\": 0, \"GrLivArea\": 1911, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 471.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 182, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2750, \"PID\": 906225180, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 9069, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1993, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 261.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 1083.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1344.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1440, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1440, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 4.0, \"GarageArea\": 920.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 288, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 224500}, {\"Order\": 2751, \"PID\": 906380110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 133.0, \"LotArea\": 11003, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1308.0, \"TotalBsmtSF\": 1308.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1308, \"2ndFlrSF\": 568, \"LowQualFinSF\": 0, \"GrLivArea\": 1876, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 848.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 229800}, {\"Order\": 2752, \"PID\": 906380150, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7488, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 393.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 815.0, \"TotalBsmtSF\": 1208.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1208, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1208, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 183600}, {\"Order\": 2753, \"PID\": 906380170, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 7406, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 84.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 684.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 515.0, \"TotalBsmtSF\": 1199.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 632.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 105, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 194000}, {\"Order\": 2754, \"PID\": 906380180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 64.0, \"LotArea\": 6762, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1286.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1294, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1294, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 662.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 55, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 193879}, {\"Order\": 2755, \"PID\": 906382030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 240.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 20.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1594.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 865.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 59, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 221500}, {\"Order\": 2756, \"PID\": 906382040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8990, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1498.0, \"TotalBsmtSF\": 1498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 675.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 351, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 204900}, {\"Order\": 2757, \"PID\": 906382050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 8760, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 464.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 927.0, \"TotalBsmtSF\": 1391.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1391, \"2ndFlrSF\": 571, \"LowQualFinSF\": 0, \"GrLivArea\": 1962, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 868.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 239799}, {\"Order\": 2758, \"PID\": 906392090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 13377, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 260.0, \"TotalBsmtSF\": 1836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1846, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1846, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233555}, {\"Order\": 2759, \"PID\": 906392100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1300.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 434.0, \"TotalBsmtSF\": 1734.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1734, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1734, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 660.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 260000}, {\"Order\": 2760, \"PID\": 906392120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1122.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 1570.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1590, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1590, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 754.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 294900}, {\"Order\": 2761, \"PID\": 906394010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 91.0, \"LotArea\": 10984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 945.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 945, \"2ndFlrSF\": 864, \"LowQualFinSF\": 0, \"GrLivArea\": 1809, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 638.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 209700}, {\"Order\": 2762, \"PID\": 906394040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 140.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 56.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1558.0, \"TotalBsmtSF\": 1614.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1614, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1614, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 225000}, {\"Order\": 2763, \"PID\": 906394060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 9316, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 532.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 812, \"LowQualFinSF\": 0, \"GrLivArea\": 1596, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 45, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 181000}, {\"Order\": 2764, \"PID\": 906420020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 10041, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SawyerW\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 789.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 119.0, \"TotalBsmtSF\": 908.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 927, \"2ndFlrSF\": 988, \"LowQualFinSF\": 0, \"GrLivArea\": 1915, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1992.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 220000}, {\"Order\": 2765, \"PID\": 906426090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 36500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1964, \"YearRemod/Add\": 1964, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkCmn\", \"MasVnrArea\": 621.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 812.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 812.0, \"TotalBsmtSF\": 1624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1582, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1582, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1964.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 198, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 190000}, {\"Order\": 2766, \"PID\": 906475050, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21453, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Sev\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Metal\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 938.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 938.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 988, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 988, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 130, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2767, \"PID\": 906475200, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 70761, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"WdShngl\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 655.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 878.0, \"TotalBsmtSF\": 1533.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1533, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1533, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 200, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 280000}, {\"Order\": 2768, \"PID\": 906476140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"ClearCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1968, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 853.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 535.0, \"TotalBsmtSF\": 1388.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1388, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 522.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 158900}, {\"Order\": 2769, \"PID\": 907125020, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 57.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 298.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 572.0, \"TotalBsmtSF\": 870.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2770, \"PID\": 907125080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13015, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1996, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1100.0, \"TotalBsmtSF\": 1100.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1100, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1100, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 462.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2771, \"PID\": 907130110, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 12438, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"PosN\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 68.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 781.0, \"TotalBsmtSF\": 781.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 795, \"2ndFlrSF\": 704, \"LowQualFinSF\": 0, \"GrLivArea\": 1499, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 473.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 413, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 187000}, {\"Order\": 2772, \"PID\": 907131070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8685, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 846.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 579.0, \"TotalBsmtSF\": 1425.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1425, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1425, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 130, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 193000}, {\"Order\": 2773, \"PID\": 907135230, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 13568, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 716.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 274.0, \"TotalBsmtSF\": 990.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 990, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 990, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1996.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 224, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 156000}, {\"Order\": 2774, \"PID\": 907175030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 244.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1400.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 125.0, \"TotalBsmtSF\": 1525.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1525, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1525, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 541.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 219, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 235000}, {\"Order\": 2775, \"PID\": 907175060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 79.0, \"LotArea\": 9236, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1200.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 279.0, \"TotalBsmtSF\": 1479.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1494, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1494, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2776, \"PID\": 907180120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10264, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 183.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1162.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 426.0, \"TotalBsmtSF\": 1588.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1588, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1588, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 472.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 158, \"OpenPorchSF\": 29, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2777, \"PID\": 907181090, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 9272, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 500.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 342.0, \"TotalBsmtSF\": 842.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 856, \"2ndFlrSF\": 893, \"LowQualFinSF\": 0, \"GrLivArea\": 1749, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 515.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 85, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196000}, {\"Order\": 2778, \"PID\": 907187010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 13426, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 57.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 828, \"LowQualFinSF\": 0, \"GrLivArea\": 1779, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 208, \"OpenPorchSF\": 107, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217000}, {\"Order\": 2779, \"PID\": 907192010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13450, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 700.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 916.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 920, \"2ndFlrSF\": 941, \"LowQualFinSF\": 0, \"GrLivArea\": 1861, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 492.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 146, \"OpenPorchSF\": 91, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2780, \"PID\": 907194130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 14006, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 144.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": null, \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 936.0, \"TotalBsmtSF\": 936.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 936, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1776, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 474.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 96, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 192500}, {\"Order\": 2781, \"PID\": 907196020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 118.0, \"LotArea\": 13704, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 150.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1541.0, \"TotalBsmtSF\": 1541.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1541, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1541, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 843.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 468, \"OpenPorchSF\": 81, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 205000}, {\"Order\": 2782, \"PID\": 907200170, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 10780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 483.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 428.0, \"TotalBsmtSF\": 911.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 954, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132500}, {\"Order\": 2783, \"PID\": 907201160, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8340, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 62.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 509.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 675.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 702, \"LowQualFinSF\": 0, \"GrLivArea\": 1388, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 317.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 406, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157500}, {\"Order\": 2784, \"PID\": 907201230, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 10385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 123.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 595.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 400.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 995.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1282, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1282, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 672.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 386, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 174000}, {\"Order\": 2785, \"PID\": 907202140, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 9920, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 523.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 448.0, \"TotalBsmtSF\": 971.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 971, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 971, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Po\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 300.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2786, \"PID\": 907203010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 9560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 360.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 504.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 128500}, {\"Order\": 2787, \"PID\": 907203040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9800, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 894.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 894.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 894, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 894, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 552.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 256, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 149900}, {\"Order\": 2788, \"PID\": 907227090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 7200, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 437.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 427.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 297.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 119900}, {\"Order\": 2789, \"PID\": 907230240, \"MSSubClass\": 160, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 3612, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Landmrk\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 338.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 292.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 690, \"LowQualFinSF\": 0, \"GrLivArea\": 1320, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2790, \"PID\": 907251100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11367, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 210.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 932.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1091, \"2ndFlrSF\": 898, \"LowQualFinSF\": 0, \"GrLivArea\": 1989, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 586.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 199, \"OpenPorchSF\": 60, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 255000}, {\"Order\": 2791, \"PID\": 907252050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 9930, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 199.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 456.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 370.0, \"TotalBsmtSF\": 826.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 878, \"2ndFlrSF\": 884, \"LowQualFinSF\": 0, \"GrLivArea\": 1762, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 591.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 54, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 222000}, {\"Order\": 2792, \"PID\": 907254050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 9468, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 148.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 639.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 201.0, \"TotalBsmtSF\": 840.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 840, \"2ndFlrSF\": 915, \"LowQualFinSF\": 0, \"GrLivArea\": 1755, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 530.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 176, \"OpenPorchSF\": 73, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 214000}, {\"Order\": 2793, \"PID\": 907255010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11088, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 872.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 476.0, \"TotalBsmtSF\": 1348.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1358, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1358, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 68, \"OpenPorchSF\": 166, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 220000}, {\"Order\": 2794, \"PID\": 907255050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 14781, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 178.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1753.0, \"TotalBsmtSF\": 1753.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1787, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1787, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 748.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 198, \"OpenPorchSF\": 150, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 275000}, {\"Order\": 2795, \"PID\": 907262080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8726, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 872.0, \"TotalBsmtSF\": 872.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 872, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 1909, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 529.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 108, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 197000}, {\"Order\": 2796, \"PID\": 907265030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8125, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 295.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 986.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 668.0, \"TotalBsmtSF\": 1654.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1654, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1654, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 900.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 136, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2797, \"PID\": 907270050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 10566, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 1999, \"YearRemod/Add\": 1999, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 261.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 920.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 170.0, \"TotalBsmtSF\": 1090.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1090, \"2ndFlrSF\": 1124, \"LowQualFinSF\": 0, \"GrLivArea\": 2214, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1999.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 646.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 197, \"OpenPorchSF\": 80, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 268500}, {\"Order\": 2798, \"PID\": 907275030, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 21533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1996, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1065.0, \"TotalBsmtSF\": 1065.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1065, \"2ndFlrSF\": 984, \"LowQualFinSF\": 0, \"GrLivArea\": 2049, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 467.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210900}, {\"Order\": 2799, \"PID\": 907285010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 227.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 796.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 258.0, \"TotalBsmtSF\": 1054.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1070, \"2ndFlrSF\": 869, \"LowQualFinSF\": 0, \"GrLivArea\": 1939, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 555.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 84, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 227000}, {\"Order\": 2800, \"PID\": 907285100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1995, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 685.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 930.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 950, \"2ndFlrSF\": 1045, \"LowQualFinSF\": 0, \"GrLivArea\": 1995, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1995.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 610.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 275, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 237000}, {\"Order\": 2801, \"PID\": 907290020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 9750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 133.0, \"TotalBsmtSF\": 1108.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1108, \"2ndFlrSF\": 989, \"LowQualFinSF\": 0, \"GrLivArea\": 2097, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 583.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 253, \"OpenPorchSF\": 170, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 274300}, {\"Order\": 2802, \"PID\": 907290080, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9100, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1836.0, \"TotalBsmtSF\": 1860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1836, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1836, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 33, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 216837}, {\"Order\": 2803, \"PID\": 907290160, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 170.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 717.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 131.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 133000}, {\"Order\": 2804, \"PID\": 907290230, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 37.0, \"LotArea\": 4435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 169.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 662.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 186.0, \"TotalBsmtSF\": 848.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 848, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 848, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 420.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 140, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 155900}, {\"Order\": 2805, \"PID\": 907290260, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 120.0, \"LotArea\": 15611, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1079.0, \"TotalBsmtSF\": 1079.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1079, \"2ndFlrSF\": 840, \"LowQualFinSF\": 0, \"GrLivArea\": 1919, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 685.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 51, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 233230}, {\"Order\": 2806, \"PID\": 907401050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8810, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1000.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 390.0, \"TotalBsmtSF\": 1390.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1390, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1390, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 545.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 68, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 207000}, {\"Order\": 2807, \"PID\": 907401080, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 41.0, \"LotArea\": 12393, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 847.0, \"TotalBsmtSF\": 847.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 847, \"2ndFlrSF\": 1101, \"LowQualFinSF\": 0, \"GrLivArea\": 1948, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 434.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 100, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2808, \"PID\": 907405030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9135, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 120.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 340.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1342.0, \"TotalBsmtSF\": 1682.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1700, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1700, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 544.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 192, \"OpenPorchSF\": 23, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200000}, {\"Order\": 2809, \"PID\": 907410040, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 8581, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 851.0, \"TotalBsmtSF\": 851.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 851, \"2ndFlrSF\": 886, \"LowQualFinSF\": 0, \"GrLivArea\": 1737, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2006.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 578.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 105, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 203160}, {\"Order\": 2810, \"PID\": 907410100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 784.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 784, \"2ndFlrSF\": 827, \"LowQualFinSF\": 0, \"GrLivArea\": 1611, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 36, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195800}, {\"Order\": 2811, \"PID\": 907410110, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10084, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 196.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1528.0, \"TotalBsmtSF\": 1552.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1552, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1552, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 782.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 144, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 212900}, {\"Order\": 2812, \"PID\": 907412010, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 89.0, \"LotArea\": 11645, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 860.0, \"TotalBsmtSF\": 860.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 860, \"2ndFlrSF\": 860, \"LowQualFinSF\": 0, \"GrLivArea\": 1720, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 565.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 70, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2813, \"PID\": 907414040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8772, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 996.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 340.0, \"TotalBsmtSF\": 1336.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 43, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 198000}, {\"Order\": 2814, \"PID\": 907418020, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 68.0, \"LotArea\": 8846, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 750.0, \"TotalBsmtSF\": 750.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 750, \"2ndFlrSF\": 750, \"LowQualFinSF\": 0, \"GrLivArea\": 1500, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 564.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 173900}, {\"Order\": 2815, \"PID\": 907420070, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8461, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 728.0, \"TotalBsmtSF\": 728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 728, \"2ndFlrSF\": 728, \"LowQualFinSF\": 0, \"GrLivArea\": 1456, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 390.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 163990}, {\"Order\": 2816, \"PID\": 907420090, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8767, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"CollgCr\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 24.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1286.0, \"TotalBsmtSF\": 1310.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1310, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1310, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 164990}, {\"Order\": 2817, \"PID\": 908102020, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8777, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1910, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 173.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 337.0, \"BsmtUnfSF\": 166.0, \"TotalBsmtSF\": 676.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 760, \"2ndFlrSF\": 676, \"LowQualFinSF\": 0, \"GrLivArea\": 1436, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 147, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": \"Shed\", \"MiscVal\": 420, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 98000}, {\"Order\": 2818, \"PID\": 908102320, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 134.0, \"LotArea\": 17755, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1959, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 132.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 176.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1290.0, \"TotalBsmtSF\": 1466.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1466, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1466, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1959.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 140, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 100, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149900}, {\"Order\": 2819, \"PID\": 908102330, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 67.0, \"LotArea\": 8877, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 836.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 836.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1220, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1220, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 396.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2820, \"PID\": 908103310, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 38.0, \"LotArea\": 7840, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 355.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 976.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1012, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1012, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2821, \"PID\": 908103320, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 35.0, \"LotArea\": 9400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Flat\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 250.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 945.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 945.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 980, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 980, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 2.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 0, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 127500}, {\"Order\": 2822, \"PID\": 908127050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 73.0, \"LotArea\": 16133, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 847.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 329.0, \"TotalBsmtSF\": 1176.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1176, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1176, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 92, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 112, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 119900}, {\"Order\": 2823, \"PID\": 908128100, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 7162, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 190.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 796.0, \"TotalBsmtSF\": 796.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 806, \"2ndFlrSF\": 918, \"LowQualFinSF\": 0, \"GrLivArea\": 1724, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 168, \"OpenPorchSF\": 57, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 196500}, {\"Order\": 2824, \"PID\": 908130020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 75.0, \"LotArea\": 8050, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": null, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 475.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 297.0, \"BsmtUnfSF\": 142.0, \"TotalBsmtSF\": 914.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 914, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 914, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 32, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 117250}, {\"Order\": 2825, \"PID\": 908178050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 11060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2003, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1150.0, \"TotalBsmtSF\": 1150.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1164, \"2ndFlrSF\": 1150, \"LowQualFinSF\": 0, \"GrLivArea\": 2314, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Ex\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 2003.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 502.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 274, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 229000}, {\"Order\": 2826, \"PID\": 908186060, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 80.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2827, \"PID\": 908186070, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 140000}, {\"Order\": 2828, \"PID\": 908186090, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 35.0, \"LotArea\": 3675, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 82.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 547.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 547.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1072, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1072, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Basment\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 44, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 142500}, {\"Order\": 2829, \"PID\": 908188110, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 134000}, {\"Order\": 2830, \"PID\": 908188120, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2831, \"PID\": 908188130, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2832, \"PID\": 908188140, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 24.0, \"LotArea\": 2522, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 50.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 970.0, \"TotalBsmtSF\": 970.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 739, \"LowQualFinSF\": 0, \"GrLivArea\": 1709, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2833, \"PID\": 908188150, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 3363, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 117.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 976.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 732, \"LowQualFinSF\": 0, \"GrLivArea\": 1708, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Maj1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 380.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 130000}, {\"Order\": 2834, \"PID\": 908225180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 56.0, \"LotArea\": 6956, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1948, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 624.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 624, \"2ndFlrSF\": 312, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1948.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 265.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Po\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 97900}, {\"Order\": 2835, \"PID\": 908227010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 72.0, \"LotArea\": 7822, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 3, \"YearBuilt\": 1915, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 832.0, \"TotalBsmtSF\": 832.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 846, \"2ndFlrSF\": 492, \"LowQualFinSF\": 0, \"GrLivArea\": 1338, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1974.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 208, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 92000}, {\"Order\": 2836, \"PID\": 908227030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 8707, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1093.0, \"TotalBsmtSF\": 1093.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 1093, \"2ndFlrSF\": 576, \"LowQualFinSF\": 0, \"GrLivArea\": 1669, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1924.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 107000}, {\"Order\": 2837, \"PID\": 908227040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 8410, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 3, \"YearBuilt\": 1910, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gambrel\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 658.0, \"TotalBsmtSF\": 658.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 658, \"2ndFlrSF\": 526, \"LowQualFinSF\": 0, \"GrLivArea\": 1184, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 151, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 81000}, {\"Order\": 2838, \"PID\": 908228040, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9738, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1924, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 392.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 392.0, \"TotalBsmtSF\": 784.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 949, \"2ndFlrSF\": 272, \"LowQualFinSF\": 0, \"GrLivArea\": 1221, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1965.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 392.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 236, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104900}, {\"Order\": 2839, \"PID\": 908275220, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1955, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 167.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 864, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 864, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 572.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 115000}, {\"Order\": 2840, \"PID\": 908275290, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 16012, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1954, \"YearRemod/Add\": 1968, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 60.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 691.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 263.0, \"TotalBsmtSF\": 954.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1482, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1482, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Min1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 609.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 30, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 125000}, {\"Order\": 2841, \"PID\": 909101050, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1918, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasW\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 686, \"2ndFlrSF\": 564, \"LowQualFinSF\": 0, \"GrLivArea\": 1250, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1955.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 280.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 207, \"OpenPorchSF\": 0, \"EnclosedPorch\": 96, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 116000}, {\"Order\": 2842, \"PID\": 909101080, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 45.0, \"LotArea\": 8248, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 864.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 964, \"2ndFlrSF\": 0, \"LowQualFinSF\": 450, \"GrLivArea\": 1414, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 83000}, {\"Order\": 2843, \"PID\": 909101190, \"MSSubClass\": 75, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6204, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Fin\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1912, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 795.0, \"TotalBsmtSF\": 795.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 954, \"2ndFlrSF\": 795, \"LowQualFinSF\": 481, \"GrLivArea\": 2230, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 188, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 118500}, {\"Order\": 2844, \"PID\": 909101330, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8088, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1922, \"YearRemod/Add\": 1955, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 498.0, \"TotalBsmtSF\": 498.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 498, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 498, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 100, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"ConLD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 35000}, {\"Order\": 2845, \"PID\": 909103020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 76.0, \"LotArea\": 11388, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Edwards\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1910, \"YearRemod/Add\": 1993, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 616.0, \"TotalBsmtSF\": 616.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1055, \"2ndFlrSF\": 218, \"LowQualFinSF\": 0, \"GrLivArea\": 1273, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1910.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 275.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 212, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 121000}, {\"Order\": 2846, \"PID\": 909131125, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": null, \"LotArea\": 7082, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 8, \"YearBuilt\": 1916, \"YearRemod/Add\": 1995, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 686.0, \"TotalBsmtSF\": 686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 948, \"2ndFlrSF\": 980, \"LowQualFinSF\": 0, \"GrLivArea\": 1928, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 228, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2847, \"PID\": 909175030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 8400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1940, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 388.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 940.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1192, \"2ndFlrSF\": 403, \"LowQualFinSF\": 0, \"GrLivArea\": 1595, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 108, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2848, \"PID\": 909176180, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 10890, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1938, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 930.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 128.0, \"TotalBsmtSF\": 1058.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1058, \"2ndFlrSF\": 493, \"LowQualFinSF\": 0, \"GrLivArea\": 1551, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1938.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137000}, {\"Order\": 2849, \"PID\": 909201180, \"MSSubClass\": 190, \"MSZoning\": \"RH\", \"LotFrontage\": 58.0, \"LotArea\": 6430, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 780.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 780.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 816, \"2ndFlrSF\": 524, \"LowQualFinSF\": 0, \"GrLivArea\": 1340, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1945.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 440.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 128000}, {\"Order\": 2850, \"PID\": 909250070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 43.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1926, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 424.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 200.0, \"TotalBsmtSF\": 624.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 743, \"2ndFlrSF\": 736, \"LowQualFinSF\": 0, \"GrLivArea\": 1479, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1926.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 530, \"OpenPorchSF\": 0, \"EnclosedPorch\": 56, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2851, \"PID\": 909250120, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 96.0, \"LotArea\": 13132, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1914, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 747.0, \"TotalBsmtSF\": 747.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 892, \"2ndFlrSF\": 892, \"LowQualFinSF\": 0, \"GrLivArea\": 1784, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1914.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 203, \"OpenPorchSF\": 40, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 138887}, {\"Order\": 2852, \"PID\": 909250200, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 4899, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 450.0, \"TotalBsmtSF\": 755.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 755, \"2ndFlrSF\": 755, \"LowQualFinSF\": 0, \"GrLivArea\": 1510, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 164, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 149000}, {\"Order\": 2853, \"PID\": 909250210, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 6000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1008.0, \"TotalBsmtSF\": 1008.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1008, \"2ndFlrSF\": 0, \"LowQualFinSF\": 514, \"GrLivArea\": 1522, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 138, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 102000}, {\"Order\": 2854, \"PID\": 909253080, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 9399, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2.5Unf\", \"OverallQual\": 7, \"OverallCond\": 8, \"YearBuilt\": 1919, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 818.0, \"TotalBsmtSF\": 818.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 818, \"2ndFlrSF\": 818, \"LowQualFinSF\": 0, \"GrLivArea\": 1636, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1919.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 212, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 167000}, {\"Order\": 2855, \"PID\": 909254070, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 7588, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 352.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 441.0, \"TotalBsmtSF\": 793.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 901, \"2ndFlrSF\": 901, \"LowQualFinSF\": 0, \"GrLivArea\": 1802, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1920.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 216.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 40, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 200100}, {\"Order\": 2856, \"PID\": 909256010, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 84.0, \"LotArea\": 10164, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1939, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 646.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 346.0, \"TotalBsmtSF\": 992.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 992, \"2ndFlrSF\": 473, \"LowQualFinSF\": 0, \"GrLivArea\": 1465, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1939.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 126, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2857, \"PID\": 909256020, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 51.0, \"LotArea\": 6191, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"SWISU\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 4, \"YearBuilt\": 1941, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 384.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 440.0, \"TotalBsmtSF\": 824.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 824, \"2ndFlrSF\": 464, \"LowQualFinSF\": 0, \"GrLivArea\": 1288, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1941.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 240.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 112000}, {\"Order\": 2858, \"PID\": 909275230, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 60.0, \"LotArea\": 9550, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1915, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 540.0, \"TotalBsmtSF\": 756.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 961, \"2ndFlrSF\": 756, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 642.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 35, \"EnclosedPorch\": 272, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 140000}, {\"Order\": 2859, \"PID\": 909275250, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 66.0, \"LotArea\": 21780, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 817.0, \"TotalBsmtSF\": 817.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseF\", \"1stFlrSF\": 940, \"2ndFlrSF\": 610, \"LowQualFinSF\": 0, \"GrLivArea\": 1550, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Min2\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1937.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 318.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 429, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 195000}, {\"Order\": 2860, \"PID\": 909276010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11435, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 8, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Stucco\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 792.0, \"TotalBsmtSF\": 792.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 792, \"2ndFlrSF\": 725, \"LowQualFinSF\": 0, \"GrLivArea\": 1517, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1931.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 400.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2861, \"PID\": 909276070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1940, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 602.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 299.0, \"TotalBsmtSF\": 901.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1125, \"2ndFlrSF\": 592, \"LowQualFinSF\": 0, \"GrLivArea\": 1717, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1940.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 410.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 113, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 194000}, {\"Order\": 2862, \"PID\": 909279040, \"MSSubClass\": 30, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 11600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1922, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 700.0, \"TotalBsmtSF\": 700.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1180, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1180, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1922.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 252.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 67, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 137500}, {\"Order\": 2863, \"PID\": 909280030, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 86.0, \"LotArea\": 11500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1936, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 223.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 794.0, \"TotalBsmtSF\": 1017.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1020, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2057, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 180.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 322, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2864, \"PID\": 909280070, \"MSSubClass\": 50, \"MSZoning\": \"RL\", \"LotFrontage\": 81.0, \"LotArea\": 8170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1929, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stucco\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 270.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 526.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 496.0, \"TotalBsmtSF\": 1022.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1122, \"2ndFlrSF\": 549, \"LowQualFinSF\": 0, \"GrLivArea\": 1671, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 451.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 218000}, {\"Order\": 2865, \"PID\": 909281010, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 16560, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 8, \"YearBuilt\": 1932, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 503.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 449.0, \"TotalBsmtSF\": 952.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1170, \"2ndFlrSF\": 1175, \"LowQualFinSF\": 0, \"GrLivArea\": 2345, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1932.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 360.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 239000}, {\"Order\": 2866, \"PID\": 909282060, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 12320, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 7, \"YearBuilt\": 1932, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 637.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 959, \"2ndFlrSF\": 650, \"LowQualFinSF\": 0, \"GrLivArea\": 1609, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"2Types\", \"GarageYrBlt\": 1963.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 579.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 104, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 199500}, {\"Order\": 2867, \"PID\": 909282110, \"MSSubClass\": 70, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 14210, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1930, \"YearRemod/Add\": 1959, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 697.0, \"TotalBsmtSF\": 697.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1104, \"2ndFlrSF\": 697, \"LowQualFinSF\": 0, \"GrLivArea\": 1801, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1930.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 365.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 90, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 210000}, {\"Order\": 2868, \"PID\": 909425120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 14115, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1956, \"YearRemod/Add\": 2004, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Stone\", \"Exterior2nd\": \"Stone\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 296.0, \"BsmtFinType2\": \"GLQ\", \"BsmtFinSF2\": 547.0, \"BsmtUnfSF\": 230.0, \"TotalBsmtSF\": 1073.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1811, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1811, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1956.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 280, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 230000}, {\"Order\": 2869, \"PID\": 909425180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 12984, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 459.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1283.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 147.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1430.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1647, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1647, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 621.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 217500}, {\"Order\": 2870, \"PID\": 909426060, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 15600, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1950, \"YearRemod/Add\": 1963, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 405.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 760.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1168.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1278, \"2ndFlrSF\": 1037, \"LowQualFinSF\": 0, \"GrLivArea\": 2315, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 3, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 1.0, \"GarageArea\": 342.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 192, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 257000}, {\"Order\": 2871, \"PID\": 909428110, \"MSSubClass\": 190, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 15750, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1953, \"YearRemod/Add\": 1953, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 56.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 841.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 324.0, \"TotalBsmtSF\": 1165.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1336, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1953.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 375.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 157000}, {\"Order\": 2872, \"PID\": 909475020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16381, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1969, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 312.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"Gd\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 1110.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 734.0, \"TotalBsmtSF\": 1844.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1844, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1844, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 540.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 73, \"EnclosedPorch\": 216, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 223000}, {\"Order\": 2873, \"PID\": 910200020, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7288, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1942, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 305.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 671.0, \"TotalBsmtSF\": 976.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 976, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 976, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1942.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 215.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"AdjLand\", \"SalePrice\": 102000}, {\"Order\": 2874, \"PID\": 910200060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 7, \"YearBuilt\": 1926, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 374.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 487.0, \"TotalBsmtSF\": 861.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 861, \"2ndFlrSF\": 424, \"LowQualFinSF\": 0, \"GrLivArea\": 1285, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1950.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 506.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 96, \"OpenPorchSF\": 0, \"EnclosedPorch\": 132, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145400}, {\"Order\": 2875, \"PID\": 910203100, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 61.0, \"LotArea\": 8534, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 432.0, \"TotalBsmtSF\": 432.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 672, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 672, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Min1\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 112, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdWo\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 72000}, {\"Order\": 2876, \"PID\": 910203230, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 7030, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1925, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 641.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 641, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 641, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1925.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 272.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 184, \"OpenPorchSF\": 0, \"EnclosedPorch\": 70, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 85000}, {\"Order\": 2877, \"PID\": 910207110, \"MSSubClass\": 30, \"MSZoning\": \"RM\", \"LotFrontage\": 50.0, \"LotArea\": 8765, \"Street\": \"Pave\", \"Alley\": \"Grvl\", \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1936, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"BrkTil\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 285.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 666.0, \"TotalBsmtSF\": 951.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 951, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 951, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1936.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 327.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 106500}, {\"Order\": 2878, \"PID\": 910226060, \"MSSubClass\": 50, \"MSZoning\": \"RM\", \"LotFrontage\": 75.0, \"LotArea\": 9060, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1957, \"YearRemod/Add\": 1957, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 327.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 967.0, \"TotalBsmtSF\": 967.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 967, \"2ndFlrSF\": 671, \"LowQualFinSF\": 0, \"GrLivArea\": 1638, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1957.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 384.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 21, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 139000}, {\"Order\": 2879, \"PID\": 911175360, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 11040, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1920, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 637.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 637.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 897, \"2ndFlrSF\": 439, \"LowQualFinSF\": 0, \"GrLivArea\": 1336, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1994.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 570.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 47, \"EnclosedPorch\": 120, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"COD\", \"SaleCondition\": \"Normal\", \"SalePrice\": 108000}, {\"Order\": 2880, \"PID\": 911175410, \"MSSubClass\": 30, \"MSZoning\": \"C (all)\", \"LotFrontage\": 69.0, \"LotArea\": 12366, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Feedr\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1945, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Wd Sdng\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Slab\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 729, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 729, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 23, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 51689}, {\"Order\": 2881, \"PID\": 911175430, \"MSSubClass\": 20, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 2, \"OverallCond\": 3, \"YearBuilt\": 1949, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"AsbShng\", \"Exterior2nd\": \"AsbShng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 50.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 430.0, \"TotalBsmtSF\": 480.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 480, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 480, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 0, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 308.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 35311}, {\"Order\": 2882, \"PID\": 911175440, \"MSSubClass\": 190, \"MSZoning\": \"C (all)\", \"LotFrontage\": 50.0, \"LotArea\": 9000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"2fmCon\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"WdShing\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Fa\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 660.0, \"TotalBsmtSF\": 660.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1060, \"2ndFlrSF\": 336, \"LowQualFinSF\": 0, \"GrLivArea\": 1396, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Min2\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 115000}, {\"Order\": 2883, \"PID\": 911225110, \"MSSubClass\": 50, \"MSZoning\": \"C (all)\", \"LotFrontage\": 60.0, \"LotArea\": 8520, \"Street\": \"Grvl\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Bnk\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"IDOTRR\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1.5Fin\", \"OverallQual\": 3, \"OverallCond\": 5, \"YearBuilt\": 1916, \"YearRemod/Add\": 1950, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Fa\", \"BsmtCond\": \"Fa\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 216.0, \"TotalBsmtSF\": 216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"N\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 576, \"2ndFlrSF\": 360, \"LowQualFinSF\": 0, \"GrLivArea\": 936, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 78000}, {\"Order\": 2884, \"PID\": 911370430, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 5748, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 473.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1573.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1573.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1778, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1778, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 495.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 123, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 153, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 2, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 375000}, {\"Order\": 2885, \"PID\": 911370530, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 44.0, \"LotArea\": 3842, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"HLS\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Crawfor\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2004, \"YearRemod/Add\": 2005, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 186.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1564.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 30.0, \"TotalBsmtSF\": 1594.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1646, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1646, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2004.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 525.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 128, \"OpenPorchSF\": 53, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 155, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 300000}, {\"Order\": 2886, \"PID\": 913350030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 69.0, \"LotArea\": 23580, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1979, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 776.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 849.0, \"TotalBsmtSF\": 1625.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1625, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1625, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Fa\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1979.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 136, \"OpenPorchSF\": 28, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 242500}, {\"Order\": 2887, \"PID\": 914452060, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 65.0, \"LotArea\": 8385, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1978, \"YearRemod/Add\": 1978, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1664.0, \"TotalBsmtSF\": 1664.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1664, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1664, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1978.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 616.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 145000}, {\"Order\": 2888, \"PID\": 914474020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 70.0, \"LotArea\": 9116, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2001, \"YearRemod/Add\": 2001, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1491.0, \"TotalBsmtSF\": 1491.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1491, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1491, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2001.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 490.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 100, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 209000}, {\"Order\": 2889, \"PID\": 914476050, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 78.0, \"LotArea\": 10530, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"ImStucc\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 90.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 975.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 975.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1004, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1004, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 4, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 504.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 135000}, {\"Order\": 2890, \"PID\": 914476130, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 140.0, \"LotArea\": 11080, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1975, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 257.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 576.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 552.0, \"TotalBsmtSF\": 1128.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1210, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1210, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 528.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 148000}, {\"Order\": 2891, \"PID\": 914476500, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 82.0, \"LotArea\": 11070, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1988, \"YearRemod/Add\": 1989, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 70.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1907.0, \"TotalBsmtSF\": 1907.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1959, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1959, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 3, \"HalfBath\": 0, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 766.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 171000}, {\"Order\": 2892, \"PID\": 916225130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 42.0, \"LotArea\": 26178, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1989, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 293.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 965.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 245.0, \"TotalBsmtSF\": 1210.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1238, \"2ndFlrSF\": 1281, \"LowQualFinSF\": 0, \"GrLivArea\": 2519, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1989.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 628.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 320, \"OpenPorchSF\": 27, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 335000}, {\"Order\": 2893, \"PID\": 916252170, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": null, \"LotArea\": 8239, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"GrnHill\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1986, \"YearRemod/Add\": 1986, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"Wd Sdng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1295, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1295, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1986.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 312.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 230000}, {\"Order\": 2894, \"PID\": 916325040, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 50102, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1958, \"YearRemod/Add\": 1958, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"Tar&Grv\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 909.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 723.0, \"TotalBsmtSF\": 1632.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1650, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1650, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1958.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 518.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 138, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Alloca\", \"SalePrice\": 250764}, {\"Order\": 2895, \"PID\": 916326010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 16669, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 6, \"YearBuilt\": 1981, \"YearRemod/Add\": 1981, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"WdShake\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 653.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1686.0, \"TotalBsmtSF\": 1686.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1707, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1707, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1981.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 511.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 574, \"OpenPorchSF\": 64, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 1, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 228000}, {\"Order\": 2896, \"PID\": 916402125, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 54.0, \"LotArea\": 13811, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1987, \"YearRemod/Add\": 1987, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 72.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 980.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 40.0, \"BsmtUnfSF\": 92.0, \"TotalBsmtSF\": 1112.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1137, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1137, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1987.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 551.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 125, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 176000}, {\"Order\": 2897, \"PID\": 916403020, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 50.0, \"LotArea\": 8049, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1990, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 54.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1053.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 256.0, \"TotalBsmtSF\": 1309.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1339, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1339, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"Gd\", \"GarageCond\": \"Gd\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 58, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 90, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 180000}, {\"Order\": 2898, \"PID\": 916403130, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11170, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR2\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1990, \"YearRemod/Add\": 1991, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 1216.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1298, \"2ndFlrSF\": 1216, \"LowQualFinSF\": 0, \"GrLivArea\": 2514, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1990.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 693.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 250000}, {\"Order\": 2899, \"PID\": 916460070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8098, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 2000, \"YearRemod/Add\": 2000, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"Wood\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1136.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 116.0, \"BsmtUnfSF\": 129.0, \"TotalBsmtSF\": 1381.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1403, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1403, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2000.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 470.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 173, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 202000}, {\"Order\": 2900, \"PID\": 916475100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 85.0, \"LotArea\": 14331, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2002, \"YearRemod/Add\": 2002, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 630.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1274.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 526.0, \"TotalBsmtSF\": 1800.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1800, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1800, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2002.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 765.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 270, \"OpenPorchSF\": 78, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 312500}, {\"Order\": 2901, \"PID\": 916477010, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 95.0, \"LotArea\": 13618, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"Stone\", \"MasVnrArea\": 198.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1350.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 378.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1960, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1960, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 714.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 172, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 320000}, {\"Order\": 2902, \"PID\": 921205030, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11443, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 8, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 208.0, \"ExterQual\": \"Gd\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1460.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 408.0, \"TotalBsmtSF\": 1868.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 2028, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 2028, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Gd\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 2, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 3.0, \"GarageArea\": 880.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 326, \"OpenPorchSF\": 66, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 369900}, {\"Order\": 2903, \"PID\": 921205050, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 88.0, \"LotArea\": 11577, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Timber\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 9, \"OverallCond\": 5, \"YearBuilt\": 2005, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 382.0, \"ExterQual\": \"Ex\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1455.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 383.0, \"TotalBsmtSF\": 1838.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1838, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1838, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 2005.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 682.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 161, \"OpenPorchSF\": 225, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"New\", \"SaleCondition\": \"Partial\", \"SalePrice\": 359900}, {\"Order\": 2904, \"PID\": 923125030, \"MSSubClass\": 20, \"MSZoning\": \"A (agr)\", \"LotFrontage\": 125.0, \"LotArea\": 31250, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Artery\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 1, \"OverallCond\": 3, \"YearBuilt\": 1951, \"YearRemod/Add\": 1951, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CBlock\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Fa\", \"Foundation\": \"CBlock\", \"BsmtQual\": null, \"BsmtCond\": null, \"BsmtExposure\": null, \"BsmtFinType1\": null, \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": null, \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 0.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"FuseA\", \"1stFlrSF\": 1600, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1600, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Mod\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1951.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 270.0, \"GarageQual\": \"Fa\", \"GarageCond\": \"TA\", \"PavedDrive\": \"N\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 135, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 81500}, {\"Order\": 2905, \"PID\": 923202025, \"MSSubClass\": 90, \"MSZoning\": \"RM\", \"LotFrontage\": 78.0, \"LotArea\": 7020, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1997, \"YearRemod/Add\": 1997, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"MetalSd\", \"Exterior2nd\": \"MetalSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 200.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1243.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 45.0, \"TotalBsmtSF\": 1288.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1368, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1368, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1997.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 4.0, \"GarageArea\": 784.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 215000}, {\"Order\": 2906, \"PID\": 923203090, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 116.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 897.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 319.0, \"TotalBsmtSF\": 1216.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1216, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1216, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 402.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 125, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 164000}, {\"Order\": 2907, \"PID\": 923203100, \"MSSubClass\": 120, \"MSZoning\": \"RM\", \"LotFrontage\": 32.0, \"LotArea\": 4500, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"FR2\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1998, \"YearRemod/Add\": 1998, \"RoofStyle\": \"Hip\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 443.0, \"ExterQual\": \"TA\", \"ExterCond\": \"Gd\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Ex\", \"BsmtCond\": \"Gd\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 1201.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 1237.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1337, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1337, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1998.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 405.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 199, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 153500}, {\"Order\": 2908, \"PID\": 923205120, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 90.0, \"LotArea\": 17217, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 2006, \"YearRemod/Add\": 2006, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1140.0, \"TotalBsmtSF\": 1140.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1140, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1140, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 36, \"OpenPorchSF\": 56, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 84500}, {\"Order\": 2909, \"PID\": 923225190, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Mn\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 264.0, \"TotalBsmtSF\": 264.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 616, \"2ndFlrSF\": 688, \"LowQualFinSF\": 0, \"GrLivArea\": 1304, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"BuiltIn\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 141, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 104500}, {\"Order\": 2910, \"PID\": 923225240, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 41.0, \"LotArea\": 2665, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 5, \"OverallCond\": 6, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 548.0, \"BsmtFinType2\": \"Rec\", \"BsmtFinSF2\": 173.0, \"BsmtUnfSF\": 36.0, \"TotalBsmtSF\": 757.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 925, \"2ndFlrSF\": 550, \"LowQualFinSF\": 0, \"GrLivArea\": 1475, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 104, \"OpenPorchSF\": 26, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 127000}, {\"Order\": 2911, \"PID\": 923225260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 42.0, \"LotArea\": 3964, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 6, \"OverallCond\": 4, \"YearBuilt\": 1973, \"YearRemod/Add\": 1973, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 837.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 105.0, \"TotalBsmtSF\": 942.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1291, \"2ndFlrSF\": 1230, \"LowQualFinSF\": 0, \"GrLivArea\": 2521, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 5, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 10, \"Functional\": \"Maj1\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1973.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 728, \"OpenPorchSF\": 20, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 151400}, {\"Order\": 2912, \"PID\": 923225510, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 58.0, \"LotArea\": 10172, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1968, \"YearRemod/Add\": 2003, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 441.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 423.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 874, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 874, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1968.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 288.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 120, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 10, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 126500}, {\"Order\": 2913, \"PID\": 923226150, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 11836, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Corner\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 149.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 1503.0, \"TotalBsmtSF\": 1652.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1652, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1652, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"2Types\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 3.0, \"GarageArea\": 928.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 146500}, {\"Order\": 2914, \"PID\": 923226180, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1470, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 4, \"OverallCond\": 6, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 522.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 108.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 73000}, {\"Order\": 2915, \"PID\": 923226290, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1484, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 4, \"YearBuilt\": 1972, \"YearRemod/Add\": 1972, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1972.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 253.0, \"GarageQual\": \"TA\", \"GarageCond\": \"Fa\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79400}, {\"Order\": 2916, \"PID\": 923227100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 13384, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1969, \"YearRemod/Add\": 1979, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 194.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 119.0, \"BsmtFinType2\": \"BLQ\", \"BsmtFinSF2\": 344.0, \"BsmtUnfSF\": 641.0, \"TotalBsmtSF\": 1104.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1360, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1360, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1969.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 1.0, \"GarageArea\": 336.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 160, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 140000}, {\"Order\": 2917, \"PID\": 923228130, \"MSSubClass\": 180, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 553.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 77.0, \"TotalBsmtSF\": 630.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 630, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 630, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 1, \"KitchenAbvGr\": 1, \"KitchenQual\": \"Ex\", \"TotRmsAbvGrd\": 3, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 8, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 92000}, {\"Order\": 2918, \"PID\": 923228180, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1533, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 408.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 138.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 12, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 87550}, {\"Order\": 2919, \"PID\": 923228210, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1526, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 34, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 79500}, {\"Order\": 2920, \"PID\": 923228260, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1936, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Twnhs\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 7, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Unf\", \"BsmtFinSF1\": 0.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 546.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 90500}, {\"Order\": 2921, \"PID\": 923228310, \"MSSubClass\": 160, \"MSZoning\": \"RM\", \"LotFrontage\": 21.0, \"LotArea\": 1894, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"MeadowV\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"TwnhsE\", \"HouseStyle\": \"2Story\", \"OverallQual\": 4, \"OverallCond\": 5, \"YearBuilt\": 1970, \"YearRemod/Add\": 1970, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"CemntBd\", \"Exterior2nd\": \"CmentBd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 252.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 294.0, \"TotalBsmtSF\": 546.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 546, \"2ndFlrSF\": 546, \"LowQualFinSF\": 0, \"GrLivArea\": 1092, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"CarPort\", \"GarageYrBlt\": 1970.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 1.0, \"GarageArea\": 286.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 24, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 71000}, {\"Order\": 2922, \"PID\": 923229110, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 55.0, \"LotArea\": 12640, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 6, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Gd\", \"BsmtFinType1\": \"Rec\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 396.0, \"BsmtUnfSF\": 396.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 574.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 40, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 150900}, {\"Order\": 2923, \"PID\": 923230040, \"MSSubClass\": 90, \"MSZoning\": \"RL\", \"LotFrontage\": 63.0, \"LotArea\": 9297, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"Duplex\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1976, \"YearRemod/Add\": 1976, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"Plywood\", \"Exterior2nd\": \"Plywood\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1606.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 122.0, \"TotalBsmtSF\": 1728.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1728, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1728, \"BsmtFullBath\": 2.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 2, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 8, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1976.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 560.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 0, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Family\", \"SalePrice\": 188000}, {\"Order\": 2924, \"PID\": 923250060, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 80.0, \"LotArea\": 17400, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1977, \"YearRemod/Add\": 1977, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"BrkFace\", \"Exterior2nd\": \"BrkFace\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 936.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 190.0, \"TotalBsmtSF\": 1126.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Fa\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1126, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1126, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"Gd\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1977.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"P\", \"WoodDeckSF\": 295, \"OpenPorchSF\": 41, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 5, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 160000}, {\"Order\": 2925, \"PID\": 923251180, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 160.0, \"LotArea\": 20000, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 7, \"YearBuilt\": 1960, \"YearRemod/Add\": 1996, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"VinylSd\", \"Exterior2nd\": \"VinylSd\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"No\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1224.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 0.0, \"TotalBsmtSF\": 1224.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1224, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1224, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 4, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 7, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1960.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 576.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 474, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 9, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Abnorml\", \"SalePrice\": 131000}, {\"Order\": 2926, \"PID\": 923275080, \"MSSubClass\": 80, \"MSZoning\": \"RL\", \"LotFrontage\": 37.0, \"LotArea\": 7937, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"CulDSac\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SLvl\", \"OverallQual\": 6, \"OverallCond\": 6, \"YearBuilt\": 1984, \"YearRemod/Add\": 1984, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"TA\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 819.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 184.0, \"TotalBsmtSF\": 1003.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1003, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1003, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Detchd\", \"GarageYrBlt\": 1984.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 588.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 120, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"GdPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 3, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 142500}, {\"Order\": 2927, \"PID\": 923276100, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": null, \"LotArea\": 8885, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"IR1\", \"LandContour\": \"Low\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1983, \"YearRemod/Add\": 1983, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"BLQ\", \"BsmtFinSF1\": 301.0, \"BsmtFinType2\": \"ALQ\", \"BsmtFinSF2\": 324.0, \"BsmtUnfSF\": 239.0, \"TotalBsmtSF\": 864.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 902, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 902, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 5, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1983.0, \"GarageFinish\": \"Unf\", \"GarageCars\": 2.0, \"GarageArea\": 484.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 164, \"OpenPorchSF\": 0, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 6, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 131000}, {\"Order\": 2928, \"PID\": 923400125, \"MSSubClass\": 85, \"MSZoning\": \"RL\", \"LotFrontage\": 62.0, \"LotArea\": 10441, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Gtl\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"SFoyer\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1992, \"YearRemod/Add\": 1992, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"Wd Shng\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"GLQ\", \"BsmtFinSF1\": 337.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 575.0, \"TotalBsmtSF\": 912.0, \"Heating\": \"GasA\", \"HeatingQC\": \"TA\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 970, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 970, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 1.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 0, \"FireplaceQu\": null, \"GarageType\": null, \"GarageYrBlt\": null, \"GarageFinish\": null, \"GarageCars\": 0.0, \"GarageArea\": 0.0, \"GarageQual\": null, \"GarageCond\": null, \"PavedDrive\": \"Y\", \"WoodDeckSF\": 80, \"OpenPorchSF\": 32, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": \"MnPrv\", \"MiscFeature\": \"Shed\", \"MiscVal\": 700, \"MoSold\": 7, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 132000}, {\"Order\": 2929, \"PID\": 924100070, \"MSSubClass\": 20, \"MSZoning\": \"RL\", \"LotFrontage\": 77.0, \"LotArea\": 10010, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"1Story\", \"OverallQual\": 5, \"OverallCond\": 5, \"YearBuilt\": 1974, \"YearRemod/Add\": 1975, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": null, \"MasVnrArea\": 0.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"CBlock\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"ALQ\", \"BsmtFinSF1\": 1071.0, \"BsmtFinType2\": \"LwQ\", \"BsmtFinSF2\": 123.0, \"BsmtUnfSF\": 195.0, \"TotalBsmtSF\": 1389.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Gd\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 1389, \"2ndFlrSF\": 0, \"LowQualFinSF\": 0, \"GrLivArea\": 1389, \"BsmtFullBath\": 1.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 1, \"HalfBath\": 0, \"BedroomAbvGr\": 2, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 6, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1975.0, \"GarageFinish\": \"RFn\", \"GarageCars\": 2.0, \"GarageArea\": 418.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 240, \"OpenPorchSF\": 38, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 4, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 170000}, {\"Order\": 2930, \"PID\": 924151050, \"MSSubClass\": 60, \"MSZoning\": \"RL\", \"LotFrontage\": 74.0, \"LotArea\": 9627, \"Street\": \"Pave\", \"Alley\": null, \"LotShape\": \"Reg\", \"LandContour\": \"Lvl\", \"Utilities\": \"AllPub\", \"LotConfig\": \"Inside\", \"LandSlope\": \"Mod\", \"Neighborhood\": \"Mitchel\", \"Condition1\": \"Norm\", \"Condition2\": \"Norm\", \"BldgType\": \"1Fam\", \"HouseStyle\": \"2Story\", \"OverallQual\": 7, \"OverallCond\": 5, \"YearBuilt\": 1993, \"YearRemod/Add\": 1994, \"RoofStyle\": \"Gable\", \"RoofMatl\": \"CompShg\", \"Exterior1st\": \"HdBoard\", \"Exterior2nd\": \"HdBoard\", \"MasVnrType\": \"BrkFace\", \"MasVnrArea\": 94.0, \"ExterQual\": \"TA\", \"ExterCond\": \"TA\", \"Foundation\": \"PConc\", \"BsmtQual\": \"Gd\", \"BsmtCond\": \"TA\", \"BsmtExposure\": \"Av\", \"BsmtFinType1\": \"LwQ\", \"BsmtFinSF1\": 758.0, \"BsmtFinType2\": \"Unf\", \"BsmtFinSF2\": 0.0, \"BsmtUnfSF\": 238.0, \"TotalBsmtSF\": 996.0, \"Heating\": \"GasA\", \"HeatingQC\": \"Ex\", \"CentralAir\": \"Y\", \"Electrical\": \"SBrkr\", \"1stFlrSF\": 996, \"2ndFlrSF\": 1004, \"LowQualFinSF\": 0, \"GrLivArea\": 2000, \"BsmtFullBath\": 0.0, \"BsmtHalfBath\": 0.0, \"FullBath\": 2, \"HalfBath\": 1, \"BedroomAbvGr\": 3, \"KitchenAbvGr\": 1, \"KitchenQual\": \"TA\", \"TotRmsAbvGrd\": 9, \"Functional\": \"Typ\", \"Fireplaces\": 1, \"FireplaceQu\": \"TA\", \"GarageType\": \"Attchd\", \"GarageYrBlt\": 1993.0, \"GarageFinish\": \"Fin\", \"GarageCars\": 3.0, \"GarageArea\": 650.0, \"GarageQual\": \"TA\", \"GarageCond\": \"TA\", \"PavedDrive\": \"Y\", \"WoodDeckSF\": 190, \"OpenPorchSF\": 48, \"EnclosedPorch\": 0, \"3SsnPorch\": 0, \"ScreenPorch\": 0, \"PoolArea\": 0, \"PoolQC\": null, \"Fence\": null, \"MiscFeature\": null, \"MiscVal\": 0, \"MoSold\": 11, \"YrSold\": 2006, \"SaleType\": \"WD \", \"SaleCondition\": \"Normal\", \"SalePrice\": 188000}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "alt.Chart(train).mark_bar(\n",
        "    opacity=0.5,\n",
        "    binSpacing=0\n",
        ").encode(\n",
        "    alt.X('SalePrice:Q', bin=alt.Bin(maxbins=50)),\n",
        "    alt.Y('count()', stack=None),\n",
        "    alt.Color('MSZoning:N')\n",
        ")"
      ],
      "id": "cell-25"
    }
  ],
  "nbformat": 4,
  "nbformat_minor": 5,
  "metadata": {
    "deepnote": {},
    "deepnote_execution_queue": [],
    "deepnote_notebook_id": "50a09f54b44643ad9c3db9911a46f413",
    "deepnote_persisted_session": {
      "createdAt": "2023-05-26T13:46:51.443Z"
    },
    "kernelspec": {
      "name": "pyenv-3.11.7",
      "display_name": "pyenv-3.11.7",
      "language": "python"
    },
    "language_info": {
      "name": "python",
      "codemirror_mode": {
        "name": "ipython",
        "version": "3"
      },
      "file_extension": ".py",
      "mimetype": "text/x-python",
      "nbconvert_exporter": "python",
      "pygments_lexer": "ipython3",
      "version": "3.11.7"
    },
    "papermill": {
      "default_parameters": {},
      "duration": "23.029284",
      "end_time": "2023-01-11T23:38:39.738482",
      "environment_variables": {},
      "exception": "",
      "input_path": "notebook.ipynb",
      "output_path": "notebook.ipynb",
      "parameters": {},
      "start_time": "2023-01-11T23:38:16.709198",
      "version": "2.3.3"
    }
  }
}